/*****************************************************************************
 *------------------------ Utility  -----------------------------------------*
 *****************************************************************************/
#include <float.h>
#include <math.h>
#include "rscmwwlm.h"

#pragma warning( disable : 4152 )

/*****************************************************************************
 * Function: rscmwwlm_InitAttributes
 * Purpose:  This function inits attributes to the desired values if needed.
 *****************************************************************************/
ViStatus rscmwwlm_InitAttributes(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    // - Driver Identification -
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION, 0, RSCMWWLM_SPECIFIC_DRIVER_DESCRIPTION));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_PREFIX, 0, RSCMWWLM_SPECIFIC_DRIVER_PREFIX));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_LOCATOR, 0, RSCMWWLM_SPECIFIC_DRIVER_LOCATOR));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_VENDOR, 0, RSCMWWLM_SPECIFIC_DRIVER_VENDOR));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION, 0, RSCMWWLM_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION, 0, RSCMWWLM_CLASS_SPEC_MINOR_VERSION));

    // - Driver Capabilities -
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SUPPORTED_INSTRUMENT_MODELS, 0, RSCMWWLM_SUPPORTED_INSTRUMENT_MODELS));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_GROUP_CAPABILITIES, 0, RSCMWWLM_GROUP_CAPABILITIES));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_FUNCTION_CAPABILITIES, 0, RSCMWWLM_FUNCTION_CAPABILITIES));

    // - Version Info -
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION, 0, RSCMWWLM_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_VERSION, 0, RSCMWWLM_MINOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_MINOR_VERSION, 0, RSCMWWLM_MINOR_MINOR_VERSION));

    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_MAJOR_VERSION, 0, RSCMWWLM_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_MINOR_VERSION, 0, RSCMWWLM_CLASS_SPEC_MINOR_VERSION));

    checkErr(RsCore_SetSpecificDriverRevision(instrSession, RS_ATTR_SPECIFIC_DRIVER_REVISION));

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_DefaultInstrSetup
 * Purpose:  This function sends a default setup to the instrument. The
 *           rscmwwlm_reset function calls this function. The
 *           rscmwwlm_RsInit function calls this function when the
 *           user passes VI_FALSE for the reset parameter. This function is
 *           useful for configuring settings that other instrument driver
 *           functions require.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rscmwwlm_DefaultInstrSetup(ViSession instrSession)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));

    // Set all the attributes to the default state. Do not update inherent attributes!
    checkErr(RsCore_ApplyAttributeDefaults(instrSession, VI_FALSE));

    // Init attributes
    checkErr(rscmwwlm_InitAttributes(instrSession));

    rsSession->fastSweepInstrument = 0;
    checkErr(RsCore_ResetRegistersEseSre(instrSession));
    checkErr(RsCore_Write(instrSession, ":FORM:BASE ASC,10"));
    checkErr(RsCore_Write(instrSession, ":SYST:DISP:UPD OFF"));
    checkErr(RsCore_QueryViInt32(instrSession, "*OPC?", NULL));

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_CheckStatus
 * Purpose:  This function checks the status of the instrument to detect
 *           whether the instrument has encountered an error. This function
 *           is called at the end of most exported driver functions. If the
 *           instrument reports an error, this function returns
 *           RS_ERROR_INSTRUMENT_SPECIFIC. The user can set the
 *           rscmwwlm_ATTR_QUERY_INSTRUMENT_STATUS attribute to VI_FALSE to disable this
 *           check and increase execution speed.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rscmwwlm_CheckStatus(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    if (RsCore_QueryInstrStatus(instrSession) && !RsCore_Simulating(instrSession))
    {
        checkErr(RsCore_CheckStatus(instrSession, VI_SUCCESS));
    }

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwlm_GetIndexOfToken
 * Purpose:  This function breaks a string into tokens, which are separated
 *           by the specified delimiter and then returns index of selected
 *           token or error code if there is no token found. If passed NUL
 *           pointer as a token or delimiter and string length of token or
 *           delimiter is zero, it returns zero as index.
 *****************************************************************************/
ViStatus rscmwwlm_GetIndexOfToken(ViConstString stringToFind,
                                  ViString table[],
                                  ViInt32* index)
{
    ViStatus error = VI_SUCCESS;

    if (strcmp(stringToFind, "NAV") == 0)
    {
        *index = RS_VAL_NAN_VI_INT32;
    }
    else
    {
        *index = RsCore_FindStringIndex(table, stringToFind);

        if (*index < 0)
            error = RS_ERROR_UNEXPECTED_RESPONSE;
    }

    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetIndexInNumArray
 * Purpose:  This function search number in array
 *****************************************************************************/
ViStatus rscmwwlm_GetIndexInNumArray(ViInt32 value,
                                     ViInt32 table[],
                                     ViUInt32 size,
                                     ViUInt32* index)
{
    ViStatus error = VI_SUCCESS;
    ViUInt32 i = 0;

    while (i < size)
    {
        if (table[i] == value)
        {
            *index = i;
            break;
        }
        i++;
    }

    if (i >= size)
        error = RS_ERROR_UNEXPECTED_RESPONSE;
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_instanceRepCap
 * Purpose:  This function checks instance repeated capability and
 *           creates proper string.
 *****************************************************************************/
ViStatus rscmwwlm_instanceRepCap(ViSession instrSession,
                                 ViInt32   instance,
                                 ViChar    repCap[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld", instance);

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_QueryMeasStatus
 * Purpose:  This function queries measurement status
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMeasStatus(ViSession instrSession,
                                           ViString  cmd,
                                           ViInt32*  mainState,
                                           ViInt32*  syncState,
                                           ViInt32*  resourcesState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   response[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViString mainStateArr[] = {"OFF", "RDY", "RUN",NULL};
    ViString syncStateArr[] = {"PEND", "ADJ", "INV",NULL};
    ViString resStateArr[] = {"QUE", "ACT", "INV",NULL};

    checkErr(RsCore_QueryViString(instrSession, cmd, response));

    p2buf = strtok(response, ",\n");
    if (p2buf == NULL)
        return RSCMWWLM_ERROR_INCORRECT_STATE;
    *mainState = RsCore_FindStringIndex(mainStateArr, p2buf);
    if (*mainState < 0)
        return RSCMWWLM_ERROR_INCORRECT_STATE;

    p2buf = strtok(NULL, ",\n");
    if (p2buf == NULL)
        return RSCMWWLM_ERROR_INCORRECT_STATE;
    *syncState = RsCore_FindStringIndex(syncStateArr, p2buf);
    if (*syncState < 0)
        return RSCMWWLM_ERROR_INCORRECT_STATE;

    p2buf = strtok(NULL, ",\n");
    if (p2buf == NULL)
        return RSCMWWLM_ERROR_INCORRECT_STATE;
    *resourcesState = RsCore_FindStringIndex(resStateArr, p2buf);
    if (*resourcesState < 0)
        return RSCMWWLM_ERROR_INCORRECT_STATE;

Error:
    return error;
}

/*****************************************************************************
 * Function: Configure Limit
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureLimit(ViSession instrSession,
                                          ViString  cmd,
                                          ViReal64  limitValue,
                                          ViInt32   limitState,
                                          ViReal64  low,
                                          ViReal64  high)
{
    ViStatus error = VI_SUCCESS;
    ViChar   fullCmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    switch (limitState)
    {
    case RSCMWWLM_VAL_LIMIT_OFF:
        snprintf(fullCmd, RS_MAX_MESSAGE_BUF_SIZE, "%s OFF", cmd);
        break;
    case RSCMWWLM_VAL_LIMIT_ON:
        snprintf(fullCmd, RS_MAX_MESSAGE_BUF_SIZE, "%s ON", cmd);
        break;
    case RSCMWWLM_VAL_LIMIT_VALUE:
        viCheckParm(RsCore_InvalidViReal64Range(instrSession, limitValue, low, high),
                3, "Limit Value");
        snprintf(fullCmd, RS_MAX_MESSAGE_BUF_SIZE, "%s %lf", cmd, limitValue);
        break;
    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, limitState), 4, "Limit Status");
    }

    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
    return error;
}

ViStatus _VI_FUNC rscmwwlm_GetOFDMResults(ViSession instrSession,
                                          ViString  cmd,
                                          ViInt32   timeout,
                                          ViInt32   arraySize,
                                          ViInt32*  reliability,
                                          ViInt32*  modulationType,
                                          ViString  modulationList[],
                                          ViReal64  result[],
                                          ViInt32*  guardInterval,
                                          ViString  guardIntervalList[],
                                          ViInt32*  returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;

    if (timeout == 0)
    {
        checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    }
    else
    {
        checkErr(RsCore_QueryViStringUnknownLengthWithOpc(instrSession, cmd, timeout, &ext_buf));
    }

    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    if (modulationType != NULL)
    {
        p2buf = strtok(NULL, ",\n");
        *modulationType = RsCore_FindStringIndex(modulationList, p2buf);
    }

    p2buf = strtok(NULL, ",\n");

    arraySize = (arraySize < 12) ? arraySize : 11;

    while (i < arraySize)
    {
        result[i++] = RsCore_Convert_String_To_ViReal64(p2buf);

        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    }

    if (arraySize >= 11)
    {
        *guardInterval = RsCore_FindStringIndex(guardIntervalList, p2buf);

        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            result[i++] = 1;
        else
            result[i++] = RsCore_Convert_String_To_ViReal64(p2buf);
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

ViStatus _VI_FUNC rscmwwlm_GetACSISOResults(ViSession instrSession,
                                            ViString  cmd,
                                            ViInt32   timeout,
                                            ViInt32   arraySize,
                                            ViInt32*  reliability,
                                            ViInt32*  modulationType,
                                            ViString  modulationList[],
                                            ViReal64  result[],
                                            ViInt32*  guardInterval,
                                            ViString  guardIntervalList[],
                                            ViInt32*  returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;

    if (timeout == 0)
    {
        checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    }
    else
    {
        checkErr(RsCore_QueryViStringUnknownLengthWithOpc(instrSession, cmd, timeout, &ext_buf));
    }

    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    if (modulationType != NULL)
    {
        p2buf = strtok(NULL, ",\n");
        *modulationType = RsCore_FindStringIndex(modulationList, p2buf);
    }

    p2buf = strtok(NULL, ",\n");

    while (i < 2)
    {
        result[i++] = RsCore_Convert_String_To_ViReal64(p2buf);

        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    }

    *guardInterval = RsCore_FindStringIndex(guardIntervalList, p2buf);

    p2buf = strtok(NULL, ",\n");

    while (i < arraySize - 2)
    {
        result[i++] = RsCore_Convert_String_To_ViReal64(p2buf);

        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

ViStatus _VI_FUNC rscmwwlm_GetDSSSResults(ViSession instrSession,
                                          ViString  cmd,
                                          ViInt32   timeout,
                                          ViInt32   arraySize,
                                          ViInt32*  reliability,
                                          ViInt32*  modulationType,
                                          ViString  modulationList[],
                                          ViInt32*  burstType,
                                          ViString  burstList[],
                                          ViReal64  result[],
                                          ViInt32*  returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;

    if (timeout == 0)
    {
        checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    }
    else
    {
        checkErr(RsCore_QueryViStringUnknownLengthWithOpc(instrSession, cmd, timeout, &ext_buf));
    }

    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");
    *modulationType = RsCore_FindStringIndex(modulationList, p2buf);

    p2buf = strtok(NULL, ",\n");
    *burstType = RsCore_FindStringIndex(burstList, p2buf);

    p2buf = strtok(NULL, ",\n");

    while (p2buf != NULL)
    {
        if (i < arraySize)
        {
            result[i++] = RsCore_Convert_String_To_ViReal64(p2buf);
        }
        p2buf = strtok(NULL, ",\n");
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetMeasResults
 * Purpose:  This function queries measurement data
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetMeasResults(ViSession instrSession,
                                          ViString  cmd,
                                          ViInt32   timeout,
                                          ViInt32   arraySize,
                                          ViInt32*  reliability,
                                          ViReal64  result[],
                                          ViInt32*  returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;

    if (timeout == 0)
    {
        checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    }
    else
    {
        checkErr(RsCore_QueryViStringUnknownLengthWithOpc(instrSession, cmd, timeout, &ext_buf));
    }

    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");

    while (p2buf != NULL)
    {
        if (i < arraySize)
        {
            result[i++] = RsCore_Convert_String_To_ViReal64(p2buf);
        }
        p2buf = strtok(NULL, ",\n");
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetDataAcquisitionResult
 * Purpose:  This function queries the data acquisition results
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetDataAcquisitionResult(ViSession instrSession,
                                                    ViString  cmd,
                                                    ViInt32   timeout,
                                                    ViInt32*  reliability,
                                                    ViInt32*  decodeStatus,
                                                    ViReal64* MCS,
                                                    ViReal64* power,
                                                    ViReal64* pilotEVM)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViString DecodeStatusArr[] = {"NAV", "INV", "OK",NULL};

    if (timeout == 0)
    {
        checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    }
    else
    {
        checkErr(RsCore_QueryViStringUnknownLengthWithOpc(instrSession, cmd, timeout, &ext_buf));
    }

    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");

    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_STATE);
    *decodeStatus = RsCore_FindStringIndex(DecodeStatusArr, p2buf);
    if (*decodeStatus < 0)
        checkErr(RSCMWWLM_ERROR_INCORRECT_STATE);

    p2buf = strtok(NULL, ",\n");

    *MCS = RsCore_Convert_String_To_ViReal64(p2buf);

    p2buf = strtok(NULL, ",\n");

    *power = RsCore_Convert_String_To_ViReal64(p2buf);

    p2buf = strtok(NULL, ",\n");

    *pilotEVM = RsCore_Convert_String_To_ViReal64(p2buf);

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetTSMOFDMMeasResults
 * Purpose:  This function queries measurement data
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetTSMOFDMMeasResults(ViSession instrSession,
                                                 ViString  cmd,
                                                 ViInt32   segmentCount,
                                                 ViInt32   arraySize,
                                                 ViInt32*  reliability,
                                                 ViInt32   segmentReliability[],
                                                 ViInt32   numberOfBursts[],
                                                 ViReal64  results[],
                                                 ViReal64  outOfTolerance[],
                                                 ViInt32*  returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0,
    x        = 0;

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");

    while (p2buf != NULL && i < segmentCount && i < arraySize)
    {
        segmentReliability[i] = RsCore_Convert_String_To_ViInt32(p2buf);

        p2buf = strtok(NULL, ",\n");

        numberOfBursts[i] = RsCore_Convert_String_To_ViInt32(p2buf);

        p2buf = strtok(NULL, ",\n");

        for (x = 0; x < 8; x++)
        {
            results[8 * i + x] = RsCore_Convert_String_To_ViReal64(p2buf);
            p2buf = strtok(NULL, ",\n");

            if (p2buf == NULL)
                checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
        }

        outOfTolerance[i++] = RsCore_Convert_String_To_ViReal64(p2buf);

        p2buf = strtok(NULL, ",\n");
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetTSMDSSSMeasResults
 * Purpose:  This function queries measurement data
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetTSMDSSSMeasResults(ViSession instrSession,
                                                 ViString  cmd,
                                                 ViInt32   segmentCount,
                                                 ViInt32   arraySize,
                                                 ViInt32*  reliability,
                                                 ViInt32   segmentReliability[],
                                                 ViInt32   numberOfBursts[],
                                                 ViReal64  results[],
                                                 ViReal64  outOfTolerance[],
                                                 ViInt32*  returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;
    ViInt32  x = 0;

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");

    while (p2buf != NULL && i < segmentCount && i < arraySize)
    {
        segmentReliability[i] = RsCore_Convert_String_To_ViInt32(p2buf);

        p2buf = strtok(NULL, ",\n");

        numberOfBursts[i] = RsCore_Convert_String_To_ViInt32(p2buf);

        p2buf = strtok(NULL, ",\n");

        for (x = 0; x < 4; x++)
        {
            results[4 * i + x] = RsCore_Convert_String_To_ViReal64(p2buf);
            p2buf = strtok(NULL, ",\n");

            if (p2buf == NULL)
                checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
        }

        outOfTolerance[i++] = RsCore_Convert_String_To_ViReal64(p2buf);

        p2buf = strtok(NULL, ",\n");
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetOFDMSegmentResults
 * Purpose:  This function queries measurement data of the OFDM segment.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetOFDMSegmentResults(ViSession instrSession,
                                                 ViString  cmd,
                                                 ViInt32   segmentCount,
                                                 ViInt32   arraySize,
                                                 ViInt32*  reliability,
                                                 ViInt32   segmentReliability[],
                                                 ViInt32   numberOfBursts[],
                                                 ViInt32   modulationType[],
                                                 ViString  modulationList[],
                                                 ViReal64  results[],
                                                 ViInt32   guardInterval[],
                                                 ViString  guardIntervalList[],
                                                 ViInt32*  returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;
    ViInt32  x = 0;

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");

    while (p2buf != NULL && i < segmentCount && i < arraySize)
    {
        segmentReliability[i] = RsCore_Convert_String_To_ViInt32(p2buf);

        p2buf = strtok(NULL, ",\n");

        numberOfBursts[i] = RsCore_Convert_String_To_ViInt32(p2buf);

        p2buf = strtok(NULL, ",\n");

        modulationType[i] = RsCore_FindStringIndex(modulationList, p2buf);

        p2buf = strtok(NULL, ",\n");

        for (x = 0; x < 11; x++)
        {
            results[11 * i + x] = RsCore_Convert_String_To_ViReal64(p2buf);
            p2buf = strtok(NULL, ",\n");

            if (p2buf == NULL)
                checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
        }

        guardInterval[i++] = RsCore_FindStringIndex(guardIntervalList, p2buf);

        p2buf = strtok(NULL, ",\n");
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetOFDMSISOResults
 * Purpose:  This function queries measurement data of the OFDM segment.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetOFDMSISOResults(ViSession instrSession,
                                              ViString  cmd,
                                              ViInt32   timeout,
                                              ViInt32   arraySize,
                                              ViInt32*  reliability,
                                              ViInt32*  modulationType,
                                              ViString  modulationList[],
                                              ViReal64  results[],
                                              ViInt32*  guardInterval,
                                              ViString  guardIntervalList[],
                                              ViInt32*  returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;

    if (timeout == 0)
    {
        checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    }
    else
    {
        checkErr(RsCore_QueryViStringUnknownLengthWithOpc(instrSession, cmd, timeout, &ext_buf));
    }

    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);

    while (p2buf != NULL && i < arraySize)
    {
        if (i == 2)
        {
            *modulationType = RsCore_FindStringIndex(modulationList, p2buf);
        }
        else if (i == 6)
        {
            *guardInterval = RsCore_FindStringIndex(guardIntervalList, p2buf);
        }
        else
        {
            results[i++] = RsCore_Convert_String_To_ViReal64(p2buf);
        }
        p2buf = strtok(NULL, ",\n");
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetOFDMMIMOResults
 * Purpose:  This function queries measurement data of the OFDM segment.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetOFDMMIMOResults(ViSession instrSession,
                                              ViString  cmd,
                                              ViInt32   timeout,
                                              ViInt32   arraySize,
                                              ViInt32*  reliability,
                                              ViInt32   modulationType[],
                                              ViString  modulationList[],
                                              ViReal64  results[],
                                              ViInt32   guardInterval[],
                                              ViString  guardIntervalList[],
                                              ViInt32*  returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;
    ViInt32  x = 0;

    if (timeout == 0)
    {
        checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    }
    else
    {
        checkErr(RsCore_QueryViStringUnknownLengthWithOpc(instrSession, cmd, timeout, &ext_buf));
    }

    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");

    while (p2buf != NULL && i < arraySize)
    {
        results[23 * i] = RsCore_Convert_String_To_ViReal64(p2buf);
        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);

        results[23 * i + 1] = RsCore_Convert_String_To_ViReal64(p2buf);
        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);

        modulationType[i] = RsCore_FindStringIndex(modulationList, p2buf);

        p2buf = strtok(NULL, ",\n");

        results[23 * i + 2] = RsCore_Convert_String_To_ViReal64(p2buf);
        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);

        results[23 * i + 3] = RsCore_Convert_String_To_ViReal64(p2buf);
        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);

        results[23 * i + 4] = RsCore_Convert_String_To_ViReal64(p2buf);
        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);

        guardInterval[i] = RsCore_FindStringIndex(guardIntervalList, p2buf);

        p2buf = strtok(NULL, ",\n");

        for (x = 0; x < 16; x++)
        {
            results[23 * i + 5 + x] = RsCore_Convert_String_To_ViReal64(p2buf);
            p2buf = strtok(NULL, ",\n");

            if (p2buf == NULL && x < 15)
                checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
        }

        i++;
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetOFDMMIMOResults
 * Purpose:  This function queries measurement data of the OFDM segment.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetMeasResultsMIMO(ViSession instrSession,
                                              ViString  cmd,
                                              ViInt32   timeout,
                                              ViInt32   arraySize,
                                              ViInt32*  reliability,
                                              ViInt32   modulationType[],
                                              ViString  modulationList[],
                                              ViReal64  results[],
                                              ViInt32*  returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;
    ViInt32  x = 0;

    if (timeout == 0)
    {
        checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    }
    else
    {
        checkErr(RsCore_QueryViStringUnknownLengthWithOpc(instrSession, cmd, timeout, &ext_buf));
    }

    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");

    while (p2buf != NULL && i < arraySize)
    {
        results[13 * i] = RsCore_Convert_String_To_ViReal64(p2buf);
        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);

        results[13 * i + 1] = RsCore_Convert_String_To_ViReal64(p2buf);
        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);

        modulationType[i] = RsCore_FindStringIndex(modulationList, p2buf);

        p2buf = strtok(NULL, ",\n");

        results[13 * i + 2] = RsCore_Convert_String_To_ViReal64(p2buf);
        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);

        results[13 * i + 3] = RsCore_Convert_String_To_ViReal64(p2buf);
        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);

        p2buf = strtok(NULL, ",\n");

        for (x = 0; x < 16; x++)
        {
            results[13 * i + 3 + x] = RsCore_Convert_String_To_ViReal64(p2buf);
            p2buf = strtok(NULL, ",\n");

            if (p2buf == NULL)
                checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
        }

        i++;
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetDSSSSegmentResults
 * Purpose:  This function queries measurement data of the DSSS segment.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetDSSSSegmentResults(ViSession instrSession,
                                                 ViString  cmd,
                                                 ViInt32   segmentCount,
                                                 ViInt32   arraySize,
                                                 ViInt32*  reliability,
                                                 ViInt32   segmentReliability[],
                                                 ViInt32   numberOfBursts[],
                                                 ViInt32   modulationType[],
                                                 ViString  modulationList[],
                                                 ViInt32   burstType[],
                                                 ViString  burstList[],
                                                 ViReal64  results[],
                                                 ViInt32*  returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;
    ViInt32  x = 0;

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");

    while (p2buf != NULL && i < segmentCount && i < arraySize)
    {
        segmentReliability[i] = RsCore_Convert_String_To_ViInt32(p2buf);

        p2buf = strtok(NULL, ",\n");

        numberOfBursts[i] = RsCore_Convert_String_To_ViInt32(p2buf);

        p2buf = strtok(NULL, ",\n");

        modulationType[i] = RsCore_FindStringIndex(modulationList, p2buf);

        p2buf = strtok(NULL, ",\n");

        burstType[i] = RsCore_FindStringIndex(burstList, p2buf);

        p2buf = strtok(NULL, ",\n");

        for (x = 0; x < 10; x++)
        {
            results[10 * i + x] = RsCore_Convert_String_To_ViReal64(p2buf);
            p2buf = strtok(NULL, ",\n");
        }
        i++;
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwm_GetLimitCheck
 * Purpose:  This function queries measurement data, only ViReal64 values!
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetLimitCheck(ViSession instrSession,
                                         ViString  cmd,
                                         ViInt32   arraySize,
                                         ViInt32*  reliability,
                                         ViInt32   result[],
                                         ViInt32*  returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;
    static   ViString check_limit_arr[] = {"OK", "ULEU", "ULEL",NULL};

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");

    while (p2buf != NULL)
    {
        if (i < arraySize)
        {
            result[i++] = RsCore_FindStringIndex(check_limit_arr, p2buf);
        }
        p2buf = strtok(NULL, ",\n");
    }
    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetOFDMMeasLimitCheck
 * Purpose:  This function queries measurement data, only ViReal64 values!
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetOFDMMeasLimitCheck(ViSession instrSession,
                                                 ViString  cmd,
                                                 ViInt32   arraySize,
                                                 ViInt32*  reliability,
                                                 ViInt32*  modulationType,
                                                 ViInt32   result[],
                                                 ViInt32*  guardInterval,
                                                 ViInt32*  returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;
    static   ViString check_limit_arr[] = {"OK", "ULEU", "ULEL",NULL};

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    if (modulationType != NULL)
    {
        p2buf = strtok(NULL, ",\n");
        *modulationType = RsCore_FindStringIndex(check_limit_arr, p2buf);
    }

    p2buf = strtok(NULL, ",\n");

    arraySize = (arraySize < 12) ? arraySize : 11;

    while (i < arraySize)
    {
        result[i++] = RsCore_FindStringIndex(check_limit_arr, p2buf);

        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    }

    if (arraySize >= 11)
    {
        *guardInterval = RsCore_FindStringIndex(check_limit_arr, p2buf);

        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            result[i++] = 0;
        else
            result[i++] = RsCore_FindStringIndex(check_limit_arr, p2buf);
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetOFDMMeasLimitCheck
 * Purpose:  This function queries measurement data, only ViReal64 values!
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetOFDMMIMOMeasLimitCheck(ViSession instrSession,
                                                     ViString  cmd,
                                                     ViInt32   arraySize,
                                                     ViInt32*  reliability,
                                                     ViInt32*  modulationType,
                                                     ViInt32   result[],
                                                     ViInt32*  returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;
    static   ViString check_limit_arr[] = {"OK", "ULEU", "ULEL",NULL};

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    if (modulationType != NULL)
    {
        p2buf = strtok(NULL, ",\n");
        *modulationType = RsCore_FindStringIndex(check_limit_arr, p2buf);
    }

    p2buf = strtok(NULL, ",\n");

    arraySize = (arraySize < 12) ? arraySize : 11;

    while (i < arraySize)
    {
        result[i++] = RsCore_FindStringIndex(check_limit_arr, p2buf);

        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetOFDMMeasResultsMIMO
 * Purpose:  This function queries measurement data of the OFDM segment.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetOFDMMeasResultsMIMO(ViSession instrSession,
                                                  ViString  cmd,
                                                  ViInt32   timeout,
                                                  ViInt32   arraySize,
                                                  ViInt32*  reliability,
                                                  ViInt32*  modulationType,
                                                  ViString  modulationList[],
                                                  ViReal64  results[],
                                                  ViInt32*  returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;

    if (timeout == 0)
    {
        checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    }
    else
    {
        checkErr(RsCore_QueryViStringUnknownLengthWithOpc(instrSession, cmd, timeout, &ext_buf));
    }

    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    //Get modulation
    p2buf = strtok(NULL, ",\n");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    modulationType[i] = RsCore_FindStringIndex(modulationList, p2buf);

    p2buf = strtok(NULL, ",\n");

    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);

    while (p2buf != NULL && i < arraySize)
    {
        results[i++] = RsCore_Convert_String_To_ViReal64(p2buf);
        p2buf = strtok(NULL, ",\n");
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetACSISOMeasLimitCheck
 * Purpose:  This function queries measurement data, only ViReal64 values!
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetACSISOMeasLimitCheck(ViSession instrSession,
                                                   ViString  cmd,
                                                   ViInt32   arraySize,
                                                   ViInt32*  reliability,
                                                   ViInt32*  modulationType,
                                                   ViInt32   result[],
                                                   ViInt32*  guardInterval,
                                                   ViInt32*  returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;
    static   ViString check_limit_arr[] = {"OK", "ULEU", "ULEL",NULL};

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    if (modulationType != NULL)
    {
        p2buf = strtok(NULL, ",\n");
        *modulationType = RsCore_FindStringIndex(check_limit_arr, p2buf);
    }

    p2buf = strtok(NULL, ",\n");

    while (i < 2)
    {
        result[i++] = RsCore_FindStringIndex(check_limit_arr, p2buf);

        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    }

    *guardInterval = RsCore_FindStringIndex(check_limit_arr, p2buf);

    p2buf = strtok(NULL, ",\n");

    while (i < arraySize - 2)
    {
        result[i++] = RsCore_FindStringIndex(check_limit_arr, p2buf);

        p2buf = strtok(NULL, ",\n");

        if (p2buf == NULL)
            checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetDSSSMeasLimitCheck
 * Purpose:  This function queries measurement data, only ViReal64 values!
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetDSSSMeasLimitCheck(ViSession instrSession,
                                                 ViString  cmd,
                                                 ViInt32   arraySize,
                                                 ViInt32*  reliability,
                                                 ViInt32*  modulationType,
                                                 ViInt32*  burstType,
                                                 ViInt32   result[],
                                                 ViInt32*  returnedValues)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;
    static   ViString check_limit_arr[] = {"OK", "ULEU", "ULEL",NULL};

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");

    *modulationType = RsCore_FindStringIndex(check_limit_arr, p2buf);

    p2buf = strtok(NULL, ",\n");

    *burstType = RsCore_FindStringIndex(check_limit_arr, p2buf);

    p2buf = strtok(NULL, ",\n");

    while (p2buf != NULL)
    {
        if (i < arraySize)
        {
            result[i++] = RsCore_FindStringIndex(check_limit_arr, p2buf);
        }
        p2buf = strtok(NULL, ",\n");
    }

    if (returnedValues) *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetBinaryAndDecimalValue
 * Purpose:  This function queries binary and decimal value.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetBinaryAndDecimalValue(ViSession instrSession,
                                                    ViString  cmd,
                                                    ViInt32   arraySize,
                                                    ViInt32*  reliability,
                                                    ViChar    binaryVal[],
                                                    ViInt32*  decimalVal)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok(NULL, ",\n");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    snprintf(binaryVal, arraySize, "%s", p2buf);

    p2buf = strtok(NULL, ",\n");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (decimalVal != NULL)
        *decimalVal = RsCore_Convert_String_To_ViInt32(p2buf);

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetBinaryAndDecimalValue
 * Purpose:  This function queries binary and decimal value.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetBinaryAndDoubleValue(ViSession instrSession,
                                                   ViString  cmd,
                                                   ViInt32   arraySize,
                                                   ViInt32*  reliability,
                                                   ViChar    binaryVal[],
                                                   ViReal64* decimalVal)
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwlm_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok(NULL, ",\n");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    snprintf(binaryVal, arraySize, "%s", p2buf);

    p2buf = strtok(NULL, ",\n");
    if (p2buf == NULL)
        checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
    if (decimalVal != NULL)
        *decimalVal = RsCore_Convert_String_To_ViReal64(p2buf);

Error:
    if (ext_buf) free(ext_buf);
    return error;
}

ViStatus rscmwwlm_utility_error_message(ViSession instrSession,
                                        ViStatus  errorCode,
                                        ViChar    errorMessage[])
{  
// TODO: ERROR!!! Missing Lock / Unlock
    ViStatus error = VI_SUCCESS;

    static RsCoreStringValueTable errorTable =
    {
         RSCMWWLM_ERROR_CODES_AND_MSGS,
         {0, NULL}
    };

    // all VISA and RS error codes are handled as well as codes in the table
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorMessage), 3, "Null address for Error Message");

    checkErr(RsCore_GetSpecificDriverStatusDesc(instrSession, errorCode, errorMessage, 256, errorTable));

Error:
    return error;
}

