/*****************************************************************************
 *  Rohde&Schwarz CMW500 Wideband Radio Communication Tester instrument driver
 *  WLAN Signaling
 *  VXIpnp Instrument Driver
 *****************************************************************************/

#ifndef __RSCMWWLS_HEADER
#define __RSCMWWLS_HEADER

#include "rscore.h"
#include "rscmwwls_attributes.h"
#include "rscmwwls_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSCMWWLS_CLASS_DRIVER_DESCRIPTION           ""
#define RSCMWWLS_CLASS_DRIVER_PREFIX                ""
#define RSCMWWLS_CLASS_DRIVER_VENDOR                ""
#define RSCMWWLS_CLASS_DRIVER_REVISION              ""
#define RSCMWWLS_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSCMWWLS_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSCMWWLS_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSCMWWLS_SPECIFIC_DRIVER_PREFIX             "RSCMWWLS"
#define RSCMWWLS_SPECIFIC_DRIVER_LOCATOR            ""
#define RSCMWWLS_SPECIFIC_DRIVER_VENDOR             ""
#define RSCMWWLS_MAJOR_VERSION                      4L    /* Instrument driver major version          */
#define RSCMWWLS_MINOR_VERSION                      0L    /* Instrument driver minor version          */
#define RSCMWWLS_MINOR_MINOR_VERSION                200L   /* Instrument driver minor minor version    */

/* Driver Capabilities */

#define RSCMWWLS_SUPPORTED_INSTRUMENT_MODELS        "CMW"    /* Instrument driver supported model(s)     */
#define RSCMWWLS_GROUP_CAPABILITIES                 ""
#define RSCMWWLS_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *------------------------------ Useful Macros -----------------------------*
 ****************************************************************************/

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define RSCMWWLS_SIMULATION_ID_QUERY      "Rohde&Schwarz,CMW,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSCMWWLS_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSCMWWLS_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSCMWWLS_OPC_TIMEOUT              5000L   /* Maximum time to wait for OPC in milliseconds */

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSCMWWLS_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSCMWWLS_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSCMWWLS_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSCMWWLS_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSCMWWLS_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSCMWWLS_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSCMWWLS_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSCMWWLS_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSCMWWLS_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSCMWWLS_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSCMWWLS_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSCMWWLS_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSCMWWLS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSCMWWLS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSCMWWLS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSCMWWLS_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSCMWWLS_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSCMWWLS_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSCMWWLS_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSCMWWLS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSCMWWLS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSCMWWLS_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSCMWWLS_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSCMWWLS_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSCMWWLS_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSCMWWLS_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSCMWWLS_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSCMWWLS_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSCMWWLS_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSCMWWLS_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSCMWWLS_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

//#define RSCMWWLS_ATTR_ID_QUERY_RESPONSE                                     (RS_SPECIFIC_PUBLIC_ATTR_BASE + 1L)                     /* ViString (Read Only)              */

/* BEGIN GENERATE */
#define RSCMWWLS_ATTR_SIGNALING_END_TO_END                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define RSCMWWLS_ATTR_RF_SIGNAL_FREQUENCY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 3
#define RSCMWWLS_ATTR_RF_FREQUENCY_OFFSET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 79
#define RSCMWWLS_ATTR_QUERY_RF_SIGNAL_BANDWIDTH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSCMWWLS_ATTR_RF_OPERATING_CHANNEL_WIDTH                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 80
#define RSCMWWLS_ATTR_RF_BAND                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 129
#define RSCMWWLS_ATTR_RF_SIGNAL_BURST_POWER_DOWNLINK                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define RSCMWWLS_ATTR_RF_SIGNAL_CHANNEL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define RSCMWWLS_ATTR_RF_NP20_INDEX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 82
#define RSCMWWLS_ATTR_RF_NP20_FREQUENCY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 83
#define RSCMWWLS_ATTR_RF_NP20_CHANNEL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 84
#define RSCMWWLS_ATTR_RF_TX_MIMO_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 55
#define RSCMWWLS_ATTR_RF_TX2_TX1_POWER_RATIO                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 56
#define RSCMWWLS_ATTR_QUERY_ACTIVE_SCENARIO                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 130
#define RSCMWWLS_ATTR_RF_SIGNAL_ROUTING_STANDARD_CELL_FADING                RS_SPECIFIC_PUBLIC_ATTR_BASE + 131
#define RSCMWWLS_ATTR_RF_SIGNAL_ROUTING_MIMO_2X2_FADING                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 132
#define RSCMWWLS_ATTR_INPUT_ANTENNA_EXTERNAL_ATTENUATION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 133
#define RSCMWWLS_ATTR_OUTPUT_ANTENNA_EXTERNAL_ATTENUATION                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 134
#define RSCMWWLS_ATTR_ANTENNA_EXPECTED_NOMINAL_POWER                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 135
#define RSCMWWLS_ATTR_ANTENNA_APPROXIMATE_BURST_POWER                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 136
#define RSCMWWLS_ATTR_ANTENNA_MIXER_LEVEL_OFFSET                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 137
#define RSCMWWLS_ATTR_EXTERNAL_DAU_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 75
#define RSCMWWLS_ATTR_EXTERNAL_DAU_SEGMENT_NUMBER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 76
#define RSCMWWLS_ATTR_EXTERNAL_DAU_NODE_ID                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 77
#define RSCMWWLS_ATTR_SIGNALING_MAIN_STATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define RSCMWWLS_ATTR_SIGNALING_SELECTED_STATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 138
#define RSCMWWLS_ATTR_CONNECT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 44
#define RSCMWWLS_ATTR_DUT_DISCONNECTION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 8
#define RSCMWWLS_ATTR_RECONNECT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define RSCMWWLS_ATTR_CONNECTION_OPERATION_MODE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 46
#define RSCMWWLS_ATTR_CONNECTION_MULTI_STATION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 139
#define RSCMWWLS_ATTR_CONNECTION_STANDARD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSCMWWLS_ATTR_BEACON_INTERVAL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define RSCMWWLS_ATTR_BASIC_SERVICE_SET_IDENTIFIER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 35
#define RSCMWWLS_ATTR_SERVICE_SET_IDENTIFIER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 36
#define RSCMWWLS_ATTR_BSS_COLOR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 93
#define RSCMWWLS_ATTR_COUNTRY_CODE_STATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define RSCMWWLS_ATTR_CONNECTION_DTIM_PERIOD                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 74
#define RSCMWWLS_ATTR_HT_SMOOTHING                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 94
#define RSCMWWLS_ATTR_CONNECTION_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 48
#define RSCMWWLS_ATTR_SSID_CONNECTION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 49
#define RSCMWWLS_ATTR_CONNECTION_HOTSPOT_NUMBER_OF_DIGITS                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 61
#define RSCMWWLS_ATTR_USER_DEFINED_SUPPORTED_RATES                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define RSCMWWLS_ATTR_USED_DEFINED_VHT_SUPPORTED_RATES                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 92
#define RSCMWWLS_ATTR_TWT_BROADCAST_ENABLE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 95
#define RSCMWWLS_ATTR_SUPPORT_DSSS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 140
#define RSCMWWLS_ATTR_ASSOCIATION_RESERVE_MAC_ADDRESS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 141
#define RSCMWWLS_ATTR_ASSOCIATION_AUTOMATIC_DISASSOCIATION                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 142
#define RSCMWWLS_ATTR_ASSOCIATION_ALLOW_PREEMPTION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 143
#define RSCMWWLS_ATTR_ASSOCIATION_STATION_PRIORITY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 144
#define RSCMWWLS_ATTR_TWT_MINIMUM_WAKE_DURATION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 145
#define RSCMWWLS_ATTR_SECURITY_ENCRYPTION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 51
#define RSCMWWLS_ATTR_PROTECTION_MANAGMENT_FRAMES                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 215
#define RSCMWWLS_ATTR_SAE_AUTHENTICATION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 216
#define RSCMWWLS_ATTR_GROUP_TRANSFORM                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 217
#define RSCMWWLS_ATTR_SECURITY_RSERVER_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define RSCMWWLS_ATTR_IP_VERSION_SUPPORT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 78
#define RSCMWWLS_ATTR_SECURITY_RSERVER_PORT_NUMBER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 60
#define RSCMWWLS_ATTR_SECURITY_RSERVER_SKEY                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 54
#define RSCMWWLS_ATTR_DATA_FRAME_SELECTED_STATION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 146
#define RSCMWWLS_ATTR_DATA_HEMU_FRAME_USER_MCS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 96
#define RSCMWWLS_ATTR_DATA_HEMU_FRAME_USER_CODING_TYPE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 97
#define RSCMWWLS_ATTR_DATA_HEMU_FRAME_USER_STREAMS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 98
#define RSCMWWLS_ATTR_DATA_HEMU_FRAME_DUMMY_USER_MCS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 99
#define RSCMWWLS_ATTR_DATA_HEMU_FRAME_RU_ALLOCATION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 148
#define RSCMWWLS_ATTR_DATA_HEMU_FRAME_USER_ALLOCATION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 149
#define RSCMWWLS_ATTR_TRIGGER_FRAME_SELECTED_STATION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 151
#define RSCMWWLS_ATTR_TRIGGER_FRAME_TRIGGER_TYPE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 100
#define RSCMWWLS_ATTR_TRIGGER_FRAME_NUMBER_OF_SYMBOLS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 101
#define RSCMWWLS_ATTR_TRIGGER_FRAME_CS_REQUIRED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 102
#define RSCMWWLS_ATTR_TRIGGER_FRAME_BANDWIDTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 103
#define RSCMWWLS_ATTR_TRIGGER_FRAME_GI_LTF                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 104
#define RSCMWWLS_ATTR_TRIGGER_FRAME_MU_MIMO_LTF                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 105
#define RSCMWWLS_ATTR_TRIGGER_FRAME_LDCP_EXTRA_SYMBOL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 106
#define RSCMWWLS_ATTR_TRIGGER_FRAME_RU_ALLOCATION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 107
#define RSCMWWLS_ATTR_TRIGGER_FRAME_CODING_TYPE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 108
#define RSCMWWLS_ATTR_TRIGGER_FRAME_MCS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 109
#define RSCMWWLS_ATTR_TRIGGER_FRAME_DCM                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 110
#define RSCMWWLS_ATTR_TRIGGER_FRAME_STARTING_SPATIAL_STREAM                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 111
#define RSCMWWLS_ATTR_TRIGGER_FRAME_NUMBER_OF_SPATIAL_STREAMS               RS_SPECIFIC_PUBLIC_ATTR_BASE + 112
#define RSCMWWLS_ATTR_TRIGGER_FRAME_TARGET_RSSI_MODE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 113
#define RSCMWWLS_ATTR_TRIGGER_FRAME_TARGET_RSSI_CONTROL                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 114
#define RSCMWWLS_ATTR_TRIGGER_FRAME_TRANSMISSION_SINGLE_SHOT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 115
#define RSCMWWLS_ATTR_TRIGGER_FRAME_TRANSMISSION_PERIODICAL_ENABLED         RS_SPECIFIC_PUBLIC_ATTR_BASE + 116
#define RSCMWWLS_ATTR_TRIGGER_FRAME_TRANSMISSION_PERIODICAL_INTERVAL        RS_SPECIFIC_PUBLIC_ATTR_BASE + 117
#define RSCMWWLS_ATTR_QOS_TID_SELECTED_STATION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 152
#define RSCMWWLS_ATTR_QOS_TID_E2E_DATA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 118
#define RSCMWWLS_ATTR_QOS_TID_PER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 119
#define RSCMWWLS_ATTR_QOS_TID_PRIORITIZATION_MODE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 120
#define RSCMWWLS_ATTR_QOS_TID_BAR_METHOD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 121
#define RSCMWWLS_ATTR_A_MPDU_SELECTED_STATION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 153
#define RSCMWWLS_ATTR_AMPDU_TX_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 154
#define RSCMWWLS_ATTR_HEMAC_BSR_SUPPORT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 155
#define RSCMWWLS_ATTR_NDP_SOUNDING_STATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 156
#define RSCMWWLS_ATTR_NDP_SOUNDING_FEEDBACK_METHOD                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 157
#define RSCMWWLS_ATTR_NDP_SOUNDING_BANDWIDTH                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 158
#define RSCMWWLS_ATTR_NDP_SOUNDING_SPATIAL_STREAMS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 159
#define RSCMWWLS_ATTR_NDP_SOUNDING_GI_LTF                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 160
#define RSCMWWLS_ATTR_NDP_SOUNDING_REPORT_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 161
#define RSCMWWLS_ATTR_NDP_SOUNDING_RU_START_INDEX                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 162
#define RSCMWWLS_ATTR_NDP_SOUNDING_RU_END_INDEX                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 163
#define RSCMWWLS_ATTR_NDP_SOUNDING_CODEBOOK_SIZE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 164
#define RSCMWWLS_ATTR_NDP_SOUNDING_NUMBER_OF_COLUMNS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 165
#define RSCMWWLS_ATTR_NDP_SOUNDING_SUBCARRIER_GROUPING                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 166
#define RSCMWWLS_ATTR_NDP_SOUNDING_TRANSMISSION_STATE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 167
#define RSCMWWLS_ATTR_NDP_SOUNDING_TRANSMISSION_INTERVAL                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 168
#define RSCMWWLS_ATTR_NDP_SOUNDING_TRANSMISSION_SINGLE_SHOT                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 169
#define RSCMWWLS_ATTR_CLEAN_EVENT_LOG                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 170
#define RSCMWWLS_ATTR_FADING_AWGN_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 171
#define RSCMWWLS_ATTR_FADING_AWGN_BANDWIDTH_RATIO                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 172
#define RSCMWWLS_ATTR_FADING_AWGN_SIGNAL_NOISE_RATIO                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 173
#define RSCMWWLS_ATTR_FADING_SIMULATOR_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 174
#define RSCMWWLS_ATTR_FADING_SIMULATOR_INSERTION_LOSS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 175
#define RSCMWWLS_ATTR_FADING_SIMULATOR_PROFILE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 176
#define RSCMWWLS_ATTR_TRIGGER_SLOPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 21
#define RSCMWWLS_ATTR_TX_TRIGGER_SLOPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 62
#define RSCMWWLS_ATTR_RX_TRIGGER_SLOPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 63
#define RSCMWWLS_ATTR_TRIGGER_PULSE_LENGTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 22
#define RSCMWWLS_ATTR_TX_TRIGGER_PULSE_LENGTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 64
#define RSCMWWLS_ATTR_RX_TRIGGER_PULSE_LENGTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 65
#define RSCMWWLS_ATTR_TRIGGER_PULSE_LENGTH_VALUE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 23
#define RSCMWWLS_ATTR_TX_TRIGGER_PULSE_LENGTH_VALUE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 66
#define RSCMWWLS_ATTR_RX_TRIGGER_PULSE_LENGTH_VALUE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 67
#define RSCMWWLS_ATTR_TRIGGER_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 57
#define RSCMWWLS_ATTR_RX_TRIGGER_BANDWIDTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 122
#define RSCMWWLS_ATTR_RX_TRIGGER_RATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 123
#define RSCMWWLS_ATTR_RX_TRIGGER_DELAY_TYPE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 177
#define RSCMWWLS_ATTR_RX_TRIGGER_RATE_RESTRICTION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 178
#define RSCMWWLS_ATTR_RX_TRIGGER_SPATIAL_STREAMS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 179
#define RSCMWWLS_ATTR_IPV4_CMW                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 180
#define RSCMWWLS_ATTR_IPV4_SELECTED_STATION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 181
#define RSCMWWLS_ATTR_IPV4_IP_ADDRESS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 182
#define RSCMWWLS_ATTR_PACKET_GENERATOR_PROTOCOL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 41
#define RSCMWWLS_ATTR_PACKET_GENERATOR_IP_VERSION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 69
#define RSCMWWLS_ATTR_PACKET_GENERATOR_DESTINATION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 183
#define RSCMWWLS_ATTR_QUERY_SECOND_STATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 184
#define RSCMWWLS_ATTR_QUERY_THIRD_STATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 185
#define RSCMWWLS_ATTR_QUERY_PACKET_SWITCHED_STATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 24
#define RSCMWWLS_ATTR_QUERY_STATION_SSID                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 186
#define RSCMWWLS_ATTR_QUERY_RX_POWER_INDICATOR                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 187
#define RSCMWWLS_ATTR_UE_CAPABILITY_SELECTED_STATION                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 188
#define RSCMWWLS_ATTR_QUERY_UE_CAPABILITY_MAC_ADDRESS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define RSCMWWLS_ATTR_QUERY_UE_CAPABILITY_MAC_VERSION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define RSCMWWLS_ATTR_QUERY_UE_ASSIGNED_IP_ADDRESS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 42
#define RSCMWWLS_ATTR_QUERY_UE_RX_BURST_POWER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 89
#define RSCMWWLS_ATTR_IP_VERSION_4_DHCP                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 71
#define RSCMWWLS_ATTR_IP_VERSION_6_PREFIX                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 72
#define RSCMWWLS_ATTR_MESSAGE_MONITORING_ADD_WLAN_SIGNALING_TO_LOGGING      RS_SPECIFIC_PUBLIC_ATTR_BASE + 90
#define RSCMWWLS_ATTR_MESSAGE_MONITORING_LOGGING_PC_IPV4_ADDRESS            RS_SPECIFIC_PUBLIC_ATTR_BASE + 91
#define RSCMWWLS_ATTR_DUT_SELECTED_STATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 189
#define RSCMWWLS_ATTR_DUT_UE_MAC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 190
#define RSCMWWLS_ATTR_DUT_UE_IP4_ADDRESS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 191
#define RSCMWWLS_ATTR_DUT_UE_IP6_ADDRESS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 192
#define RSCMWWLS_ATTR_DUT_CMW_IP4_ADDRESS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 193
#define RSCMWWLS_ATTR_DUT_CMW_IP6_ADDRESS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 194
#define RSCMWWLS_ATTR_HE_TB_SELECTED_STATION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 195
#define RSCMWWLS_ATTR_HE_TB_UPH_INFO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 196
#define RSCMWWLS_ATTR_HE_TB_UE_CAPABILITY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 197
#define RSCMWWLS_ATTR_QUERY_RX_TRIGGER_FRAMES                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 198
#define RSCMWWLS_ATTR_RESET_STATISTICS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 199
#define RSCMWWLS_ATTR_STATISTICS_SETTINGS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 200
#define RSCMWWLS_ATTR_STATISTICS_RX_PSDU_HEMU                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 201
#define RSCMWWLS_ATTR_STATISTICS_RX_PSDU_HESU                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 202
#define RSCMWWLS_ATTR_STATISTICS_RX_PSDU_HETB                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 203
#define RSCMWWLS_ATTR_STATISTICS_RX_PSDU_HT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 204
#define RSCMWWLS_ATTR_STATISTICS_RX_PSDU_NHT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 205
#define RSCMWWLS_ATTR_STATISTICS_RX_PSDU_VHT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 206
#define RSCMWWLS_ATTR_PER_MODULATION_CODING_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define RSCMWWLS_ATTR_PER_ACKNOWLEDGEMENT_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define RSCMWWLS_ATTR_PER_DATA_PATTERN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define RSCMWWLS_ATTR_PER_NUMBER_OF_PACKETS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define RSCMWWLS_ATTR_PER_DATA_INTERVAL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define RSCMWWLS_ATTR_PER_PAYLOAD_SIZE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define RSCMWWLS_ATTR_PER_QOS_TID                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 124
#define RSCMWWLS_ATTR_PER_DESTINATION_STATION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 207
#define RSCMWWLS_ATTR_PER_LINK_TO_SIG_FRAME_SETTINGS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 125
#define RSCMWWLS_ATTR_PER_DATA_HEMU_FRAME_USER_MCS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 126
#define RSCMWWLS_ATTR_PER_DATA_HEMU_FRAME_USER_CODING_TYPE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 127
#define RSCMWWLS_ATTR_PER_DATA_HEMU_FRAME_USER_STREAMS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 208
#define RSCMWWLS_ATTR_PER_DATA_HEMU_FRAME_DUMMY_USER_MCS                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 128
#define RSCMWWLS_ATTR_PER_MEASUREMENT_INITIATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 32
#define RSCMWWLS_ATTR_PER_MEASUREMENT_ABORT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 33
#define RSCMWWLS_ATTR_PER_MEASUREMENT_STOP                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 34
#define RSCMWWLS_ATTR_PER_LAST_ACK_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 73
#define RSCMWWLS_ATTR_HETB_NUMBER_OF_FRAMES                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 209
#define RSCMWWLS_ATTR_HETB_MEASUREMENT_INITIATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 210
#define RSCMWWLS_ATTR_HETB_MEASUREMENT_ABORT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 211
#define RSCMWWLS_ATTR_HETB_MEASUREMENT_STOP                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 212
#define RSCMWWLS_ATTR_HETB_MEASUREMENT_STATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 213
#define RSCMWWLS_ATTR_SYSTEM_VERSION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define RSCMWWLS_ATTR_SYSTEM_ERROR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define RSCMWWLS_ATTR_SYSTEM_ALL_ERRORS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 18
#define RSCMWWLS_ATTR_SYSTEM_PRESET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 19
#define RSCMWWLS_ATTR_ID_QUERY_RESPONSE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 20

// rscmwwls_rngConnectionStandard
#define RSCMWWLS_VAL_WLAN_AOFD                                              0
#define RSCMWWLS_VAL_WLAN_NMXM                                              2
#define RSCMWWLS_VAL_WLAN_GOST                                              3
#define RSCMWWLS_VAL_WLAN_GONS                                              4
#define RSCMWWLS_VAL_WLAN_BSTD                                              5
#define RSCMWWLS_VAL_WLAN_GSTD                                              6
#define RSCMWWLS_VAL_WLAN_GNST                                              7
#define RSCMWWLS_VAL_WLAN_ACST                                              8
#define RSCMWWLS_VAL_WLAN_AXST                                              9

// rscmwwls_rngTriggerSlope
#define RSCMWWLS_VAL_TRIGGER_REDG                                           0
#define RSCMWWLS_VAL_TRIGGER_FEDG                                           1

// rscmwwls_rngRxTriggerPulseLength
#define RSCMWWLS_VAL_PULSE_LENGTH_DEF                                       0
#define RSCMWWLS_VAL_PULSE_LENGTH_UDEF                                      1

// rscmwwls_rngPERModulationCodingRate
#define RSCMWWLS_VAL_PER_CODE_RATE_BR12                                     0
#define RSCMWWLS_VAL_PER_CODE_RATE_BR34                                     1
#define RSCMWWLS_VAL_PER_CODE_RATE_QR12                                     2
#define RSCMWWLS_VAL_PER_CODE_RATE_QR34                                     3
#define RSCMWWLS_VAL_PER_CODE_RATE_Q1M12                                    4
#define RSCMWWLS_VAL_PER_CODE_RATE_Q1M34                                    5
#define RSCMWWLS_VAL_PER_CODE_RATE_Q6M23                                    6
#define RSCMWWLS_VAL_PER_CODE_RATE_Q6M34                                    7
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS                                      8
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS1                                     9
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS2                                     10
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS3                                     11
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS4                                     12
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS5                                     13
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS6                                     14
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS7                                     15
#define RSCMWWLS_VAL_PER_CODE_RATE_D1MB                                     16
#define RSCMWWLS_VAL_PER_CODE_RATE_D2MB                                     17
#define RSCMWWLS_VAL_PER_CODE_RATE_C55M                                     18
#define RSCMWWLS_VAL_PER_CODE_RATE_C11M                                     19
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS8                                     20
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS9                                     21
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS10                                    22
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS11                                    23
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS12                                    24
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS13                                    25
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS14                                    26
#define RSCMWWLS_VAL_PER_CODE_RATE_MCS15                                    27

// rscmwwls_rngPERAcknowledgementType
#define RSCMWWLS_VAL_PER_ACKNOWLEDGEMENT_ACK                                0

// rscmwwls_rngQueryPacketSwitchedState
#define RSCMWWLS_VAL_PSWITCHED_STATE_IDLE                                   0
#define RSCMWWLS_VAL_PSWITCHED_STATE_PROB                                   1
#define RSCMWWLS_VAL_PSWITCHED_STATE_AUTH                                   2
#define RSCMWWLS_VAL_PSWITCHED_STATE_ASS                                    3
#define RSCMWWLS_VAL_PSWITCHED_STATE_DEA                                    4
#define RSCMWWLS_VAL_PSWITCHED_STATE_DIS                                    5
#define RSCMWWLS_VAL_PSWITCHED_STATE_CTIM                                   6

// rscmwwls_rngPERDataPattern
#define RSCMWWLS_VAL_DATA_PATTERN_PN1                                       1
#define RSCMWWLS_VAL_DATA_PATTERN_PN2                                       2
#define RSCMWWLS_VAL_DATA_PATTERN_PN3                                       3
#define RSCMWWLS_VAL_DATA_PATTERN_PN4                                       4
#define RSCMWWLS_VAL_DATA_PATTERN_PN5                                       5
#define RSCMWWLS_VAL_DATA_PATTERN_PN6                                       6
#define RSCMWWLS_VAL_DATA_PATTERN_PN7                                       7
#define RSCMWWLS_VAL_DATA_PATTERN_PN8                                       8
#define RSCMWWLS_VAL_DATA_PATTERN_PN9                                       9
#define RSCMWWLS_VAL_DATA_PATTERN_PN10                                      10
#define RSCMWWLS_VAL_DATA_PATTERN_PN11                                      11
#define RSCMWWLS_VAL_DATA_PATTERN_PN12                                      12
#define RSCMWWLS_VAL_DATA_PATTERN_PN13                                      13
#define RSCMWWLS_VAL_DATA_PATTERN_PN14                                      14
#define RSCMWWLS_VAL_DATA_PATTERN_PN15                                      15
#define RSCMWWLS_VAL_DATA_PATTERN_PN16                                      16
#define RSCMWWLS_VAL_DATA_PATTERN_PN17                                      17
#define RSCMWWLS_VAL_DATA_PATTERN_PN18                                      18
#define RSCMWWLS_VAL_DATA_PATTERN_PN19                                      19
#define RSCMWWLS_VAL_DATA_PATTERN_PN20                                      20
#define RSCMWWLS_VAL_DATA_PATTERN_PN21                                      21
#define RSCMWWLS_VAL_DATA_PATTERN_PN22                                      22
#define RSCMWWLS_VAL_DATA_PATTERN_PN23                                      23
#define RSCMWWLS_VAL_DATA_PATTERN_PN24                                      24
#define RSCMWWLS_VAL_DATA_PATTERN_PN25                                      25
#define RSCMWWLS_VAL_DATA_PATTERN_PN26                                      26
#define RSCMWWLS_VAL_DATA_PATTERN_PN27                                      27
#define RSCMWWLS_VAL_DATA_PATTERN_PN28                                      28
#define RSCMWWLS_VAL_DATA_PATTERN_PN29                                      29
#define RSCMWWLS_VAL_DATA_PATTERN_PN30                                      30
#define RSCMWWLS_VAL_DATA_PATTERN_PN31                                      31
#define RSCMWWLS_VAL_DATA_PATTERN_PN32                                      32
#define RSCMWWLS_VAL_DATA_PATTERN_PRAN                                      33
#define RSCMWWLS_VAL_DATA_PATTERN_AZER                                      34
#define RSCMWWLS_VAL_DATA_PATTERN_AONE                                      35
#define RSCMWWLS_VAL_DATA_PATTERN_PT01                                      36
#define RSCMWWLS_VAL_DATA_PATTERN_PT10                                      37

// rscmwwls_rngDisableEnable
#define RSCMWWLS_VAL_DISABLE                                                0
#define RSCMWWLS_VAL_ENABLE                                                 1

// rscmwwls_rngPacketGeneratorProtocol
#define RSCMWWLS_VAL_PROTOCOL_ICMP                                          0
#define RSCMWWLS_VAL_PROTOCOL_UDP                                           1

// rscmwwls_rngRXFilterType
#define RSCMWWLS_VAL_RX_FILTER_DEFAULT                                      0
#define RSCMWWLS_VAL_RX_FILTER_ALTERNATIVE                                  1
#define RSCMWWLS_VAL_RX_FILTER_AUTO                                         2

// rscmwwls_rngSSIDConnection
#define RSCMWWLS_VAL_SSID_CONNECTION_ANY                                    0
#define RSCMWWLS_VAL_SSID_CONNECTION_SSID                                   1

// rscmwwls_rngSecurityEncryptionType
#define RSCMWWLS_VAL_ENCRYPTION_DISABLED                                    0
#define RSCMWWLS_VAL_ENCRYPTION_AES                                         1
#define RSCMWWLS_VAL_ENCRYPTION_TKIP                                        2
#define RSCMWWLS_VAL_ENCRYPTION_GCMP                                        3

// rscmwwls_rngConnectionMode
#define RSCMWWLS_VAL_CONNECTION_MODE_ACON                                   0
#define RSCMWWLS_VAL_CONNECTION_MODE_MAN                                    1

// rscmwwls_rngOperationMode
#define RSCMWWLS_VAL_OPERATION_MODE_AP                                      0
#define RSCMWWLS_VAL_OPERATION_MODE_STATION                                 1
#define RSCMWWLS_VAL_OPERATION_MODE_WIFI_HOTSPOT                            4

// rscmwwls_rngRFTXMIMOMode
#define RSCMWWLS_VAL_TX_MIMO_SPATIAL_MULTIPLEXING                           0
#define RSCMWWLS_VAL_TX_MIMO_SPACE_TIME_BLOCK_CODING                        2

// rscmwwls_rngTriggerMode
#define RSCMWWLS_VAL_TRIGGER_MODE_ALL_BURSTS                                0
#define RSCMWWLS_VAL_TRIGGER_MODE_ONLY_OFDM                                 1
#define RSCMWWLS_VAL_TRIGGER_MODE_ONLY_DSSS                                 2
#define RSCMWWLS_VAL_TRIGGER_MODE_ONLY_NHT                                  3
#define RSCMWWLS_VAL_TRIGGER_MODE_ONLY_HT                                   4
#define RSCMWWLS_VAL_TRIGGER_MODE_ONLY_VHT                                  5
#define RSCMWWLS_VAL_TRIGGER_MODE_ONLY_HES                                  6

// rscmwwls_rngRadiusServerMode
#define RSCMWWLS_VAL_RADIUS_SERVER_INTERNAL                                 0
#define RSCMWWLS_VAL_RADIUS_SERVER_EXTERNAL                                 1

// rscmwwls_rngHotspotNumberOfDigits
#define RSCMWWLS_VAL_DIGITS_TWO                                             0
#define RSCMWWLS_VAL_DIGITS_THREE                                           1

// rscmwwls_rngPacketGeneratorIPVersion
#define RSCMWWLS_VAL_IPV4                                                   0
#define RSCMWWLS_VAL_IPV6                                                   1

// rscmwwls_rngIPVersionSupport
#define RSCMWWLS_VAL_IP_VERSION_4                                           0
#define RSCMWWLS_VAL_IP_VERSION_6                                           1
#define RSCMWWLS_VAL_IP_VERSION_BOTH                                        2

// rscmwwls_rngDAUSegmentNumber
#define RSCMWWLS_VAL_DAU_SEGMENT_A                                          0
#define RSCMWWLS_VAL_DAU_SEGMENT_B                                          1
#define RSCMWWLS_VAL_DAU_SEGMENT_C                                          2

// rscmwwls_rngTxTriggerPulseLength
#define RSCMWWLS_VAL_PULSE_LENGTH_BLEN                                      2

// rscmwwls_rngOperatingChannelWidth
#define RSCMWWLS_VAL_BANDWIDTH_20_MHZ                                       0
#define RSCMWWLS_VAL_BANDWIDTH_40_MHZ                                       1
#define RSCMWWLS_VAL_BANDWIDTH_80_MHZ                                       2
#define RSCMWWLS_VAL_BANDWIDTH_160_MHZ                                      3

// rscmwwls_rngMessageMonitoringLoggingPCIPv4Address
#define RSCMWWLS_VAL_ADDRESS_POOL_INDEX_1                                   1
#define RSCMWWLS_VAL_ADDRESS_POOL_INDEX_2                                   2
#define RSCMWWLS_VAL_ADDRESS_POOL_INDEX_3                                   3

// rscmwwls_rngUsedDefinedVHTSupportedRates
#define RSCMWWLS_VAL_VHT_MC07                                               0
#define RSCMWWLS_VAL_VHT_MC08                                               1
#define RSCMWWLS_VAL_VHT_MC09                                               2

// rscmwwls_rngMCS
#define RSCMWWLS_VAL_MCS1                                                   1
#define RSCMWWLS_VAL_MCS2                                                   2
#define RSCMWWLS_VAL_MCS3                                                   3
#define RSCMWWLS_VAL_MCS4                                                   4
#define RSCMWWLS_VAL_MCS5                                                   5
#define RSCMWWLS_VAL_MCS6                                                   6
#define RSCMWWLS_VAL_MCS7                                                   7
#define RSCMWWLS_VAL_MCS8                                                   8
#define RSCMWWLS_VAL_MCS9                                                   9
#define RSCMWWLS_VAL_MCS10                                                  10
#define RSCMWWLS_VAL_MCS11                                                  11
#define RSCMWWLS_VAL_MCS                                                    0

// rscmwwls_rngCodingType
#define RSCMWWLS_CODING_TYPE_LDPC                                           0
#define RSCMWWLS_CODING_TYPE_BCC                                            1

// rscmwwls_rngDataFrameStreams
#define RSCMWWLS_VAL_STREAM1                                                1
#define RSCMWWLS_VAL_STREAM2                                                2

// rscmwwls_rngTriggerFrameTriggerType
#define RSCMWWLS_VAL_TRIGGER_BTR                                            0
#define RSCMWWLS_VAL_TRIGGER_BRP                                            1
#define RSCMWWLS_VAL_TRIGGER_MRTS                                           2
#define RSCMWWLS_VAL_TRIGGER_BSRP                                           3
#define RSCMWWLS_VAL_TRIGGER_BQRP                                           4

// rscmwwls_rngTriggerFrameBandwidth
#define RSCMWWLS_VAL_BW20                                                   0
#define RSCMWWLS_VAL_BW40                                                   1
#define RSCMWWLS_VAL_BW80                                                   2
#define RSCMWWLS_VAL_BW160                                                  3

// rscmwwls_rngTriggerFrameGILTF
#define RSCMWWLS_VAL_GILTF_L116                                             0
#define RSCMWWLS_VAL_GILTF_L216                                             1
#define RSCMWWLS_VAL_GILTF_L432                                             2

// rscmwwls_rngTriggerFrameMUMIMOLTF
#define RSCMWWLS_MUMIMO_LTF_SINGLE                                          0
#define RSCMWWLS_MUMIMO_LTF_MASK                                            1

// rscmwwls_rngTriggerFrameRUAllocation
#define RSCMWWLS_VAL_RU_ALLOCATION_RU0                                      0
#define RSCMWWLS_VAL_RU_ALLOCATION_RU1                                      1
#define RSCMWWLS_VAL_RU_ALLOCATION_RU2                                      2
#define RSCMWWLS_VAL_RU_ALLOCATION_RU3                                      3
#define RSCMWWLS_VAL_RU_ALLOCATION_RU4                                      4
#define RSCMWWLS_VAL_RU_ALLOCATION_RU5                                      5
#define RSCMWWLS_VAL_RU_ALLOCATION_RU6                                      6
#define RSCMWWLS_VAL_RU_ALLOCATION_RU7                                      7
#define RSCMWWLS_VAL_RU_ALLOCATION_RU8                                      8
#define RSCMWWLS_VAL_RU_ALLOCATION_RU9                                      9
#define RSCMWWLS_VAL_RU_ALLOCATION_RU10                                     10
#define RSCMWWLS_VAL_RU_ALLOCATION_RU11                                     11
#define RSCMWWLS_VAL_RU_ALLOCATION_RU12                                     12
#define RSCMWWLS_VAL_RU_ALLOCATION_RU13                                     13
#define RSCMWWLS_VAL_RU_ALLOCATION_RU14                                     14
#define RSCMWWLS_VAL_RU_ALLOCATION_RU15                                     15
#define RSCMWWLS_VAL_RU_ALLOCATION_RU16                                     16
#define RSCMWWLS_VAL_RU_ALLOCATION_RU17                                     17
#define RSCMWWLS_VAL_RU_ALLOCATION_RU18                                     18
#define RSCMWWLS_VAL_RU_ALLOCATION_RU19                                     19
#define RSCMWWLS_VAL_RU_ALLOCATION_RU20                                     20
#define RSCMWWLS_VAL_RU_ALLOCATION_RU21                                     21
#define RSCMWWLS_VAL_RU_ALLOCATION_RU22                                     22
#define RSCMWWLS_VAL_RU_ALLOCATION_RU23                                     23
#define RSCMWWLS_VAL_RU_ALLOCATION_RU24                                     24
#define RSCMWWLS_VAL_RU_ALLOCATION_RU25                                     25
#define RSCMWWLS_VAL_RU_ALLOCATION_RU26                                     26
#define RSCMWWLS_VAL_RU_ALLOCATION_RU27                                     27
#define RSCMWWLS_VAL_RU_ALLOCATION_RU28                                     28
#define RSCMWWLS_VAL_RU_ALLOCATION_RU29                                     29
#define RSCMWWLS_VAL_RU_ALLOCATION_RU30                                     30
#define RSCMWWLS_VAL_RU_ALLOCATION_RU31                                     31
#define RSCMWWLS_VAL_RU_ALLOCATION_RU32                                     32
#define RSCMWWLS_VAL_RU_ALLOCATION_RU33                                     33
#define RSCMWWLS_VAL_RU_ALLOCATION_RU34                                     34
#define RSCMWWLS_VAL_RU_ALLOCATION_RU35                                     35
#define RSCMWWLS_VAL_RU_ALLOCATION_RU36                                     36
#define RSCMWWLS_VAL_RU_ALLOCATION_RU37                                     37
#define RSCMWWLS_VAL_RU_ALLOCATION_RU38                                     38
#define RSCMWWLS_VAL_RU_ALLOCATION_RU39                                     39
#define RSCMWWLS_VAL_RU_ALLOCATION_RU40                                     40
#define RSCMWWLS_VAL_RU_ALLOCATION_RU41                                     41
#define RSCMWWLS_VAL_RU_ALLOCATION_RU42                                     42
#define RSCMWWLS_VAL_RU_ALLOCATION_RU43                                     43
#define RSCMWWLS_VAL_RU_ALLOCATION_RU44                                     44
#define RSCMWWLS_VAL_RU_ALLOCATION_RU45                                     45
#define RSCMWWLS_VAL_RU_ALLOCATION_RU46                                     46
#define RSCMWWLS_VAL_RU_ALLOCATION_RU47                                     47
#define RSCMWWLS_VAL_RU_ALLOCATION_RU48                                     48
#define RSCMWWLS_VAL_RU_ALLOCATION_RU49                                     49
#define RSCMWWLS_VAL_RU_ALLOCATION_RU50                                     50
#define RSCMWWLS_VAL_RU_ALLOCATION_RU51                                     51
#define RSCMWWLS_VAL_RU_ALLOCATION_RU52                                     52
#define RSCMWWLS_VAL_RU_ALLOCATION_RU53                                     53
#define RSCMWWLS_VAL_RU_ALLOCATION_RU54                                     54
#define RSCMWWLS_VAL_RU_ALLOCATION_RU55                                     55
#define RSCMWWLS_VAL_RU_ALLOCATION_RU56                                     56
#define RSCMWWLS_VAL_RU_ALLOCATION_RU57                                     57
#define RSCMWWLS_VAL_RU_ALLOCATION_RU58                                     58
#define RSCMWWLS_VAL_RU_ALLOCATION_RU59                                     59
#define RSCMWWLS_VAL_RU_ALLOCATION_RU60                                     60
#define RSCMWWLS_VAL_RU_ALLOCATION_RU61                                     61
#define RSCMWWLS_VAL_RU_ALLOCATION_RU62                                     62
#define RSCMWWLS_VAL_RU_ALLOCATION_RU63                                     63
#define RSCMWWLS_VAL_RU_ALLOCATION_RU64                                     64
#define RSCMWWLS_VAL_RU_ALLOCATION_RU65                                     65
#define RSCMWWLS_VAL_RU_ALLOCATION_RU66                                     66
#define RSCMWWLS_VAL_RU_ALLOCATION_RU67                                     67
#define RSCMWWLS_VAL_RU_ALLOCATION_RU68                                     68

// rscmwwls_rngTriggerFrameCodingType
#define RSCMWWLS_VAL_CODING_TYPE_BCC                                        0
#define RSCMWWLS_VAL_CODING_TYPE_LDPC                                       1

// rscmwwls_rngTriggerFrameTargetRSSIMode
#define RSCMWWLS_VAL_MODE_AUTO                                              0
#define RSCMWWLS_VAL_MODE_MANUAL                                            1
#define RSCMWWLS_VAL_MODE_MAXPOWER                                          2

// rscmwwls_rngTID
#define RSCMWWLS_VAL_TID0                                                   0
#define RSCMWWLS_VAL_TID1                                                   1
#define RSCMWWLS_VAL_TID2                                                   2
#define RSCMWWLS_VAL_TID3                                                   3
#define RSCMWWLS_VAL_TID4                                                   4
#define RSCMWWLS_VAL_TID5                                                   5
#define RSCMWWLS_VAL_TID6                                                   6
#define RSCMWWLS_VAL_TID7                                                   7

// rscmwwls_rngQOSTIDPrioritizationMode
#define RSCMWWLS_VAL_PRIORITIZATION_MODE_ROUND_ROBIN                        0
#define RSCMWWLS_VAL_PRIORITIZATION_MODE_TID_PRIORITY                       1
#define RSCMWWLS_VAL_PRIORITIZATION_MODE_AUTO                               2

// rscmwwls_rngQOSTIDBARMethod
#define RSCMWWLS_VAL_BAR_IMPLICIT                                           0
#define RSCMWWLS_VAL_BAR_EXPLICIT                                           1
#define RSCMWWLS_VAL_BAR_MULTI_USER                                         2

// rscmwwls_rngHTSmoothing
#define RSCMWWLS_VAL_HT_SMOOTHING_NOT_RECOMMENDED                           0
#define RSCMWWLS_VAL_HT_SMOOTHING_RECOMMENDED                               1

// rscmwwls_rngTriggerBandwidth
#define RSCMWWLS_VAL_TRIGGER_BANDWIDTH_OFF                                  0
#define RSCMWWLS_VAL_TRIGGER_BANDWIDTH_ON                                   1
#define RSCMWWLS_VAL_TRIGGER_BANDWIDTH_ALL                                  2
#define RSCMWWLS_VAL_TRIGGER_BANDWIDTH_20_MHZ                               3
#define RSCMWWLS_VAL_TRIGGER_BANDWIDTH_40_MHZ                               4
#define RSCMWWLS_VAL_TRIGGER_BANDWIDTH_80_MHZ                               5
#define RSCMWWLS_VAL_TRIGGER_BANDWIDTH_160_MHZ                              6

// rscmwwls_rngRXTriggerRate
#define RSCMWWLS_VAL_TRIGGER_RATE_OFF                                       0
#define RSCMWWLS_VAL_TRIGGER_RATE_ON                                        1
#define RSCMWWLS_VAL_TRIGGER_RATE_ALL                                       2
#define RSCMWWLS_VAL_TRIGGER_RATE_BR12                                      3
#define RSCMWWLS_VAL_TRIGGER_RATE_QR12                                      4
#define RSCMWWLS_VAL_TRIGGER_RATE_QR34                                      5
#define RSCMWWLS_VAL_TRIGGER_RATE_Q1M12                                     6
#define RSCMWWLS_VAL_TRIGGER_RATE_Q1M34                                     7
#define RSCMWWLS_VAL_TRIGGER_RATE_Q6M23                                     8
#define RSCMWWLS_VAL_TRIGGER_RATE_Q6M34                                     9
#define RSCMWWLS_VAL_TRIGGER_RATE_BR34                                      10
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS0                                      11
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS1                                      12
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS2                                      13
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS3                                      14
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS4                                      15
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS5                                      16
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS6                                      17
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS7                                      18
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS8                                      19
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS9                                      20
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS10                                     21
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS11                                     22
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS12                                     23
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS13                                     24
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS14                                     25
#define RSCMWWLS_VAL_TRIGGER_RATE_MCS15                                     26
#define RSCMWWLS_VAL_TRIGGER_RATE_D1MB                                      27
#define RSCMWWLS_VAL_TRIGGER_RATE_D2MB                                      28
#define RSCMWWLS_VAL_TRIGGER_RATE_C55M                                      29
#define RSCMWWLS_VAL_TRIGGER_RATE_C11M                                      30

// rscmwwls_rngMeasurementState
#define RSCMWWLS_VAL_MEAS_STATE_OFF                                         0
#define RSCMWWLS_VAL_MEAS_STATE_RUN                                         1
#define RSCMWWLS_VAL_MEAS_STATE_RDY                                         2

// rscmwwls_rngAssociationStationPriority
#define RSCMWWLS_VAL_STATION_PRIORITY_AUTO                                  0
#define RSCMWWLS_VAL_STATION_PRIORITY_ROUR                                  1

// rscmwwls_rngNDPSoundingBandwidth
#define RSCMWWLS_VAL_NDPS_BW_BW20                                           0
#define RSCMWWLS_VAL_NDPS_BW_BW40                                           1
#define RSCMWWLS_VAL_NDPS_BW_BW80                                           2
#define RSCMWWLS_VAL_NDPS_BW_BW160                                          3

// rscmwwls_rngNDPSoundingCodebookSize
#define RSCMWWLS_VAL_NDPS_CODEBOOK_SIZE0                                    0
#define RSCMWWLS_VAL_NDPS_CODEBOOK_SIZE1                                    1

// rscmwwls_rngNDPSoundingGILTF
#define RSCMWWLS_VAL_NDPS_LTFGI_L208                                        0
#define RSCMWWLS_VAL_NDPS_LTFGI_L216                                        1
#define RSCMWWLS_VAL_NDPS_LTFGI_L432                                        2

// rscmwwls_rngNDPSoundingFeedbackMethod
#define RSCMWWLS_VAL_NDPS_METHOD_NONT                                       0
#define RSCMWWLS_VAL_NDPS_METHOD_TBAS                                       1

// rscmwwls_rngNDPSoundingNumberOfColumns
#define RSCMWWLS_VAL_NDPS_COLUMNS_0                                         0
#define RSCMWWLS_VAL_NDPS_COLUMNS_1                                         1

// rscmwwls_rngNDPSoundingSpatialStreams
#define RSCMWWLS_VAL_NDPS_SPATIAL_STREAM1                                   0
#define RSCMWWLS_VAL_NDPS_SPATIAL_STREAM2                                   1

// rscmwwls_rngNDPSoundingSubcarrierGrouping
#define RSCMWWLS_VAL_NDPS_SUBCARRIER_GRP4                                   0
#define RSCMWWLS_VAL_NDPS_SUBCARRIER_GRP16                                  1

// rscmwwls_rngNDPSoundingStation
#define RSCMWWLS_VAL_NDPS_TARGET_STA1                                       0
#define RSCMWWLS_VAL_NDPS_TARGET_STA2                                       1
#define RSCMWWLS_VAL_NDPS_TARGET_STA3                                       2

// rscmwwls_rngNDPSoundingReportType
#define RSCMWWLS_VAL_NDPS_REPORT_TYPE_SU                                    0
#define RSCMWWLS_VAL_NDPS_REPORT_TYPE_MU                                    1
#define RSCMWWLS_VAL_NDPS_REPORT_TYPE_CQI                                   2

// rscmwwls_rngFadingSimulatorProfile
#define RSCMWWLS_VAL_FSIM_PROFILE_MODA                                      0
#define RSCMWWLS_VAL_FSIM_PROFILE_MODB                                      1
#define RSCMWWLS_VAL_FSIM_PROFILE_MODC                                      2
#define RSCMWWLS_VAL_FSIM_PROFILE_MODD                                      3
#define RSCMWWLS_VAL_FSIM_PROFILE_MODE                                      4
#define RSCMWWLS_VAL_FSIM_PROFILE_MODF                                      5

// rscmwwls_rngPERDestinationStation
#define RSCMWWLS_VAL_PER_DEST_STA1                                          0
#define RSCMWWLS_VAL_PER_DEST_STA2                                          1
#define RSCMWWLS_VAL_PER_DEST_STA3                                          2

// rscmwwls_rngPacketGeneratorDestination
#define RSCMWWLS_VAL_PGEN_DESTINATION_STA1                                  0
#define RSCMWWLS_VAL_PGEN_DESTINATION_STA2                                  1
#define RSCMWWLS_VAL_PGEN_DESTINATION_STA3                                  2

// rscmwwls_rngRFBand
#define RSCMWWLS_VAL_RF_BAND_BS6GHZ                                         0
#define RSCMWWLS_VAL_RF_BAND_B6GHZ                                          1

// rscmwwls_rngRXTriggerDelayType
#define RSCMWWLS_VAL_TRIGGER_DELAY_TYPE_BURST                               0
#define RSCMWWLS_VAL_TRIGGER_DELAY_TYPE_CONSTANT                            1

// rscmwwls_rngRXTriggerSpatialStreams
#define RSCMWWLS_VAL_TRIGGER_SPATIAL_STREAMS_ALL                            0
#define RSCMWWLS_VAL_TRIGGER_SPATIAL_STREAMS_STR1                           1
#define RSCMWWLS_VAL_TRIGGER_SPATIAL_STREAMS_STR2                           2
#define RSCMWWLS_VAL_TRIGGER_SPATIAL_STREAMS_ON                             3
#define RSCMWWLS_VAL_TRIGGER_SPATIAL_STREAMS_OFF                            4

// rscmwwls_rngScenario
#define RSCMWWLS_VAL_RF_SCENARIO_STANDARD                                   0
#define RSCMWWLS_VAL_RF_SCENARIO_MIMO2                                      1
#define RSCMWWLS_VAL_RF_SCENARIO_SCF                                        2
#define RSCMWWLS_VAL_RF_SCENARIO_MIMF                                       3

// rscmwwls_rngSecurityType
#define RSCMWWLS_VAL_SECURITY_TYPE_DISABLED                                 0
#define RSCMWWLS_VAL_SECURITY_TYPE_AUTO                                     1
#define RSCMWWLS_VAL_SECURITY_TYPE_WPA_PERSONAL                             2
#define RSCMWWLS_VAL_SECURITY_TYPE_WPA_ENTERPRISE                           3
#define RSCMWWLS_VAL_SECURITY_TYPE_WPA2_PERSONAL                            4
#define RSCMWWLS_VAL_SECURITY_TYPE_WPA2_ENTERPRISE                          5
#define RSCMWWLS_VAL_SECURITY_TYPE_OWE                                      6
#define RSCMWWLS_VAL_SECURITY_TYPE_WPA3_PERSONAL                            7
#define RSCMWWLS_VAL_SECURITY_TYPE_WPA3_ENTERPRISE                          8

// rscmwwls_rngGroupTransform
#define RSCMWWLS_VAL_GROUP_TRANSFORM_ECP256                                 0
#define RSCMWWLS_VAL_GROUP_TRANSFORM_ECP384                                 1

// rscmwwls_rngSAEAuthentication
#define RSCMWWLS_VAL_SAE_AUTHENTICATION_HUNT                                0
#define RSCMWWLS_VAL_SAE_AUTHENTICATION_H2E                                 1
#define RSCMWWLS_VAL_SAE_AUTHENTICATION_BOTH                                2

// rscmwwls_rngKeyMode
#define RSCMWWLS_VAL_KEY_MODE_RANDOM                                        0
#define RSCMWWLS_VAL_KEY_MODE_FIXED                                         1

// rscmwwls_rngProtectionManagmentFrames
#define RSCMWWLS_VAL_PROTECTION_MANAGMENT_FRAMES_UNSUPPORTED                0
#define RSCMWWLS_VAL_PROTECTION_MANAGMENT_FRAMES_SUPPORTED                  1
#define RSCMWWLS_VAL_PROTECTION_MANAGMENT_FRAMES_REQUIRED                   2

//repcap instance
#define RSCMWWLS_REPCAP_INSTANCE_I1                                         1
#define RSCMWWLS_REPCAP_INSTANCE_I2                                         2
#define RSCMWWLS_REPCAP_INSTANCE_I3                                         3
#define RSCMWWLS_REPCAP_INSTANCE_I4                                         4
#define RSCMWWLS_REPCAP_INSTANCE_I5                                         5
#define RSCMWWLS_REPCAP_INSTANCE_I6                                         6
#define RSCMWWLS_REPCAP_INSTANCE_I7                                         7
#define RSCMWWLS_REPCAP_INSTANCE_I8                                         8
#define RSCMWWLS_REPCAP_INSTANCE_I9                                         9
#define RSCMWWLS_REPCAP_INSTANCE_I10                                        10
#define RSCMWWLS_REPCAP_INSTANCE_I11                                        11
#define RSCMWWLS_REPCAP_INSTANCE_I12                                        12
#define RSCMWWLS_REPCAP_INSTANCE_I13                                        13
#define RSCMWWLS_REPCAP_INSTANCE_I14                                        14
#define RSCMWWLS_REPCAP_INSTANCE_I15                                        15
#define RSCMWWLS_REPCAP_INSTANCE_I16                                        16
#define RSCMWWLS_REPCAP_INSTANCE_I17                                        17
#define RSCMWWLS_REPCAP_INSTANCE_I18                                        18
#define RSCMWWLS_REPCAP_INSTANCE_I19                                        19
#define RSCMWWLS_REPCAP_INSTANCE_I20                                        20
#define RSCMWWLS_REPCAP_INSTANCE_I21                                        21
#define RSCMWWLS_REPCAP_INSTANCE_I22                                        22
#define RSCMWWLS_REPCAP_INSTANCE_I23                                        23
#define RSCMWWLS_REPCAP_INSTANCE_I24                                        24
#define RSCMWWLS_REPCAP_INSTANCE_I25                                        25
#define RSCMWWLS_REPCAP_INSTANCE_I26                                        26
#define RSCMWWLS_REPCAP_INSTANCE_I27                                        27
#define RSCMWWLS_REPCAP_INSTANCE_I28                                        28
#define RSCMWWLS_REPCAP_INSTANCE_I29                                        29
#define RSCMWWLS_REPCAP_INSTANCE_I30                                        30
#define RSCMWWLS_REPCAP_INSTANCE_I31                                        31
#define RSCMWWLS_REPCAP_INSTANCE_I32                                        32

//repcap TriggerType
#define RSCMWWLS_REPCAP_TRIGGERTYPE_TRIGTX                                  0
#define RSCMWWLS_REPCAP_TRIGGERTYPE_TRIGRX                                  1

//repcap ip
#define RSCMWWLS_REPCAP_IP_IPV4                                             0
#define RSCMWWLS_REPCAP_IP_IPV6                                             1

//repcap carrier
#define RSCMWWLS_REPCAP_CARRIER_C1                                          1
#define RSCMWWLS_REPCAP_CARRIER_C2                                          2

//repcap user
#define RSCMWWLS_REPCAP_USER_USER1                                          1
#define RSCMWWLS_REPCAP_USER_USER2                                          2
#define RSCMWWLS_REPCAP_USER_USER3                                          3

//repcap index
#define RSCMWWLS_REPCAP_INDEX_INDEX1                                        1
#define RSCMWWLS_REPCAP_INDEX_INDEX2                                        2
#define RSCMWWLS_REPCAP_INDEX_INDEX3                                        3

//repcap station
#define RSCMWWLS_REPCAP_STATION_S1                                          1
#define RSCMWWLS_REPCAP_STATION_S2                                          2
#define RSCMWWLS_REPCAP_STATION_S3                                          3

//repcap antenna
#define RSCMWWLS_REPCAP_ANTENNA_A1                                          1
#define RSCMWWLS_REPCAP_ANTENNA_A2                                          2
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSCMWWLS_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSCMWWLS_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSCMWWLS_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSCMWWLS_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *---------------- Constant definition  ------------------------------------*
 ****************************************************************************/

#define RSCMWWLS_VAL_CONN_RF1C     0
#define RSCMWWLS_VAL_CONN_RF2C     1
#define RSCMWWLS_VAL_CONN_RF3C     2
#define RSCMWWLS_VAL_CONN_RF4C     3
#define RSCMWWLS_VAL_CONN_RFAC     4
#define RSCMWWLS_VAL_CONN_RFBC     5
#define RSCMWWLS_VAL_CONN_R11C 6
#define RSCMWWLS_VAL_CONN_R12C 7
#define RSCMWWLS_VAL_CONN_R13C 8
#define RSCMWWLS_VAL_CONN_R14C 9
#define RSCMWWLS_VAL_CONN_R21C 10
#define RSCMWWLS_VAL_CONN_R22C 11
#define RSCMWWLS_VAL_CONN_R23C 12
#define RSCMWWLS_VAL_CONN_R24C 13
#define RSCMWWLS_VAL_CONN_R31C 14
#define RSCMWWLS_VAL_CONN_R32C 15
#define RSCMWWLS_VAL_CONN_R33C 16
#define RSCMWWLS_VAL_CONN_R34C 17
#define RSCMWWLS_VAL_CONN_R41C 18
#define RSCMWWLS_VAL_CONN_R42C 19
#define RSCMWWLS_VAL_CONN_R43C 20
#define RSCMWWLS_VAL_CONN_R44C 21

#define RSCMWWLS_VAL_CONV_RX1      0
#define RSCMWWLS_VAL_CONV_RX2      1
#define RSCMWWLS_VAL_CONV_RX3      2
#define RSCMWWLS_VAL_CONV_RX4      3
#define RSCMWWLS_VAL_CONV_RX11 4
#define RSCMWWLS_VAL_CONV_RX12 5
#define RSCMWWLS_VAL_CONV_RX13 6
#define RSCMWWLS_VAL_CONV_RX14 7
#define RSCMWWLS_VAL_CONV_RX21 8
#define RSCMWWLS_VAL_CONV_RX22 9
#define RSCMWWLS_VAL_CONV_RX23 10
#define RSCMWWLS_VAL_CONV_RX24 11
#define RSCMWWLS_VAL_CONV_RX31 12
#define RSCMWWLS_VAL_CONV_RX32 13
#define RSCMWWLS_VAL_CONV_RX33 14
#define RSCMWWLS_VAL_CONV_RX34 15
#define RSCMWWLS_VAL_CONV_RX41 16
#define RSCMWWLS_VAL_CONV_RX42 17
#define RSCMWWLS_VAL_CONV_RX43 18
#define RSCMWWLS_VAL_CONV_RX44 19

#define RSCMWWLS_VAL_TX_CONN_RF1C  0
#define RSCMWWLS_VAL_TX_CONN_RF2C  1
#define RSCMWWLS_VAL_TX_CONN_RF3C  2
#define RSCMWWLS_VAL_TX_CONN_RF4C  3
#define RSCMWWLS_VAL_TX_CONN_RF1O  4
#define RSCMWWLS_VAL_TX_CONN_RF3O  5
#define RSCMWWLS_VAL_TX_CONN_RFAC  6
#define RSCMWWLS_VAL_TX_CONN_RFAO  7
#define RSCMWWLS_VAL_TX_CONN_RFBC  8
#define RSCMWWLS_VAL_TX_CONN_R11C 9
#define RSCMWWLS_VAL_TX_CONN_R12C 10
#define RSCMWWLS_VAL_TX_CONN_R13C 11
#define RSCMWWLS_VAL_TX_CONN_R14C 12
#define RSCMWWLS_VAL_TX_CONN_R21C 13
#define RSCMWWLS_VAL_TX_CONN_R22C 14
#define RSCMWWLS_VAL_TX_CONN_R23C 15
#define RSCMWWLS_VAL_TX_CONN_R24C 16
#define RSCMWWLS_VAL_TX_CONN_R31C 17
#define RSCMWWLS_VAL_TX_CONN_R32C 18
#define RSCMWWLS_VAL_TX_CONN_R33C 19
#define RSCMWWLS_VAL_TX_CONN_R34C 20
#define RSCMWWLS_VAL_TX_CONN_R41C 21
#define RSCMWWLS_VAL_TX_CONN_R42C 22
#define RSCMWWLS_VAL_TX_CONN_R43C 23
#define RSCMWWLS_VAL_TX_CONN_R44C 24
#define RSCMWWLS_VAL_TX_CONN_R11O 25
#define RSCMWWLS_VAL_TX_CONN_R13O 26
#define RSCMWWLS_VAL_TX_CONN_R21O 27
#define RSCMWWLS_VAL_TX_CONN_R23O 28
#define RSCMWWLS_VAL_TX_CONN_R31O 29
#define RSCMWWLS_VAL_TX_CONN_R33O 30
#define RSCMWWLS_VAL_TX_CONN_R41O 31
#define RSCMWWLS_VAL_TX_CONN_R43O 32

#define RSCMWWLS_VAL_CONV_TX1      0
#define RSCMWWLS_VAL_CONV_TX2      1
#define RSCMWWLS_VAL_CONV_TX3      2
#define RSCMWWLS_VAL_CONV_TX4      3
#define RSCMWWLS_VAL_CONV_TX11 4
#define RSCMWWLS_VAL_CONV_TX12 5
#define RSCMWWLS_VAL_CONV_TX13 6
#define RSCMWWLS_VAL_CONV_TX14 7
#define RSCMWWLS_VAL_CONV_TX21 8
#define RSCMWWLS_VAL_CONV_TX22 9
#define RSCMWWLS_VAL_CONV_TX23 10
#define RSCMWWLS_VAL_CONV_TX24 11
#define RSCMWWLS_VAL_CONV_TX31 12
#define RSCMWWLS_VAL_CONV_TX32 13
#define RSCMWWLS_VAL_CONV_TX33 14
#define RSCMWWLS_VAL_CONV_TX34 15
#define RSCMWWLS_VAL_CONV_TX41 16
#define RSCMWWLS_VAL_CONV_TX42 17
#define RSCMWWLS_VAL_CONV_TX43 18
#define RSCMWWLS_VAL_CONV_TX44 19

#define RSCMWWLS_VAL_PATH_INPUT    0
#define RSCMWWLS_VAL_PATH_OUTPUT   1

#define RSCMWWLS_VAL_MANAGEMENT_FRAMES 0
#define RSCMWWLS_VAL_DATA_FRAMES       1

#define RSCMWWLS_VAL_RATE_DSSS_1M   0
#define RSCMWWLS_VAL_RATE_DSSS_2M   1
#define RSCMWWLS_VAL_RATE_CCK_5M5   2
#define RSCMWWLS_VAL_RATE_CCK_11M   3
#define RSCMWWLS_VAL_RATE_BPSK_1_2  4
#define RSCMWWLS_VAL_RATE_BPSK_3_4  5
#define RSCMWWLS_VAL_RATE_QPSK_1_2  6
#define RSCMWWLS_VAL_RATE_QPSK_3_4  7
#define RSCMWWLS_VAL_RATE_16QAM_1_2 8
#define RSCMWWLS_VAL_RATE_16QAM_3_4 9
#define RSCMWWLS_VAL_RATE_64QAM_1_2 10
#define RSCMWWLS_VAL_RATE_64QAM_2_3 10
#define RSCMWWLS_VAL_RATE_64QAM_3_4 11
#define RSCMWWLS_VAL_RATE_MCS0      12
#define RSCMWWLS_VAL_RATE_MCS1      13
#define RSCMWWLS_VAL_RATE_MCS2      14
#define RSCMWWLS_VAL_RATE_MCS3      15
#define RSCMWWLS_VAL_RATE_MCS4      16
#define RSCMWWLS_VAL_RATE_MCS5      17
#define RSCMWWLS_VAL_RATE_MCS6      18
#define RSCMWWLS_VAL_RATE_MCS7      19
#define RSCMWWLS_VAL_RATE_MCS8      20
#define RSCMWWLS_VAL_RATE_MCS9      21
#define RSCMWWLS_VAL_RATE_MCS10     22
#define RSCMWWLS_VAL_RATE_MCS11     23
#define RSCMWWLS_VAL_RATE_MCS12     24
#define RSCMWWLS_VAL_RATE_MCS13     25
#define RSCMWWLS_VAL_RATE_MCS14     26
#define RSCMWWLS_VAL_RATE_MCS15     27

#define RSCMWWLS_VAL_NAV           -1

#define RSCMWWLS_VAL_TRIGGER_TX 0
#define RSCMWWLS_VAL_TRIGGER_RX 1

#define RSCMWWLS_VAL_PAYLOAD_TYPE_DEFAULT        0
#define RSCMWWLS_VAL_PAYLOAD_TYPE_ALL_ZERO       1
#define RSCMWWLS_VAL_PAYLOAD_TYPE_ALL_ONES       2
#define RSCMWWLS_VAL_PAYLOAD_TYPE_BIT_PATTERN_01 3
#define RSCMWWLS_VAL_PAYLOAD_TYPE_BIT_PATTERN_10 4
#define RSCMWWLS_VAL_PAYLOAD_TYPE_PSEUDO_RANDOM  5

#define RSCMWWLS_VAL_SECURITY_MODE_DISABLED                                 RSCMWWLS_VAL_SECURITY_TYPE_DISABLED//0
#define RSCMWWLS_VAL_SECURITY_MODE_WPER                                     RSCMWWLS_VAL_SECURITY_TYPE_WPA_PERSONAL//1
#define RSCMWWLS_VAL_SECURITY_MODE_WENT                                     RSCMWWLS_VAL_SECURITY_TYPE_WPA_ENTERPRISE//2
#define RSCMWWLS_VAL_SECURITY_MODE_W2P                                      RSCMWWLS_VAL_SECURITY_TYPE_WPA2_PERSONAL//3
#define RSCMWWLS_VAL_SECURITY_MODE_W2EN                                     RSCMWWLS_VAL_SECURITY_TYPE_WPA2_ENTERPRISE//4

#define RSCMWWLS_VAL_WPS_AUTHENTICATION_PUSH    0
#define RSCMWWLS_VAL_WPS_AUTHENTICATION_DISPLAY 1
#define RSCMWWLS_VAL_WPS_AUTHENTICATION_KEYPAD  2

#define RSCMWWLS_VAL_WIFI_DIRECT_AUTHENTICATION_PUSH     0
#define RSCMWWLS_VAL_WIFI_DIRECT_AUTHENTICATION_DISPLAY  1
#define RSCMWWLS_VAL_WIFI_DIRECT_AUTHENTICATION_KEYPAD   2

#define RSCMWWLS_VAL_MODE_AUTO     0
#define RSCMWWLS_VAL_MODE_MANUAL   1

#define RSCMWWLS_VAL_TONE_ONE      1
#define RSCMWWLS_VAL_TONE_TWO      2
#define RSCMWWLS_VAL_TONE_THREE    3

#define RSCMWWLS_VAL_ALGORITHM_MILENAGE  0
#define RSCMWWLS_VAL_ALGORITHM_XOR       1

#define RSCMWWLS_VAL_NETWORK_TYPE_PNET 0
#define RSCMWWLS_VAL_NETWORK_TYPE_PNWG 1
#define RSCMWWLS_VAL_NETWORK_TYPE_CPN  2
#define RSCMWWLS_VAL_NETWORK_TYPE_FPN  3
#define RSCMWWLS_VAL_NETWORK_TYPE_PDN  4
#define RSCMWWLS_VAL_NETWORK_TYPE_ESON 5
#define RSCMWWLS_VAL_NETWORK_TYPE_TOEX 6
#define RSCMWWLS_VAL_NETWORK_TYPE_WILD 7

#define RSCMWWLS_VAL_VENUE_GROUP_UNSP 0
#define RSCMWWLS_VAL_VENUE_GROUP_ASS  1
#define RSCMWWLS_VAL_VENUE_GROUP_BUS  2
#define RSCMWWLS_VAL_VENUE_GROUP_EDUC 3
#define RSCMWWLS_VAL_VENUE_GROUP_FAIN 4
#define RSCMWWLS_VAL_VENUE_GROUP_INST 5
#define RSCMWWLS_VAL_VENUE_GROUP_MERC 6
#define RSCMWWLS_VAL_VENUE_GROUP_RES  7
#define RSCMWWLS_VAL_VENUE_GROUP_STOR 8
#define RSCMWWLS_VAL_VENUE_GROUP_UAM  9
#define RSCMWWLS_VAL_VENUE_GROUP_VEH  10
#define RSCMWWLS_VAL_VENUE_GROUP_OUTD 11

#define RSCMWWLS_VAL_IPV6_AVAILABILITY_ATN  0
#define RSCMWWLS_VAL_IPV6_AVAILABILITY_ATAV 1
#define RSCMWWLS_VAL_IPV6_AVAILABILITY_AATN 2

#define RSCMWWLS_VAL_IPV4_AVAILABILITY_ATN  0
#define RSCMWWLS_VAL_IPV4_AVAILABILITY_PIA  1
#define RSCMWWLS_VAL_IPV4_AVAILABILITY_PRI  2
#define RSCMWWLS_VAL_IPV4_AVAILABILITY_SNP  3
#define RSCMWWLS_VAL_IPV4_AVAILABILITY_DNP  4
#define RSCMWWLS_VAL_IPV4_AVAILABILITY_PSN  5
#define RSCMWWLS_VAL_IPV4_AVAILABILITY_PDN  6
#define RSCMWWLS_VAL_IPV4_AVAILABILITY_AATN 7

#define RSCMWWLS_VAL_EAP_TYPE_SIM  0
#define RSCMWWLS_VAL_EAP_TYPE_TTLS 1
#define RSCMWWLS_VAL_EAP_TYPE_AKA  2
#define RSCMWWLS_VAL_EAP_TYPE_APR  3
#define RSCMWWLS_VAL_EAP_TYPE_TLS  4

#define RSCMWWLS_VAL_NETWORK_AUTHENTICATION_ATC  0
#define RSCMWWLS_VAL_NETWORK_AUTHENTICATION_OES  1
#define RSCMWWLS_VAL_NETWORK_AUTHENTICATION_HRED 2
#define RSCMWWLS_VAL_NETWORK_AUTHENTICATION_DRED 3

#define RSCMWWLS_VAL_TRIGGER_MIN_LENGTH_DEFAULT 0
#define RSCMWWLS_VAL_TRIGGER_MIN_LENGTH_USER    1

#define RSCMWWLS_VAL_LOG_CATEGORY_INFO 0
#define RSCMWWLS_VAL_LOG_CATEGORY_WARN 1
#define RSCMWWLS_VAL_LOG_CATEGORY_ERR  2
#define RSCMWWLS_VAL_LOG_CATEGORY_EMPT 3

#define RSCMWWLS_VAL_FRAME_FORMAT_NHT 0
#define RSCMWWLS_VAL_FRAME_FORMAT_HTM 1
#define RSCMWWLS_VAL_FRAME_FORMAT_HTG 2
#define RSCMWWLS_VAL_FRAME_FORMAT_VHT 3
#define RSCMWWLS_VAL_FRAME_FORMAT_HES 4
#define RSCMWWLS_VAL_FRAME_FORMAT_HEM 5

#define RSCMWWLS_VAL_GUARD_INTERVAL_SHORT 0
#define RSCMWWLS_VAL_GUARD_INTERVAL_LONG  1
#define RSCMWWLS_VAL_GUARD_INTERVAL_GI08  2
#define RSCMWWLS_VAL_GUARD_INTERVAL_GI16  3
#define RSCMWWLS_VAL_GUARD_INTERVAL_GI32  4

#define RSCMWWLS_VAL_SUU 0
#define RSCMWWLS_VAL_SUA 1

#define RSCMWWLS_VAL_LTF_X1 0
#define RSCMWWLS_VAL_LTF_X2 1
#define RSCMWWLS_VAL_LTF_X4 2

#define RSCMWWLS_VAL_PE_DURATION_AUTO 0
#define RSCMWWLS_VAL_PE_DURATION_PE0  1
#define RSCMWWLS_VAL_PE_DURATION_PE4  2
#define RSCMWWLS_VAL_PE_DURATION_PE8  3
#define RSCMWWLS_VAL_PE_DURATION_PE12 4
#define RSCMWWLS_VAL_PE_DURATION_PE16 5

#define RSCMWWLS_VAL_SUBFIELD_A000  0
#define RSCMWWLS_VAL_SUBFIELD_A001  1
#define RSCMWWLS_VAL_SUBFIELD_A002  2
#define RSCMWWLS_VAL_SUBFIELD_A003  3
#define RSCMWWLS_VAL_SUBFIELD_A004  4
#define RSCMWWLS_VAL_SUBFIELD_A005  5
#define RSCMWWLS_VAL_SUBFIELD_A006  6
#define RSCMWWLS_VAL_SUBFIELD_A007  7
#define RSCMWWLS_VAL_SUBFIELD_A008  8
#define RSCMWWLS_VAL_SUBFIELD_A009  9
#define RSCMWWLS_VAL_SUBFIELD_A010 10
#define RSCMWWLS_VAL_SUBFIELD_A011 11
#define RSCMWWLS_VAL_SUBFIELD_A012 12
#define RSCMWWLS_VAL_SUBFIELD_A013 13
#define RSCMWWLS_VAL_SUBFIELD_A014 14
#define RSCMWWLS_VAL_SUBFIELD_A015 15
#define RSCMWWLS_VAL_SUBFIELD_A016 16
#define RSCMWWLS_VAL_SUBFIELD_A024 17
#define RSCMWWLS_VAL_SUBFIELD_A032 18
#define RSCMWWLS_VAL_SUBFIELD_A040 19
#define RSCMWWLS_VAL_SUBFIELD_A048 20
#define RSCMWWLS_VAL_SUBFIELD_A056 21
#define RSCMWWLS_VAL_SUBFIELD_A064 22
#define RSCMWWLS_VAL_SUBFIELD_A072 23
#define RSCMWWLS_VAL_SUBFIELD_A080 24
#define RSCMWWLS_VAL_SUBFIELD_A088 25
#define RSCMWWLS_VAL_SUBFIELD_A096 26
#define RSCMWWLS_VAL_SUBFIELD_A112 27
#define RSCMWWLS_VAL_SUBFIELD_A113 28
#define RSCMWWLS_VAL_SUBFIELD_A114 29
#define RSCMWWLS_VAL_SUBFIELD_A115 30
#define RSCMWWLS_VAL_SUBFIELD_A116 31
#define RSCMWWLS_VAL_SUBFIELD_A120 32
#define RSCMWWLS_VAL_SUBFIELD_A128 33
#define RSCMWWLS_VAL_SUBFIELD_A192 34
#define RSCMWWLS_VAL_SUBFIELD_A200 35
#define RSCMWWLS_VAL_SUBFIELD_A208 36
#define RSCMWWLS_VAL_SUBFIELD_A216 37
#define RSCMWWLS_VAL_SUBFIELD_A224 38

#define RSCMWWLS_VAL_RU1  1
#define RSCMWWLS_VAL_RU2  2
#define RSCMWWLS_VAL_RU3  3
#define RSCMWWLS_VAL_RU4  4
#define RSCMWWLS_VAL_RU5  5
#define RSCMWWLS_VAL_RU6  6
#define RSCMWWLS_VAL_RU7  7
#define RSCMWWLS_VAL_RU8  8
#define RSCMWWLS_VAL_RU9  9

#define RSCMWWLS_VAL_USER_MAPPING_OFF  0
#define RSCMWWLS_VAL_USER_MAPPING_USR1 1
#define RSCMWWLS_VAL_USER_MAPPING_DMY1 2
#define RSCMWWLS_VAL_USER_MAPPING_DMY2 3
#define RSCMWWLS_VAL_USER_MAPPING_DMY3 4

#define RSCMWWLS_VAL_FLOW_TYPE_ANNOUNCED   0
#define RSCMWWLS_VAL_FLOW_TYPE_UNANNOUNCED 1

#define RSCMWWLS_VAL_EDCA    0
#define RSCMWWLS_VAL_MU_EDCA 1

#define RSCMWWLS_VAL_AC_BE 0
#define RSCMWWLS_VAL_AC_BK 1
#define RSCMWWLS_VAL_AC_VI 2
#define RSCMWWLS_VAL_AC_VO 3

#define RSCMWWLS_VAL_POWER_UNDERDRIVEN  0
#define RSCMWWLS_VAL_POWER_RANGE        1
#define RSCMWWLS_VAL_POWER_OVERDRIVEN   2

#define RSCMWWLS_VAL_STAT_FRAME_FORMAT_HEMU     0
#define RSCMWWLS_VAL_STAT_FRAME_FORMAT_HESU     1
#define RSCMWWLS_VAL_STAT_FRAME_FORMAT_HETB  2
#define RSCMWWLS_VAL_STAT_FRAME_FORMAT_HT    3
#define RSCMWWLS_VAL_STAT_FRAME_FORMAT_NHT   4
#define RSCMWWLS_VAL_STAT_FRAME_FORMAT_VHT   5

#define RSCMWWLS_VAL_RESERVATION_OFF 0
#define RSCMWWLS_VAL_RESERVATION_ANY 1
#define RSCMWWLS_VAL_RESERVATION_SET 2

#define RSCMWWLS_VAL_CH20_INDEX_CHA1  1
#define RSCMWWLS_VAL_CH20_INDEX_CHA2  2
#define RSCMWWLS_VAL_CH20_INDEX_CHA3  3
#define RSCMWWLS_VAL_CH20_INDEX_CHA4  4

#define RSCMWWLS_VAL_ALLOC_STATE_OFF   0
#define RSCMWWLS_VAL_ALLOC_STATE_USR1  1
#define RSCMWWLS_VAL_ALLOC_STATE_DMY1  2
#define RSCMWWLS_VAL_ALLOC_STATE_DMY2  3
#define RSCMWWLS_VAL_ALLOC_STATE_DMY3  4

/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
ViStatus _VI_FUNC rscmwwls_init(ViRsrc     resourceName,
                                ViBoolean  IDQuery,
                                ViBoolean  resetDevice,
                                ViSession* instrSession);

ViStatus _VI_FUNC rscmwwls_InitWithOptions(ViRsrc     resourceName,
                                           ViBoolean  IDQuery,
                                           ViBoolean  resetDevice,
                                           ViString   optionString,
                                           ViSession* instrSession);

ViStatus _VI_FUNC rscmwwls_ConfigureEndToEnd(ViSession instrSession,
                                             ViInt32   instance,
                                             ViBoolean endToEnd);

ViStatus _VI_FUNC rscmwwls_ConfigureIPRoutesList(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32   routeAddress,
                                                 ViBoolean state,
                                                 ViInt32   IP4Octet1,
                                                 ViInt32   IP4Octet2,
                                                 ViInt32   IP4Octet3,
                                                 ViInt32   IP4Octet4,
                                                 ViInt32   IP4Netmask,
                                                 ViString  IP6Prefix,
                                                 ViInt32   IP6Netmask);

ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalRoutingStandardCell(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   signalingUnit,
                            ViInt32   signalingUnitNumber,
                            ViInt32   RFInputConnector,
                            ViInt32   RFInputConverter,
                            ViInt32   RFOutputConnector,
                            ViInt32   RFOutputConverter);

ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalRoutingMIMO(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   CMWNumber,
                                                        ViInt32   signalingUnit,
                                                        ViInt32   signalingUnitNumber,
                                                        ViInt32   RFInputConnector[],
                                                        ViInt32   RFInputConverter[],
                                                        ViInt32   RFOutputConnector[],
                                                        ViInt32   RFOutputConverter[]);

ViStatus _VI_FUNC rscmwwls_QueryRFSignalRoutingSettings(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32*  scenario,
                                                        ViChar    master[],
                                                        ViInt32*  RXConnector,
                                                        ViInt32*  RXConverter,
                                                        ViInt32*  TXConnector,
                                                        ViInt32*  TXConverter,
                                                        ViInt32*  TXConnector2,
                                                        ViInt32*  TXConverter2,
                                                        ViInt32*  RXConnector2,
                                                        ViInt32*  RXConverter2);

ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalFrequency(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViReal64  frequency);

ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalChannel(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   channel);

ViStatus _VI_FUNC rscmwwls_ConfigureRFFrequencyOffset(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32   frequencyOffset);

ViStatus _VI_FUNC rscmwwls_ConfigureRFNp20Index(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32   np20Index);

ViStatus _VI_FUNC rscmwwls_ConfigureRFNp20Frequency(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViReal64  frequency);

ViStatus _VI_FUNC rscmwwls_ConfigureRFNp20Channel(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViInt32   channel);

ViStatus _VI_FUNC rscmwwls_ConfigureRFOperatingChannelWidth(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   channelBandwidth);

ViStatus _VI_FUNC rscmwwls_QueryRFActiveScenario(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32*  activeScenario);

ViStatus _VI_FUNC rscmwwls_ConfigureRFBand(ViSession instrSession,
                                           ViInt32   instance,
                                           ViInt32   RFBand);

ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalBurstPowerDownlink(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  TXBurstPower);

ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalRoutingStandardCellFading(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   CMWNumber,
                            ViInt32   signalingUnit,
                            ViInt32   signalingUnitNumber,
                            ViInt32   RFInputConnector,
                            ViInt32   RFInputConverter,
                            ViInt32   RFOutputConnector,
                            ViInt32   RFOutputConverter,
                            ViInt32   internalFader);

ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalRoutingMIMO2x2Fading(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   CMWNumber,
                            ViInt32   signalingUnit,
                            ViInt32   signalingUnitNumber,
                            ViInt32   RFInputConnector[],
                            ViInt32   RFInputConverter[],
                            ViInt32   RFOutputConnector[],
                            ViInt32   RFOutputConverter[],
                            ViInt32   internalFader);

ViStatus _VI_FUNC rscmwwls_ConfigureRFTXMIMOMode(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32   TXMIMOMode);

ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalTXPowerRatio(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViReal64  TX2TX1PowerRatio);

ViStatus _VI_FUNC rscmwwls_ConfigureRFRoutingAntennas(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32   antenna,
                                                      ViReal64  nominalPower,
                                                      ViReal64  levelOffset);

ViStatus _VI_FUNC rscmwwls_ConfigureRFRoutingAntennasAttenuation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antenna,
                            ViInt32   path,
                            ViReal64  externalAttenuation);

ViStatus _VI_FUNC rscmwwls_QueryRFRoutingAntennaApproximateBurstPower(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antenna,
                            ViReal64* approximateBurstPower);

ViStatus _VI_FUNC rscmwwls_ConfigureDAU(ViSession instrSession,
                                        ViInt32   instance,
                                        ViBoolean state,
                                        ViInt32   segmentNumber,
                                        ViInt32   nodeID);

ViStatus _VI_FUNC rscmwwls_ConfigureDAUIPv4Address(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViBoolean state,
                                                   ViInt32   octet1,
                                                   ViInt32   octet2,
                                                   ViInt32   octet3,
                                                   ViInt32   octet4);

ViStatus _VI_FUNC rscmwwls_ConfigureMainState(ViSession instrSession,
                                              ViInt32   instance,
                                              ViBoolean enable);

ViStatus _VI_FUNC rscmwwls_QuerySignalingState(ViSession  instrSession,
                                               ViInt32    instance,
                                               ViBoolean* mainState,
                                               ViInt32*   syncState,
                                               ViInt32*   DUT1,
                                               ViInt32*   DUT2,
                                               ViInt32*   DUT3);

ViStatus _VI_FUNC rscmwwls_ConfigureConnect(ViSession instrSession,
                                            ViInt32   instance);

ViStatus _VI_FUNC rscmwwls_ConfigureDUTDisconnection(ViSession instrSession,
                                                     ViInt32   instance);

ViStatus _VI_FUNC rscmwwls_ConfigureReconnect(ViSession instrSession,
                                              ViInt32   instance);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionAssociation(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   station,
                                                          ViInt32   reservation,
                                                          ViString  reserveMACAddress,
                                                          ViBoolean automaticDisassociationState,
                                                          ViInt32   automaticDisassociation,
                                                          ViBoolean allowPreemption,
                                                          ViInt32   stationPriority);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionAMPDUSettings(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   station,
                                                            ViBoolean TXEnable,
                                                            ViBoolean multiTID,
                                                            ViInt32   maxLength);

ViStatus _VI_FUNC rscmwwls_ConfigureOperationMode(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViInt32   operationMode);

ViStatus _VI_FUNC rscmwwls_ConfigureMultiStation(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViBoolean multiStation);

ViStatus _VI_FUNC rscmwwls_ConfigureAPConnectionSettings(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   standard,
                                                         ViInt32   beaconInterval,
                                                         ViString  MACAddress_BSSID,
                                                         ViString  SSID);

ViStatus _VI_FUNC rscmwwls_ConfigureBSSColor(ViSession instrSession,
                                             ViInt32   instance,
                                             ViInt32   BSSColor);

ViStatus _VI_FUNC rscmwwls_ConfigureAssociationIDRange(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   start,
                                                       ViInt32   stop);

ViStatus _VI_FUNC rscmwwls_ConfigureCountryCode(ViSession instrSession,
                                                ViInt32   instance,
                                                ViBoolean enable,
                                                ViString  countryCode,
                                                ViInt32   firstChannel,
                                                ViInt32   numberOfChannels,
                                                ViInt32   maxTXPower);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionManagementFrameRateControl(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean userDefined,
                            ViInt32   frameFormat,
                            ViInt32   rate);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataFrame(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViBoolean userDefined,
                                                        ViInt32   frameFormat,
                                                        ViInt32   channelBandwidth,
                                                        ViInt32   rate,
                                                        ViInt32   guardInterval);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataFrameExtended(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean userDefined,
                            ViInt32   frameFormat,
                            ViInt32   channelBandwidth,
                            ViInt32   rate,
                            ViInt32   guardInterval,
                            ViInt32   LTFType,
                            ViInt32   PEDuration,
                            ViInt32   codingType,
                            ViInt32   streams);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataHEMUFrameRUAllocationSubfield(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channel,
                            ViInt32   subfield);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataHEMUFrameRUAllocation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channel,
                            ViInt32   resourceUnit,
                            ViInt32   userMapping);

ViStatus _VI_FUNC rscmwwls_QueryConnectionDataHEMUFrameRUAllocation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channel,
                            ViInt32   arraySize,
                            ViInt32   userMapping[],
                            ViInt32   size[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataHEMUFrameUser(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   user,
                            ViInt32   MCS,
                            ViInt32   codingType,
                            ViInt32   streams);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataHEMUFrameUserAllocation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   user,
                            ViInt32   channel,
                            ViInt32   resourceUnit);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataHEMUFrameDummyUserMCS(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   user,
                            ViInt32   MCS);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataHEMUFrameResourceUnitAllocation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   CH20Index,
                            ViInt32   resourceUnitIndex,
                            ViInt32   allocState);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDTIMPeriod(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   DTIMPeriod);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionSecurity(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   mode,
                                                       ViInt32   encryptionType,
                                                       ViString  passphrase);

ViStatus _VI_FUNC rscmwwls_ConfigureSecurityMode(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32   securityType,
                                                 ViString  lastPassphraseCharacter);

ViStatus _VI_FUNC rscmwwls_ConfigureSecurityProtectionManagmentFrames(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   protectionManagmentFrames);

ViStatus _VI_FUNC rscmwwls_ConfigureSecuritySAEAuthentication(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   SAEAuthentication);

ViStatus _VI_FUNC rscmwwls_ConfigureSecurityGroupTransform(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   groupTransform);

ViStatus _VI_FUNC rscmwwls_ConfigureSecurityPrivateKey(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   keyMode,
                                                       ViString  privateSecurityKey);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionSecurityRadiusServerMode(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   mode);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionSecurityRadiusServer(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViString  IPAddress,
                            ViInt32   portNumber,
                            ViString  sharedKey);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionSecurityEAPSIMRadiusServer(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   tones,
                            ViString  rand,
                            ViString  SRES,
                            ViString  KC);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionSecurityEAPAKARadiusServer(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViString  ki,
                            ViString  OPC,
                            ViString  rand,
                            ViInt32   algorithm);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionIPVersionSupport(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   IPVersionSupport);

ViStatus _VI_FUNC rscmwwls_ConfigureHTSmoothing(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32   HTSmoothing);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionMode(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   connectionMode);

ViStatus _VI_FUNC rscmwwls_ConfigureSSIDConnection(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   SSIDConnection);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHotspotBasic(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   accessNetworkType,
                                                           ViInt32   venueGroup,
                                                           ViInt32   venueType,
                                                           ViString  HESSID,
                                                           ViString  venueName,
                                                           ViString  MCC,
                                                           ViString  MNC,
                                                           ViString  domainName,
                                                           ViString  operatorFriendlyName);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHotspotSuplement(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   downlinkSpeed,
                            ViInt32   uplinkSpeed,
                            ViInt32   IPV6AddressField,
                            ViInt32   IPV4AddressField,
                            ViString  realmName,
                            ViInt32   EAPType,
                            ViBoolean internetAccess,
                            ViInt32   networkAuthentication);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHotspotNumberOfDigit(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   numberOfDigits);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHotspotDomainName(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   listItem,
                            ViBoolean state,
                            ViString  domainName);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHotspotPLMN(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   listItem,
                                                          ViBoolean state,
                                                          ViInt32   MCC,
                                                          ViInt32   MNC,
                                                          ViInt32   MNCLength);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHotspotRealmName(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   listItem,
                            ViBoolean state,
                            ViString  realmName,
                            ViBoolean SIM,
                            ViBoolean TLS,
                            ViBoolean TTLS,
                            ViBoolean AKA,
                            ViBoolean AKAPrime);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHotspotBSSLoadElement(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stationCount,
                            ViInt32   channelUtilization,
                            ViInt32   admissionCapacity);

ViStatus _VI_FUNC rscmwwls_ConfigureAMPDU(ViSession instrSession,
                                          ViInt32   instance,
                                          ViBoolean enable,
                                          ViBoolean multiTID,
                                          ViInt32   maxLength);

ViStatus _VI_FUNC rscmwwls_ConfigureBroadcastTWTState(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViBoolean enabled);

ViStatus _VI_FUNC rscmwwls_ConfigureBroadcastTWTFlowID(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   flowID,
                                                       ViBoolean enabled,
                                                       ViInt32   flowType,
                                                       ViReal64  startTime,
                                                       ViBoolean triggerEnabled);

ViStatus _VI_FUNC rscmwwls_ConfigureBroadcastTWTMinimumWakeDuration(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   flowID,
                            ViReal64  minimumWakeDuration);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHEMACBSRSupport(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean BSRSupport);

ViStatus _VI_FUNC rscmwwls_ConfigureConnectionSupportDSSS(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViBoolean supportDSSS);

ViStatus _VI_FUNC rscmwwls_ConfigureEDCA(ViSession instrSession,
                                         ViInt32   instance,
                                         ViInt32   parameterSet,
                                         ViInt32   accessCategory,
                                         ViInt32   AIFSN,
                                         ViInt32   minContentionWindow,
                                         ViInt32   maxContentionWindow,
                                         ViInt32   TXOpportunityLimit);

ViStatus _VI_FUNC rscmwwls_ConfigureQOSTID(ViSession instrSession,
                                           ViInt32   instance,
                                           ViInt32   e2EData,
                                           ViInt32   PER,
                                           ViInt32   prioritizationMode);

ViStatus _VI_FUNC rscmwwls_ConfigureQOSTIDBARMethod(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   BARMethod);

ViStatus _VI_FUNC rscmwwls_ConfigureQOSTIDBlockAck(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViBoolean enabled[]);

ViStatus _VI_FUNC rscmwwls_ConfigureTriggerFrameCommonInfo(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   triggerType,
                                                           ViInt32   numberOfSymbols,
                                                           ViBoolean CSRequired,
                                                           ViInt32   bandwidth,
                                                           ViInt32   GILTF,
                                                           ViInt32   MUMIMOLTF,
                                                           ViBoolean LDCPExtraSymbol);

ViStatus _VI_FUNC rscmwwls_QueryTriggerFrameAPTxPower(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32*  index,
                                                      ViReal64* value);

ViStatus _VI_FUNC rscmwwls_ConfigureTriggerFrameUserInfo(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   RUAllocation,
                                                         ViInt32   codingType,
                                                         ViInt32   MCS,
                                                         ViBoolean DCM);

ViStatus _VI_FUNC rscmwwls_QueryTriggerFrameSpatialStream(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32*  startingSpatialStream,
                                                          ViInt32*  numberOfSpatialStreams);

ViStatus _VI_FUNC rscmwwls_ConfigureTriggerFrameTargetRSSI(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   mode,
                                                           ViReal64  control);

ViStatus _VI_FUNC rscmwwls_QueryTriggerFrameTargetRSSI(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32*  index,
                                                       ViReal64* value);

ViStatus _VI_FUNC rscmwwls_TriggerFrameTransmissionSingleShot(
                            ViSession instrSession,
                            ViInt32   instance);

ViStatus _VI_FUNC rscmwwls_ConfigureTriggerFrameTransmissionPeriodical(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean enabled,
                            ViReal64  periodicalInterval);

ViStatus _VI_FUNC rscmwwls_ConfigureUserDefinedSupportedRatesState(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   state);

ViStatus _VI_FUNC rscmwwls_ConfigureUserDefinedDSSSSupportedRates(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   state[]);

ViStatus _VI_FUNC rscmwwls_ConfigureUserDefinedOFDMSupportedRates(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   state[]);

ViStatus _VI_FUNC rscmwwls_ConfigureUserDefinedOFDMSupportedModulationSchemes(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   state[]);

ViStatus _VI_FUNC rscmwwls_ConfigureUserDefinedVHTSupportedRates(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   MCS);

ViStatus _VI_FUNC rscmwwls_ConfigureNDPSoundingStation(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   station);

ViStatus _VI_FUNC rscmwwls_ConfigureNDPSounding(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32   feedbackMethod,
                                                ViInt32   bandwidth,
                                                ViInt32   spatialStreams,
                                                ViInt32   GILTF,
                                                ViInt32   reportType,
                                                ViInt32   RUStartIndex,
                                                ViInt32   RUEndIndex,
                                                ViInt32   codebookSize,
                                                ViInt32   numberOfColumns,
                                                ViInt32   subcarrierGrouping);

ViStatus _VI_FUNC rscmwwls_NDPSoundingTransmissionSingleShot(ViSession instrSession,
                                                             ViInt32   instance);

ViStatus _VI_FUNC rscmwwls_ConfigureNDPSoundingTransmission(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViBoolean transmissionState,
                                                            ViReal64  interval);

ViStatus _VI_FUNC rscmwwls_CleanEventLog(ViSession instrSession,
                                         ViInt32   instance);

ViStatus _VI_FUNC rscmwwls_ConfigureFadingModuleAWGN(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViBoolean enabled,
                                                     ViReal64  bandwidthRatio,
                                                     ViReal64  signalNoiseRatio);

ViStatus _VI_FUNC rscmwwls_ConfigureFadingSimulator(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViBoolean enabled,
                                                    ViInt32   profile);

ViStatus _VI_FUNC rscmwwls_QueryFadingSimulatorInsertionLoss(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViReal64* insertionLoss);

ViStatus _VI_FUNC rscmwwls_ConfigureTriggerSettings(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   triggerType,
                                                    ViInt32   triggerSlope,
                                                    ViInt32   pulseLength,
                                                    ViReal64  pulseLengthValue);

ViStatus _VI_FUNC rscmwwls_ConfigureTriggerMode(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32   triggerMode);

ViStatus _VI_FUNC rscmwwls_ConfigureRXTriggerBandwidth(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   bandwidth);

ViStatus _VI_FUNC rscmwwls_ConfigureRXTriggerRate(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViInt32   rate);

ViStatus _VI_FUNC rscmwwls_ConfigureRXTriggerDelayType(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   delayType);

ViStatus _VI_FUNC rscmwwls_ConfigureRXTriggerRateRestriction(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViBoolean rateRestriction);

ViStatus _VI_FUNC rscmwwls_ConfigureRXTriggerSpatialStreams(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   spatialStreams);

ViStatus _VI_FUNC rscmwwls_ConfigureTriggerMinLength(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32   mode,
                                                     ViInt32   length);

ViStatus _VI_FUNC rscmwwls_ConfigureTriggerOFDMMinLength(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   mode,
                                                         ViInt32   length);

ViStatus _VI_FUNC rscmwwls_ConfigureTriggerDSSMinLength(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   mode,
                                                        ViInt32   length);

ViStatus _VI_FUNC rscmwwls_ConfigurePacketGenerator(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   index,
                                                    ViBoolean state,
                                                    ViInt32   interval,
                                                    ViInt32   payloadSize,
                                                    ViInt32   payloadType);

ViStatus _VI_FUNC rscmwwls_ConfigurePacketGeneratorIPVersion(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   index,
                                                             ViInt32   IPVersion);

ViStatus _VI_FUNC rscmwwls_ConfigurePacketGeneratorProtocol(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   index,
                                                            ViInt32   protocol,
                                                            ViInt32   UDPSourcePort,
                                                            ViInt32   UDPDestinationPort);

ViStatus _VI_FUNC rscmwwls_ConfigurePacketGeneratorDestination(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   index,
                            ViInt32   destination);

ViStatus _VI_FUNC rscmwwls_QuerySecondState(ViSession instrSession,
                                            ViInt32   instance,
                                            ViInt32*  secondState);

ViStatus _VI_FUNC rscmwwls_QueryThirdState(ViSession instrSession,
                                           ViInt32   instance,
                                           ViInt32*  thirdState);

ViStatus _VI_FUNC rscmwwls_QueryPacketSwitchedState(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32*  connectionStatus);

ViStatus _VI_FUNC rscmwwls_QueryEAPConnectionState(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   bufferSize,
                                                   ViChar    state[],
                                                   ViChar    type[]);

ViStatus _VI_FUNC rscmwwls_QueryStationSSID(ViSession instrSession,
                                            ViInt32   instance,
                                            ViInt32   bufferSize,
                                            ViChar    stationSSID[]);

ViStatus _VI_FUNC rscmwwls_QueryRXPowerIndicator(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32   antenna,
                                                 ViReal64* powerValue,
                                                 ViInt32*  powerIndicator);

ViStatus _VI_FUNC rscmwwls_QueryUECapabilityMACAddress(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   bufferSize,
                                                       ViChar    MACAddress[]);

ViStatus _VI_FUNC rscmwwls_QueryUECapabilityMACVersion(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32*  MACVersion);

ViStatus _VI_FUNC rscmwwls_QueryUECapabilityAssignedAddress(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   IPVersion,
                                                            ViInt32   bufferSize,
                                                            ViChar    assignedIPAddress[]);

ViStatus _VI_FUNC rscmwwls_QueryUECapabilityRXBurstPower(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViReal64* RXBurstPower);

ViStatus _VI_FUNC rscmwwls_QueryUECapabilityDataRate(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32*  frameFormat,
                                                     ViInt32*  rate,
                                                     ViInt32*  channelBandwidth,
                                                     ViInt32*  spatialStreams);

ViStatus _VI_FUNC rscmwwls_QueryUECapabilityBufferedData(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32*  total,
                                                         ViInt32*  bufferedDataTID,
                                                         ViInt32*  TIDx,
                                                         ViInt32*  bufferedDataAC,
                                                         ViInt32*  ACx);

ViStatus _VI_FUNC rscmwwls_QueryUEHECapabilities(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32*  deviceClass,
                                                 ViInt32*  dynamicFragmentation,
                                                 ViInt32*  aBSR,
                                                 ViInt32*  broadcastTWT,
                                                 ViInt32*  OFDMARandomAccess);

ViStatus _VI_FUNC rscmwwls_ConfigureIPv4Settings(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViString  IPAddressStack,
                                                 ViString  IPAddressDestination,
                                                 ViString  subnetMask,
                                                 ViString  defaultGatway,
                                                 ViString  DNS,
                                                 ViBoolean DHCP);

ViStatus _VI_FUNC rscmwwls_ConfigureIPv4CMWIPAddress(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViString  CMWIPAddress);

ViStatus _VI_FUNC rscmwwls_ConfigureIPv4StationIPAddress(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViString  stationIPAddress);

ViStatus _VI_FUNC rscmwwls_ConfigureIPv6Settings(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViString  prefix);

ViStatus _VI_FUNC rscmwwls_QueryDUTUEMAC(ViSession instrSession,
                                         ViInt32   instance,
                                         ViInt32   bufferSize,
                                         ViChar    MACAddress[]);

ViStatus _VI_FUNC rscmwwls_QueryDUTUEIPAddress(ViSession instrSession,
                                               ViInt32   instance,
                                               ViInt32   IPVersion,
                                               ViInt32   bufferSize,
                                               ViChar    IPAddress[]);

ViStatus _VI_FUNC rscmwwls_QueryDUTUECMWIPAddress(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViInt32   IPVersion,
                                                  ViInt32   bufferSize,
                                                  ViChar    CMWIPAddress[]);

ViStatus _VI_FUNC rscmwwls_QueryHETBUPHInfo(ViSession  instrSession,
                                            ViInt32    instance,
                                            ViReal64*  burstPower,
                                            ViInt32*   UPH,
                                            ViBoolean* minTXPowerFlag);

ViStatus _VI_FUNC rscmwwls_QueryHETBUECapability(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32*  deviceClass,
                                                 ViInt32*  dynamicFragmentation,
                                                 ViInt32*  ABSR,
                                                 ViInt32*  broadcastTWT,
                                                 ViInt32*  OFDMARandomAccess);

ViStatus _VI_FUNC rscmwwls_QueryEventLog(ViSession instrSession,
                                         ViInt32   instance,
                                         ViInt32   bufferSize,
                                         ViChar    entries[]);

ViStatus _VI_FUNC rscmwwls_ConfigureMessageMonitoring(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViBoolean addWLANSignalingToLogging,
                                                      ViInt32   loggingPCIPv4Address);

ViStatus _VI_FUNC rscmwwls_QueryMessageMonitoringLoggingPCIPv4Address(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32*  addressPoolIndex,
                            ViInt32   bufferSize,
                            ViChar    IPAddress[]);

ViStatus _VI_FUNC rscmwwls_QueryRXTriggerFrames(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32*  totalTriggerFrames,
                                                ViInt32*  stationTriggerFrames);

ViStatus _VI_FUNC rscmwwls_ResetStatistics(ViSession instrSession,
                                           ViInt32   instance);

ViStatus _VI_FUNC rscmwwls_ConfigureStatisticsSettings(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViReal64  reportingInterval,
                                                       ViInt32   timeSpan);

ViStatus _VI_FUNC rscmwwls_QueryStatisticsRXTrafficData(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   frameFormat,
                                                        ViInt32*  dataRate,
                                                        ViInt32*  bandwidth,
                                                        ViInt32*  numberOfSpatialStreams,
                                                        ViInt32*  framesCurrent,
                                                        ViInt32*  framesTotal,
                                                        ViReal64* bytesCurrent,
                                                        ViReal64* bytesTotal,
                                                        ViReal64* mbpsCurrent,
                                                        ViReal64* mbpsTotal,
                                                        ViReal64* powerCurrent,
                                                        ViReal64* powerTotal);

ViStatus _VI_FUNC rscmwwls_ConfigurePERAcknowledgementType(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   ackType);

ViStatus _VI_FUNC rscmwwls_ConfigurePERDataPattern(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   dataPattern);

ViStatus _VI_FUNC rscmwwls_ConfigurePERPacketSettings(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32   numberOfPackets,
                                                      ViInt32   dataInterval,
                                                      ViInt32   payloadSize,
                                                      ViReal64  PERLimit);

ViStatus _VI_FUNC rscmwwls_ConfigurePERTrafficBurst(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   frameFormat,
                                                    ViInt32   channelBandwidth,
                                                    ViInt32   modulationCodingRate,
                                                    ViInt32   guardInterval);

ViStatus _VI_FUNC rscmwwls_ConfigurePERTrafficBurstExtended(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   frameFormat,
                                                            ViInt32   channelBandwidth,
                                                            ViInt32   modulationCodingRate,
                                                            ViInt32   guardInterval,
                                                            ViInt32   LTFType,
                                                            ViInt32   PEDuration,
                                                            ViInt32   codingType);

ViStatus _VI_FUNC rscmwwls_ConfigurePERDestinationStation(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   destinationStation);

ViStatus _VI_FUNC rscmwwls_ConfigurePERLinkToSIGFrameSettings(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean linkToSIGFrame);

ViStatus _VI_FUNC rscmwwls_ConfigurePERDataHEMUFrameRUAllocationSubfield(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channel,
                            ViInt32   subfield);

ViStatus _VI_FUNC rscmwwls_ConfigurePERDataHEMUFrameRUAllocation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channel,
                            ViInt32   resourceUnit,
                            ViInt32   userMapping);

ViStatus _VI_FUNC rscmwwls_QueryPERDataHEMUFrameRUAllocation(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   channel,
                                                             ViInt32   arraySize,
                                                             ViInt32   userMapping[],
                                                             ViInt32   size[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwls_ConfigurePERDataHEMUFrameUser(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   user,
                                                         ViInt32   MCS,
                                                         ViInt32   codingType);

ViStatus _VI_FUNC rscmwwls_ConfigurePERDataHEMUFrameUserAllocation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   user,
                            ViInt32   channel,
                            ViInt32   resourceUnit);

ViStatus _VI_FUNC rscmwwls_ConfigurePERDataHEMUFrameUserStreams(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   user,
                            ViInt32   streams);

ViStatus _VI_FUNC rscmwwls_ConfigurePERDataHEMUFrameDummyUserMCS(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   user,
                            ViInt32   MCS);

ViStatus _VI_FUNC rscmwwls_PERMeasurementInit(ViSession instrSession,
                                              ViInt32   instance);

ViStatus _VI_FUNC rscmwwls_PERMeasurementAbort(ViSession instrSession,
                                               ViInt32   instance);

ViStatus _VI_FUNC rscmwwls_PERMeasurementStop(ViSession instrSession,
                                              ViInt32   instance);

ViStatus _VI_FUNC rscmwwls_QueryPERMeasurementStatus(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32*  mainState,
                                                     ViInt32*  syncState,
                                                     ViInt32*  resourcesState);

ViStatus _VI_FUNC rscmwwls_ReadPERResults(ViSession instrSession,
                                          ViInt32   instance,
                                          ViInt32*  reliability,
                                          ViReal64* PER,
                                          ViInt32*  packets,
                                          ViInt32*  packetsLost,
                                          ViReal64* RXBurstPower);

ViStatus _VI_FUNC rscmwwls_FetchPERResults(ViSession instrSession,
                                           ViInt32   instance,
                                           ViInt32*  reliability,
                                           ViReal64* PER,
                                           ViInt32*  packets,
                                           ViInt32*  packetsLost,
                                           ViReal64* RXBurstPower);

ViStatus _VI_FUNC rscmwwls_QueryPERLastACKRate(ViSession instrSession,
                                               ViInt32   instance,
                                               ViInt32*  reliability,
                                               ViInt32*  lastACKRate);

ViStatus _VI_FUNC rscmwwls_ConfigureHETBNumberOfFrames(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   HETBNumberOfFrames);

ViStatus _VI_FUNC rscmwwls_HETBMeasurementInitiate(ViSession instrSession,
                                                   ViInt32   instance);

ViStatus _VI_FUNC rscmwwls_HETBMeasurementAbort(ViSession instrSession,
                                                ViInt32   instance);

ViStatus _VI_FUNC rscmwwls_HETBMeasurementStop(ViSession instrSession,
                                               ViInt32   instance);

ViStatus _VI_FUNC rscmwwls_QueryHETBMeasurementState(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32*  measurementState);

ViStatus _VI_FUNC rscmwwls_QueryHETBMeasurementULPowerHeadroom(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViReal64  burstPower[],
                            ViInt32   UPH[],
                            ViBoolean minTXPowerFlag[],
                            ViReal64  LST[],
                            ViInt32*  numberOfResults);

ViStatus _VI_FUNC rscmwwls_SetAttributeViInt32(ViSession instrSession,
                                               ViString  repeatedCapabilityName,
                                               ViAttr    attributeId,
                                               ViInt32   attributeValue);

ViStatus _VI_FUNC rscmwwls_SetAttributeViReal64(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViReal64  attributeValue);

ViStatus _VI_FUNC rscmwwls_SetAttributeViString(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViString  attributeValue);

ViStatus _VI_FUNC rscmwwls_SetAttributeViBoolean(ViSession instrSession,
                                                 ViString  repeatedCapabilityName,
                                                 ViAttr    attributeId,
                                                 ViBoolean attributeValue);

ViStatus _VI_FUNC rscmwwls_GetAttributeRepCapName(ViSession instrSession,
                                                  ViAttr    attributeId,
                                                  ViString  repCapNameID,
                                                  ViInt32   index,
                                                  ViInt32   bufferSize,
                                                  ViChar    repCapName[]);

ViStatus _VI_FUNC rscmwwls_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                             ViAttr    attributeID,
                                                             ViInt32   bufferSize,
                                                             ViChar    repeatedCapabilityIds[]);

ViStatus _VI_FUNC rscmwwls_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViAttr    attributeID,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdNames[]);

ViStatus _VI_FUNC rscmwwls_GetAttributeViInt32(ViSession instrSession,
                                               ViString  repeatedCapabilityName,
                                               ViAttr    attributeId,
                                               ViInt32*  attributeValue);

ViStatus _VI_FUNC rscmwwls_GetAttributeViReal64(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViReal64* attributeValue);

ViStatus _VI_FUNC rscmwwls_GetAttributeViString(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViInt32   bufferSize,
                                                ViChar    attributeValue[]);

ViStatus _VI_FUNC rscmwwls_GetAttributeViBoolean(ViSession  instrSession,
                                                 ViString   repeatedCapabilityName,
                                                 ViAttr     attributeId,
                                                 ViBoolean* attributeValue);

ViStatus _VI_FUNC rscmwwls_reset(ViSession instrSession);

ViStatus _VI_FUNC rscmwwls_self_test(ViSession instrSession,
                                     ViInt16*  selfTestResult,
                                     ViChar    selfTestMessage[]);

ViStatus _VI_FUNC rscmwwls_SelfTestResults(ViSession instrSession,
                                           ViInt32   bufferSize,
                                           ViChar    results[]);

ViStatus _VI_FUNC rscmwwls_revision_query(ViSession instrSession,
                                          ViChar    instrumentDriverRevision[],
                                          ViChar    firmwareRevision[]);

ViStatus _VI_FUNC rscmwwls_SystemVersion(ViSession instrSession,
                                         ViInt32   length,
                                         ViChar    systemVersion[]);

ViStatus _VI_FUNC rscmwwls_error_query(ViSession instrSession,
                                       ViInt32*  errorCode,
                                       ViChar    errorMessage[]);

ViStatus _VI_FUNC rscmwwls_ErrorList(ViSession instrSession,
                                     ViInt32   bufferSize,
                                     ViChar    errors[]);

ViStatus _VI_FUNC rscmwwls_error_message(ViSession instrSession,
                                         ViStatus  errorCode,
                                         ViChar    errorMessage[]);

ViStatus _VI_FUNC rscmwwls_ReliabilityIndicator(ViSession instrSession,
                                                ViInt32   reliabilityCode,
                                                ViChar    reliabilityMessage[]);

ViStatus _VI_FUNC rscmwwls_Preset(ViSession instrSession);

ViStatus _VI_FUNC rscmwwls_ConfigureErrorChecking(ViSession instrSession,
                                                  ViBoolean optionChecking,
                                                  ViBoolean rangeChecking,
                                                  ViBoolean statusChecking);

ViStatus _VI_FUNC rscmwwls_IDQueryResponse(ViSession instrSession,
                                           ViInt32   bufferSize,
                                           ViChar    IDQueryResponse[],
                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwls_QueryOPC(ViSession instrSession,
                                    ViInt32*  OPC);

ViStatus _VI_FUNC rscmwwls_ProcessAllPreviousCommands(ViSession instrSession);

ViStatus _VI_FUNC rscmwwls_ClearStatus(ViSession instrSession);

ViStatus _VI_FUNC rscmwwls_SetOPCTimeout(ViSession instrSession,
                                         ViUInt32  OPCTimeout);

ViStatus _VI_FUNC rscmwwls_GetOPCTimeout(ViSession instrSession,
                                         ViUInt32* OPCTimeout);

ViStatus _VI_FUNC rscmwwls_SetVISATimeout(ViSession instrSession,
                                          ViUInt32  VISATimeout);

ViStatus _VI_FUNC rscmwwls_GetVISATimeout(ViSession instrSession,
                                          ViUInt32* VISATimeout);

ViStatus _VI_FUNC rscmwwls_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                       ViBoolean autoSystErrQuery);

ViStatus _VI_FUNC rscmwwls_ConfigureMultiThreadLocking(ViSession instrSession,
                                                       ViBoolean multiThreadLocking);

ViStatus _VI_FUNC rscmwwls_GetError(ViSession instrSession,
                                    ViStatus* code,
                                    ViInt32   bufferSize,
                                    ViChar    description[]);

ViStatus _VI_FUNC rscmwwls_ClearError(ViSession instrSession);

ViStatus _VI_FUNC rscmwwls_ReadToFileFromInstrument(ViSession instrSession,
                                                    ViString  source,
                                                    ViString  destination);

ViStatus _VI_FUNC rscmwwls_WriteFromFileToInstrument(ViSession instrSession,
                                                     ViString  source,
                                                     ViString  destination);

ViStatus _VI_FUNC rscmwwls_WriteInstrData(ViSession instrSession,
                                          ViString  writeBuffer);

ViStatus _VI_FUNC rscmwwls_ReadInstrData(ViSession instrSession,
                                         ViInt32   numberOfBytesToRead,
                                         ViChar    readBuffer[],
                                         ViUInt32* numBytesRead);

ViStatus _VI_FUNC rscmwwls_QueryViBoolean(ViSession  instrSession,
                                          ViString   command,
                                          ViBoolean* value);

ViStatus _VI_FUNC rscmwwls_QueryViInt32(ViSession instrSession,
                                        ViString  command,
                                        ViInt32*  value);

ViStatus _VI_FUNC rscmwwls_QueryViReal64(ViSession instrSession,
                                         ViString  command,
                                         ViReal64* value);

ViStatus _VI_FUNC rscmwwls_QueryViString(ViSession instrSession,
                                         ViString  command,
                                         ViInt32   bufferSize,
                                         ViChar    value[]);

ViStatus _VI_FUNC rscmwwls_close(ViSession instrSession);

/****************************************************************************/

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSCMWWLS_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSCMWWLS_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSCMWWLS_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSCMWWLS_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSCMWWLS_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)
#define RSCMWWLS_ERROR_RELIABILITY_INDICATOR  (RS_SPECIFIC_ERROR_BASE + 0x0004L)

#define RSCMWWLS_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSCMWWLS_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSCMWWLS_ERRMSG_INCORRECT_STATE     "Instrument in incorrect state"
#define RSCMWWLS_ERRMSG_INCORRECT_RESPONSE      "Response incorrect; report problem to R&S support!"
#define RSCMWWLS_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"
#define RSCMWWLS_ERRMSG_RELIABILITY_INDICATOR "Reliability Indicator error"

#define RSCMWWLS_ERROR_CODES_AND_MSGS \
    {RSCMWWLS_WARN_MEASURE_UNCALIBRATED,  RSCMWWLS_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSCMWWLS_WARN_OVER_RANGE,            RSCMWWLS_WARNMSG_OVER_RANGE},\
    {RSCMWWLS_ERROR_INCORRECT_STATE ,   RSCMWWLS_ERRMSG_INCORRECT_STATE },\
    {RSCMWWLS_ERROR_INCORRECT_RESPONSE,     RSCMWWLS_ERRMSG_INCORRECT_RESPONSE},\
    {RSCMWWLS_ERROR_MAX_TIME_EXCEEDED,    RSCMWWLS_ERRMSG_MAX_TIME_EXCEEDED},\
    {RSCMWWLS_ERROR_RELIABILITY_INDICATOR, RSCMWWLS_ERRMSG_RELIABILITY_INDICATOR}

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSCMWWLS_HEADER */