/*****************************************************************************
 *------------------------ Utility  -----------------------------------------*
 *****************************************************************************/
#include "rscmwwls.h"

#pragma warning( disable : 4152 )

/*****************************************************************************
 *- Callback Declarations ---------------------------------------------------*
 *****************************************************************************/
/*****************************************************************************
 * Function: rscmwwls_InitAttributes
 * Purpose:  This function inits attributes to the desired values if needed.
 *****************************************************************************/
ViStatus rscmwwls_InitAttributes(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    // - Driver Capabilities -
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_SUPPORTED_INSTRUMENT_MODELS, 0, RSCMWWLS_SUPPORTED_INSTRUMENT_MODELS));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_GROUP_CAPABILITIES, 0, RSCMWWLS_GROUP_CAPABILITIES));
    checkErr(RsCore_SetAttributeViString(instrSession, "", RS_ATTR_FUNCTION_CAPABILITIES, 0, RSCMWWLS_FUNCTION_CAPABILITIES));

    // - Version Info -
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MAJOR_VERSION, 0, RSCMWWLS_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_VERSION, 0, RSCMWWLS_MINOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_SPECIFIC_DRIVER_MINOR_MINOR_VERSION, 0, RSCMWWLS_MINOR_MINOR_VERSION));

    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_MAJOR_VERSION, 0, RSCMWWLS_CLASS_SPEC_MAJOR_VERSION));
    checkErr(RsCore_SetAttributeViInt32(instrSession, "", RS_ATTR_CLASS_DRIVER_MINOR_VERSION, 0, RSCMWWLS_CLASS_SPEC_MINOR_VERSION));

    checkErr(RsCore_SetSpecificDriverRevision(instrSession, RS_ATTR_SPECIFIC_DRIVER_REVISION));

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwwls_DefaultInstrSetup
 * Purpose:  This function sends a default setup to the instrument. The
 *           rscmwwls_reset function calls this function. The
 *           rscmwwls_RsInit function calls this function when the
 *           user passes VI_FALSE for the reset parameter. This function is
 *           useful for configuring settings that other instrument driver
 *           functions require.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rscmwwls_DefaultInstrSetup(ViSession instrSession)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));

    // Set all the attributes to the default state. Do not update inherent attributes!
    checkErr(RsCore_ApplyAttributeDefaults(instrSession, VI_FALSE));

    // Init attributes
    checkErr(rscmwwls_InitAttributes(instrSession));

    rsSession->fastSweepInstrument = 0;
    checkErr(RsCore_ResetRegistersEseSre(instrSession));
    checkErr(RsCore_Write(instrSession, ":FORM:BASE ASC,10"));
    checkErr(RsCore_Write(instrSession, ":SYST:DISP:UPD OFF"));
    checkErr(RsCore_QueryViInt32(instrSession, "*OPC?", NULL));

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwwls_CheckStatus
 * Purpose:  This function checks the status of the instrument to detect
 *           whether the instrument has encountered an error. This function
 *           is called at the end of most exported driver functions. If the
 *           instrument reports an error, this function returns
 *           RS_ERROR_INSTRUMENT_SPECIFIC. The user can set the
 *           rscmwwls_ATTR_QUERY_INSTRUMENT_STATUS attribute to VI_FALSE to disable this
 *           check and increase execution speed.
 *
 *           Note:  Call this function only when the session is locked.
 *****************************************************************************/
ViStatus rscmwwls_CheckStatus(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    if (RsCore_QueryInstrStatus(instrSession) && !RsCore_Simulating(instrSession))
    {
        checkErr(RsCore_CheckStatus(instrSession, VI_SUCCESS));
    }

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwls_GetIndexOfToken
 * Purpose:  This function breaks a string into tokens, which are separated
 *           by the specified delimiter and then returns index of selected
 *           token or error code if there is no token found. If passed NUL
 *           pointer as a token or delimiter and string length of token or
 *           delimiter is zero, it returns zero as index.
 *****************************************************************************/
ViStatus rscmwwls_GetIndexOfToken(ViConstString stringToFind,
                                  ViString table[],
                                  ViInt32* index)
{
    ViStatus error = VI_SUCCESS;

    if (strcmp(stringToFind, "NAV") == 0)
    {
        *index = RSCMWWLS_VAL_NAV;
        return error;
    }

    *index = RsCore_FindStringIndex(table, stringToFind);
    if (*index == -1)
        error = RS_ERROR_UNEXPECTED_RESPONSE;

    return error;
}

/*****************************************************************************
 * Function: rscmwwls_instanceRepCap
 * Purpose:  This function checks instance repeated capability and
 *           creates proper string.
 *****************************************************************************/
ViStatus rscmwwls_instanceRepCap(ViSession instrSession,
                                 ViInt32   instance,
                                 ViChar    repCap[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld", instance);

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwwls_QueryMeasStatus
 * Purpose:  This function queries measurement status
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_QueryMeasStatus(ViSession instrSession,
                                           ViString  cmd,
                                           ViInt32*  mainState,
                                           ViInt32*  syncState,
                                           ViInt32*  resourcesState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   response[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViString mainStateArr[] = {"OFF", "RDY", "RUN", NULL};
    ViString syncStateArr[] = {"PEND", "ADJ", "INV", NULL};
    ViString resStateArr[] = {"QUE", "ACT", "INV", NULL};

    checkErr(RsCore_QueryViString(instrSession, cmd, response));

    p2buf = strtok(response, ",\n");
    if (p2buf == NULL)
        return RSCMWWLS_ERROR_INCORRECT_STATE;
    *mainState = RsCore_FindStringIndex(mainStateArr, p2buf);
    if (*mainState < 0)
        return RSCMWWLS_ERROR_INCORRECT_STATE;

    p2buf = strtok(NULL, ",\n");
    if (p2buf == NULL)
        return RSCMWWLS_ERROR_INCORRECT_STATE;
    *syncState = RsCore_FindStringIndex(syncStateArr, p2buf);
    if (*syncState < 0)
        return RSCMWWLS_ERROR_INCORRECT_STATE;

    p2buf = strtok(NULL, ",\n");
    if (p2buf == NULL)
        return RSCMWWLS_ERROR_INCORRECT_STATE;
    *resourcesState = RsCore_FindStringIndex(resStateArr, p2buf);
    if (*resourcesState < 0)
        return RSCMWWLS_ERROR_INCORRECT_STATE;

Error:
    return error;
}

ViStatus rscmwwls_utility_error_message(ViSession instrSession,
                                        ViStatus  errorCode,
                                        ViChar    errorMessage[])
{  
   ViStatus error = VI_SUCCESS;

   static RsCoreStringValueTable errorTable =
   {
       RSCMWWLS_ERROR_CODES_AND_MSGS,
       {0, NULL}
   };

   // all VISA and RS error codes are handled as well as codes in the table
   viCheckParm(RsCore_InvalidNullPointer(instrSession, errorMessage), 3, "Null address for Error Message");

   checkErr(RsCore_GetSpecificDriverStatusDesc(instrSession, errorCode, errorMessage, 256, errorTable));

Error:
   return error;
}
