/*****************************************************************************
 *  Rohde&Schwarz CMW500 Wideband Radio Communication Tester instrument driver
 *  WLAN Measurements
 *  Original Release: March 2009
 *  By: Jiri Kominek
 *
 *  Should you have any technical questions please contact the hotline of
 *  Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
 *
 *  e-mail: CustomerSupport@rohde-schwarz.com
 *
 *  Modification History:
 *     see ChangeLog
 *
 *****************************************************************************/
#include "rscmwwlm.h"

#if (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__))
#define ANSI
#endif
#ifndef ANSI                /* UNIX compatible */
#include <sys/timeb.h>
#include <sys/types.h>
#include <unistd.h>
#define Sleep sleep
#else                       /* ANSI compatible */
#include <windows.h>
#endif

 /*****************************************************************************
  *- Value Definition and Range Tables ---------------------------------------*
  *****************************************************************************/
static ViString switchArr[] = { "OFF", "ON", NULL };
static ViString resultTypeArr[] = { "CURR", "AVER", "MAX", "MIN", "SDEV", NULL };
static ViString resultTypeCFieldArr[] = { "CRC", "CRU", "RUAL", "TAIL", NULL };
static ViString resultTypeUFieldArr[] = { "COD", "CRC", "DCM", "MCS", "NSTS", "RES", "SPAC", "STA", "TAIL", "TXB", NULL };
static ViString resultTypeHEMUFieldArr[] = { "BDCM", "BMCS", "BSSC", "BW", "CRC", "DOPP", "GILT", "LDPC", "NLTF", "NSBS", "PED", "PFEC", "RES", "SBC", "SPAT", "STBC", "TAIL", "TXOP", "ULDL", NULL };
static ViString resultTypeHESUFieldArr[] = { "BEAM", "BSSC", "BW", "COD", "CRC", "DCM", "DOPP", "FORM", "GILT", "LDPC", "MCS", "NSTS", "PED", "PFEC", "RES1", "RES2", "SPAT", "STBC", "TAIL", "TXBF", "TXOP", "ULDL", NULL };
static ViString resultTypeHETBFieldArr[] = { "BSSC", "BW", "CRC", "FORM", "RES1", "RES2", "SPAT1", "SPAT2", "SPAT3", "SPAT4", "TAIL", "TXOP", NULL };
static ViString resultTypeHTSIGFieldArr[] = { "AGGR", "CBW", "CRC", "FECC", "HTL", "MCS", "NESS", "NSO", "RES", "SHOR", "SMO", "STBC", "TAIL", NULL };
static ViString resultTypeLSIGFieldArr[] = { "LENG", "PAR", "RATE", "RES", "TAIL", NULL };
static ViString resultTypeVHTSIGFieldArr[] = { "BEAM", "BW", "CRC", "FECC", "GID", "LDPC", "PAID", "RES1", "RES2", "RES3", "SDIS", "SGI", "SMCS", "STBC", "SUNS", "TAIL", "TXOP", NULL };
static ViString ofdmModulationArr[] = {
    "BPM6", "BPM9", "QM12", "QM18", "Q1M24", "Q1M36",
    "Q6M48", "Q6M54", "BR12", "QR12", "QR34", "Q1R12",
    "Q1R34", "Q6R23", "Q6R34", "Q6R56", "BP1_5", "BP2_25", "BP3", "BP4_5", "QM3",
    "QM4_5", "QM6", "QM9", "Q1M6", "Q1M9", "Q1M12", "Q1M18", "Q6M12", "Q6M135", "Q6M24", "Q6M27", NULL
};
static ViString dsssModulationArr[] = { "DBPS", "DQPS", "CCK5", "CCK11", NULL };
static ViString inputConnectorArr[] = {
    "", "RF1C", "RF2C", "RF3C", "RF4C", "RFAC", "RFBC",
    "R11", "R12", "R13", "R14", "R15", "R16", "R17", "R18",
    "R21", "R22", "R23", "R24", "R25", "R26", "R27", "R28",
    "R31", "R32", "R33", "R34", "R35", "R36", "R37", "R38",
    "RA1", "RA2", "RA3", "RA4", "RA5", "RA6", "RA7", "RA8",
    "RB1", "RB2", "RB3", "RB4", NULL
};
static ViString converterArr[] = { "", "RX1", "RX2", "RX3", "RX4", NULL };
static ViString standardArr[] = { "BDSS", "GOFD", "GDSS", "AOFD", "NSIS", "CMIM", "SMIM", "ACS", "POFD", "DSSS", "LOFD", "HTOF", "VHT", NULL };
static ViString modulationTypeListModeArr[] = {
    "BPM6", "BPM9", "QM12", "QM18", "Q1M24", "Q1M36",
    "Q6M48", "Q6M54", "BR12", "QR12", "QR34", "Q1R12",
    "Q1R34", "Q6R23", "Q6R34", "Q6R56", "DBPS",
    "DQPS", "CCK5", "CCK11", NULL
};
static ViString burstTypeArr[] = { "MIXM", "GF20", "SHOR", "LONG", NULL };
static ViString guardIntervalArr[] = { "SHOR", "LONG", "NCAP", "GI08", "GI16", "GI32", NULL };
static ViString OFDMSignalArr[] = { "OFDM", "NSIS", NULL };
static ViString analyzerSalScenRXCArr[] = {
    "RF1C", "RF2C", "RF3C", "RF4C", "RFAC", "RFBC",
    "R11", "R12", "R13", "R14", "R15", "R16", "R17", "R18",
    "R21", "R22", "R23", "R24", "R25", "R26", "R27", "R28",
    "R31", "R32", "R33", "R34", "R35", "R36", "R37", "R38",
    "RA1", "RA2", "RA3", "RA4", "RA5", "RA6", "RA7", "RA8",
    "RB1", "RB2", "RB3", "RB4", NULL
};
static ViString analyzerSalScenRFCArr[] = { "RX1", "RX2", "RX3", "RX4", NULL };
static ViString routingScenarioArr[] = { "SAL", "CSP", "SMI4", "MIMO2x2", "MIMO4x4", "MIMO8x8", NULL };
static ViString EdgeTimeArr[] = { "REDG", "FEDG", NULL };
static ViString BandArr[] = { "B20", "B40", "B80", "B160", "B5", "B10", "B8080", NULL };
static ViString BandwidthArr[] = { "20", "40", "80", "160", "5", "10", NULL };
static ViString conenctorTupleArr[] = { "CT12", "CT34", "CT56", "CT78", "CT14", "CT58", "CT18", NULL };
static ViString modulationSchemeArr[] = {
    "BPSK12", "BPSK34", "QPSK12", "QPSK34", "16Q12", "16Q34", "64Q12",
    "64Q23", "64Q34", "64Q56", "256Q34", "256Q56", "1KQ34", "1KQ56",
    "UNSP", "BPSK14", "QPSK14", "16Q14", "16Q38", "BPSK", "QPSK",
    "16Q", "64Q", "256Q", "1KQ", NULL
};
static ViString freqBandArr[] = { "Band2_4GHz", "Band5GHz", NULL };
static ViString codeRateArr[] = { "CR14", "CR38", "CR12", "CR23", "CR34", "CR56", NULL };
static ViString segmStandardArr[] = { "DSSS", "LOFD", "POFD", "HTOF", "VHT", "HEOF", NULL };
static ViString segmBwArr[] = { "BW05", "BW10", "BW20", "BW40", "BW80", "BW16", NULL };

/*****************************************************************************
 *- User-Callable Functions (Exportable Functions) --------------------------*
 *****************************************************************************/

 /*****************************************************************************
  * Function: rscmwwlm_init
  * Purpose:  VXIplug&play required function. Calls the
  *           rscmwwlm_InitWithOptions function.
  *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_init(ViRsrc resourceName, ViBoolean IDQuery,
   ViBoolean resetDevice, ViSession* newInstrSession)
{
   ViStatus error = VI_SUCCESS;

   if (newInstrSession == NULL)
   {
      (void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER,
         VI_ERROR_PARAMETER4, "Null address for Instrument Handle");

      checkErr(RS_ERROR_INVALID_PARAMETER);
   }

   checkErr(rscmwwlm_InitWithOptions(resourceName, IDQuery, resetDevice, "", newInstrSession));

Error:
   return error;
}

/*****************************************************************************
 * Function: rscmwwlm_InitWithOptions
 * Purpose:  This function creates a new RS session and calls the
 *           RsInit function.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_InitWithOptions(
   ViRsrc resourceName,
   ViBoolean IDQuery,
   ViBoolean resetDevice,
   ViString optionString,
   ViSession* newInstrSession
)
{
   ViStatus error = VI_SUCCESS;
   RsCoreAttributePtr* attrList = NULL;
   ViSession instrSession = 0;
   RsCoreSessionPtr sessionProperties = NULL;

   if (newInstrSession == NULL)
   {
      (void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER, VI_ERROR_PARAMETER5,
         "Null address for Instrument Handle");
      checkErr(RS_ERROR_INVALID_PARAMETER);
   }

   attrList = (RsCoreAttributePtr*)rscmwwlm_RsCoreAttributeList;

   *newInstrSession = 0;

   checkErr(RsCore_NewSpecificDriver(
      resourceName, // VISA Resource Name
      "rscmwwlm", // driver prefix
      optionString, // Init Options string, is applied to the session settings
      attrList, // List of all attributes from the rscmwwlm_RsCoreAttributeList
      rscmwwlm_RsCoreAttributeListLength, // Length of list of all attributes
      VI_FALSE, //idnModelFullName Model has the full *IDN? query name e.g. true: "CMW100A", VI_FALSE: "CMW" Used in CheckInstrument()
      0, // WriteDelay
      0, // ReadDelay
      100000, // IO Segment Size
      RS_VAL_OPCWAIT_STBPOLLING, // OPC Wait Mode
      RSCMWWLM_OPC_TIMEOUT, // OPC timeout
      15000, // VISA Timeout
      600000, // Self-test timeout
      RS_VAL_BIN_FLOAT_FORMAT_SINGLE_4BYTES, // BinaryFloatNumbersFormat
      RS_VAL_BIN_INTEGER_FORMAT_INT32_4BYTES, // binaryIntegerNumbersFormat
      &instrSession));

   // Minimal allowed rscore version is 4.3.0
   checkErr(RsCore_CheckMinimalEngineVersion(instrSession, 4, 3, 0));

   checkErr(RsCore_GetRsSession(instrSession, &sessionProperties));

   // No SCPI command has been sent yet.
   // Call viClear before sending any SCPI command
   checkErr(RsCore_ViClear(instrSession));

   /* --- Here perform settings that are default for this driver,
   but can be overwritten by the optionsString settings */

   sessionProperties->autoSystErrQuery = VI_FALSE;

   // Parse option string and optionally sets the initial state of the following session attributes
   checkErr(RsCore_ApplyOptionString(instrSession, optionString));
   checkErr(RsCore_BuildRepCapTable(instrSession, rscmwwlm_RsCoreRepCapTable, rscmwwlm_RsCoreRepCapTableCount));

   // Query *IDN? string, parse it and set the following attributes:
   // -RS_ATTR_INSTRUMENT_MANUFACTURER
   // - RS_ATTR_INSTRUMENT_MODEL - based on the idnModelFullName true: "CMW100A", false : "CMW"
   // - RS_ATTR_INSTRUMENT_FIRMWARE_REVISION
   checkErr(RsCore_QueryAndParseIDNstring(instrSession, RSCMWWLM_SIMULATION_ID_QUERY, NULL));

   // Query *OPT? string, parse the options, remove the duplicates, sort them and store the result string to RS_ATTR_OPTIONS_LIST
   checkErr(RsCore_QueryAndParseOPTstring(instrSession, RSCMWWLM_SIMULATION_OPT_QUERY, RS_VAL_OPTIONS_PARSING_AUTO));

   // Default Instrument Setup + optional *RST
   if (resetDevice == VI_TRUE)
   {
      checkErr(rscmwwlm_reset(instrSession));
   }
   else
   {
      checkErr(rscmwwlm_DefaultInstrSetup(instrSession));
   }

   if (IDQuery == VI_TRUE)
   {
      checkErr(RsCore_FitsIDNpattern(instrSession, RSCMWWLM_VALID_ID_RESPONSE_STRING, NULL));
   }

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   if (error < VI_SUCCESS)
   {
      if (error == RS_ERROR_INSTRUMENT_STATUS && sessionProperties->autoSystErrQuery == VI_FALSE)
      {
         sessionProperties->autoSystErrQuery = VI_TRUE;
         (void)rscmwwlm_CheckStatus(instrSession);
         sessionProperties->autoSystErrQuery = VI_FALSE;
      }

      if (instrSession != 0)
         (void)RsCore_ViClose(instrSession);
   }
   else
   {
      *newInstrSession = instrSession;
   }

   return error;
}

/*****************************************************************************
 * Function: Configure Analyzer Combined Signal Path Scenario
 * Purpose:  Activates the combined signal path scenario and selects a
             master. The master controls the signal routing and analyzer
             settings while the combined signal path scenario is active.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerCombinedSignalPathScenario(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViString  master)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViString(instrSession, repCap, RSCMWWLM_ATTR_ANALYZER_COMBINED_SIGNAL_PATH_SCENARIO, master),
           3, "Master");

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Signal Routing Switched MIMO Scenario
 * Purpose:  This function returns the switched MIMO scenario and the
 *             RF routing.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QuerySignalRoutingSwitchedMIMOScenario(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   connector,
                            ViInt32   RXConnector[],
                            ViInt32   RXConverter[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  ext_buf = NULL;
   ViChar*  p2buf;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, connector, 1, 4),
           3, "Connector");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:WLAN:MEAS%ld:SCEN:SMI%ld?", instance, connector);
   checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   p2buf = strtok(ext_buf, ",");

   if (connector == 1)
   {
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConnector[0] = RsCore_FindStringIndex(inputConnectorArr, p2buf);

      p2buf = strtok(NULL, ",\n");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConverter[0] = RsCore_FindStringIndex(converterArr, p2buf);
   }
   else if (connector == 2)
   {
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConnector[0] = RsCore_FindStringIndex(inputConnectorArr, p2buf);

      p2buf = strtok(NULL, ",");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConverter[0] = RsCore_FindStringIndex(converterArr, p2buf);

      p2buf = strtok(NULL, ",");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConnector[1] = RsCore_FindStringIndex(inputConnectorArr, p2buf);

      p2buf = strtok(NULL, ",");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConverter[1] = RsCore_FindStringIndex(converterArr, p2buf);
   }
   else if (connector == 3)
   {
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConnector[0] = RsCore_FindStringIndex(inputConnectorArr, p2buf);

      p2buf = strtok(NULL, ",");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConverter[0] = RsCore_FindStringIndex(converterArr, p2buf);

      p2buf = strtok(NULL, ",");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConnector[1] = RsCore_FindStringIndex(inputConnectorArr, p2buf);

      p2buf = strtok(NULL, ",");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConverter[1] = RsCore_FindStringIndex(converterArr, p2buf);

      p2buf = strtok(NULL, ",");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConnector[2] = RsCore_FindStringIndex(inputConnectorArr, p2buf);

      p2buf = strtok(NULL, ",");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConverter[2] = RsCore_FindStringIndex(converterArr, p2buf);
   }
   else if (connector == 4)
   {
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConnector[0] = RsCore_FindStringIndex(inputConnectorArr, p2buf);

      p2buf = strtok(NULL, ",");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConverter[0] = RsCore_FindStringIndex(converterArr, p2buf);

      p2buf = strtok(NULL, ",");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConnector[1] = RsCore_FindStringIndex(inputConnectorArr, p2buf);

      p2buf = strtok(NULL, ",");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConverter[1] = RsCore_FindStringIndex(converterArr, p2buf);

      p2buf = strtok(NULL, ",");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConnector[2] = RsCore_FindStringIndex(inputConnectorArr, p2buf);

      p2buf = strtok(NULL, ",");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConverter[2] = RsCore_FindStringIndex(converterArr, p2buf);

      p2buf = strtok(NULL, ",");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConnector[3] = RsCore_FindStringIndex(inputConnectorArr, p2buf);

      p2buf = strtok(NULL, ",");
      if (p2buf == NULL)
         return RSCMWWLM_ERROR_INCORRECT_STATE;
      RXConverter[3] = RsCore_FindStringIndex(converterArr, p2buf);
   }

Error:
   if (ext_buf) free(ext_buf);
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Number Of Paths TMIMO Scenario
 * Purpose:  Configures the number of paths for the true MIMO scenario .
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureNumberOfPathsTMIMOScenario(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   numberOfPaths)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, numberOfPaths, 2, 4),
           3, "Number Of Paths");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:WLAN:MEAS%ld:SCEN:TMIM%ld", instance, numberOfPaths);
   checkErr(RsCore_Write(instrSession, cmd));
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Number Of MIMO Antennas
 * Purpose:  Configures the number of connected antennas for switched or
 *             true MIMO measurements.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureNumberOfMIMOAntennas(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   numberOfAntennas)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_ANALYZER_NUMBER_OF_MIMO_ANTENNAS, numberOfAntennas),
           3, "Number Of Antennas");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  This function specifies whether the DUT uses separate antennas for the
/// HIFN  two segments of an 80+80 MHz signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR separateAntennas/This control  is available on the R&S CMW100 only. It specifies
/// HIPAR separateAntennas/whether the DUT uses separate antennas for the two segments of an 80+80
/// HIPAR separateAntennas/MHz signal.
ViStatus _VI_FUNC rscmwwlm_ConfigureUseSeparateAntennasFor80Plus80MHz(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean separateAntennas)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_ANALYZER_USE_SEPARATE_ANTENNAS_FOR_80_PLUS_80_MHZ, separateAntennas),
           3, "Separate Antennas");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Assigns an RF input connector to antenna <n>. The function is relevant
/// HIFN  if several configurable input connectors are used, for example for MIMO
/// HIFN  scenarios. If you use separate antennas for the segments of an 80+80
/// HIFN  MHz signal, the antenna numbering continues for the second segment.
/// HIFN  Example: Two antennas per segment. Segment 0 uses antenna 1 and 2.
/// HIFN  Segment 1 uses antenna 3 and 4.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR antennaNumber/Sets antenna number.
/// HIPAR connector/Assigns an RF input connector to antenna <n>.
ViStatus _VI_FUNC rscmwwlm_ConfigureRFRoutingAntennaConnector(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antennaNumber,
                            ViInt32   connector)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   rep_capp[15] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antennaNumber, 1, 8),
           3, "antenna Number");

   sprintf(rep_capp, "%s,a%ld", repCap, antennaNumber);

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, rep_capp, RSCMWWLM_ATTR_ANALYZER_RF_ROUTING_ANTENNA_CONNECTOR, connector),
           4, "Connector");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Configures the RF Antenna.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR antennaNumber/Sets antenna number.
/// HIPAR externalAttenuation/Specifies the external attenuation for the specified antenna in the
/// HIPAR externalAttenuation/analyzer path. Antenna 2 is only available in a MIMO scenario with two
/// HIPAR externalAttenuation/input paths.
/// HIPAR epep/Specifies the expected peak envelope power of the specified antenna at
/// HIPAR epep/the I/Q input. Antenna 2 is only available in MIMO scenarios with two
/// HIPAR epep/input paths.
/// HIPAR mixerLevelOffset/Varies the input level of the mixer for the specified antenna in the
/// HIPAR mixerLevelOffset/analyzer path. Antenna 2 is only available in MIMO scenarios with two
/// HIPAR mixerLevelOffset/input paths.
ViStatus _VI_FUNC rscmwwlm_ConfigureRFRoutingAntenna(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32   antennaNumber,
                                                     ViReal64  externalAttenuation,
                                                     ViReal64  epep,
                                                     ViReal64  mixerLevelOffset)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   rep_capp[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antennaNumber, 1, 8),
           3, "Antenna Number");

   sprintf(rep_capp, "%s,a%ld", repCap, antennaNumber);

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, rep_capp, RSCMWWLM_ATTR_ANALYZER_RF_ROUTING_ANTENNA_EXTERNAL_ATTENUATION, externalAttenuation),
           4, "External Attenuation");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, rep_capp, RSCMWWLM_ATTR_ANALYZER_RF_ROUTING_ANTENNA_EXPECTED_PEAK_ENVELOP_POWER, epep),
           5, "EPEP");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, rep_capp, RSCMWWLM_ATTR_ANALYZER_RF_ROUTING_ANTENNA_MIXER_LEVEL_OFFSET, mixerLevelOffset),
           6, "Mixer Level Offset");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Defines an external attenuation (or gain, if the value is negative),
/// HIFN  to be applied to RF connector no. <connector> during switched MIMO
/// HIFN  measurements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR connector/Number of the RF connector.
/// HIPAR externalAttenuation/Defines an external attenuation (or gain, if the value is negative),
/// HIPAR externalAttenuation/to be applied to RF connector no. <connector> during switched MIMO
/// HIPAR externalAttenuation/measurements.
ViStatus _VI_FUNC rscmwwlm_ConfigureRFRoutingExternalAttenuation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   connector,
                            ViReal64  externalAttenuation)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   rep_capp[15] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, connector, 1, 4),
           3, "Connector");

   sprintf(rep_capp, "%s,C%ld", repCap, connector);

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, rep_capp, RSCMWWLM_ATTR_ANALYZER_EXTERNAL_ATTENUATION_ON_RF_CONNECTOR, externalAttenuation),
           4, "External Attenuation");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure External Attenuation
 * Purpose:  Defines an external attenuation (or gain, if the value is
 *           negative), to be applied to the selected RF input connector.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureExternalAttenuation(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViReal64  externalAttenuation)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_INPUT_EXTERNAL_ATTENUATION, externalAttenuation),
           5, "Input External Attenutation");

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Analyzer Stand Alone Scenario
 * Purpose:  This function activates the standalone scenario and selects the
 *           input connector for the measured RF signal.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerStandAloneScenario(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   RXConnector,
                            ViInt32   RFConverter)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, RXConnector, RSCMWWLM_VAL_ANALYZER_CONN_RF1C, RSCMWWLM_VAL_ANALYZER_CONN_RB4),
           3, "RX Connector");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFConverter, RSCMWWLM_VAL_ANALYZER_SAL_CONV_RX1, RSCMWWLM_VAL_ANALYZER_SAL_CONV_RX4),
           4, "RF Converter");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:WLAN:MEAS%ld:SCEN:SAL %s,%s",
      instance, analyzerSalScenRXCArr[RXConnector], analyzerSalScenRFCArr[RFConverter]);
   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  This function enables the switched MIMO scenario selected via <PathCount> and
/// HIFN  specifies the RF connectors to be reserved.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR MIMO/Defines the MIMO scenario
/// HIPAR connectorTuple/Defines the connector tuple
ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerSwitchedMIMOScenario(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   MIMO,
                            ViInt32   connectorTuple)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   if (MIMO != 2 && MIMO != 8)
   {
      viCheckParm(RsCore_InvalidViInt32Value(instrSession, MIMO), 3, "MIMO");
   }

   switch (MIMO)
   {
   case 2:
      viCheckParm(RsCore_InvalidViInt32Range(instrSession, connectorTuple, 0, 3),
              4, "Connector Tuple");
      break;
   case 4:
      viCheckParm(RsCore_InvalidViInt32Range(instrSession, connectorTuple, 4, 5),
              4, "Connector Tuple");
      break;
   case 8:
      viCheckParm(RsCore_InvalidViInt32Range(instrSession, connectorTuple, 6, 6),
              4, "Connector Tuple");
      break;
   }

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUTe:WLAN:MEAS%ld:SCENario:SMIMO%ld %s", instance, MIMO, conenctorTupleArr[connectorTuple]);
   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Query Signal Routing Settings
 * Purpose:  This function returns the configured routing settings.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QuerySignalRoutingSettings(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32*  scenario,
                                                      ViChar    controller[],
                                                      ViInt32*  RXConnector,
                                                      ViInt32*  RXConverter)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  ext_buf = NULL;
   ViChar*  p2buf;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidNullPointer(instrSession, controller), 4, "Controller");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:WLAN:MEAS%ld?", instance);
   checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   p2buf = strtok(ext_buf, ",");
   checkErr(rscmwwlm_GetIndexOfToken(p2buf, routingScenarioArr, scenario));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   p2buf = strtok(NULL, ",");
   sscanf(p2buf, "\"%[^\"]", controller);

   p2buf = strtok(NULL, ",");
   checkErr(rscmwwlm_GetIndexOfToken(p2buf, inputConnectorArr, RXConnector));

   p2buf = strtok(NULL, ",\n");
   checkErr(rscmwwlm_GetIndexOfToken(p2buf, converterArr, RXConverter));

Error:
   if (ext_buf) free(ext_buf);
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Signal Routing Switched MIMO Settings
 * Purpose:  This function returns the configured routing settings for
 *             the switched MIMO scenario.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QuerySignalRoutingSwitchedMIMOSettings(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32*  scenario,
                            ViChar    controller[],
                            ViInt32*  RXConnector1,
                            ViInt32*  RXConverter1,
                            ViInt32*  RXConnector2,
                            ViInt32*  RXConverter2,
                            ViInt32*  RXConnector3,
                            ViInt32*  RXConverter3,
                            ViInt32*  RXConnector4,
                            ViInt32*  RXConverter4)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  ext_buf = NULL;
   ViChar*  p2buf;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidNullPointer(instrSession, controller), 4, "Controller");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:WLAN:MEAS%ld:SMIM?", instance);
   checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   p2buf = strtok(ext_buf, ",");
   checkErr(rscmwwlm_GetIndexOfToken(p2buf, routingScenarioArr, scenario));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   p2buf = strtok(NULL, ",");
   sscanf(p2buf, "\"%[^\"]", controller);

   p2buf = strtok(NULL, ",");
   checkErr(rscmwwlm_GetIndexOfToken(p2buf, inputConnectorArr, RXConnector1));

   p2buf = strtok(NULL, ",");
   checkErr(rscmwwlm_GetIndexOfToken(p2buf, converterArr, RXConverter1));

   p2buf = strtok(NULL, ",");
   checkErr(rscmwwlm_GetIndexOfToken(p2buf, inputConnectorArr, RXConnector2));

   p2buf = strtok(NULL, ",");
   checkErr(rscmwwlm_GetIndexOfToken(p2buf, converterArr, RXConverter2));

   p2buf = strtok(NULL, ",");
   checkErr(rscmwwlm_GetIndexOfToken(p2buf, inputConnectorArr, RXConnector3));

   p2buf = strtok(NULL, ",");
   checkErr(rscmwwlm_GetIndexOfToken(p2buf, converterArr, RXConverter3));

   p2buf = strtok(NULL, ",");
   checkErr(rscmwwlm_GetIndexOfToken(p2buf, inputConnectorArr, RXConnector4));

   p2buf = strtok(NULL, ",\n");
   checkErr(rscmwwlm_GetIndexOfToken(p2buf, converterArr, RXConverter4));

Error:
   if (ext_buf) free(ext_buf);
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Analyzer
 * Purpose:  Configures the RF input path.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzer(ViSession instrSession,
                                             ViInt32   instance,
                                             ViReal64  expectedNominalPower,
                                             ViReal64  margin,
                                             ViReal64  centerFrequency)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_ANALYZER_EXPECTED_NOMINAL_POWER, expectedNominalPower),
           3, "Expected Nominal Power");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_ANALYZER_USER_MARGIN, margin),
           4, "Margin");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_ANALYZER_CENTER_FREQUENCY, centerFrequency),
           5, "Center Frequency");

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Analyzer Mixer Level Offset
 * Purpose:  Configures the input level of the mixer in the analyzer path.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerMixerLevelOffset(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViReal64  mixerLevelOffset)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_ANALYZER_MIXER_LEVEL_OFFSET, mixerLevelOffset),
           3, "Mixer Level Offset");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Analyzer Frequency Offset
 * Purpose:  Sets a positive or negative frequency offset to be added to the
 *           center frequency.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerFrequencyOffset(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViReal64  frequencyOffset)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_ANALYZER_FREQUENCY_OFFSET, frequencyOffset),
           3, "Frequency Offset");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Analyzer Second Channel Position
 * Purpose:  Sets the position of the secondary relative to the primary 20
             MHz channel for 40 MHz IEEE 802.11n signals.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerSecondChannelPosition(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   secondaryChannel)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_ANALYZER_SECOND_CHANNEL_POSITION, secondaryChannel),
           3, "Secondary Channel");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Analyzer Display Mode
 * Purpose:  Display mode of "Spectrum Flatness" results to switch between
 *             relative and absolute result values (dB vs. dBm).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerDisplayMode(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   displayMode)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_ANALYZER_DISPLAY_MODE, displayMode),
           3, "Display Mode");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Display mode of Spectrum Flatness results to switch between relative
/// HIFN  and absolute result values (dB vs. dBm).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR displayMode/Display mode of Spectrum Flatness results to switch between relative
/// HIPAR displayMode/and absolute result values (dB vs. dBm).
ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerMaskDisplayMode(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   displayMode)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_ANALYZER_MASK_DISPLAY_MODE, displayMode),
           3, "Display Mode");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Input Signal
 * Purpose:  Configures the input signal.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignal(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32   standard,
                                                ViInt32   burstType,
                                                ViInt32   evaluationLength)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_INPUT_SIGNAL_STANDARD, standard),
           3, "Standard");

   if ((standard == RSCMWWLM_VAL_STD_HTOF) || (standard == RSCMWWLM_VAL_STD_NOFD)) // RSCMWWLM_VAL_STD_NOFD is for backward compatibility only
   {
      viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_INPUT_SIGNAL_BURST, burstType),
              4, "Burst Type");
   }

   if ((standard == RSCMWWLM_VAL_STD_DSSS) || (standard == RSCMWWLM_VAL_STD_BDSS) || (standard == RSCMWWLM_VAL_STD_GDSS)) //RSCMWWLM_VAL_STD_BDSS and RSCMWWLM_VAL_STD_GDSS are for backward comaptibility only
   {
      viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_INPUT_SIGNAL_EVALUATION_LENGTH, evaluationLength),
              5, "Evaluation Length");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Input Signal Bandwidth
 * Purpose:  Configures the channel bandwidth for standard version 802.11n.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalBandwidth(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   bandwidth)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_INPUT_SIGNAL_BANDWIDTH, bandwidth),
           3, "Bandwidth");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN Sets the receive mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR receiveMode/Selects the receive mode.
ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalReceiveMode(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   receiveMode)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_INPUT_SIGNAL_RECEIVE_MODE, receiveMode),
           3, "Receive Mode");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Configures the distance between the center frequencies of the two
/// HIFN  80-MHz segments of an 802.11ac 80+80 MHz signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR channelDistance/Configures the distance between the center frequencies of the two
/// HIPAR channelDistance/80-MHz segments of an 802.11ac 80+80 MHz signal.
ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalChannelDistance(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  channelDistance)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_INPUT_SIGNAL_CHANNEL_DISTANCE, channelDistance),
           3, "Channel Distance");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Input Signal Frequency Band
 * Purpose:  Selects the frequency band for standard 802.11n.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalFrequencyBand(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   band)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_INPUT_SIGNAL_FREQUENCY_BAND, band),
           3, "Band");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Input Signal Frequency Channel
 * Purpose:  Sets the channel indices of the 20 MHz channels of an 802.11ac
 *           signal.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalFrequencyChannel(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channel,
                            ViInt32   channelValue)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, 8),
           3, "Channel");

   snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,channel%ld", instance, channel);

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_INPUT_SIGNAL_FREQUENCY_CHANNEL, channelValue),
           4, "Channel Value");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Input Signal Training Data Source
 * Purpose:  Specifies the training data source to be used as the reference
             signal for 802.11n CMIMO measurements.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalTrainingDataSource(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViString  standard)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViString(instrSession, repCap, RSCMWWLM_ATTR_INPUT_SOURCE_SIGNAL_TRAINING_DATA_SOURCE, standard),
           3, "Standard");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Get Loaded Traning Data File Date
 * Purpose:  Returns the last modified date of the currently loaded training
             data ("mif") file, if any.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetLoadedTraningDataFileDate(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   bufferSize,
                                                        ViChar    fileDate[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_GetAttributeViString(instrSession, repCap, RSCMWWLM_ATTR_LOAD_TRAINING_DATA_FILE_DATE,
           bufferSize, fileDate),
           4, "File Date");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Input Signal IQ Swap State
 * Purpose:  Swaps the role of the I and Q axes in the baseband.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalIQSwapState(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViBoolean IQSwap)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_INPUT_SIGNAL_IQ_SWAP_STATE, IQSwap),
           3, "IQ Swap");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Input Signal Modulation Filter Bursts
 * Purpose:  This function allows to limits the evaluation to bursts
             of a particular modulation type.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalModulationFilterBursts(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   modulationFilter)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_INPUT_SIGNAL_MODULATION_FILTER_BURSTS, modulationFilter),
           3, "Modulation Filter");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Input Signal Power Class
 * Purpose:  Sets the STA transmit power class for standard IEEE 802.11p.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalPowerClass(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   powerClass)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_INPUT_SIGNAL_POWER_CLASS, powerClass),
           3, "Power Class");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Configures the evaluation length for R&S CMW100.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR measuredChips_DSSS/Sets the number of payload chips
/// HIPAR skipPreambleandHeader_DSSS/Preamble and header skipping.
/// HIPAR measuredSymbols_OFDM/Specifies the evaluation length of the burst for OFDM signals.
ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalEvaluationLength(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   measuredChips_DSSS,
                            ViBoolean skipPreambleandHeader_DSSS,
                            ViInt32   measuredSymbols_OFDM)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:ISIG:DSSS:ELEN %ld,%s", instance, measuredChips_DSSS, switchArr[skipPreambleandHeader_DSSS]);
   checkErr(RsCore_Write(instrSession, cmd));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_INPUT_SIGNAL_EVALUATION_LENGTH_SYMBOLS_OFDM, measuredSymbols_OFDM),
           5, "Measured Symbols OFDM");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Returns all scenarios possible for the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the array size.
/// HIPAR possibleScenarios/Returns all scenarios possible for the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryInputSignalPossibleScenarios(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   arraySize,
                                                             ViChar    possibleScenarios[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_GetAttributeViString(instrSession, repCap, RSCMWWLM_ATTR_QUERY_INPUT_POSSIBLE_SCENARIOS,
           arraySize, possibleScenarios),
           4, "Possible Scenarios");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement Statistics
 * Purpose:  This function configures the scope of the multi-evaluation
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasStatistics(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   repetition,
                                                        ViInt32   stopCondition)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_REPETITION_MODE, repetition),
           3, "Repetition Mode");

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_STOP_CONDITION, stopCondition),
           4, "Stop Condition");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement Statistics Count
 * Purpose:  Configures the statistics count. The statistic count (also termed
 *           statistic length) is the integer number of measurement intervals
 *           per measurement cycle (statistics cycle, single-shot measurement).
 *           The length of a measurement interval is measurement-specific.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasStatisticsCount(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   statisticCount)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_STATISTIC_COUNT, statisticCount),
           3, "Statistic Count");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits Error Vector Magnitude
 * Purpose:  This function defines upper limits for the RMS and peak values
 *           of the error vector magnitude (EVM).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsEVM(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViReal64  RMSLimit,
                                                   ViBoolean RMSLimitStatus,
                                                   ViReal64  peakLimit,
                                                   ViBoolean peakLimitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  p2buf = cmd;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViReal64Range(instrSession, RMSLimit, 0.0, 20.0), 3, "RMS Limit");
   viCheckParm(RsCore_InvalidViReal64Range(instrSession, peakLimit, 0.0, 20.0), 5, "Peak Limit");

   p2buf += snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:TDSC:MEAS%ld:MEV:LIM:EVM ", instance);
   if (RMSLimitStatus == VI_TRUE)
      p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "%lf,", RMSLimit);
   else
      p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "%s,", switchArr[RMSLimitStatus ? 1 : 0]);

   if (peakLimitStatus == VI_TRUE)
      snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "%lf", peakLimit);
   else
      snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "%s", switchArr[peakLimitStatus ? 1 : 0]);

   checkErr(RsCore_Write(instrSession, cmd));
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement Parameters
 * Purpose:  This function configures the scope of the multi-evaluation
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasParameters(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViBoolean measureonException)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_RESULTS_REJECTION, measureonException),
           3, "Measure on Exception");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement Modulation Tracking
 * Purpose:  This function activate or deactivate phase tracking, timing
 *           tracking and level tracking. With enabled tracking, fluctuations
 *           are compensated.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasModulationTracking(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean phase,
                            ViBoolean timing,
                            ViBoolean level)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_PHASE_TRACKING, phase),
           3, "Phase");

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TIMING_TRACKING, timing),
           4, "Timing");

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LEVEL_TRACKING, level),
           5, "Level");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement Channel Estimation
 * Purpose:  This function specifies whether channel estimation is done in
 *           payload or preamble.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasChannelEstimation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channelEstimation)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_CHANNEL_ESTIMATION, channelEstimation),
           3, "Channel Estimation");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement FFT Demodulation Offset
 * Purpose:  This function specifies whether channel estimation is done in
 *           payload or preamble.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasFFTDemodulationOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   FFTDemodulationOffset)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_FFT_DEMODULATION_OFFSET, FFTDemodulationOffset),
           3, "FFT Demodulation Offset");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN This function determines if and how accurate the transmit filter
/// HIFN shall be estimated.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR state/Enables or disables TX filter estimation.
/// HIPAR taps/Number of equalizer filter taps.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasDSSSTxFilterEstimation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean state,
                            ViInt32   taps)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  p2buf = cmd;
   ViInt32  valueArr[] = { 0, 2, 5, 7, 9, 11, 13, 15 };
   ViUInt32 idx;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   if (state == VI_TRUE)
   {
      viCheckParm(rscmwwlm_GetIndexInNumArray(taps, valueArr, 8, &idx), 4, "Value");
   }

   p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:COMP:EFT %s", instance, switchArr[state ? 1 : 0]);
   if (state == VI_TRUE && taps > 0)
      sprintf(p2buf, ",%ld", taps);

   checkErr(RsCore_Write(instrSession, cmd));
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  This function is relevant for 802.11b signals only. It selects the EVM
/// HIFN  measurement method - according to standard 802.11-2007 or according to
/// HIFN  standard 802.11b-1999.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR dsssEVMMethod/This control is relevant for 802.11b signals only. It selects the EVM
/// HIPAR dsssEVMMethod/measurement method - according to standard 802.11-2007 or according to
/// HIPAR dsssEVMMethod/standard 802.11b-1999.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasDSSSEVMMethod(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   dsssEVMMethod)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_DSSS_EVM_METHOD, dsssEVMMethod),
           3, "DSSS EVM Method");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN This function defines how many head and tail symbols shall be
/// HIFN excluded from OFDM modulation measurements.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR head/Number of heading symbols to be skipped.
/// HIPAR tail/Number of tailing symbols to be skipped.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasSkipOFDMSymbols(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   head,
                                                             ViInt32   tail)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, head, 0, 100),
           3, "Head");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, tail, 0, 100),
           4, "Tail");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:COMP:SKIP %ld,%ld", instance, head, tail);
   checkErr(RsCore_Write(instrSession, cmd));
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement Transmit Spectrum Mask
 * Purpose:  This function configures the Transmit Spectrum Mask of the
 *           multi-evaluation measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasTransmitSpectrumMask(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   statisticCount,
                            ViReal64  triggerOffsetTime,
                            ViInt32   averageFFTNumber)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TS_MASK_STATISTIC_COUNT, statisticCount),
           3, "Statistic Count");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TS_MASK_TRIGGER_OFFSET_TIME, triggerOffsetTime),
           4, "Trigger Offset Time");

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TS_MASK_AVERAGE_FFT_NUMBER, averageFFTNumber),
           5, "Average FFT Number");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement Assign Views
 * Purpose:  This function enables or disables the evaluation of results and
 *           shows or hides the views in the multi evaluation measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasAssignViews(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   measurement,
                                                         ViBoolean state)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, measurement, RSCMWWLM_VAL_RES_EVM, RSCMWWLM_VAL_RES_UTER),
           3, "Measurement");

   snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld", instance);

   switch (measurement)
   {
   case RSCMWWLM_VAL_RES_EVM:
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_EVM_VS_CHIP_VIEW, state),
              4, "State");
      break;
   case RSCMWWLM_VAL_RES_EVMS:
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_EVM_VS_SYMBOL_VIEW, state),
              4, "State");
      break;
   case RSCMWWLM_VAL_RES_EVMC:
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_EVM_VS_CARRIER_VIEW, state),
              4, "State");
      break;
   case RSCMWWLM_VAL_RES_IQC:
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_IQ_CONSTELLATION_VIEW, state),
              4, "State");
      break;
   case RSCMWWLM_VAL_RES_MSC:
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_MODULATION_SCALAR_VIEW, state),
              4, "State");
      break;
   case RSCMWWLM_VAL_RES_TSM:
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TRANSMIT_SPECTRUM_MASK_VIEW, state),
              4, "State");
      break;
   case RSCMWWLM_VAL_RES_SFL:
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SPECTRUM_FLATNESS_VIEW, state),
              4, "State");
      break;
   case RSCMWWLM_VAL_RES_UTER:
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_UNUSED_TONE_ERROR_VIEW, state),
              4, "State");
      break;

   default:
      viCheckParm(RsCore_InvalidViInt32Value(instrSession, measurement), 3, "measurement");
      break;
   }

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement Assign Views All
 * Purpose:  This function enables or disables the evaluation of results and
 *           shows or hides the views in the multi evaluation measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasAssignViewsAll(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViBoolean modulationScalar,
                                                            ViBoolean powerVsTime,
                                                            ViBoolean EVMvsChip,
                                                            ViBoolean EVMvsSymbol,
                                                            ViBoolean EVMvsCarrier,
                                                            ViBoolean iQConstellationDiagram,
                                                            ViBoolean SpectrumFlatness,
                                                            ViBoolean transmitSpectrumMask,
                                                            ViBoolean unusedToneErr)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:RES:ALL %s,%s,%s,%s,%s,%s,%s,%s,%s", instance, switchArr[modulationScalar ? 1 : 0], switchArr[powerVsTime ? 1 : 0],
      switchArr[EVMvsChip ? 1 : 0], switchArr[EVMvsSymbol ? 1 : 0], switchArr[EVMvsCarrier ? 1 : 0],
      switchArr[iQConstellationDiagram ? 1 : 0], switchArr[SpectrumFlatness ? 1 : 0], switchArr[transmitSpectrumMask ? 1 : 0], switchArr[unusedToneErr ? 1 : 0]);
   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement PVT
 * Purpose:  Selects the evaluated results and the displayed views for the
 *           Power vs. Time.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementPVT(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   edge,
                                                        ViBoolean edgeEnable,
                                                        ViBoolean burst,
                                                        ViBoolean PVTEnable)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, edge, RSCMWWLM_VAL_REDG, RSCMWWLM_VAL_FEDG),
           3, "edge");

   snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld", instance);

   switch (edge)
   {
   case RSCMWWLM_VAL_REDG:

      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_VS_TIME_RISING_EDGE, edgeEnable),
              4, "Edge Enable");
      break;

   case RSCMWWLM_VAL_FEDG:

      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_VS_TIME_FALLING_EDGE, edgeEnable),
              4, "Edge Enable");
      break;

   default:
      viCheckParm(RsCore_InvalidViInt32Value(instrSession, edge), 3, "edge");
      break;
   }

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_VS_TIME_BURST, burst),
           5, "Burst");

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_VS_TIME_RESULT_ENABLE, PVTEnable),
           6, "PVT Enable");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement DSSS Average Length
 * Purpose:  Sets the length of the moving average filter, which smoothes the
             power trace and thus eliminates the modulation.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementDSSSAverageLength(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   averageLength)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_DSSS_AVERAGE_LENGTH, averageLength),
           3, "Average Length");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement DSSS Reference Power
 * Purpose:  Sets the reference power. In DSSS the thresholds for rising and
             falling edge results are defined as percentage values of the
             reference power. The reference can be set to either the max or
             mean power of the burst.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementDSSSReferencePower(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   referencePower)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_DSSS_REFERENCE_POWER, referencePower),
           3, "Reference Power");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement Timeout
 * Purpose:  Defines the timeout for the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementTimeout(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   timeout)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TIMEOUT, timeout),
           3, "Timeout");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement Mask Spectrum Selection
 * Purpose:  Selects the spectrum limit mask to be applied to 10 and 20 MHz
 *           IEEE 802.11p signals.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementMaskSpectrumSelection(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   maskSelection)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_MASK_SPECTRUM_SELECTION, maskSelection),
           3, "Mask Selection");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement Occupied Bandwidth
 * Purpose:  Sets the OBW measurement state and percentage.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementOccupiedBandwidth(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   measurementStatus,
                            ViReal64  occupiedBandwidth)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (measurementStatus != RSCMWWLM_VAL_MEASUREMENT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_CONFIGURE_MULTI_EVAL_MEASUREMENT_OCCUPIED_BANDWIDTH_ENABLE, measurementStatus == VI_TRUE), 3, "Measurement Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_CONFIGURE_MULTI_EVAL_MEASUREMENT_OCCUPIED_BANDWIDTH_VALUE, occupiedBandwidth),
              4, "Occupied Bandwidth");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Configure the limit of timing error distribution for PvT measurements
/// HIFN  for OFDM standards.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR measurementStatus/Sets the measurement status. Defines, if the measurement is applied.
/// HIPAR te/Configure the limit of timing error distribution for PvT measurements
/// HIPAR te/for OFDM standards.
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementOFDMTEPercentage(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   measurementStatus,
                            ViReal64  te)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (measurementStatus != RSCMWWLM_VAL_MEASUREMENT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_VS_TIME_TE_PERCENTAGE_ENABLED, measurementStatus == VI_TRUE), 3, "Measurement Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_VS_TIME_TE_PERCENTAGE, te),
              4, "TE");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Sets the synchronization mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR mode/Sets the synchronization mode.
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementSyncMode(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   mode)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SYNC_MODE, mode),
           3, "Mode");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Configures the HE TB PPDU.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR bandwidth/Specifies the channel bandwidth of the HE TB PPDU.
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementHETBPPDUBandwidth(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_HE_TB_PPDU_BANDWIDTH, bandwidth),
           3, "Bandwidth");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Specifies the modulation and coding scheme (MCS) used by the HE TB
/// HIFN  PPDU.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR station/Sets the station.
/// HIPAR mcs/Specifies the modulation and coding scheme (MCS) used by the HE TB
/// HIPAR mcs/PPDU.
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementHETBPPDUMCS(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   station,
                            ViInt32   mcs)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   repCap2[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, station, 1, 3),
           3, "Station");

   snprintf(repCap2, RS_REPCAP_BUF_SIZE, "%s,S%ld", repCap, station);

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap2, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_HE_TB_PPDU_MCS, mcs),
           4, "MCS");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Specifies the standard for segment <no> in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR segment/Sets the segment number.
/// HIPAR standard/Specifies the standard for segment <no> in list mode.
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementSegmentStandard(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   standard)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   repCap2[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   snprintf(repCap2, RS_REPCAP_BUF_SIZE, "%s,seg%ld", repCap, segment);

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap2, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_STANDARD, standard),
           4, "Standard");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Selects the RF input connector for segment <no> in list mode for the
/// HIFN  connector mode LIST.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR segment/Sets the segment number.
/// HIPAR connector/Selects the RF input connector for segment <no> in list mode for the
/// HIPAR connector/connector mode LIST.
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementSegmentConnector(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   connector)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   repCap2[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   snprintf(repCap2, RS_REPCAP_BUF_SIZE, "%s,seg%ld", repCap, segment);

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap2, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_CONNECTOR, connector),
           4, "Connector");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Specifies the burst types for standard 802.11n for segment <no> in
/// HIFN  list mode. Do not use the command for other standards.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR segment/Sets the segment number.
/// HIPAR burstType/Specifies the burst types for standard 802.11n for segment <no> in
/// HIPAR burstType/list mode. Do not use the command for other standards.
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementSegmentBurstType(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   burstType)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   repCap2[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   snprintf(repCap2, RS_REPCAP_BUF_SIZE, "%s,seg%ld", repCap, segment);

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap2, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_BURST_TYPE, burstType),
           4, "Burst Type");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Configures the list segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR segment/Sets the segment number.
/// HIPAR bandwidth/Specifies the channel bandwidth for segment <no> in list mode.
/// HIPAR enp/Specifies the expected nominal power of the measured RF signal for
/// HIPAR enp/segment <no> in list mode.
/// HIPAR frequency/Specifies the center frequency of the RF analyzer for segment <no> in
/// HIPAR frequency/list mode.
/// HIPAR measurementOffset/Specifies the measurement offset for segment <no> in list mode.
/// HIPAR measurementTime/Specifies the measurement time for segment <no> in list mode.
/// HIPAR time/Specifies the duration of the segment for segment <no> in list mode.
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   bandwidth,
                            ViReal64  enp,
                            ViReal64  frequency,
                            ViReal64  measurementOffset,
                            ViReal64  measurementTime,
                            ViReal64  time)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   repCap2[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   snprintf(repCap2, RS_REPCAP_BUF_SIZE, "%s,seg%ld", repCap, segment);

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap2, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_BANDWIDTH, bandwidth),
           4, "Bandwidth");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap2, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_ENP, enp),
           5, "ENP");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap2, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_FREQUENCY, frequency),
           6, "Frequency");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap2, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_MEASUREMENT_OFFSET, measurementOffset),
           7, "Measurement Offset");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap2, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_MEASUREMENT_TIME, measurementTime),
           8, "Measurement Time");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap2, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_TIME, time),
           9, "Time");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement Trigger
 * Purpose:  This function configures the trigger parameters.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasTrigger(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViString  source,
                                                     ViInt32   slope,
                                                     ViReal64  threshold,
                                                     ViReal64  timeout,
                                                     ViReal64  IFMinGAP)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViString(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_SOURCE, source),
           3, "Source");

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_SLOPE, slope),
           4, "Slope");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_THRESHOLD, threshold),
           5, "Threshold");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_TIMEOUT, timeout),
           6, "Timeout");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_IF_MIN_GAP, IFMinGAP),
           4, "IF Min GAP");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval Measurement Trigger Source Catalog
 * Purpose:  This function lists all trigger source values that can be set
 *           using TRIGger:WLAN:MEAS<instance>:MEValuation:SOURce.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasTriggerSourceCatalog(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViChar    catalog[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidNullPointer(instrSession, catalog), 7, "catalog");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "TRIG:WLAN:MEAS%ld:MEV:CAT:SOUR?", instance);
   checkErr(RsCore_QueryViStringUnknownLengthToUserBuffer(instrSession, cmd, arraySize, catalog, NULL));
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval Measurement Trigger Source Catalog Enhanced
 * Purpose:  This function lists all trigger source values that can be set
 *           using TRIGger:WLAN:MEAS<instance>:MEValuation:SOURce.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasTriggerSourceCatalogEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean fullList,
                            ViInt32   arraySize,
                            ViChar    catalog[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidNullPointer(instrSession, catalog), 7, "catalog");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "TRIG:WLAN:MEAS%ld:MEV:CAT:SOUR? %s", instance, switchArr[fullList]);
   checkErr(RsCore_QueryViStringUnknownLengthToUserBuffer(instrSession, cmd, arraySize, catalog, NULL));
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement List Mode State
 * Purpose:  This function enables or disables the list mode.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeState(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViBoolean listMode)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE_STATE, listMode),
           3, "List Mode");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Specifies how the input connector is selected for list mode
/// HIFN  measurements with an R&S CMW100 or R&S CMWS.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR connector/Specifies how the input connector is selected for list mode
/// HIPAR connector/measurements with an R&S CMW100 or R&S CMWS.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeConnector(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   connector)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE_CONNECTOR, connector),
           3, "Connector");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement List Mode Number Of Segments
 * Purpose:  This function defines the number of segments in the entire
 *           measurement interval.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeNumberOfSegments(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   numberOfSegments)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE_NUMBER_OF_SEGMENTS, numberOfSegments),
           3, "Number Of Segments");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement List Mode Capture Time
 * Purpose:  This function defines the total capture time of the measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeCaptureTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  captureTime)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE_CAPTURE_TIME, captureTime),
           3, "Capture Time");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement List Mode Channel Filter Estimation
 * Purpose:  This function selects the channel filter estimation mode for
 *           802.11b signals.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeChannelFilterEstimation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channelFilterEstimation)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE_CHANNEL_FILTER_ESTIMATION, channelFilterEstimation),
           3, "Channel Filter Estimation");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement List Mode Statistical Length
 * Purpose:  This function defines the statistical length for AVERage,
 *           MAXimum and SDEViation calculation and enables the calculation
 *           of the modulation results in segment <nr>.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeStatisticalLength(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   statistics,
                            ViBoolean EVMEnable)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 100),
           3, "Segment");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, statistics, 1, 1000),
           4, "Statistics");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:MOD %ld,%s", instance, segment, statistics, switchArr[EVMEnable]);
   checkErr(RsCore_Write(instrSession, cmd));
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement List Mode Transmit Spectrum Mask
 * Purpose:  This function defines the statistical length for AVERage,
             MAXimum calculation and enables the calculation of the transmit
             spectrum mask results in segment <nr>.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeTransmitSpectrumMask(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   statistics,
                            ViBoolean transmitSpectrumMaskEnable)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 100),
           3, "Segment");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, statistics, 1, 1000),
           4, "statistics");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:TSM %ld,%s", instance, segment, statistics, switchArr[transmitSpectrumMaskEnable ? 1 : 0]);
   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement List Mode Burst
 * Purpose:  This function defines burst parameter settings for segment <nr>.
 *           In general this function must be sent for all segments measured
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeBurst(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   segment,
                                                           ViInt32   burstsInSegment,
                                                           ViInt32   standard,
                                                           ViInt32   modulationType,
                                                           ViInt32   burstType)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 100),
           3, "Segment");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, burstsInSegment, 1, 1000),
           4, "Bursts In Segment");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, standard, RSCMWWLM_VAL_STD_BDSS, RSCMWWLM_VAL_STD_VHT),
           5, "Standard");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, modulationType, RSCMWWLM_VAL_MOD_TYPE_BPM6, RSCMWWLM_VAL_MOD_TYPE_CCK11),
           6, "Modulation Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, burstType, RSCMWWLM_VAL_BURST_MIXED, RSCMWWLM_VAL_BURST_LONG),
           7, "Burst Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:SET %ld,%s,%s,%s",
           instance, segment, burstsInSegment, standardArr[standard], modulationTypeListModeArr[modulationType], burstTypeArr[burstType]);
   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval Measurement ListMode Burst
 * Purpose:  This function returns burst parameter settings for segment <nr>.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasListModeBurst(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   segment,
                                                       ViInt32*  burstsInSegment,
                                                       ViInt32*  standard,
                                                       ViInt32*  modulationType,
                                                       ViInt32*  burstType)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  ext_buf = NULL;
   ViChar*  p2buf;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 100),
           3, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:SET?", instance, segment);
   checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   p2buf = strtok(ext_buf, ",");
   sscanf(p2buf, "%ld", burstsInSegment);

   p2buf = strtok(NULL, ",");
   *standard = RsCore_FindStringIndex(standardArr, p2buf);

   p2buf = strtok(NULL, ",");
   *modulationType = RsCore_FindStringIndex(modulationTypeListModeArr, p2buf);

   p2buf = strtok(NULL, ",\r\n");
   *burstType = RsCore_FindStringIndex(burstTypeArr, p2buf);

Error:
   if (ext_buf) free(ext_buf);
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Measurement List Mode TS Mask
 * Purpose:  This function defines the statistical length for AVERage and
             MAXimum calculation and enables the calculation of the transmit
             spectrum mask results in segment.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeTSMask(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   statistics,
                            ViBoolean TSMEnable)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 100),
           3, "Segment");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, statistics, 1, 1000),
           4, "Statistics");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:TSM %ld,%s", instance,
      segment, statistics, switchArr[TSMEnable]);
   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Specifies burst parameter settings for segment <no> in list mode. Send
/// HIFN  this command for all segments to be measured.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR segment/No. of segments.
/// HIPAR segmentTime/Duration of the segment.
/// HIPAR measTime/Duration of measurement for the segment.
/// HIPAR measOffset/Measurement offset for the segment.
/// HIPAR level/Expected nominal power of the measured RF signal within the segment.
/// HIPAR frequency/Configures the center frequency of the RF analyzer. Set it to the
/// HIPAR frequency/center frequency of the received WLAN channel.
/// HIPAR standard/Specifies the standard for segment <no> in list mode.
/// HIPAR bandwidth/Specifies the channel bandwidth for segment <no> in list mode.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViReal64  segmentTime,
                            ViReal64  measTime,
                            ViReal64  measOffset,
                            ViReal64  level,
                            ViReal64  frequency,
                            ViInt32   standard,
                            ViInt32   bandwidth)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 100),
           3, "Segment");
   viCheckParm(RsCore_InvalidViReal64Range(instrSession, segmentTime, 4e-5, 1),
      4, "Segment Time");
   viCheckParm(RsCore_InvalidViReal64Range(instrSession, measTime, 1e-5, 1),
      5, "Meas Time");
   viCheckParm(RsCore_InvalidViReal64Range(instrSession, measOffset, 1e-5, 1),
      6, "Meas Offset");
   viCheckParm(RsCore_InvalidViReal64Range(instrSession, frequency, 70e-6, 6e9),
      8, "Frequency");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, standard, RSCMWWLM_VAL_SEGMENT_STANDARD_DSSS, RSCMWWLM_VAL_SEGMENT_STANDARD_HEOFDM),
           9, "Standard");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, bandwidth, RSCMWWLM_VAL_SEGMENT_BW_BW05, RSCMWWLM_VAL_SEGMENT_BW_BW80),
           10, "Bandwidth");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:SET %.12lG,%.12lG,%.12lG,%.12lG,%.12lG,%s,%s", instance,
      segment, segmentTime, measTime, measOffset, level, frequency, segmStandardArr[standard], segmBwArr[bandwidth]);
   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Specifies the burst types for standard 802.11n for all segments in
/// HIFN  list mode. Do not use the command for other standards.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the array size.
/// HIPAR burstTypes/Specifies the burst types for standard 802.11n for all segments in
/// HIPAR burstTypes/list mode. Do not use the command for other standards.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeBurstTypes(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   burstTypes[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:BTYP", instance);
   checkErr(RsCore_WriteAsciiViInt32Array(instrSession, cmd, burstTypes, arraySize));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Specifies the channel bandwidths for all segments in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR bandwidths/Specifies the channel bandwidths for all segments in list mode.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeBandwidths(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   bandwidths[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:BWID", instance);
   checkErr(RsCore_WriteAsciiViInt32Array(instrSession, cmd, bandwidths, arraySize));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Selects the RF input connector for all segments in list mode for the connector mode LIST.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR connectors/Selects the RF input connector for all segments in list mode for the
/// HIPAR connectors/connector mode LIST.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeConnectors(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   connectors[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:CMWS:CONN", instance);
   checkErr(RsCore_WriteAsciiViInt32Array(instrSession, cmd, connectors, arraySize));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Specifies the expected nominal power of the measured RF signal for all
/// HIFN  segments in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR enps/Specifies the expected nominal power of the measured RF signal for all
/// HIPAR enps/segments in list mode.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeENPs(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViReal64  enps[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:ENP", instance);
   checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, enps, arraySize));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Specifies the measurement frequencies for all segments in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR frequencies/Specifies the measurement frequencies for all segments in list mode.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeFrequencies(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViReal64  frequencies[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:FREQ", instance);
   checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, frequencies, arraySize));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Specifies the measurement offsets for all segments in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR offsets/Specifies the measurement offsets for all segments in list mode.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeOffsets(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViReal64  offsets[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:MOFF", instance);
   checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, offsets, arraySize));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Specifies the measurement times for all segments in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR times/Specifies the measurement times for all segments in list mode.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeTimes(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViReal64  times[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:MTIM", instance);
   checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, times, arraySize));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Specifies the standard for all segments in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR standards/Specifies the standard for all segments in list mode.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeStandards(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   standards[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:STAN", instance);
   checkErr(RsCore_WriteAsciiViInt32Array(instrSession, cmd, standards, arraySize));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Specifies the segment times for all segments in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR times/Specifies the segment times for all segments in list mode.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeSegmentTimes(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViReal64  times[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:STIM", instance);
   checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, times, arraySize));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Enables or disables the evaluation of results for modulation and
/// HIFN  transmit spectrum mask measurements for segment <no> in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR modulation/Enables or disables modulation.
/// HIPAR sem/Enables or disables SEM.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeSegmentEnabled(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViBoolean modulation,
                            ViBoolean sem)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 100),
           3, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:RES %s,%s", instance, segment, switchArr[modulation], switchArr[sem]);
   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Specifies for segment <no> in list mode, whether the measurement waits
/// HIFN  for a trigger event before measuring the segment, or not. For the first
/// HIFN  segment, the value OFF is always interpreted as ON.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR retriggers/Specifies for segment <no> in list mode, whether the measurement waits
/// HIPAR retriggers/for a trigger event before measuring the segment, or not. For the first
/// HIPAR retriggers/segment, the value OFF is always interpreted as ON.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeSegmentRetriggers(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   arraySize,
                            ViBoolean retriggers[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 100),
           3, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:RTR", instance, segment);
   checkErr(RsCore_WriteAsciiViBooleanArray(instrSession, cmd, retriggers, arraySize));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Specifies the modulation and spectrum statistical length for segment
/// HIFN  <no> in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR modulation/No. of burst to be measured during modulation measurements.
/// HIPAR sem/No. of burst to be measured during spectrum measurements
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeSegmentStatCount(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   modulation,
                            ViInt32   sem)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 100),
           3, "Segment");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, modulation, 1, 2000),
           4, "Modulation");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, modulation, 1, 1000),
           5, "SEM");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:SCO %ld,%ld", instance, segment, modulation, sem);
   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Configures the Measurement List Results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR modulation/Enables or disables the evaluation of results for modulation
/// HIPAR modulation/(..:MODulation) and transmit spectrum mask (..:TSMask) measurements in
/// HIPAR modulation/list mode.
/// HIPAR transmitSpectrumMask/Enables or disables the evaluation of results for modulation
/// HIPAR transmitSpectrumMask/(..:MODulation) and transmit spectrum mask (..:TSMask) measurements in
/// HIPAR transmitSpectrumMask/list mode.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViBoolean modulation[],
                            ViBoolean transmitSpectrumMask[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:RES:MOD", instance);
   checkErr(RsCore_WriteAsciiViBooleanArray(instrSession, cmd, modulation, arraySize));

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:RES:TSM", instance);
   checkErr(RsCore_WriteAsciiViBooleanArray(instrSession, cmd, transmitSpectrumMask, arraySize));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Specifies, whether the measurement in list mode waits for a trigger
/// HIFN  event before measuring the segment, or not. For the first segment, the
/// HIFN  value OFF is always interpreted as ON.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR retriggers/Specifies, whether the measurement in list mode waits for a trigger
/// HIPAR retriggers/event before measuring the segment, or not. For the first segment, the
/// HIPAR retriggers/value OFF is always interpreted as ON.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeRetriggers(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViBoolean retriggers[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:RTR", instance);
   checkErr(RsCore_WriteAsciiViBooleanArray(instrSession, cmd, retriggers, arraySize));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Specifies the spectrum statistical length for transmit spectrum mask
/// HIFN  measurements for all segments in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR statCounts/Specifies the spectrum statistical length for transmit spectrum mask
/// HIPAR statCounts/measurements for all segments in list mode.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeStatCountsSEM(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   statCounts[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIST:SCO:TSM", instance);
   checkErr(RsCore_WriteAsciiViInt32Array(instrSession, cmd, statCounts, arraySize));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval PVT DSSS Limits
 * Purpose:  Defines limits for results characterizing the pulse shape of
             DSSS signals.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalPVTDSSSLimits(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   edge,
                                                           ViBoolean enable,
                                                           ViReal64  limit)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, edge, RSCMWWLM_VAL_REDG, RSCMWWLM_VAL_FEDG),
           3, "edge");

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   switch (edge)
   {
   case RSCMWWLM_VAL_REDG:

      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_RISE_TIME_LIMIT_ENABLE, enable),
              4, "Enable");

      if (enable == VI_TRUE)
      {
         viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_POWER_VS_TIME_RISE_TIME_LIMIT, limit),
                 5, "Limit");
      }

      break;

   case RSCMWWLM_VAL_FEDG:

      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_FALL_TIME_LIMIT_ENABLE, enable),
              4, "Enable");

      if (enable == VI_TRUE)
      {
         viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_POWER_VS_TIME_FALL_TIME_LIMIT, limit),
                 5, "Limit");
      }
      break;

   default:
      viCheckParm(RsCore_InvalidViInt32Value(instrSession, edge), 3, "edge");
      break;
   }

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Sets the upper limit for timing error.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR limitStatus/Sets the limit status. Defines, if the limit is applied.
/// HIPAR limitValue/Sets the upper limit for timing error.
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalPVTTimingErrorUpperLimit(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   limitStatus,
                            ViReal64  limitValue)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   switch (limitStatus)
   {
   case RSCMWWLM_VAL_LIMIT_OFF:
   case RSCMWWLM_VAL_LIMIT_ON:
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_POWER_VS_TIME_UPPER_LIMIT_ERROR_ENABLED, (ViBoolean)limitStatus), 3, "Limit Status");
      break;
   case RSCMWWLM_VAL_LIMIT_VALUE:
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_POWER_VS_TIME_UPPER_LIMIT_ERROR, limitValue),
              4, "Limit Value");
      break;
   default:
      viCheckParm(RsCore_InvalidViInt32Value(instrSession, limitStatus), 3, "Limit Status");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM Error Vector Magnitude
 * Purpose:  Defines and activates upper limits for the error vector magnitude
 *           (EVM) of the data carriers (transmission scheme OFDM).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDMEVM(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViReal64  limitValues[],
                                                       ViInt32   limitStatus[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  p2buf = cmd;
   ViInt32  i = 0;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   p2buf += snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:LOFD:EVM ", instance);
   for (i = 0; i < 8; i++)
   {
      switch (limitStatus[i])
      {
      case RSCMWWLM_VAL_LIMIT_OFF:
      case RSCMWWLM_VAL_LIMIT_ON:
         p2buf += sprintf(p2buf, "%s,", switchArr[limitStatus[i]]);
         break;
      case RSCMWWLM_VAL_LIMIT_VALUE:
         viCheckParm(RsCore_InvalidViReal64Range(instrSession, limitValues[i], -100.0, 0.0), 3, "Limit Value");

         p2buf += sprintf(p2buf, "%lf,", limitValues[i]);
         break;
      default:
         viCheckParm(RsCore_InvalidViInt32Value(instrSession, limitStatus[i]), 4, "Limit Status[i]");
      }
   }
   *--p2buf = '\0';

   checkErr(RsCore_Write(instrSession, cmd));
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM EVM Pilot
 * Purpose:  Defines and activates an upper limit for the error vector
 *           magnitude (EVM) of the pilot carriers (transmission scheme OFDM).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDMEVMPilot(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViReal64  limitValue,
                                                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:LOFD:EVMP", instance);
   checkErr(rscmwwlm_ConfigureLimit(instrSession, cmd, limitValue, limitStatus, -100.0, 0.0));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM IQ Offset
 * Purpose:  Defines and activates an upper limit for the I/Q origin offset
 *           (transmission scheme OFDM).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDMIQOffset(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViReal64  limitValue,
                                                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:LOFD:IQOF", instance);
   checkErr(rscmwwlm_ConfigureLimit(instrSession, cmd, limitValue, limitStatus, -100.0, 0.0));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM Center Frequency Error
 * Purpose:  Defines and activates an upper limit for the center frequency
 *           error (transmission scheme OFDM).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDMCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:LOFD:CFER", instance);
   checkErr(rscmwwlm_ConfigureLimit(instrSession, cmd, limitValue, limitStatus, 0.0, 100.0e6));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM Symbol Clock Error
 * Purpose:  Defines and activates an upper limit for the symbol clock error
 *           (transmission scheme OFDM).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDMSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:LOFD:SCER", instance);
   checkErr(rscmwwlm_ConfigureLimit(instrSession, cmd, limitValue, limitStatus, 0.0, 100.0));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11p Center Frequency Error
 * Purpose:  Defines and activates an upper limit for the center frequency
 *           error (IEEE 802.11p).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_CENTER_FREQUENCY_ERROR_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_CENTER_FREQUENCY_ERROR_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11p Error Vector Magnitude
 * Purpose:  Defines and activates upper limits for the error vector
 *           magnitude (EVM) of the data carriers in IEEE 802.11p signals.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pErrorVectorMagnitude(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValues[],
                            ViInt32   limitStatus[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  p2buf = cmd;
   ViInt32  i = 0;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:POFD:EVM ", instance);

   for (i = 0; i < 8; i++)
   {
      switch (limitStatus[i])
      {
      case RSCMWWLM_VAL_LIMIT_OFF:
         strcat(p2buf, "OFF,");
         break;
      case RSCMWWLM_VAL_LIMIT_ON:
         strcat(p2buf, "ON,");
         break;
      case RSCMWWLM_VAL_LIMIT_VALUE:
         viCheckParm(RsCore_InvalidViReal64Range(instrSession, limitValues[i], -100.0, 0.0), 3, "Limit Values");

         p2buf += sprintf(p2buf, "%lf,", limitValues[i]);
         break;
      default:
         viCheckParm(RsCore_InvalidViInt32Value(instrSession, limitStatus[i]), 4, "Limit Status[i]");
      }
   }

   *--p2buf = '\0';

   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11p EVM Pilot
 * Purpose:  Defines and activates an upper limit for the error vector
 *           magnitude (EVM) of IEEE 802.11p pilot carriers.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pEVMPilot(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_EVM_PILOT_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_EVM_PILOT_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11p IQ Offset
 * Purpose:  Defines and activates an upper limit for the I/Q origin offset
 *           of IEEE 802.11p signals.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pIQOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_IQ_OFFSET_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_IQ_OFFSET_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11p Symbol Clock Error
 * Purpose:  Defines and activates an upper limit for the symbol clock error
 *           (IEEE 802.11p).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_SYMBOL_CLOCK_ERROR_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_SYMBOL_CLOCK_ERROR_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11p Spectrum Flatness
 * Purpose:  Defines and activates the spectrum flatness limit check for IEEE
 *           802.11p OFDM signals with the appropriate bandwidth.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pSpectrumFlatness(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean enable,
                            ViReal64  center,
                            ViReal64  side,
                            ViReal64  upper)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   repCap_1[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, bandwidth, RSCMWWLM_VAL_INPUT_SIGNAL_BW_20MHZ, RSCMWWLM_VAL_INPUT_SIGNAL_BW_10MHZ),
           3, "Bandwidth");
   viCheckParm(RsCore_InvalidViReal64Range(instrSession, center, -20.0, 4.0), 5, "Center");
   viCheckParm(RsCore_InvalidViReal64Range(instrSession, side, -20.0, 4.0), 6, "Side");

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   snprintf(repCap_1, RS_REPCAP_BUF_SIZE, ",%s", BandArr[bandwidth]);

   strcat(repCap, repCap_1);

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211P_ENABLE, enable),
           4, "Enable");

   switch (enable)
   {
   case VI_TRUE:
      snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:SFL:POFD:BW%s:LOW %.12lG, %.12lG", instance, BandwidthArr[bandwidth], center, side);
      checkErr(RsCore_Write(instrSession, cmd));

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211P_UPPER, upper),
              7, "Upper");
      break;

   case VI_FALSE:
      break;
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits DSSS Error Vector Magnitude
 * Purpose:  Defines and activates upper limits for the error vector magnitude
 *           (EVM) peak and RMS values of the data carriers (transmission
 *           scheme DSSS).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsDSSSEVM(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   type,
                                                       ViInt32   limitStatus,
                                                       ViReal64  limitValue)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, type, 0, 1),
           3, "Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:DSSS:EVM%c", instance, (type == RSCMWWLM_VAL_TYPE_RMS) ? 'R' : 'P');
   checkErr(rscmwwlm_ConfigureLimit(instrSession, cmd, limitValue, limitStatus, 0.0, 100.0));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits DSSS IQ Offset
 * Purpose:  Defines and activates an upper limit for the I/Q origin offset
 *           (transmission scheme DSSS).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsDSSSIQOffset(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViReal64  limitValue,
                                                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:DSSS:IQOF", instance);
   checkErr(rscmwwlm_ConfigureLimit(instrSession, cmd, limitValue, limitStatus, -100.0, 0.0));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits DSSS Center Frequency Error
 * Purpose:  Defines and activates an upper limit for the center frequency
 *           error (transmission scheme DSSS).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsDSSSCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:DSSS:CFER", instance);
   checkErr(rscmwwlm_ConfigureLimit(instrSession, cmd, limitValue, limitStatus, 0.0, 100.0e6));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits DSSS Symbol Clock Error
 * Purpose:  Defines and activates an upper limit for the chip clock error
 *           (transmission scheme DSSS).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsDSSSSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:DSSS:CCER", instance);
   checkErr(rscmwwlm_ConfigureLimit(instrSession, cmd, limitValue, limitStatus, 0.0, 100.0));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11n Error Vector Magnitude
 * Purpose:  Defines and activates upper limits for the error vector
 *           magnitude (EVM) of the data carriers (transmission scheme OFDM).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NEVM(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViReal64  limitValues[],
                                                             ViInt32   limitStatus[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  p2buf = cmd;
   ViInt32  i = 0;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:HTOF:EVM ", instance);

   for (i = 0; i < 8; i++)
   {
      switch (limitStatus[i])
      {
      case RSCMWWLM_VAL_LIMIT_OFF:
         strcat(p2buf, "OFF,");
         break;
      case RSCMWWLM_VAL_LIMIT_ON:
         strcat(p2buf, "ON,");
         break;
      case RSCMWWLM_VAL_LIMIT_VALUE:
         viCheckParm(RsCore_InvalidViReal64Range(instrSession, limitValues[i], -100.0, 0.0), 3, "Limit Values");

         p2buf += sprintf(p2buf, "%lf,", limitValues[i]);
         break;
      default:
         viCheckParm(RsCore_InvalidViInt32Value(instrSession, limitStatus[i]), 4, "Limit Status[i]");
      }
   }

   *--p2buf = '\0';

   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11n EVM Pilot
 * Purpose:  Defines and activates an upper limit for the error vector
 *           magnitude (EVM) of the pilot carriers (transmission scheme
 *           OFDM).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NEVMPilot(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:HTOF:EVMP", instance);
   checkErr(rscmwwlm_ConfigureLimit(instrSession, cmd, limitValue, limitStatus, -100.0, 0.0));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11n IQ Offset
 * Purpose:  Defines and activates an upper limit for the I/Q origin offset
 *           (transmission scheme OFDM).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NIQOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, bandwidth, 5, 40),
           3, "Bandwidth");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:HTOF:IQOF:BW%ld", instance, bandwidth);
   checkErr(rscmwwlm_ConfigureLimit(instrSession, cmd, limitValue, limitStatus, -100.0, 0.0));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11n Center Frequency Error
 * Purpose:  Defines and activates an upper limit for the center frequency
 *           error (transmission scheme OFDM).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:HTOF:CFER", instance);
   checkErr(rscmwwlm_ConfigureLimit(instrSession, cmd, limitValue, limitStatus, 0.0, 100.0e6));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11n Symbol Clock Error
 * Purpose:  Defines and activates an upper limit for the symbol clock error
 *           (transmission scheme OFDM).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:HTOF:SCER", instance);
   checkErr(rscmwwlm_ConfigureLimit(instrSession, cmd, limitValue, limitStatus, 0.0, 100.0));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11n MIMO Error Vector Magnitude
 * Purpose:  Defines and activates upper limits for the error vector
 *           magnitude (EVM) of the data carriers in Switched MIMO
 *           Measurements.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NMIMOEVM(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValues[],
                            ViInt32   limitStatus[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  p2buf = cmd;
   ViInt32  i = 0;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:SMIM:EVM ", instance);

   for (i = 0; i < 8; i++)
   {
      switch (limitStatus[i])
      {
      case RSCMWWLM_VAL_LIMIT_OFF:
         strcat(p2buf, "OFF,");
         break;
      case RSCMWWLM_VAL_LIMIT_ON:
         strcat(p2buf, "ON,");
         break;
      case RSCMWWLM_VAL_LIMIT_VALUE:
         viCheckParm(RsCore_InvalidViReal64Range(instrSession, limitValues[i], -100.0, 0.0), 3, "Limit Values");

         p2buf += sprintf(p2buf, "%lf,", limitValues[i]);
         break;
      default:
         viCheckParm(RsCore_InvalidViInt32Value(instrSession, limitStatus[i]), 4, "Limit Status[i]");
      }
   }

   *--p2buf = '\0';

   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11n MIMO EVM Pilot
 * Purpose:  Defines and activates an upper limit for the error vector
 *           magnitude (EVM) of the pilot carriers in 802.11n Switched MIMO
 *           Measurements.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NMIMOEVMPilot(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_EVM_PILOT_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_EVM_PILOT_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11n MIMO IQ Offset
 * Purpose:  Defines and activates an upper limit for the I/Q origin offset
 *           in IEEE 802.11n Switched MIMO Measurements..
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NMIMOIQOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_IQ_OFFSET_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_IQ_OFFSET_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11n MIMO Center Frequency Error
 * Purpose:  Defines and activates an upper limit for the center frequency
 *           error in 802.11n Switched MIMO Measurements.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NMIMOCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_CFERROR_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_CFERROR_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11n MIMO Symbol Clock Error
 * Purpose:  Defines and activates an upper limit for the symbol clock error
 *           in 802.11n Switched MIMO Measurements.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NMIMOSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_SCERROR_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_SCERROR_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11ac Error Vector Magnitude
 * Purpose:  Defines and activates upper limits for the error vector
 *           magnitude (EVM) of 802.11ac SISO data carriers.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211ACEVM(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValues[],
                            ViInt32   limitStatus[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  p2buf = cmd;
   ViInt32  i = 0;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:VHT:EVM ", instance);

   for (i = 0; i < 12; i++)
   {
      switch (limitStatus[i])
      {
      case RSCMWWLM_VAL_LIMIT_OFF:
         strcat(p2buf, "OFF,");
         break;
      case RSCMWWLM_VAL_LIMIT_ON:
         strcat(p2buf, "ON,");
         break;
      case RSCMWWLM_VAL_LIMIT_VALUE:
         viCheckParm(RsCore_InvalidViReal64Range(instrSession, limitValues[i], -100.0, 0.0), 3, "Limit Values");

         p2buf += sprintf(p2buf, "%lf,", limitValues[i]);
         break;
      default:
         viCheckParm(RsCore_InvalidViInt32Value(instrSession, limitStatus[i]), 4, "Limit Status[i]");
      }
   }

   *--p2buf = '\0';

   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11ac EVM Pilot
 * Purpose:  Defines and activates an upper limit for the error vector
 *           magnitude (EVM) of the pilot carriers in 802.11ac SISO signals.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211ACEVMPilot(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_EVM_PILOT_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_EVM_PILOT_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11ac IQ Offset
 * Purpose:  Defines and activates an upper limit for the I/Q origin offset
 *           in IEEE 802.11ac SISO signals.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211ACIQOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViReal64  relativeLimitValue,
                            ViInt32   relativeLimitStatus,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   rep_capp[30] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, bandwidth, RSCMWWLM_VAL_INPUT_SIGNAL_BW_20MHZ, RSCMWWLM_VAL_INPUT_SIGNAL_BW_88MHZ),
           3, "Bandwidth");

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   sprintf(rep_capp, "%s,%s", repCap, BandArr[bandwidth]);

   if (bandwidth != RSCMWWLM_VAL_INPUT_SIGNAL_BW_88MHZ)
   {
      if (relativeLimitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
      {
         viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, rep_capp,
            RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_IQ_OFFSET_ENABLE, relativeLimitStatus == VI_TRUE), 5, "Relative Limit Status");
      }
      else
      {
         viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, rep_capp, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_IQ_OFFSET_LIMIT, relativeLimitValue),
                 4, "Relative Limit Value");
      }
   }
   else
   {
      if (relativeLimitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
      {
         if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
         {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:VHT:IQOF:BW8080 %s, %s", instance, switchArr[relativeLimitStatus], switchArr[limitStatus]);
            checkErr(RsCore_Write(instrSession, cmd));
         }
         else
         {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:VHT:IQOF:BW8080 %s, %.12lG", instance, switchArr[relativeLimitStatus], limitValue);
            checkErr(RsCore_Write(instrSession, cmd));
         }
      }
      else
      {
         if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
         {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:VHT:IQOF:BW8080 %.12lG, %s", instance, relativeLimitValue, switchArr[limitStatus]);
            checkErr(RsCore_Write(instrSession, cmd));
         }
         else
         {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:VHT:IQOF:BW8080 %.12lG, %.12lG", instance, relativeLimitValue, limitValue);
            checkErr(RsCore_Write(instrSession, cmd));
         }
      }

      checkErr(rscmwwlm_CheckStatus(instrSession));
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11ac Center Frequency Error
 * Purpose:  Defines and activates an upper limit for the center frequency
 *           error (transmission scheme OFDM).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211ACCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_CFERROR_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_CFERROR_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11ac Symbol Clock Error
 * Purpose:  Defines and activates an upper limit for the symbol clock error
 *           in 802.11ac SISO signals.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211ACSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_SCERROR_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_SCERROR_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11ax Error Vector Magnitude
 * Purpose:  Defines and activates upper limits for the error vector
 *           magnitude (EVM) of 802.11ax data carriers.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXEVM(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValues[],
                            ViInt32   limitStatus[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  p2buf = cmd;
   ViInt32  i = 0;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:HEOF:EVM ", instance);

   for (i = 0; i < 16; i++)
   {
      switch (limitStatus[i])
      {
      case RSCMWWLM_VAL_LIMIT_OFF:
         p2buf += sprintf(p2buf, "OFF,");
         break;
      case RSCMWWLM_VAL_LIMIT_ON:
         p2buf += sprintf(p2buf, "ON,");
         break;
      case RSCMWWLM_VAL_LIMIT_VALUE:
         viCheckParm(RsCore_InvalidViReal64Range(instrSession, limitValues[i], -100.0, 0.0), 3, "Limit Values");
         p2buf += sprintf(p2buf, "%lf,", limitValues[i]);
         break;
      default:
         viCheckParm(RsCore_InvalidViInt32Value(instrSession, limitStatus[i]), 4, "Limit Status[i]");
      }
   }

   *--p2buf = '\0';

   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11ax Error Vector Magnitude TB Code Rate
 * Purpose:  Defines and activates the coding rate of HE TB PPDU per modulation type,
 *             used for the calculation of unused tone error limit line.
 *****************************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXEVMTBCodeRate(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   codingRates[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  p2buf = cmd;
   ViInt32  i = 0;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:HEOF:EVM ", instance);

   for (i = 0; i < 6; i++)
   {
      viCheckParm(RsCore_InvalidViInt32Range(instrSession, codingRates[i], RSCMWWLM_VAL_CODE_RATE_14, RSCMWWLM_VAL_CODE_RATE_56),
              3, "Limit Values");

      p2buf += sprintf(p2buf, "%s,", codeRateArr[codingRates[i]]);
   }

   *--p2buf = '\0';

   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/************************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11ax Error Vector Magnitude TB High
 * Purpose:  Defines and activates EVM limits for HE TB PPDU when transmit power is
 *             larger than the maximum power of MCS 7.
 ************************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXEVMTBHigh(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValues[],
                            ViInt32   limitStatus[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  p2buf = cmd;
   ViInt32  i = 0;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:HEOF:EVM:TBH ", instance);

   for (i = 0; i < 6; i++)
   {
      switch (limitStatus[i])
      {
      case RSCMWWLM_VAL_LIMIT_OFF:
         p2buf += sprintf(p2buf, "OFF,");
         break;
      case RSCMWWLM_VAL_LIMIT_ON:
         p2buf += sprintf(p2buf, "ON,");
         break;
      case RSCMWWLM_VAL_LIMIT_VALUE:
         p2buf += sprintf(p2buf, "%lf,", limitValues[i]);
         break;
      default:
         viCheckParm(RsCore_InvalidViInt32Value(instrSession, limitStatus[i]), 4, "Limit Status[i]");
      }
   }

   *--p2buf = '\0';

   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/************************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11ax Error Vector Magnitude TB Low
 * Purpose:  Defines and activates EVM limits for HE TB PPDU when transmit power is
 *             less than or equal to the maximum power of MCS 7.
 ************************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXEVMTBLow(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValues[],
                            ViInt32   limitStatus[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  p2buf = cmd;
   ViInt32  i = 0;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:HEOF:EVM:TBL ", instance);

   for (i = 0; i < 6; i++)
   {
      switch (limitStatus[i])
      {
      case RSCMWWLM_VAL_LIMIT_OFF:
         p2buf += sprintf(p2buf, "OFF,");
         break;
      case RSCMWWLM_VAL_LIMIT_ON:
         p2buf += sprintf(p2buf, "ON,");
         break;
      case RSCMWWLM_VAL_LIMIT_VALUE:
         p2buf += sprintf(p2buf, "%lf,", limitValues[i]);
         break;
      default:
         viCheckParm(RsCore_InvalidViInt32Value(instrSession, limitStatus[i]), 4, "Limit Status[i]");
      }
   }

   *--p2buf = '\0';

   checkErr(RsCore_Write(instrSession, cmd));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11ax EVM Pilot
 * Purpose:  Defines and activates an upper limit for the error vector
 *           magnitude (EVM) of the pilot carriers in 802.11ax signals.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXEVMPilot(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_EVM_PILOT_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_EVM_PILOT_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11ax EVM Pilot TB High
 * Purpose:  Defines and activates an upper limit for the error vector
 *           magnitude (EVM) of the pilot subcarrier in IEEE 802.11ax signals,
 *             when transmit power is larger than the maximum power of MCS 7.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXEVMPilotTBHigh(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_EVM_PILOT_TBHIGH_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_EVM_PILOT_TBHIGH_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11ax EVM Pilot TB Low
 * Purpose:  Defines and activates an upper limit for the error vector
 *           magnitude (EVM) of the pilot subcarrier in IEEE 802.11ax signals,
 *             when transmit power is less than or equal to the maximum power
 *             of MCS 7.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXEVMPilotTBLow(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_EVM_PILOT_TBLOW_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_EVM_PILOT_TBLOW_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11ax IQ Offset
 * Purpose:  Defines and activates an upper limit for the I/Q origin offset
 *           in IEEE 802.11ax signals.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXIQOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViReal64  relativeLimitValue,
                            ViInt32   relativeLimitStatus,
                            ViReal64  absoluteLimitValue,
                            ViInt32   absoluteLimitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   rep_capp[30] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, bandwidth, RSCMWWLM_VAL_INPUT_SIGNAL_BW_20MHZ, RSCMWWLM_VAL_INPUT_SIGNAL_BW_88MHZ),
           3, "Bandwidth");

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   sprintf(rep_capp, "%s,%s", repCap, BandArr[bandwidth]);

   if (bandwidth != RSCMWWLM_VAL_INPUT_SIGNAL_BW_88MHZ)
   {
      if (relativeLimitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
      {
         viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, rep_capp,
            RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_IQ_OFFSET_ENABLE, relativeLimitStatus == VI_TRUE), 5, "Relative Limit Status");
      }
      else
      {
         viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, rep_capp, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_IQ_OFFSET_LIMIT, relativeLimitValue),
                 4, "Relative Limit Value");
      }
   }
   else
   {
      if (relativeLimitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
      {
         if (absoluteLimitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
         {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:HEOF:IQOF:BW8080 %s, %s", instance, switchArr[relativeLimitStatus], switchArr[absoluteLimitStatus]);
            checkErr(RsCore_Write(instrSession, cmd));
         }
         else
         {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:HEOF:IQOF:BW8080 %s, %.12lG", instance, switchArr[relativeLimitStatus], absoluteLimitValue);
            checkErr(RsCore_Write(instrSession, cmd));
         }
      }
      else
      {
         if (absoluteLimitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
         {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:HEOF:IQOF:BW8080 %.12lG, %s", instance, relativeLimitValue, switchArr[absoluteLimitStatus]);
            checkErr(RsCore_Write(instrSession, cmd));
         }
         else
         {
            snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:MOD:HEOF:IQOF:BW8080 %.12lG, %.12lG", instance, relativeLimitValue, absoluteLimitValue);
            checkErr(RsCore_Write(instrSession, cmd));
         }
      }

      checkErr(rscmwwlm_CheckStatus(instrSession));
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11ax Center Frequency Error
 * Purpose:  Defines and activates an upper limit for the center frequency
 *           error (transmission scheme OFDM).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_CFERROR_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_CFERROR_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11ax Symbol Clock Error
 * Purpose:  Defines and activates an upper limit for the symbol clock error
 *           in 802.11ax signals.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   if (limitStatus != RSCMWWLM_VAL_LIMIT_VALUE)
   {
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap,
         RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_SCERROR_ENABLE, limitStatus == VI_TRUE), 4, "Limit Status");
   }
   else
   {
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_SCERROR_LIMIT, limitValue),
              3, "Limit Value");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Sets the type of limits to be applied for the unused tone error of HE TB PPDU.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR UTEPower/Sets the type of limits to be applied for the unused tone error of HE TB PPDU.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXUTEPower(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   UTEPower)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_UTE_POWER, UTEPower),
           3, "UTE Power");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Enables/disables an upper limit for the unused tone error of HE TB PPDU.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR UTELimit/Activate or deactivate an upper limit for the unused tone error of HE TB PPDU.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXIQOffsetUTELimit(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean UTELimit)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_UTE_LIMIT, UTELimit),
           3, "UTE Limit");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits Transmit Spectrum Mask DSSS
 * Purpose:  Defines and activates the transmit spectrum mask. The limits
 *           apply to DSSS signals, standard version IEEE 802.11b/g.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskDSSS(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean DSSSEnable,
                            ViReal64  ABLevel,
                            ViReal64  CDLevel)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_DSSS_ENABLE, DSSSEnable),
           3, "DSSS Enable");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_DSSS_AB_LEVEL, ABLevel),
           4, "AB Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_DSSS_CD_LEVEL, CDLevel),
           5, "CD Level");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits Transmit Spectrum Mask OFDM
 * Purpose:  Defines and activates the transmit spectrum mask. The limits
 *           apply to OFDM signals, standard version IEEE 802.11b/g.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskOFDM(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean OFDMEnable,
                            ViReal64  aLevel,
                            ViReal64  bLevel,
                            ViReal64  cLevel,
                            ViReal64  dLevel)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_ENABLE, OFDMEnable),
           3, "OFDM Enable");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_LEVEL_A, aLevel),
           4, "A Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_LEVEL_B, bLevel),
           5, "B Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_LEVEL_C, cLevel),
           6, "C Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_LEVEL_D, dLevel),
           7, "D Level");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits Transmit Spectrum Flatness OFDM
 * Purpose:  Defines and activates the spectrum flatness limit check for IEEE
             802.11a/g OFDM signal.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumFlatnessOFDM(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean enable,
                            ViReal64  center,
                            ViReal64  side,
                            ViReal64  upper)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViReal64Range(instrSession, center, -20.0, 2.0), 4, "Center");
   viCheckParm(RsCore_InvalidViReal64Range(instrSession, side, -20.0, 2.0), 5, "Side");

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM_ENABLE, enable),
           3, "Enable");

   switch (enable)
   {
   case VI_TRUE:
      snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:SFL:LOFD:LOW %.12lG, %.12lG", instance, center, side);
      checkErr(RsCore_Write(instrSession, cmd));

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM_UPPER, upper),
              6, "Upper");
      break;

   case VI_FALSE:
      break;
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits Transmit Spectrum Mask OFDM 802.11n
 * Purpose:  Defines and activates the transmit spectrum mask. The limits
             apply to OFDM signals, standard version IEEE 802.11n.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskOFDM80211N(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean OFDMEnable,
                            ViReal64  aLevel,
                            ViReal64  bLevel,
                            ViReal64  cLevel,
                            ViReal64  dLevel,
                            ViReal64  absolute11nLimit)
{
   ViStatus error = VI_SUCCESS;
   ViReal64 aLevelArr[2];
   ViReal64 bLevelArr[2];
   ViReal64 cLevelArr[2];
   ViReal64 dLevelArr[2];
   ViInt32  i = 0;

   checkErr(RsCore_LockSession(instrSession));

   for (i = 0; i < 2; i++)
   {
      aLevelArr[i] = aLevel;
      bLevelArr[i] = bLevel;
      cLevelArr[i] = cLevel;
      dLevelArr[i] = dLevel;
   }
   checkErr(rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskOFDM80211NEnhanced(instrSession, instance, OFDMEnable,
      aLevelArr, bLevelArr, cLevelArr, dLevelArr, absolute11nLimit));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits Transmit Spectrum Mask OFDM 802.11n Enhanced
 * Purpose:  Defines and activates the transmit spectrum mask. The limits
 *           apply to OFDM signals, standard version IEEE 802.11n.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskOFDM80211NEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean OFDMEnable,
                            ViReal64  aLevel[],
                            ViReal64  bLevel[],
                            ViReal64  cLevel[],
                            ViReal64  dLevel[],
                            ViReal64  absolute11nLimit)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11N_ENABLE, OFDMEnable),
           3, "OFDM Enable");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:TSM:NSTW:Y:A ", instance);
   viCheckParm(RsCore_InvalidViReal64ArrayRange(instrSession, aLevel, 2, -90.0, 10.0), 4, "A Level");
   checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, aLevel, 2));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:TSM:NSTW:Y:B ", instance);
   viCheckParm(RsCore_InvalidViReal64ArrayRange(instrSession, bLevel, 2, -90.0, 10.0), 5, "B Level");
   checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, bLevel, 2));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:TSM:NSTW:Y:C ", instance);
   viCheckParm(RsCore_InvalidViReal64ArrayRange(instrSession, cLevel, 2, -90.0, 10.0), 6, "C Level");
   checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, cLevel, 2));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:TSM:NSTW:Y:D ", instance);
   viCheckParm(RsCore_InvalidViReal64ArrayRange(instrSession, dLevel, 2, -90.0, 10.0), 7, "D Level");
   checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, dLevel, 2));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_ABSOLUTE_11N_LIMIT, absolute11nLimit),
           8, "Absolute 11n Limit");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits Transmit Spectrum Flatness Enable OFDM 802.11n
 * Purpose:  Enables and desables the spectrum flatness limit check for IEEE
             802.11n signals with the appropriate bandwidth.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumFlatnessEnableOFDM80211N(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean enable)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, bandwidth, 0, 1),
           3, "Bandwidth");

   switch (bandwidth)
   {
   case RSCMWWLM_VAL_INPUT_SIGNAL_BW_20MHZ:

      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_20MHZ_OFDM80211N_ENABLE, enable),
              4, "Enable");
      break;

   case RSCMWWLM_VAL_INPUT_SIGNAL_BW_40MHZ:

      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_40MHZ_OFDM80211N_ENABLE, enable),
              4, "Enable");
      break;
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Lower Limits Transmit Spectrum Flatness OFDM 802.11n
 * Purpose:  Defines the spectrum flatness lower limit check for IEEE
             802.11a/n OFDM signals with the appropriate bandwidth.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLowerLimitsTransmitSpectrumFlatnessOFDM80211N(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViReal64  center,
                            ViReal64  side)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, bandwidth, 0, 1),
           3, "Bandwidth");
   viCheckParm(RsCore_InvalidViReal64Range(instrSession, center, -20.0, 20.0), 4, "Center");
   viCheckParm(RsCore_InvalidViReal64Range(instrSession, side, -20.0, 20.0), 5, "Side");

   switch (bandwidth)
   {
   case RSCMWWLM_VAL_INPUT_SIGNAL_BW_20MHZ:

      snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:SFL:NOTW:LOW %.12lG, %.12lG", instance, center, side);
      checkErr(RsCore_Write(instrSession, cmd));
      break;

   case RSCMWWLM_VAL_INPUT_SIGNAL_BW_40MHZ:

      snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:SFL:NOF:LOW %.12lG, %.12lG", instance, center, side);
      checkErr(RsCore_Write(instrSession, cmd));
      break;
   }

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Upper Limits Transmit Spectrum Flatness OFDM 802.11n
 * Purpose:  Defines  the spectrum flatness upper limit check for IEEE
             802.11a/n OFDM signals with the appropriate bandwidth.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalUpperLimitsTransmitSpectrumFlatnessOFDM80211N(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViReal64  upper)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, bandwidth, 0, 1),
           3, "Bandwidth");
   viCheckParm(RsCore_InvalidViReal64Range(instrSession, upper, -2.0, 20.0), 4, "Upper");

   switch (bandwidth)
   {
   case RSCMWWLM_VAL_INPUT_SIGNAL_BW_20MHZ:

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_20MHZ_OFDM80211N_UPPER, upper),
              4, "Upper");
      break;

   case RSCMWWLM_VAL_INPUT_SIGNAL_BW_40MHZ:

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_40MHZ_OFDM80211N_UPPER, upper),
              4, "Upper");
      break;
   }

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits Transmit Spectrum Mask 40 MHz
 * Purpose:  Defines the transmit spectrum mask. The limits apply to OFDM
             signals, standard version IEEE 802.11n, SISO measurements.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMask40MHz(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean enable,
                            ViReal64  aLevel,
                            ViReal64  bLevel,
                            ViReal64  cLevel,
                            ViReal64  dLevel,
                            ViReal64  absolute11nLimit)
{
   ViStatus error = VI_SUCCESS;
   ViReal64 aLevelArr[2];
   ViReal64 bLevelArr[2];
   ViReal64 cLevelArr[2];
   ViReal64 dLevelArr[2];
   ViInt32  i = 0;

   checkErr(RsCore_LockSession(instrSession));

   for (i = 0; i < 2; i++)
   {
      aLevelArr[i] = aLevel;
      bLevelArr[i] = bLevel;
      cLevelArr[i] = cLevel;
      dLevelArr[i] = dLevel;
   }
   checkErr(rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMask40MHzEnhanced(instrSession, instance, enable,
      aLevelArr, bLevelArr, cLevelArr, dLevelArr, absolute11nLimit));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits Transmit Spectrum Mask 40 MHz Enhanced
 * Purpose:  Defines the transmit spectrum mask. The limits apply to OFDM
 *           signals, standard version IEEE 802.11n, SISO measurements.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMask40MHzEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean enable,
                            ViReal64  aLevel[],
                            ViReal64  bLevel[],
                            ViReal64  cLevel[],
                            ViReal64  dLevel[],
                            ViReal64  absolute11nLimit)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_FORTY_ENABLE, enable),
           3, "Enable");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:TSM:NSF:Y:A ", instance);
   viCheckParm(RsCore_InvalidViReal64ArrayRange(instrSession, aLevel, 2, -90.0, 10.0), 4, "A Level");
   checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, aLevel, 2));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:TSM:NSF:Y:B ", instance);
   viCheckParm(RsCore_InvalidViReal64ArrayRange(instrSession, bLevel, 2, -90.0, 10.0), 5, "B Level");
   checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, bLevel, 2));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:TSM:NSF:Y:C ", instance);
   viCheckParm(RsCore_InvalidViReal64ArrayRange(instrSession, cLevel, 2, -90.0, 10.0), 6, "C Level");
   checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, cLevel, 2));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:TSM:NSF:Y:D ", instance);
   viCheckParm(RsCore_InvalidViReal64ArrayRange(instrSession, dLevel, 2, -90.0, 10.0), 7, "D Level");
   checkErr(RsCore_WriteAsciiViReal64Array(instrSession, cmd, dLevel, 2));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_FORTY_ABSOLUTE_LIMIT, absolute11nLimit),
           8, "Absolute 11n Limit");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Defines and activates the spectrum flatness limit check for IEEE
/// HIFN  802.11n OFDM signal with the appropriate bandwidth.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR bandwidth/Selects the channel bandwidth for standard version 802.11n.
/// HIPAR enable/Enables or disables the spectrum flatness limit check for 802.11n
/// HIPAR enable/signals with the specified <bandwidth>.
/// HIPAR center/Sets the center subcarriers.
/// HIPAR side/Sets the side subcarriers.
/// HIPAR upper/Defines an upper limit for the spectrum flatness of 802.11n signals
/// HIPAR upper/with the specified <bandwidth>. The upper limit must be larger than the
/// HIPAR upper/lower limits.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumFlatnessOFDM80211N(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean enable,
                            ViReal64  center,
                            ViReal64  side,
                            ViReal64  upper)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   rep_caps[30] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, bandwidth, RSCMWWLM_VAL_INPUT_SIGNAL_BW_20MHZ, RSCMWWLM_VAL_INPUT_SIGNAL_BW_10MHZ),
           3, "Bandwidth");

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   sprintf(rep_caps, "%s,%s", repCap, BandArr[bandwidth]);

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, rep_caps, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211N_ENABLE, enable),
           4, "Enable");

   if (enable == VI_TRUE)
   {
      viCheckParm(RsCore_InvalidViReal64Range(instrSession, center, -20.0, 4.0), 5, "Center");
      viCheckParm(RsCore_InvalidViReal64Range(instrSession, side, -20.0, 4.0), 6, "Side");

      snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:SFL:HTOF:BW%s:LOW %.12lG, %.12lG", instance, BandwidthArr[bandwidth], center, side);
      checkErr(RsCore_Write(instrSession, cmd));

      checkErr(rscmwwlm_CheckStatus(instrSession));

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, rep_caps, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211N_UPPER, upper),
              7, "Upper");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Defines and activates the transmit spectrum mask. The limits apply to
/// HIFN  OFDM signals, standard version IEEE 802.11n
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR bandwidth/Selects the channel bandwidth for standard version 802.11n.
/// HIPAR frequencyBand/Selects the frequency band.
/// HIPAR ofdmEnable/Activate or deactivate the transmit spectrum mask (transmission scheme
/// HIPAR ofdmEnable/OFDM), i.e. the limit check.
/// HIPAR aLevel/Defines the relative spectral density limit for point A (frequency
/// HIPAR aLevel/offset: 2*bandwidth) on the transmit spectrum mask for 802.11n signals
/// HIPAR aLevel/with the specified <bandwidth> and the selected <band>.
/// HIPAR bLevel/Defines the relative spectral density limit for point B (frequency
/// HIPAR bLevel/offset: 3/2*bandwidth) on the transmit spectrum mask for 802.11n
/// HIPAR bLevel/signals with the specified <bandwidth> and the selected <band>.
/// HIPAR cLevel/Defines the relative spectral density limit for point C (frequency
/// HIPAR cLevel/offset: 1*bandwidth) on the transmit spectrum mask for 802.11n signals
/// HIPAR cLevel/with the specified <bandwidth> and the selected <band>.
/// HIPAR dLevel/Defines the relative spectral density limit for point D (frequency
/// HIPAR dLevel/offset: 1/2*bandwidth + 1 MHz) on the transmit spectrum mask for
/// HIPAR dLevel/802.11n signals with the specified <bandwidth> and the selected <band>.
/// HIPAR absolute11nLimit/Defines an absolute power limit for 802.11n signals with the specified
/// HIPAR absolute11nLimit/<bandwidth>.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskBandOFDM80211N(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViInt32   frequencyBand,
                            ViBoolean ofdmEnable,
                            ViReal64  aLevel,
                            ViReal64  bLevel,
                            ViReal64  cLevel,
                            ViReal64  dLevel,
                            ViReal64  absolute11nLimit)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   rep_caps[50] = "";
   ViChar   rep_caps_freq[50] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, bandwidth, RSCMWWLM_VAL_INPUT_SIGNAL_BW_20MHZ, RSCMWWLM_VAL_INPUT_SIGNAL_BW_10MHZ),
           3, "Bandwidth");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, frequencyBand, RSCMWWLM_VAL_INPUT_SIGNAL_BAND_24GHZ, RSCMWWLM_VAL_INPUT_SIGNAL_BAND_5GHZ),
           4, "Frequency Band");

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   sprintf(rep_caps, "%s,%s", repCap, BandArr[bandwidth]);

   sprintf(rep_caps_freq, "%s,%s,%s", repCap, BandArr[bandwidth], freqBandArr[frequencyBand]);

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, rep_caps, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211N_ENABLE, ofdmEnable),
           5, "OFDM Enable");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, rep_caps_freq, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211N_LEVEL_A, aLevel),
           6, "A Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, rep_caps_freq, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211N_LEVEL_B, bLevel),
           7, "B Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, rep_caps_freq, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211N_LEVEL_C, cLevel),
           8, "C Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, rep_caps_freq, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211N_LEVEL_D, dLevel),
           9, "D Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, rep_caps, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211N_ABSOLUTE_LIMIT, absolute11nLimit),
           10, "Absolute 11n Limit");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits Transmit Spectrum Mask OFDM 802.11ac
 * Purpose:  Defines and activates the transmit spectrum mask. The limits
 *           apply to OFDM signals with the appropriate bandwidth, standard
 *           version IEEE 802.11ac.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskOFDM80211AC(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean OFDMEnable,
                            ViReal64  aLevel,
                            ViReal64  bLevel,
                            ViReal64  cLevel,
                            ViReal64  dLevel,
                            ViReal64  absolute11ac)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   switch (bandwidth)
   {
   case RSCMWWLM_VAL_INPUT_SIGNAL_BW_20MHZ:
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO20MHZ_ENABLE, OFDMEnable),
              4, "OFDM Enable");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO20MHZ_A_LEVEL, aLevel),
              5, "A Level");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO20MHZ_B_LEVEL, bLevel),
              6, "B Level");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO20MHZ_C_LEVEL, cLevel),
              7, "C Level");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO20MHZ_D_LEVEL, dLevel),
              8, "D Level");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_ABSOLUTE_11ACSISO20MHZ_LIMIT, absolute11ac),
              9, "Absolute 11ac");
      break;
   case RSCMWWLM_VAL_INPUT_SIGNAL_BW_40MHZ:
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO40MHZ_ENABLE, OFDMEnable),
              4, "OFDM Enable");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO40MHZ_A_LEVEL, aLevel),
              5, "A Level");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO40MHZ_B_LEVEL, bLevel),
              6, "B Level");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO40MHZ_C_LEVEL, cLevel),
              7, "C Level");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO40MHZ_D_LEVEL, dLevel),
              8, "D Level");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_ABSOLUTE_11ACSISO40MHZ_LIMIT, absolute11ac),
              9, "Absolute 11ac");
      break;
   case RSCMWWLM_VAL_INPUT_SIGNAL_BW_80MHZ:
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO80MHZ_ENABLE, OFDMEnable),
              4, "OFDM Enable");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO80MHZ_A_LEVEL, aLevel),
              5, "A Level");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO80MHZ_B_LEVEL, bLevel),
              6, "B Level");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO80MHZ_C_LEVEL, cLevel),
              7, "C Level");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO80MHZ_D_LEVEL, dLevel),
              8, "D Level");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_ABSOLUTE_11ACSISO80MHZ_LIMIT, absolute11ac),
              9, "Absolute 11ac");
      break;

   default:
      viCheckParm(RsCore_InvalidViInt32Value(instrSession, bandwidth), 3, "Bandwidth");
      break;
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits Transmit Spectrum Mask OFDM 802.11ac Enhanced
 * Purpose:  Defines and activates the transmit spectrum mask. The limits
 *           apply to OFDM signals with the appropriate bandwidth, standard
 *           version IEEE 802.11ac.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskOFDM80211ACEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean OFDMEnable,
                            ViReal64  aLevel,
                            ViReal64  bLevel,
                            ViReal64  cLevel,
                            ViReal64  dLevel,
                            ViReal64  absolute11ac)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   repCap_1[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   snprintf(repCap_1, RS_REPCAP_BUF_SIZE, ",%s", BandArr[bandwidth]);

   strcat(repCap, repCap_1);

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AC_ENABLE, OFDMEnable),
           4, "OFDM Enable");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AC_LEVEL_A, aLevel),
           5, "A Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AC_LEVEL_B, bLevel),
           6, "B Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AC_LEVEL_C, cLevel),
           7, "C Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AC_LEVEL_D, dLevel),
           8, "D Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AC_ABSOLUTE_LIMIT, absolute11ac),
           9, "Absolute 11ac");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits Transmit Spectrum Flatness OFDM 802.11ac
 * Purpose:  Defines and activates the spectrum flatness limit check for IEEE
 *           802.11ac SISO OFDM signal with the appropriate bandwidth.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumFlatnessOFDM80211AC(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean enable,
                            ViReal64  center,
                            ViReal64  side,
                            ViReal64  upper)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   switch (bandwidth)
   {
   case RSCMWWLM_VAL_INPUT_SIGNAL_BW_20MHZ:
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM80211ACSISO20MHZ_ENABLE, enable),
              4, "Enable");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM80211ACSISO20MHZ_UPPER, upper),
              7, "Upper");
      snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:SFL:ACTW:LOW %.12G,%.12G", instance, center, side);
      break;
   case RSCMWWLM_VAL_INPUT_SIGNAL_BW_40MHZ:
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM80211ACSISO40MHZ_ENABLE, enable),
              4, "Enable");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM80211ACSISO40MHZ_UPPER, upper),
              7, "Upper");
      snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:SFL:ACF:LOW %.12G,%.12G", instance, center, side);
      break;
   case RSCMWWLM_VAL_INPUT_SIGNAL_BW_80MHZ:
      viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM80211ACSISO80MHZ_ENABLE, enable),
              4, "Enable");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM80211ACSISO80MHZ_UPPER, upper),
              7, "Upper");
      snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:SFL:ACE:LOW %.12G,%.12G", instance, center, side);
      break;
   default:
      viCheckParm(RsCore_InvalidViInt32Value(instrSession, bandwidth), 3, "Bandwidth");
      break;
   }

   checkErr(RsCore_Write(instrSession, cmd));
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits Transmit Spectrum Flatness OFDM 802.11ac Enhanced
 * Purpose:  Defines and activates the spectrum flatness limit check for IEEE
 *           802.11ac SISO OFDM signal with the appropriate bandwidth.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumFlatnessOFDM80211ACEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean enable,
                            ViReal64  center,
                            ViReal64  side,
                            ViReal64  upper)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   repCap_1[RS_REPCAP_BUF_SIZE] = "";
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, bandwidth, RSCMWWLM_VAL_INPUT_SIGNAL_BW_20MHZ, RSCMWWLM_VAL_INPUT_SIGNAL_BW_88MHZ),
           3, "Bandwidth");
   viCheckParm(RsCore_InvalidViReal64Range(instrSession, center, -20.0, 4.0), 5, "Center");
   viCheckParm(RsCore_InvalidViReal64Range(instrSession, side, -20.0, 4.0), 6, "Side");

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   snprintf(repCap_1, RS_REPCAP_BUF_SIZE, ",%s", BandArr[bandwidth]);

   strcat(repCap, repCap_1);

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211AC_ENABLE, enable),
           4, "Enable");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211AC_UPPER, upper),
           7, "Upper");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:SFL:VHT:BW%s:LOW %.12G,%.12G", instance, BandwidthArr[bandwidth], center, side);
   checkErr(RsCore_Write(instrSession, cmd));
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11p Transmit Spectrum Mask State
 * Purpose:  Activates or deactivates the transmit spectrum mask for IEEE
 *           802.11p signals with bandwith, i.e. the transmit spectral
 *           density (IEEE) and absolute (ETSI) limit checks.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pTransmitSpectrumMaskState(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean enable)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   repCap_1[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   snprintf(repCap_1, RS_REPCAP_BUF_SIZE, ",%s", BandArr[bandwidth]);

   strcat(repCap, repCap_1);

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_ENABLE, enable),
           4, "Enable");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11p Absolute Emission Limits
 * Purpose:  Define and enable the absolute transmit spectrum masks on the
 *           ETSI ITS.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pAbsoluteEmissionLimits(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViReal64  absoluteLevelA,
                            ViReal64  absoluteLevelB,
                            ViReal64  absoluteLevelC,
                            ViReal64  absoluteLevelD,
                            ViReal64  absoluteLevelE,
                            ViReal64  absoluteLevelF)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   repCap_1[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   snprintf(repCap_1, RS_REPCAP_BUF_SIZE, ",%s", BandArr[bandwidth]);

   strcat(repCap, repCap_1);

   switch (bandwidth)
   {
   case RSCMWWLM_VAL_INPUT_SIGNAL_BW_10MHZ:
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_ABSOLUTE_LEVEL_A, absoluteLevelA),
              4, "Absolute Level A");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_ABSOLUTE_LEVEL_B, absoluteLevelB),
              5, "Absolute Level B");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_ABSOLUTE_LEVEL_C, absoluteLevelC),
              6, "Absolute Level C");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_ABSOLUTE_LEVEL_D, absoluteLevelD),
              7, "Absolute Level D");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_ABSOLUTE_LEVEL_E, absoluteLevelE),
              8, "Absolute Level E");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_ABSOLUTE_LEVEL_F, absoluteLevelF),
              9, "Absolute Level F");

      break;

   default:
      viCheckParm(RsCore_InvalidViInt32Value(instrSession, bandwidth), 3, "Bandwidth");
      break;
   }

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Multi Eval Limits OFDM 802.11p Spectral Density Limits
 * Purpose:  Defines the spectral density limits (IEEE), relative levels, for
 *           power classes A and B.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pSpectralDensityLimits(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViInt32   powerClass,
                            ViReal64  relativeLevelA,
                            ViReal64  relativeLevelB,
                            ViReal64  relativeLevelC,
                            ViReal64  relativeLevelD,
                            ViReal64  relativeLevelE)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   repCap_1[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   snprintf(repCap_1, RS_REPCAP_BUF_SIZE, ",%s", BandArr[bandwidth]);

   strcat(repCap, repCap_1);

   switch (powerClass)
   {
   case RSCMWWLM_VAL_INPUT_SIGNAL_POWER_CLASS_A:
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_A_RELATIVE_LEVEL_A, relativeLevelA),
              5, "Relative Level A");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_A_RELATIVE_LEVEL_B, relativeLevelB),
              6, "Relative Level B");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_A_RELATIVE_LEVEL_C, relativeLevelC),
              7, "Relative Level C");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_A_RELATIVE_LEVEL_D, relativeLevelD),
              8, "Relative Level D");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_A_RELATIVE_LEVEL_E, relativeLevelE),
              9, "Relative Level E");

      break;

   case RSCMWWLM_VAL_INPUT_SIGNAL_POWER_CLASS_B:
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_B_RELATIVE_LEVEL_A, relativeLevelA),
              5, "Relative Level A");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_B_RELATIVE_LEVEL_B, relativeLevelB),
              6, "Relative Level B");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_B_RELATIVE_LEVEL_C, relativeLevelC),
              7, "Relative Level C");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_B_RELATIVE_LEVEL_D, relativeLevelD),
              8, "Relative Level D");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_B_RELATIVE_LEVEL_E, relativeLevelE),
              9, "Relative Level E");

      break;

   case RSCMWWLM_VAL_INPUT_SIGNAL_POWER_CLASS_USER:
      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_USER_DEFINED_POWER_CLASS_RELATIVE_LEVEL_A, relativeLevelA),
              5, "Relative Level A");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_USER_DEFINED_POWER_CLASS_RELATIVE_LEVEL_B, relativeLevelB),
              6, "Relative Level B");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_USER_DEFINED_POWER_CLASS_RELATIVE_LEVEL_C, relativeLevelC),
              7, "Relative Level C");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_USER_DEFINED_POWER_CLASS_RELATIVE_LEVEL_D, relativeLevelD),
              8, "Relative Level D");

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_USER_DEFINED_POWER_CLASS_RELATIVE_LEVEL_E, relativeLevelE),
              9, "Relative Level E");

      break;

   default:
      viCheckParm(RsCore_InvalidViInt32Value(instrSession, powerClass), 4, "powerClass");
      break;
   }

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Defines and activates the transmit spectrum mask. The limits apply to
/// HIFN  OFDM signals with the appropriate bandwidth, standard version IEEE
/// HIFN  802.11ax.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR bandwidth/Selects the channel bandwidth for standard version 802.11ax.
/// HIPAR ofdmEnable/Enables or disables the transmit spectrum mask for 802.11ax signals
/// HIPAR ofdmEnable/with the specified <bandwidth>, i.e. activates or deactivates the
/// HIPAR ofdmEnable/corresponding limit checks.
/// HIPAR aLevel/Defines the relative spectral density limit for point A (frequency
/// HIPAR aLevel/offset: 2*bandwidth) on the transmit spectrum mask for 802.11ax signals
/// HIPAR aLevel/with the specified <bandwidth>.
/// HIPAR bLevel/Defines the relative spectral density limit for point B (frequency
/// HIPAR bLevel/offset: 3/2*bandwidth) on the transmit spectrum mask for 802.11ax
/// HIPAR bLevel/signals with the specified <bandwidth>.
/// HIPAR cLevel/Defines the relative spectral density limit for point C (frequency
/// HIPAR cLevel/offset: 1*bandwidth) on the transmit spectrum mask for 802.11ax signals
/// HIPAR cLevel/with the specified <bandwidth>.
/// HIPAR dLevel/Defines the relative spectral density limit for point D (center
/// HIPAR dLevel/frequency offset: 1/2*bandwidth + 1 MHz) on the transmit spectrum mask
/// HIPAR dLevel/for 802.11ax signals with the specified <bandwidth>.
/// HIPAR absolute11ax/Defines an absolute power limit for 802.11ax signals with the
/// HIPAR absolute11ax/specified <bandwidth>.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskOFDM80211AX(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean ofdmEnable,
                            ViReal64  aLevel,
                            ViReal64  bLevel,
                            ViReal64  cLevel,
                            ViReal64  dLevel,
                            ViReal64  absolute11ax)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   rep_capp[50] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, bandwidth, RSCMWWLM_VAL_INPUT_SIGNAL_BW_20MHZ, RSCMWWLM_VAL_INPUT_SIGNAL_BW_40MHZ),
           3, "Bandwidth");

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   sprintf(rep_capp, "%s,%s", repCap, BandArr[bandwidth]);

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AX_ENABLE, ofdmEnable),
           4, "OFDM Enable");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AX_LEVEL_A, aLevel),
           5, "A Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AX_LEVEL_B, bLevel),
           6, "B Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AX_LEVEL_C, cLevel),
           7, "C Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AX_LEVEL_D, dLevel),
           8, "D Level");

   viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AX_ABSOLUTE_LIMIT, absolute11ax),
           9, "Absolute 11ax");

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Defines and activates the spectrum flatness limit check for IEEE
/// HIFN  802.11ax OFDM signal with the appropriate bandwidth.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR bandwidth/Selects the channel bandwidth for standard version 802.11ax.
/// HIPAR enable/Enables or disables the spectrum flatness limit check for 802.11ax
/// HIPAR enable/signals with the specified <bandwidth>.
/// HIPAR center/Sets the center subcarriers.
/// HIPAR side/Sets the side subcarriers.
/// HIPAR upper/Defines an upper limit for the spectrum flatness of 802.11ax signals
/// HIPAR upper/with the specified <bandwidth>. The upper limit must be larger than the
/// HIPAR upper/lower limits.
ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumFlatnessOFDM80211AX(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean enable,
                            ViReal64  center,
                            ViReal64  side,
                            ViReal64  upper)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViChar   rep_caps[30] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, bandwidth, RSCMWWLM_VAL_INPUT_SIGNAL_BW_20MHZ, RSCMWWLM_VAL_INPUT_SIGNAL_BW_160MHZ),
           3, "Bandwidth");

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   sprintf(rep_caps, "%s,%s", repCap, BandArr[bandwidth]);

   viCheckParm(rscmwwlm_SetAttributeViBoolean(instrSession, rep_caps, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211AX_ENABLE, enable),
           4, "Enable");

   if (enable == VI_TRUE)
   {
      viCheckParm(RsCore_InvalidViReal64Range(instrSession, center, -20.0, 4.0), 5, "Center");
      viCheckParm(RsCore_InvalidViReal64Range(instrSession, side, -20.0, 4.0), 6, "Side");

      snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:MEAS%ld:MEV:LIM:SFL:HEOF:BW%s:LOW %.12lG, %.12lG", instance, BandwidthArr[bandwidth], center, side);
      checkErr(RsCore_Write(instrSession, cmd));

      checkErr(rscmwwlm_CheckStatus(instrSession));

      viCheckParm(rscmwwlm_SetAttributeViReal64(instrSession, rep_caps, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211AX_UPPER, upper),
              7, "Upper");
   }

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Multi Eval Measurement Init
 * Purpose:  Starts or restarts the measurement; the R&S CMW 500 enters the
 *           "RUN" state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_MEvalMeasInit(ViSession instrSession,
                                         ViInt32   instance)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViString(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_INIT, NULL),
           3, "Multi Eval Measurement Init");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Multi Eval Measurement Abort
 * Purpose:  Causes a running measurement to stop immediately; the R&S CMW 500
 *           enters the "OFF" state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_MEvalMeasAbort(ViSession instrSession,
                                          ViInt32   instance)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViString(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_ABORT, NULL),
           3, "Multi Eval Measurement Abort");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Multi Eval Measurement Stop
 * Purpose:  Causes a running measurement to stop after the current evaluation
 *           period is terminated and valid results are available; the R&S CMW
 *           500 enters the "RDY" state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_MEvalMeasStop(ViSession instrSession,
                                         ViInt32   instance)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViString(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_STOP, NULL),
           3, "Multi Eval Measurement Stop");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval Measurement Status
 * Purpose:  Queries the main measurement state and the measurement substates.
 *           Both measurement substates are relevant for running measurements
 *           only. Use FETCh...MEASurement<instance>:STATe? to query the main
 *           measurement state only. Use INITiate..., STOP..., ABORt... to
 *           change the measurement state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasurementStatus(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32*  mainState,
                                                       ViInt32*  syncState,
                                                       ViInt32*  resourcesState)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:STAT:ALL?", instance);
   checkErr(rscmwwlm_QueryMeasStatus(instrSession, cmd, mainState, syncState,
      resourcesState));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query OFDMA Information
 * Purpose:  Queries OFDMA common information.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryOFDMAInformation(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32*  reliability,
                                                 ViInt32*  numberOfUsers,
                                                 ViInt32*  numberOfResourceUnits)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:OFDM:INFO?", instance);
   checkErr(RsCore_QueryTupleViInt32(instrSession, cmd, reliability, numberOfUsers, numberOfResourceUnits, NULL));
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Queries OFDMA user-specific information signaled in a HE signal field.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/OFDMA user-specific information signaled in a HE signal field.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR user/User number.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchOFDMAUserInformation(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32   user,
                                                     ViInt32   arraySize,
                                                     ViInt32*  reliability,
                                                     ViInt32   results[],
                                                     ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar*  ext_buf = NULL;
   ViChar*  p2buf;
   ViInt32  i = 0;
   ViString codingTypeArr[] = { "BCC", "LDPC", NULL };

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, user, 1, 74),
           3, "User");
   viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, arraySize, 10), 4, "Array Size");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:OFDM:UINF%ld?", instance, user);
   checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
   checkErr(rscmwwlm_CheckStatus(instrSession));

   p2buf = strtok(ext_buf, ",");
   if (p2buf == NULL)
      checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
   if (reliability != NULL)
      *reliability = atol(p2buf);

   for (i = 0; i < 9; i++)
   {
      p2buf = strtok(NULL, ",\n");
      if (p2buf == NULL)
         checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
      results[i] = RsCore_Convert_String_To_ViInt32(p2buf);
   }

   p2buf = strtok(NULL, ",\n");
   if (p2buf == NULL)
      checkErr(RSCMWWLM_ERROR_INCORRECT_RESPONSE);
   results[i++] = RsCore_FindStringIndex(codingTypeArr, p2buf);

   *returnedValues = i;

Error:
   if (ext_buf) free(ext_buf);
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM Values
 * Purpose:  Starts a new single shot measurement and returns current single
 *           value results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMValues(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   resultType,
                                                   ViInt32   arraySize,
                                                   ViInt32*  reliability,
                                                   ViInt32*  modulationType,
                                                   ViReal64  results[],
                                                   ViInt32*  guardInterval,
                                                   ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, 0, 2),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:OFDM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetOFDMResults(instrSession, cmd, 10000, (arraySize > 12) ? 12 : arraySize, reliability, modulationType, ofdmModulationArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM Values
 * Purpose:  Returns current single value results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMValues(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   resultType,
                                                    ViInt32   arraySize,
                                                    ViInt32*  reliability,
                                                    ViInt32*  modulationType,
                                                    ViReal64  results[],
                                                    ViInt32*  guardInterval,
                                                    ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, 0, 2),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:OFDM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetOFDMResults(instrSession, cmd, 0, (arraySize > 12) ? 12 : arraySize, reliability, modulationType, ofdmModulationArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval OFDM Limit Check Results
 * Purpose:  Queries OFDM measurement limit check results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViInt32   results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, 0, 2),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:OFDM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetOFDMMeasLimitCheck(instrSession, cmd, (arraySize > 12) ? 12 : arraySize, reliability, modulationType, results, guardInterval, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM Standard Deviation
 * Purpose:  Starts a new single shot measurement and returns standard
 *           deviations.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:OFDM:SDEV?", instance);
   checkErr(rscmwwlm_GetOFDMResults(instrSession, cmd, 10000, (arraySize > 12) ? 12 : arraySize, reliability, modulationType, ofdmModulationArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM Standard Deviation
 * Purpose:  Returns standard deviations.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:OFDM:SDEV?", instance);
   checkErr(rscmwwlm_GetOFDMResults(instrSession, cmd, 0, (arraySize > 12) ? 12 : arraySize, reliability, modulationType, ofdmModulationArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval OFDM Standard Deviation Limit Check Results
 * Purpose:  Queries limit check results of standard deviation of OFDM
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMStandardDeviationLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViInt32   results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:OFDM:SDEV?", instance);
   checkErr(rscmwwlm_GetOFDMMeasLimitCheck(instrSession, cmd, (arraySize > 12) ? 12 : arraySize, reliability, modulationType, results, guardInterval, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM Transmit Spectrum Mask Values
 * Purpose:  Starts a new single shot measurement and returns the limit line
 *           margin values of the transmit spectrum mask measurement results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:OFDM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM Transmit Spectrum Mask Values
 * Purpose:  Returns the limit line margin values of the transmit spectrum
 *           mask measurement results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:OFDM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval OFDM Transmit Spectrum Mask Limit Check Results
 * Purpose:  Returns the limit check results of the transmit spectrum mask
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMTransmitSpectrumMaskLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:TSM:OFDM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM EVM vs Carrier Trace
 * Purpose:  Starts a new single shot measurement and returns values of the
 *           EVM vs subcarrier traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMEVMCarrierTrace(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   resultType,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  results[],
                                                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:EVM:CARR:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM EVM vs Carrier Trace
 * Purpose:  Returns values of the EVM vs subcarrier traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMEVMCarrierTrace(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:EVM:CARR:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM EVM vs Carrier Trace Enhanced
 * Purpose:  Starts a new single shot measurement and returns values of the
 *           EVM vs subcarrier traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMEVMCarrierTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:EVM:CARR:%s? %ld, %ld, %ld", instance, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM EVM vs Carrier Trace Enhanced
 * Purpose:  Returns values of the EVM vs subcarrier traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMEVMCarrierTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:EVM:CARR:%s? %ld, %ld, %ld", instance, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM Spectrum Flatness Trace
 * Purpose:  Starts a new single shot measurement and returns values of the
             spectrum flatness traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMSpectrumFlatnessTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:SFL:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM Spectrum Flatness Trace
 * Purpose:  Returns values of the spectrum flatness traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSpectrumFlatnessTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:SFL:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM Spectrum Flatness Trace Enhanced
 * Purpose:  Starts a new single shot measurement and returns values of the
 *           spectrum flatness traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMSpectrumFlatnessTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:SFL:%s? %ld, %ld, %ld", instance, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM Spectrum Flatness Trace Enhanced
 * Purpose:  Returns values of the spectrum flatness traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSpectrumFlatnessTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:SFL:%s? %ld, %ld, %ld", instance, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return carrier frequency offset (CFO) error traces for HE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return carrier frequency offset (CFO) error traces for HE.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMTraceCFOErrors(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   start,
                                                           ViInt32   count,
                                                           ViInt32   decimation,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  results[],
                                                           ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:CFER? %ld, %ld, %ld", instance, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return carrier frequency offset (CFO) error traces for HE.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return carrier frequency offset (CFO) error traces for HE.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMTraceCFOErrors(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   start,
                                                            ViInt32   count,
                                                            ViInt32   decimation,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  results[],
                                                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:SFL:CFER? %ld, %ld, %ld", instance, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the scalar results for carrier frequency offset (CFO) error
/// HIFN  distribution.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the scalar results for carrier frequency offset (CFO) error
/// HIPAR results/distribution.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMCFO(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32   arraySize,
                                                ViInt32*  reliability,
                                                ViReal64  results[],
                                                ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:CFD?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the scalar results for carrier frequency offset (CFO) error
/// HIFN  distribution.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the scalar results for carrier frequency offset (CFO) error
/// HIPAR results/distribution.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMCFO(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32   arraySize,
                                                 ViInt32*  reliability,
                                                 ViReal64  results[],
                                                 ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:CFD?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the scalar results for carrier frequency offset (CFO) error
/// HIFN  distribution.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the scalar results for carrier frequency offset (CFO) error
/// HIPAR results/distribution.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMultiEvalOFDMCFOLimitCheckResult(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:CFD?", instance);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the scalar results for timing error (TE) distribution.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the scalar results for timing error (TE) distribution.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMTE(ViSession instrSession,
                                               ViInt32   instance,
                                               ViInt32   arraySize,
                                               ViInt32*  reliability,
                                               ViReal64  results[],
                                               ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:PVT:TED?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the scalar results for timing error (TE) distribution.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the scalar results for timing error (TE) distribution.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMTE(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32   arraySize,
                                                ViInt32*  reliability,
                                                ViReal64  results[],
                                                ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:PVT:TED?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the scalar results for timing error (TE) distribution.
/// HIFN
/// HIFN     The commands are only supported for OFDM standards.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the scalar results for timing error (TE) distribution.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMultiEvalOFDMTELimitCheckResult(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:PVT:TED?", instance);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Queries OFDMA common information.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Queries OFDMA common information.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMCommonInformation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:OFDM:INFO?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM 802.11n EVM vs Carrier Trace
 * Purpose:  Starts a new single shot measurement and returns OFDM 802.11n
             values of the EVM vs subcarrier traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDM80211NEVMCarrierTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:EVM:NSIS:CARR:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM 802.11n EVM vs Carrier Trace
 * Purpose:  Returns OFDM 802.11n values of the EVM vs subcarrier traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDM80211NEVMCarrierTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:EVM:NSIS:CARR:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM 802.11n EVM vs Carrier Trace Enhanced
 * Purpose:  Starts a new single shot measurement and returns OFDM 802.11n
 *           values of the EVM vs subcarrier traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDM80211NEVMCarrierTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:EVM:NSIS:CARR:%s? %ld, %ld, %ld", instance, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM 802.11n EVM vs Carrier Trace Enhanced
 * Purpose:  Starts a new single shot measurement and returns OFDM 802.11n
 *           values of the EVM vs subcarrier traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDM80211NEVMCarrierTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:EVM:NSIS:CARR:%s? %ld, %ld, %ld", instance, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM 802.11n Transmit Spectrum Mask Values
 * Purpose:  Starts a new single shot measurement and returns the limit line
             margin values of the transmit spectrum mask measurement results,
             standard 802.11n.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDM80211NTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:NSIS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM 802.11n Transmit Spectrum Mask Values
 * Purpose:  Returns the limit line margin values of the transmit spectrum
             mask measurement results, standard 802.11n.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDM80211NTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:NSIS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval OFDM 802.11n Transmit Spectrum Mask Limit Check Results
 * Purpose:  Returns the limit check results of the transmit spectrum mask
             measurement, standard 802.11n.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDM80211NTransmitSpectrumMaskLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:TSM:NSIS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM 802.11ac Values
 * Purpose:  Starts a new single shot measurement and returns current single
 *           value results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDM80211ACValues(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   resultType,
                                                          ViInt32   arraySize,
                                                          ViInt32*  reliability,
                                                          ViReal64  results[],
                                                          ViInt32*  guardInterval,
                                                          ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, 0, 2),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:ACS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetACSISOResults(instrSession, cmd, 10000, (arraySize > 13) ? 13 : arraySize, reliability, NULL, ofdmModulationArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM 802.11ac Values
 * Purpose:  Returns current single value results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDM80211ACValues(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   resultType,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  results[],
                                                           ViInt32*  guardInterval,
                                                           ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, 0, 2),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:ACS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetACSISOResults(instrSession, cmd, 0, (arraySize > 13) ? 13 : arraySize, reliability, NULL, ofdmModulationArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval OFDM 802.11ac Limit Check Results
 * Purpose:  Queries OFDM measurement limit check results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDM80211ACLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, 0, 2),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:ACS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetACSISOMeasLimitCheck(instrSession, cmd, (arraySize > 13) ? 13 : arraySize, reliability, NULL, results, guardInterval, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM 802.11ac Standard Deviation
 * Purpose:  Starts a new single shot measurement and returns standard
 *           deviations.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDM80211ACStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:ACS:SDEV?", instance);
   checkErr(rscmwwlm_GetACSISOResults(instrSession, cmd, 10000, (arraySize > 13) ? 13 : arraySize, reliability, NULL, ofdmModulationArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM 802.11ac Standard Deviation
 * Purpose:  Returns standard deviations.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDM80211ACStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:ACS:SDEV?", instance);
   checkErr(rscmwwlm_GetACSISOResults(instrSession, cmd, 0, (arraySize > 13) ? 13 : arraySize, reliability, NULL, ofdmModulationArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval OFDM 802.11ac Standard Deviation Limit Check Results
 * Purpose:  Queries limit check results of standard deviation of OFDM
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDM80211ACStandardDeviationLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:ACS:SDEV?", instance);
   checkErr(rscmwwlm_GetACSISOMeasLimitCheck(instrSession, cmd, (arraySize > 13) ? 13 : arraySize, reliability, NULL, results, guardInterval, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM 802.11ac Transmit Spectrum Mask Values
 * Purpose:  Starts a new single shot measurement and returns the limit line
 *           margin values of the transmit spectrum mask measurement results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDM80211ACTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:ACS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM 802.11ac Transmit Spectrum Mask Values
 * Purpose:  Returns the limit line margin values of the transmit spectrum
 *           mask measurement results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDM80211ACTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:ACS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval OFDM 802.11ac Transmit Spectrum Mask Limit Check Results
 * Purpose:  Returns the limit check results of the transmit spectrum mask
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDM80211ACTransmitSpectrumMaskLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:TSM:ACS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval DSSS Values
 * Purpose:  Starts a new single shot measurement and returns current single
 *           value results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasDSSSValues(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   resultType,
                                                   ViInt32   arraySize,
                                                   ViInt32*  reliability,
                                                   ViInt32*  modulationType,
                                                   ViInt32*  PLCPType,
                                                   ViReal64  results[],
                                                   ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, 0, 3),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:DSSS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetDSSSResults(instrSession, cmd, 10000, arraySize, reliability, modulationType, dsssModulationArr, PLCPType, burstTypeArr, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval DSSS Values
 * Purpose:  Returns current single value results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasDSSSValues(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   resultType,
                                                    ViInt32   arraySize,
                                                    ViInt32*  reliability,
                                                    ViInt32*  modulationType,
                                                    ViInt32*  PLCPType,
                                                    ViReal64  results[],
                                                    ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, 0, 3),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:DSSS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetDSSSResults(instrSession, cmd, 0, arraySize, reliability, modulationType, dsssModulationArr, PLCPType, burstTypeArr, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval DSSS Limit Check Results
 * Purpose:  Queries DSSS measurement limit check results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasDSSSLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViInt32*  PLCPType,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, 0, 3),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:DSSS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetDSSSMeasLimitCheck(instrSession, cmd, arraySize, reliability, modulationType, PLCPType, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval DSSS Standard Deviation
 * Purpose:  Starts a new single shot measurement and returns standard
 *           deviations.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasDSSSStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViInt32*  PLCPType,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:DSSS:SDEV?", instance);
   checkErr(rscmwwlm_GetDSSSResults(instrSession, cmd, 10000, arraySize, reliability, modulationType, dsssModulationArr, PLCPType, burstTypeArr, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval DSSS Standard Deviation
 * Purpose:  Returns standard deviations.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasDSSSStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViInt32*  PLCPType,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:DSSS:SDEV?", instance);
   checkErr(rscmwwlm_GetDSSSResults(instrSession, cmd, 0, arraySize, reliability, modulationType, dsssModulationArr, PLCPType, burstTypeArr, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval DSSS Standard Deviation Limit Check Results
 * Purpose:  Queries limit check results of standard deviation of DSSS
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasDSSSStandardDeviationLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViInt32*  PLCPType,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:DSSS:SDEV?", instance);
   checkErr(rscmwwlm_GetDSSSMeasLimitCheck(instrSession, cmd, arraySize, reliability, modulationType, PLCPType, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval DSSS Transmit Spectrum Mask Values
 * Purpose:  Starts a new single shot measurement and returns the limit line
 *           margin values of the transmit spectrum mask measurement results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasDSSSTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:DSSS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval DSSS Transmit Spectrum Mask Values
 * Purpose:  Returns the limit line margin values of the transmit spectrum mask
 *           measurement results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasDSSSTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:DSSS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval DSSS Transmit Spectrum Mask Limit Check Results
 * Purpose:  Returns the limit check results of the transmit spectrum mask
 *           measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasDSSSTransmitSpectrumMaskLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:TSM:DSSS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval DSSS EVM Trace
 * Purpose:  Starts a new single shot measurement and returns values of the
 *           EVM vs chip traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasDSSSEVMTrace(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32   resultType,
                                                     ViInt32   arraySize,
                                                     ViInt32*  reliability,
                                                     ViReal64  results[],
                                                     ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:EVM:DSSS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval DSSS EVM Trace
 * Purpose:  Returns values of the EVM vs chip traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasDSSSEVMTrace(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32   resultType,
                                                      ViInt32   arraySize,
                                                      ViInt32*  reliability,
                                                      ViReal64  results[],
                                                      ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:EVM:DSSS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval DSSS EVM Trace Enhanced
 * Purpose:  Starts a new single shot measurement and returns values of the
 *           EVM vs chip traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasDSSSEVMTraceEnhanced(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   start,
                                                             ViInt32   count,
                                                             ViInt32   decimation,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:EVM:DSSS:%s? %ld, %ld, %ld", instance, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval DSSS EVM Trace Enhanced
 * Purpose:  Returns values of the EVM vs chip traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasDSSSEVMTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:EVM:DSSS:%s? %ld, %ld, %ld", instance, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and returns current single value
/// HIFN  results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR modulationScheme/Modulation scheme and coding rate.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMMIMOValues(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   resultType,
                                                   ViInt32   arraySize,
                                                   ViInt32   stream,
                                                   ViInt32*  reliability,
                                                   ViInt32*  modulationScheme,
                                                   ViReal64  results[],
                                                   ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:MIMO%ld:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetOFDMMeasResultsMIMO(instrSession, cmd, 10000, arraySize, reliability, modulationScheme, modulationSchemeArr, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns current single value results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR modulationScheme/Modulation scheme and coding rate.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMMIMOValues(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   resultType,
                                                    ViInt32   arraySize,
                                                    ViInt32   stream,
                                                    ViInt32*  reliability,
                                                    ViInt32*  modulationScheme,
                                                    ViReal64  results[],
                                                    ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:MIMO%ld:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetOFDMMeasResultsMIMO(instrSession, cmd, 0, arraySize, reliability, modulationScheme, modulationSchemeArr, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Queries OFDM MIMO measurement limit check results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR modulationScheme/Modulation scheme and coding rate.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMMIMOLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:MIMO%ld:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetOFDMMIMOMeasLimitCheck(instrSession, cmd, arraySize, reliability, modulationScheme, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and returns standard deviations.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
/// HIPAR stream/Select the MIMO
/// HIPAR modulationScheme/Modulation scheme and coding rate.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMMIMOStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:MIMO%ld:SDEV?", instance, stream);
   checkErr(rscmwwlm_GetOFDMMeasResultsMIMO(instrSession, cmd, 10000, arraySize, reliability, modulationScheme, modulationSchemeArr, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns standard deviations.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
/// HIPAR stream/Select the MIMO
/// HIPAR modulationScheme/Modulation scheme and coding rate.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMMIMOStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:MIMO%ld:SDEV?", instance, stream);
   checkErr(rscmwwlm_GetOFDMMeasResultsMIMO(instrSession, cmd, 0, arraySize, reliability, modulationScheme, modulationSchemeArr, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Queries limit check results of standard deviation of OFDM MIMO
/// HIFN  measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
/// HIPAR stream/Select the MIMO
/// HIPAR modulationScheme/Modulation scheme and coding rate.
ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMMIMOStandardDeviationLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:MIMO%ld:SDEV?", instance, stream);
   checkErr(rscmwwlm_GetOFDMMIMOMeasLimitCheck(instrSession, cmd, arraySize, reliability, modulationScheme, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and return the segment-specific
/// HIFN  single value results for switched MIMO measurements, antenna/stream
/// HIFN  number <n>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMMIMOSegments80Plus80Values(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:MIMO%ld:SEGM:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the segment-specific single value results for switched MIMO
/// HIFN  measurements, antenna/stream number <n>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMMIMOSegments80Plus80Values(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:MIMO%ld:SEGM:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the segment-specific single value limit check results for
/// HIFN  switched MIMO measurements, antenna/stream number <n>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMMIMOSegments80Plus80LimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:MIMO%ld:SEGM:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and return the segment-specific
/// HIFN  single value standard deviations for switched MIMO measurements,
/// HIFN  antenna/stream number <n>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMMIMOSegments80Plus80StandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:MIMO%ld:SEGM:SDEV?", instance, stream);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the segment-specific single value standard deviations for
/// HIFN  switched MIMO measurements, antenna/stream number <n>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMMIMOSegments80Plus80StandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:MIMO%ld:SEGM:SDEV?", instance, stream);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the segment-specific single value standard deviations limit
/// HIFN  check results for switched MIMO measurements, antenna/stream number
/// HIFN  <n>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMMIMOSegments80Plus80StandardDeviationLimitCheckResult(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:MIMO%ld:SEGM:SDEV?", instance, stream);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM MIMO Spectrum Flatness Values
 * Purpose:  Returns the single value margins for switched MIMO measurements.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMMIMOSpectrumFlatnessValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:SFL:MIMO%ld:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM MIMO Spectrum Flatness Values
 * Purpose:  Returns the single value margins for switched MIMO measurements.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMMIMOSpectrumFlatnessValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:SFL:MIMO%ld:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/********************************************************************************
 * Function: Read Multi Eval OFDM MIMO Spectrum Flatness Margin Positions Values
 * Purpose:  Starts a new single shot measurement and returns the subcarrier
 *           indices for the current, average, minimum and maximum margin values
 *           for switched MIMO, antenna/stream number <n>.
 ********************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMMIMOSpectrumFlatnessMarginPositionsValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:SFL:MIMO%ld:X:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/********************************************************************************
 * Function: Fetch Multi Eval OFDM MIMO Spectrum Flatness Margin Positions Values
 * Purpose:  Return the subcarrier indices for the current, average, minimum and
 *             maximum margin values for switched MIMO, antenna/stream number <n>.
 ********************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMMIMOSpectrumFlatnessMarginPositionsValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:SFL:MIMO%ld:X:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval OFDM MIMO Spectrum Flatness Limit Check Results
 * Purpose:  Returns limit check results of the spectrum flatness margins
 *             single value results of the MIMO measurement.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMMIMOSpectrumFlatnessLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   stream,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:SFL:MIMO%ld:%s?", instance, stream, resultTypeArr[resultType]);

   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval Meas OFDM Spectrum Flatness Rx Antenna Trace
 * Purpose:  Starts a new single shot measurement and returns the spectrum
 *           flatness traces for Rx antenna {n} and stream {s}, for switched
 *             and true MIMO measurements.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMSpectrumFlatnessRxAntennaTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   stream,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           2, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           3, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:SFL:MIMO:RXAN%ld:STR%ld:%s? %ld, %ld, %ld", instance, antenna, stream, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval Meas OFDM Spectrum Flatness Rx Antenna Trace
 * Purpose:  Return the spectrum flatness traces for Rx antenna <n> and
 *           stream, for switched and true MIMO measurements.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSpectrumFlatnessRxAntennaTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   stream,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           2, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           3, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:SFL:MIMO:RXAN%ld:STR%ld:%s? %ld, %ld, %ld", instance, antenna, stream, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/******************************************************************************************
 * Function: Query Multi Eval Meas OFDM Spectrum Flatness Rx Antenna Limit Chech Results
 * Purpose:  Queries the spectrum flatness traces for Rx antenna <n> and
 *           stream limit check results.
 ******************************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMSpectrumFlatnessRxAntennaLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   stream,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           2, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           3, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:TRAC:SFL:MIMO:RXAN%ld:STR%ld:%s? %ld, %ld, %ld", instance, antenna, stream, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/************************************************************************************
 * Function: Read Multi Eval Meas OFDM Spectrum Flatness Rx Antenna segment Trace
 * Purpose:  Starts a new single shot measurement and returns the spectrum flatness
 *             traces for Rx antenna {n}, stream {s}, and segment {seg} for switched
 *             MIMO measurements and bandwidths with two segments (80+80 MHz).
 ************************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMSpectrumFlatnessRxAntennaSegmentTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   stream,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           2, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           3, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           5, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:SFL:MIMO:RXAN%ld:STR%ld:SEGM%ld:%s? %ld, %ld, %ld", instance, antenna, stream, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/************************************************************************************
 * Function: Fetch Multi Eval Meas OFDM Spectrum Flatness Rx Antenna segment Trace
 * Purpose:  Return the spectrum flatness traces for Rx antenna {n}, stream {s},
 *             and segment <seg> for switched MIMO measurements and bandwidths with
 *             two segments (80+80 MHz).
 ************************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSpectrumFlatnessRxAntennaSegmentTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   stream,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           2, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           3, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           5, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:SFL:MIMO:RXAN%ld:STR%ld:SEGM%ld:%s? %ld, %ld, %ld", instance, antenna, stream, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/************************************************************************************
 * Function: Query Multi Eval Meas OFDM SFL Rx Antenna Segment Limit Check Results
 * Purpose:  Queries the spectrum flatness traces for Rx antenna {n}, stream {s},
 *             and segment {seg} limit check results.
 ************************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMSFLRxAntennaSegmentLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   stream,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           2, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           3, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           5, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:TRAC:SFL:MIMO:RXAN%ld:STR%ld:SEGM%ld:%s? %ld, %ld, %ld", instance, antenna, stream, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM CMIMO Power STS
 * Purpose:  Starts a new single shot measurement and returns the single
 *             value RMS power results for the individual space-time streams.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMCMIMOPowerSTS(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32   resultType,
                                                      ViInt32   arraySize,
                                                      ViInt32*  reliability,
                                                      ViReal64  results[],
                                                      ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:CMIM:PSTS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM CMIMO Power STS
 * Purpose:  Returns the single value RMS power results for the individual
 *             space-time streams.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMCMIMOPowerSTS(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   resultType,
                                                       ViInt32   arraySize,
                                                       ViInt32*  reliability,
                                                       ViReal64  results[],
                                                       ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:CMIM:PSTS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM SMIMO Values
 * Purpose:  Starts a new single shot measurement and returns current single
 *           value results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMSMIMOValues(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   resultType,
                                                    ViInt32   arraySize,
                                                    ViInt32*  reliability,
                                                    ViReal64  results[],
                                                    ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:SMIM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval OFDM SMIMO Values
 * Purpose:  Returns current single value results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMSMIMOValues(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32   resultType,
                                                     ViInt32   arraySize,
                                                     ViInt32*  reliability,
                                                     ViReal64  results[],
                                                     ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:SMIM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval OFDM SMIMO Limit Check Results
 * Purpose:  Queries OFDM SMIMO measurement limit check results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMSMIMOLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:SMIM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM SMIMO Standard Deviation
 * Purpose:  Starts a new single shot measurement and returns current single
 *           value results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMSMIMOStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:SMIM:SDEV?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval OFDM SMIMO Standard Deviation
 * Purpose:  Returns current single value results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMSMIMOStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:SMIM:SDEV?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval OFDM SMIMO Standard Deviation Limit Check Results
 * Purpose:  Queries OFDM SMIMO measurement limit check results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMSMIMOStandardDeviationLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:SMIM:SDEV?", instance);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval Spectrum Flatness OFDM SISO
 * Purpose:  Reads the statistical spectrum flatness results for an OFDM SISO
             signal.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalSpectrumFlatnessOFDMSISO(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:SFL:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval Spectrum Flatness OFDM SISO
 * Purpose:  Returns the margin values of the Spectrum Flatness measurement
             for the current, average, maximum and minimum traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalSpectrumFlatnessOFDMSISO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:SFL:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval Spectrum Flatness OFDM SISO Limit Check
 * Purpose:  Returns limit check results of the spectrum flatness.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalSpectrumFlatnessOFDMSISOLimitCheck(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:SFL:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval Spectrum Flatness Subcarrier Indices
 * Purpose:  Reads the subcarrier indices corresponding to the statistical
             spectrum flatness results for an OFDM SISO signal.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalSpectrumFlatnessSubcarrierIndices(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:SFL:X:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval Spectrum Flatness Subcarrier Indices
 * Purpose:  Returns the subcarrier indices corresponding to the statistical
             spectrum flatness results for an OFDM SISO signal.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalSpectrumFlatnessSubcarrierIndices(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:SFL:X:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and returns the single value
/// HIFN  results for OFDM SISO measurements. For switched MIMO measurements, the
/// HIFN  stream/antenna-independent values are returned. For 80+80 MHz signals,
/// HIFN  the segment-independent values are returned.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR modulationScheme/Modulation scheme and coding rate.
/// HIPAR results/Returns result values.
/// HIPAR guardInterval/Returns the guard interval.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMSISOValues(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   resultType,
                                                       ViInt32   arraySize,
                                                       ViInt32*  reliability,
                                                       ViInt32*  modulationScheme,
                                                       ViReal64  results[],
                                                       ViInt32*  guardInterval,
                                                       ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetOFDMSISOResults(instrSession, cmd, 10000, arraySize, reliability, modulationScheme, modulationSchemeArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the single value results for OFDM SISO measurements. For
/// HIFN  switched MIMO measurements, the stream/antenna-independent values are
/// HIFN  returned. For 80+80 MHz signals, the segment-independent values are
/// HIFN  returned.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR modulationScheme/Modulation scheme and coding rate.
/// HIPAR results/Returns result values.
/// HIPAR guardInterval/Returns the guard interval.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSISOValues(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   resultType,
                                                        ViInt32   arraySize,
                                                        ViInt32*  reliability,
                                                        ViInt32*  modulationScheme,
                                                        ViReal64  results[],
                                                        ViInt32*  guardInterval,
                                                        ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetOFDMSISOResults(instrSession, cmd, 0, arraySize, reliability, modulationScheme, modulationSchemeArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Queries OFDM SISO measurement limit check results.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR modulationScheme/Modulation scheme and coding rate.
/// HIPAR results/Returns result values.
/// HIPAR guardInterval/Returns the guard interval.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMSISOLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViInt32   results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetOFDMMeasLimitCheck(instrSession, cmd, arraySize, reliability, modulationScheme, results, guardInterval, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and returns the single value
/// HIFN  standard deviations for OFDM SISO measurements. For switched MIMO
/// HIFN  measurements, the stream/antenna-independent values are returned. For
/// HIFN  80+80 MHz signals, the segment-independent values are returned.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR modulationScheme/Modulation scheme and coding rate.
/// HIPAR results/Returns result values.
/// HIPAR guardInterval/Returns the guard interval.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMSISOStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:SDEV?", instance);
   checkErr(rscmwwlm_GetOFDMSISOResults(instrSession, cmd, 10000, arraySize, reliability, modulationScheme, modulationSchemeArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the single value standard deviations for OFDM SISO
/// HIFN  measurements. For switched MIMO measurements, the
/// HIFN  stream/antenna-independent values are returned. For 80+80 MHz signals,
/// HIFN  the segment-independent values are returned.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR modulationScheme/Modulation scheme and coding rate.
/// HIPAR results/Returns result values.
/// HIPAR guardInterval/Returns the guard interval.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSISOStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:SDEV?", instance);
   checkErr(rscmwwlm_GetOFDMSISOResults(instrSession, cmd, 0, arraySize, reliability, modulationScheme, modulationSchemeArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Queries limit check results of standard deviation of OFDM SISO
/// HIFN  measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR modulationScheme/Modulation scheme and coding rate.
/// HIPAR results/Returns result values.
/// HIPAR guardInterval/Returns the guard interval.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMSISOStandardDeviationLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViInt32   results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:SDEV?", instance);
   checkErr(rscmwwlm_GetOFDMMeasLimitCheck(instrSession, cmd, arraySize, reliability, modulationScheme, results, guardInterval, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and return the segment-specific
/// HIFN  single value results for 80+80 MHz SISO measurements. For switched MIMO
/// HIFN  measurements, the stream/antenna-independent values are returned.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMSegments80Plus80Values(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:SEGM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the segment-specific single value results for 80+80 MHz SISO
/// HIFN  measurements. For switched MIMO measurements, the
/// HIFN  stream/antenna-independent values are returned.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMSegments80Plus80Values(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:SEGM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Queries the segment-specific single value measurement limit check
/// HIFN  results for 80+80 MHz SISO measurements. For switched MIMO
/// HIFN  measurements, the stream/antenna-independent values are returned.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMSegments80Plus80LimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:SEGM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and return the segment-specific
/// HIFN  single value standard deviations for 80+80 MHz SISO measurements. For
/// HIFN  switched MIMO measurements, the stream/antenna-independent values are
/// HIFN  returned.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMSegments80Plus80StandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:MOD:SEGM:SDEV?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the segment-specific single value standard deviations for 80+80
/// HIFN  MHz SISO measurements. For switched MIMO measurements, the
/// HIFN  stream/antenna-independent values are returned.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMSegments80Plus80StandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:SEGM:SDEV?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Queries the segment-specific single value standard deviations limit
/// HIFN  check results for 80+80 MHz SISO measurements. For switched MIMO
/// HIFN  measurements, the stream/antenna-independent values are returned.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMSegments80Plus80StandardDeviationLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:MOD:SEGM:SDEV?", instance);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the single value results per user for OFDMA SISO measurements.
/// HIFN  For MIMO measurements, the stream/antenna-independent values are returned.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSISOEVMValues(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   resultType,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  results[],
                                                           ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:EVM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the single value results per user for OFDMA SISO measurements.
/// HIFN  For MIMO measurements, the stream/antenna-independent values are returned.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR user/Sets the specified user.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSISOEVMUserValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   user,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, user, 1, 74),
           4, "User");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:EVM:USER%ld:%s?", instance, user, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the single value results for OFDMA MIMO measurements for
/// HIFN  the specified user and stream.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR user/Sets the specified user.
/// HIPAR stream/Sets the stream.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSISOEVMUserStreamValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   user,
                            ViInt32   stream,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, user, 1, 74),
           4, "User");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:MOD:EVM:USER%ld:STR%ld:%s?", instance, user, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and returns the spectrum flatness traces
/// HIFN  for segment <seg>, for SISO measurements and bandwidths with two segments (80+80 MHz).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR segment/Select the segment
/// HIPAR start/This control limits the returned array to the segment beginning with position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMSISOSpectrumFlatnessSegmentTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           2, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           3, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:SFL:SEGM%ld:%s? %ld, %ld, %ld",
           instance, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the spectrum flatness traces for segment <seg>, for SISO
/// HIFN  measurements and bandwidths with two segments (80+80 MHz).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR segment/Select the segment
/// HIPAR start/This control limits the returned array to the segment beginning with position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSISOSpectrumFlatnessSegmentTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           2, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           3, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:SFL:SEGM%ld:%s? %ld, %ld, %ld",
           instance, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Queries the spectrum flatness traces for segment <seg> limit check results
/// HIFN  measurements and bandwidths with two segments (80+80 MHz).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR segment/Select the segment
/// HIPAR start/This control limits the returned array to the segment beginning with position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMSISOSpectrumFlatnessSegmentLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           2, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           3, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:TRAC:SFL:SEGM%ld:%s? %ld, %ld, %ld",
           instance, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval PVT Burst Trace Results
 * Purpose:  Reads the values of Power vs. Time burst trace results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTBurstTraceResults(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   start,
                                                             ViInt32   count,
                                                             ViInt32   decimation,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:%s? %ld, %ld, %ld", instance, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval PVT Burst Trace Results
 * Purpose:  Returns the values of Power vs. Time burst trace results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTBurstTraceResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:%s? %ld, %ld, %ld", instance, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval PVT DSSS Statistical Edge
 * Purpose:  Reads the statistical Rise Time and Fall Time (edge) results for
             DSSS signals.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalPVTDSSSStatisticalEdge(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   edge,
                                                           ViInt32   resultType,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  results[],
                                                           ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:PVT:%s:%s?", instance, EdgeTimeArr[edge], resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval PVT DSSS Statistical Edge
 * Purpose:  Reads the statistical Rise Time and Fall Time (edge) results for
             DSSS signals.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalPVTDSSSStatisticalEdge(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   edge,
                                                            ViInt32   resultType,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  results[],
                                                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:PVT:%s:%s?", instance, EdgeTimeArr[edge], resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval PVT DSSS Limit Check Results
 * Purpose:  Returns the limit check results of the Power vs. Time
             statistical edge measurement for DSSS signals.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMultiEvalPVTDSSSLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:PVT:%s:%s?", instance, EdgeTimeArr[edge], resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval PVT Ramp Trace Results.
 * Purpose:  Reads the PvT ramp trace results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceResults(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   edge,
                                                            ViInt32   resultType,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  results[],
                                                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:%s?", instance, EdgeTimeArr[edge], resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval PVT Ramp Trace Results.
 * Purpose:  Returns the PvT ramp trace results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceResults(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   edge,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:%s?", instance, EdgeTimeArr[edge], resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval PVT Ramp Trace Time
 * Purpose:  Starts a new single shot measurement and returns the time
 *             indices for the current, average, minimum and maximum power vs.
 *             time traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceTime(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   arraySize,
                                                         ViInt32*  reliability,
                                                         ViReal64  results[],
                                                         ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:TIME?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval PVT Ramp Trace Time
 * Purpose:  Return the time indices for the current, average, minimum and
 *             maximum power vs. time traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceTime(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   arraySize,
                                                          ViInt32*  reliability,
                                                          ViReal64  results[],
                                                          ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:TIME?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval PVT Ramp Trace MIMO Results.
 * Purpose:  Starts a new single shot measurement and returns the PvT ramp
 *           traces for MIMO results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceMIMOResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           2, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:MIMO%ld:%s?", instance, EdgeTimeArr[edge], antenna, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval PVT Ramp Trace MIMO Results.
 * Purpose:  Returns the PvT ramp traces for MIMO results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceMIMOResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           2, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:MIMO%ld:%s?", instance, EdgeTimeArr[edge], antenna, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval PVT Ramp Trace MIMO Enhanced
 * Purpose:  Starts a new single shot measurement and returns the PvT ramp
 *             traces for MIMO enhanced Results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceMIMOEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:MIMO%ld:%s? %ld,%ld,%ld",
           instance, antenna, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval PVT Ramp Trace MIMO Enhanced
 * Purpose:  Returns the PvT ramp traces for MIMO enhanced Results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceMIMOEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:MIMO%ld:%s? %ld,%ld,%ld",
           instance, antenna, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval PVT Ramp Trace MIMO Time
 * Purpose:  Starts a new single shot measurement and returns the time
 *             indices for the current, average, minimum and maximum power vs.
 *             time traces (for MIMO)
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceMIMOTime(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   antenna,
                                                             ViInt32   start,
                                                             ViInt32   count,
                                                             ViInt32   decimation,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           3, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:MIMO%ld:TIME? %ld,%ld,%ld", instance, antenna, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval PVT Ramp Trace MIMO Time
 * Purpose:  Return the time indices for the current, average, minimum and
 *             maximum power vs. time traces (for MIMO)
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceMIMOTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antenna,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           3, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:MIMO%ld:TIME? %ld,%ld,%ld", instance, antenna, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*******************************************************************************
 * Function: Read Multi Eval PVT Ramp Trace MIMO Segment Enhanced
 * Purpose:  Starts a new single shot measurement and returns the values of
 *           the power vs. time traces for 80+80 MHz MIMO. The results of
 *             the current, average, maximum and minimum traces can be retrieved.
 *******************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceMIMOSegmentEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           5, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:MIMO%ld:SEGM%ld:%s? %ld,%ld,%ld", instance, antenna, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval PVT Ramp Trace MIMO Segment Enhanced
 * Purpose:  Returns the values of the power vs. time traces for 80+80 MHz
 *             MIMO. The results of the current, average, maximum and minimum
 *             traces can be retrieved.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceMIMOSegmentEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           5, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:MIMO%ld:SEGM%ld:%s? %ld,%ld,%ld", instance, antenna, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval PVT Ramp Trace Segment Results
 * Purpose:  Starts a new single shot measurement and returns the PvT ramp
 *           traces (for 80+80 MHz) results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceSegmentResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           4, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:SEGM%ld:%s? %ld,%ld,%ld", instance, EdgeTimeArr[edge], segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval PVT Ramp Trace Segment Results
 * Purpose:  Returns the PvT ramp traces (for 80+80 MHz) results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceSegmentResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           4, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:SEGM%ld:%s? %ld,%ld,%ld", instance, EdgeTimeArr[edge], segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval PVT Ramp Trace Segment Enhanced
 * Purpose:  Starts a new single shot measurement and returns the values of
 *             the power vs. time traces for 80+80 MHz. The results of the
 *             current, average, maximum and minimum traces can be retrieved.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceSegmentEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           4, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:SEGM%ld:%s? %ld,%ld,%ld",
           instance, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval PVT Ramp Trace Segment Enhanced
 * Purpose:  Return the values of the power vs. time traces for 80+80 MHz.
 *             The results of the current, average, maximum and minimum traces
 *             can be retrieved.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceSegmentEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           4, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:SEGM%ld:%s? %ld,%ld,%ld",
           instance, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval PVT Ramp Trace Segment Time
 * Purpose:  Starts a new single shot measurement and returns the time
 *             indices for the current, average, minimum and maximum power vs.
 *             time traces (for 80+80 MHz),
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           3, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:SEGM%ld:TIME? %ld,%ld,%ld", instance, segment, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval PVT Ramp Trace Segment Time
 * Purpose:  Returns the time indices for the current, average, minimum and
 *             maximum power vs. time traces (for 80+80 MHz),
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           3, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:SEGM%ld:TIME? %ld,%ld,%ld", instance, segment, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval PVT Ramp Trace Segment MIMO Results
 * Purpose:  Starts a new single shot measurement and returns the PvT ramp
 *           traces (for 80+80 MHz, MIMO) results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceSegmentMIMOResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           5, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:MIMO%ld:SEGM%ld:%s? %ld,%ld,%ld", instance, EdgeTimeArr[edge], antenna, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval PVT Ramp Trace Segment MIMO Results
 * Purpose:  Returns the PvT ramp traces (for 80+80 MHz, MIMO) results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceSegmentMIMOResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           5, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:MIMO%ld:SEGM%ld:%s? %ld,%ld,%ld", instance, EdgeTimeArr[edge], antenna, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval PVT Ramp Trace Results Enhanced
 * Purpose:  Reads the PvT ramp trace results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceResultsEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:%s? %ld, %ld, %ld",
           instance, EdgeTimeArr[edge], resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval PVT Ramp Trace Results Enhanced
 * Purpose:  Returns the PvT ramp trace results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceResultsEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:%s? %ld, %ld, %ld",
           instance, EdgeTimeArr[edge], resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the time indices for the power vs. time ramp traces (for 80+80
/// HIFN  MHz, MIMO), rising edge (REDGe) and falling edge (FEDGe).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR edge/Selects the appropriate edge.
/// HIPAR antenna/Sets the MIMO Antenna.
/// HIPAR segment/Sets the Segment.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Comma-separated list of time indices corresponding to the ramp power
/// HIPAR results/results.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasPVTRampTraceMIMOSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           5, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:MIMO%ld:SEGM%ld:TIME? %ld,%ld,%ld",
      instance, EdgeTimeArr[edge], antenna, segment, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the time indices for the power vs. time ramp traces (for 80+80
/// HIFN  MHz, MIMO), rising edge (REDGe) and falling edge (FEDGe).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR edge/Selects the appropriate edge.
/// HIPAR antenna/Sets the MIMO Antenna.
/// HIPAR segment/Sets the Segment.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Comma-separated list of time indices corresponding to the ramp power
/// HIPAR results/results.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasPVTRampTraceMIMOSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           5, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:MIMO%ld:SEGM%ld:TIME? %ld, %ld, %ld",
      instance, EdgeTimeArr[edge], antenna, segment, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the time indices for the power vs. time ramp traces for MIMO,
/// HIFN  rising edge (REDGe) and falling edge (FEDGe).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR edge/Selects the appropriate edge.
/// HIPAR antenna/Sets the MIMO Antenna.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Comma-separated list of time indices corresponding to the ramp power
/// HIPAR results/results.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasPVTRampTraceMIMOTime(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   edge,
                                                             ViInt32   antenna,
                                                             ViInt32   start,
                                                             ViInt32   count,
                                                             ViInt32   decimation,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:MIMO%ld:TIME? %ld, %ld, %ld",
           instance, EdgeTimeArr[edge], antenna, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the time indices for the power vs. time ramp traces for MIMO,
/// HIFN  rising edge (REDGe) and falling edge (FEDGe).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR edge/Selects the appropriate edge.
/// HIPAR antenna/Sets the MIMO Antenna.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Comma-separated list of time indices corresponding to the ramp power
/// HIPAR results/results.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasPVTRampTraceMIMOTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   antenna,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:MIMO%ld:TIME? %ld, %ld, %ld",
           instance, EdgeTimeArr[edge], antenna, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the time indices for the power vs. time ramp traces (for 80+80
/// HIFN  MHz, MIMO), rising edge (REDGe) and falling edge (FEDGe).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR edge/Selects the appropriate edge.
/// HIPAR segment/Sets the Segment.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Comma-separated list of time indices corresponding to the ramp power
/// HIPAR results/results.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasPVTRampTraceSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           4, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:SEG%ld:TIME? %ld, %ld, %ld",
           instance, EdgeTimeArr[edge], segment, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the time indices for the power vs. time ramp traces (for 80+80
/// HIFN  MHz, MIMO), rising edge (REDGe) and falling edge (FEDGe).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR edge/Selects the appropriate edge.
/// HIPAR segment/Sets the Segment.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Comma-separated list of time indices corresponding to the ramp power
/// HIPAR results/results.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasPVTRampTraceSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           4, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:SEG%ld:TIME? %ld, %ld, %ld",
           instance, EdgeTimeArr[edge], segment, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the time indices for the power vs. time ramp traces (for 80+80
/// HIFN  MHz, MIMO), rising edge (REDGe) and falling edge (FEDGe).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR edge/Selects the appropriate edge.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Comma-separated list of time indices corresponding to the ramp power
/// HIPAR results/results.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasPVTRampTraceTime(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   edge,
                                                         ViInt32   start,
                                                         ViInt32   count,
                                                         ViInt32   decimation,
                                                         ViInt32   arraySize,
                                                         ViInt32*  reliability,
                                                         ViReal64  results[],
                                                         ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:TIME? %ld, %ld, %ld",
      instance, EdgeTimeArr[edge], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the time indices for the power vs. time ramp traces (for 80+80
/// HIFN  MHz, MIMO), rising edge (REDGe) and falling edge (FEDGe).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR edge/Selects the appropriate edge.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Comma-separated list of time indices corresponding to the ramp power
/// HIPAR results/results.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasPVTRampTraceTime(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   edge,
                                                          ViInt32   start,
                                                          ViInt32   count,
                                                          ViInt32   decimation,
                                                          ViInt32   arraySize,
                                                          ViInt32*  reliability,
                                                          ViReal64  results[],
                                                          ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:%s:TIME? %ld, %ld, %ld",
      instance, EdgeTimeArr[edge], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the time indices for the power vs. time ramp traces (for 80+80
/// HIFN  MHz, MIMO), rising edge (REDGe) and falling edge (FEDGe).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR antenna/Sets the MIMO Antenna.
/// HIPAR segment/Sets the Segment.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Comma-separated list of time indices corresponding to the ramp power
/// HIPAR results/results.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasPVTRampMIMOSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           5, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:PVT:MIMO%ld:SEGM%ld:TIME? %ld, %ld, %ld",
           instance, antenna, segment, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the time indices for the power vs. time ramp traces (for 80+80
/// HIFN  MHz, MIMO), rising edge (REDGe) and falling edge (FEDGe).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR antenna/Sets the MIMO Antenna.
/// HIPAR segment/Sets the Segment.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Comma-separated list of time indices corresponding to the ramp power
/// HIPAR results/results.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasPVTRampMIMOSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           5, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:PVT:MIMO%ld:SEGM%ld:TIME? %ld, %ld, %ld",
           instance, antenna, segment, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return timing error traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Comma-separated list of timing error values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTraceTimingError(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   start,
                                                         ViInt32   count,
                                                         ViInt32   decimation,
                                                         ViInt32   arraySize,
                                                         ViInt32*  reliability,
                                                         ViReal64  results[],
                                                         ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:TERR? %ld, %ld, %ld",
      instance, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return timing error traces.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Comma-separated list of timing error values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTraceTimingError(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   start,
                                                          ViInt32   count,
                                                          ViInt32   decimation,
                                                          ViInt32   arraySize,
                                                          ViInt32*  reliability,
                                                          ViReal64  results[],
                                                          ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:TERR? %ld, %ld, %ld",
      instance, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and returns the timing error
/// HIFN  single value results of the power vs. time measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR timingError/Returns the timing error single value results of the power vs. time
/// HIPAR timingError/measurement.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalPVTTimingErrorResults(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   resultType,
                                                          ViInt32*  reliability,
                                                          ViReal64* timingError)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViReal64 results[1] = { RS_VAL_NAN_VI_REAL64 };

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:PVT:TERR:%s?", instance, resultTypeArr[resultType]);

   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, 1, reliability, results, NULL));

   *timingError = results[0];

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Returns the timing error single value results of the power vs. time
/// HIFN  measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR timingError/Returns the timing error single value results of the power vs. time
/// HIPAR timingError/measurement.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalPVTTimingErrorResults(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   resultType,
                                                           ViInt32*  reliability,
                                                           ViReal64* timingError)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViReal64 results[1] = { RS_VAL_NAN_VI_REAL64 };

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:PVT:TERR:%s?", instance, resultTypeArr[resultType]);

   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, 1, reliability, results, NULL));

   *timingError = results[0];

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Returns limit check results of the timing error single value results
/// HIFN  of the power vs. time measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR timingError/Returns limit check results of the timing error single value results
/// HIPAR timingError/of the power vs. time measurement.
ViStatus _VI_FUNC rscmwwlm_QueryMEvalPVTTimingErrorLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32*  reliability,
                            ViInt32*  timingError)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViInt32  results[1] = { RS_VAL_NAN_VI_INT32 };

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:PVT:TERR:%s?", instance, resultTypeArr[resultType]);

   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, 1, reliability, results, NULL));

   *timingError = results[0];

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Returns single power value measured for RU at all antennas (OFDMA).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR resourceUnit/Select the resource unit
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR powerVsRU/Returns the power vs RU for all antennas.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalPVRUResults(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32   resultType,
                                                 ViInt32   resourceUnit,
                                                 ViInt32*  reliability,
                                                 ViReal64* powerVsRU)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViReal64 results[1] = { RS_VAL_NAN_VI_REAL64 };

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resourceUnit, 1, 74),
           4, "Resource Unit");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:POW:RUN%ld:%s?", instance, resourceUnit, resultTypeArr[resultType]);

   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, 1, reliability, results, NULL));

   *powerVsRU = results[0];

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns single power value measured for RU at all antennas (OFDMA).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR resourceUnit/Select the resource unit
/// HIPAR antenna/Select the antenna
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR powerVsAntennaVsRU/Returns the power vs RU vs antenna
ViStatus _VI_FUNC rscmwwlm_FetchMEvalPVRURXAntennaResults(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   resultType,
                                                          ViInt32   resourceUnit,
                                                          ViInt32   antenna,
                                                          ViInt32*  reliability,
                                                          ViReal64* powerVsAntennaVsRU)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViReal64 results[1] = { RS_VAL_NAN_VI_REAL64 };

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resourceUnit, 1, 74),
           4, "Resource Unit");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           5, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:POW:RUN%ld:RXAN%ld:%s?", instance, resourceUnit, antenna, resultTypeArr[resultType]);

   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, 1, reliability, results, NULL));

   *powerVsAntennaVsRU = results[0];

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns single power value measured at the specified antenna for all RUs (OFDMA).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR antenna/Select the antenna
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR powerVsAntenna/Returns the power vs antenna for all RUs
ViStatus _VI_FUNC rscmwwlm_FetchMEvalPowerRXAntennaResults(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   resultType,
                                                           ViInt32   antenna,
                                                           ViInt32*  reliability,
                                                           ViReal64* powerVsAntenna)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViReal64 results[1] = { RS_VAL_NAN_VI_REAL64 };

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:POW:RXAN%ld:%s?", instance, antenna, resultTypeArr[resultType]);

   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, 1, reliability, results, NULL));

   *powerVsAntenna = results[0];

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval Constellation Diagram I Trace
 * Purpose:  Starts a new single shot measurement and returns the I (in
 *           phase) component results in the I/Q constellation diagram.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasConstellationDiagramITrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:IQC:INPH?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval Constellation Diagram I Trace
 * Purpose:  Returns the I (in phase) component results in the I/Q constellation
 *           diagram.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasConstellationDiagramITrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:IQC:INPH?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval Constellation Diagram Q Trace
 * Purpose:  Starts a new single shot measurement and returns the Q
 *           (quadrature) component results in the I/Q constellation diagram.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasConstellationDiagramQTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:IQC:QUAD?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval Constellation Diagram Q Trace
 * Purpose:  Returns the Q (quadrature) component results in the I/Q
 *           constellation diagram.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasConstellationDiagramQTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:IQC:QUAD?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval Meas UTER Trace
 * Purpose:  Starts a new single shot measurement and returns the values of
 *           the unused tone error traces according to standard 802.11ax.
 *           The results of the current, average, minimum and maximum traces
 *           can be retrieved.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasUTERTrace(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViInt32   resultType,
                                                  ViInt32   antenna,
                                                  ViInt32   arraySize,
                                                  ViInt32*  reliability,
                                                  ViReal64  results[],
                                                  ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:UTER%ld:%s?", instance, antenna, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval Meas UTER Trace
 * Purpose:  Return the values of the unused tone error traces according to
 *             standard 802.11ax. The results of the current, average, minimum
 *             and maximum traces can be retrieved.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasUTERTrace(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   resultType,
                                                   ViInt32   antenna,
                                                   ViInt32   arraySize,
                                                   ViInt32*  reliability,
                                                   ViReal64  results[],
                                                   ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:UTER%ld:%s?", instance, antenna, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval Meas UTER Limits
 * Purpose:  Starts a new single shot measurement and returns the values of
 *             the unused tone error limits.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasUTERLimits(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   antenna,
                                                   ViInt32   arraySize,
                                                   ViInt32*  reliability,
                                                   ViReal64  results[],
                                                   ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           3, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:UTER%ld:LIM?", instance, antenna);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval Meas UTER Limits
 * Purpose:  Return the values of the unused tone error limits.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasUTERLimits(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   antenna,
                                                    ViInt32   arraySize,
                                                    ViInt32*  reliability,
                                                    ViReal64  results[],
                                                    ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           3, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:UTER%ld:LIM?", instance, antenna);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval Meas UTER Limit Check Results
 * Purpose:  Queries the values of the unused tone error limit check results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasUTERLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antenna,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           3, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:UTER%ld:LIM?", instance, antenna);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval Meas UTER Trace Limit Check Results
 * Purpose:  Queries the unused tone error measurement limit check results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasUTERTraceLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:UTER%ld:%s?", instance, antenna, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval Meas UTER Margin Values
 * Purpose:  Starts a new single shot measurement and returns the margin
 *           values of the unused tone error measurement for the current,
 *             average, minimum and maximum traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasUTERMarginValues(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   resultType,
                                                         ViInt32   antenna,
                                                         ViInt32   arraySize,
                                                         ViInt32*  reliability,
                                                         ViReal64  results[],
                                                         ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:UTER%ld:MARG:%s?", instance, antenna, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval Meas UTER Margin Values
 * Purpose:  Returns the margin values of the unused tone error measurement
 *             for the current, average, minimum and maximum traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasUTERMarginValues(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   resultType,
                                                          ViInt32   antenna,
                                                          ViInt32   arraySize,
                                                          ViInt32*  reliability,
                                                          ViReal64  results[],
                                                          ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:UTER%ld:MARG:%s?", instance, antenna, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Query Multi Eval Meas UTER Margin Limit Check Results
 * Purpose:  Queries the unused tone error measurement limit check results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasUTERMarginLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:UTER%ld:MARG:%s?", instance, antenna, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval Transmit Spectrum Mask Trace
 * Purpose:  Starts a new single shot measurement and returns the values of the
 *           transmit spectrum mask traces. The results of the current, average
 *           and maximum traces can be retrieved.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:TSM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval Transmit Spectrum Mask Trace
 * Purpose:  Returns the values of the transmit spectrum mask traces.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:TSM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval Transmit Spectrum Mask Trace Enhanced
 * Purpose:  Starts a new single shot measurement and returns the values of
 *           the transmit spectrum mask traces. The results of the current,
 *           average and maximum traces can be retrieved.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:TSM:%s? %ld,%ld,%ld", instance, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval Transmit Spectrum Mask Trace Enhanced
 * Purpose:  Returns the values of the transmit spectrum mask traces. The
 *           results of the current, average and maximum traces can be
 *           retrieved.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:TSM:%s? %ld,%ld,%ld", instance, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and returns the values of the
/// HIFN  transmit spectrum mask traces for segment <seg>, for SISO measurements
/// HIFN  and bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR segment/Select the segment
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           4, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:TSM:SEGM%ld:%s? %ld,%ld,%ld",
           instance, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the values of the transmit spectrum mask traces for segment
/// HIFN  <seg>, for SISO measurements and bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR segment/Select the segment
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           4, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:TSM:SEGM%ld:%s? %ld,%ld,%ld",
           instance, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and returns the values of the
/// HIFN  transmit spectrum mask traces for MIMO measurements, antenna/stream
/// HIFN  number <n>, bandwidths with one segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR stream/Select the MIMO
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   stream,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:TSM:MIMO%ld:%s? %ld,%ld,%ld",
           instance, stream, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the values of the transmit spectrum mask traces for MIMO
/// HIFN  measurements, antenna/stream number <n>, bandwidths with one segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR stream/Select the MIMO
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   stream,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:TSM:MIMO%ld:%s? %ld,%ld,%ld",
           instance, stream, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and returns the values of the
/// HIFN  transmit spectrum mask traces for segment <seg> and antenna/stream
/// HIFN  number <n>, for MIMO measurements and bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR stream/Select the MIMO
/// HIPAR segment/Select the segment
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceMIMOSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   stream,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           5, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:TSM:MIMO%ld:SEGM%ld:%s? %ld,%ld,%ld", instance, stream, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the values of the transmit spectrum mask traces for segment
/// HIFN  <seg> and antenna/stream number <n>, for MIMO measurements and
/// HIFN  bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR stream/Select the MIMO
/// HIPAR segment/Select the segment
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceMIMOSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   stream,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           4, "Stream");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           5, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:TSM:MIMO%ld:SEGM%ld:%s? %ld,%ld,%ld", instance, stream, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the frequency values (X axis) of the transmit spectrum mask
/// HIFN  limit line trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceFrequency(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:TSM:FREQ? %ld,%ld,%ld", instance, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the frequency values (X axis) of the transmit spectrum mask
/// HIFN  limit line trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceFrequency(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:TSM:FREQ? %ld,%ld,%ld", instance, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the frequency values (X axis) of the transmit spectrum mask
/// HIFN  limit line trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceMask(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:TSM:MASK? %ld,%ld,%ld", instance, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the frequency values (X axis) of the transmit spectrum mask
/// HIFN  limit line trace.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceMask(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:TSM:MASK? %ld,%ld,%ld", instance, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and returns the power values
/// HIFN  (Y-values) of the transmit spectrum mask limit line trace for segment
/// HIFN  <seg>, for SISO measurements and bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR segment/Select the segment
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceMaskSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           3, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:TSM:MASK:SEGM%ld? %ld,%ld,%ld", instance, segment, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the power values (Y-values) of the transmit spectrum mask
/// HIFN  limit line trace for segment <seg>, for SISO measurements and
/// HIFN  bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR segment/Select the segment
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceMaskSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           3, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:TSM:MASK:SEGM%ld? %ld,%ld,%ld", instance, segment, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and returns the power values
/// HIFN  (Y-values) of the transmit spectrum mask limit line trace, for MIMO
/// HIFN  measurements, antenna/stream number <n>, bandwidths with one segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR stream/Select the MIMO
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceMaskMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           3, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:TSM:MASK:MIMO%ld? %ld,%ld,%ld", instance, stream, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the power values (Y-values) of the transmit spectrum mask
/// HIFN  limit line trace, for MIMO measurements, antenna/stream number <n>,
/// HIFN  bandwidths with one segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR stream/Select the MIMO
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceMaskMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           3, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:TSM:MASK:MIMO%ld? %ld,%ld,%ld", instance, stream, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and returns the power values
/// HIFN  (Y-values) of the transmit spectrum mask limit line trace for segment
/// HIFN  <seg> and antenna/stream number <n>, for MIMO measurements and
/// HIFN  bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR stream/Select the MIMO
/// HIPAR segment/Select the segment
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceMaskMIMOSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           3, "Stream");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           4, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:TSM:MASK:MIMO%ld:SEGM%ld? %ld,%ld,%ld",
           instance, stream, segment, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the power values (Y-values) of the transmit spectrum mask
/// HIFN  limit line trace for segment <seg> and antenna/stream number <n>, for
/// HIFN  MIMO measurements and bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR stream/Select the MIMO
/// HIPAR segment/Select the segment
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceMaskMIMOSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           3, "Stream");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           4, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:TSM:MASK:MIMO%ld:SEGM%ld? %ld,%ld,%ld",
           instance, stream, segment, start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Read Multi Eval Transmit Spectrum Mask Occupied Bandwidth Results
 * Purpose:  Reads for SISO signals the current, average, maximum and
 *           standard deviation single value results, plus the current lower
 *           and upper edge frequencies of the occupied bandwidth (OBW).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalTransmitSpectrumMaskOccupiedBandwidthResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:OBW?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval Transmit Spectrum Mask Occupied Bandwidth Results
 * Purpose:  Returns for SISO signals the current, average, maximum and
 *           standard deviation single value results, plus the current lower
 *           and upper edge frequencies of the occupied bandwidth (OBW).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalTransmitSpectrumMaskOccupiedBandwidthResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:OBW?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and returns the OBW results for
/// HIFN  SISO measurements and bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalTransmitSpectrumMaskOccupiedBandwidthSegmentResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:OBW:SEGM?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the OBW results for SISO measurements and bandwidths with two
/// HIFN  segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalTransmitSpectrumMaskOccupiedBandwidthSegmentResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:OBW:SEGM?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and returns the OBW results for
/// HIFN  MIMO measurements, antenna/stream number <n>, bandwidths with one
/// HIFN  segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR stream/Select the MIMO
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalTransmitSpectrumMaskOccupiedBandwidthMIMOResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           3, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:OBW:MIMO%ld?", instance, stream);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the OBW results for MIMO measurements, antenna/stream number
/// HIFN  <n>, bandwidths with one segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR stream/Select the MIMO
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalTransmitSpectrumMaskOccupiedBandwidthMIMOResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           3, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:OBW:MIMO%ld?", instance, stream);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and returns the OBW results for
/// HIFN  MIMO measurements, antenna/stream number <n>, bandwidths with two
/// HIFN  segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR stream/Select the MIMO
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalTransmitSpectrumMaskOccupiedBandwidthMIMOSegmentResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           3, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:OBW:MIMO%ld:SEGM?", instance, stream);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the OBW results for MIMO measurements, antenna/stream number
/// HIFN  <n>, bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR stream/Select the MIMO
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalTransmitSpectrumMaskOccupiedBandwidthMIMOSegmentResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           3, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:OBW:MIMO%ld:SEGM?", instance, stream);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and return the X-positions of the
/// HIFN  limit line margins of the transmit spectrum mask for SISO measurements
/// HIFN  and bandwidths with one segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskSISOXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:FREQ:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the X-positions of the limit line margins of the transmit
/// HIFN  spectrum mask for SISO measurements and bandwidths with one segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskSISOXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:FREQ:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the limit check results of the X-positions of the transmit
/// HIFN  spectrum mask for SISO measurements and bandwidths with one segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasTransmitSpectrumMaskSISOXLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:TSM:FREQ:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and return the X-positions of the
/// HIFN  limit line margin values of the transmit spectrum mask for SISO
/// HIFN  measurements and bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskSISOSegmentsXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:SEGM:FREQ:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the X-positions of the limit line margin values of the transmit
/// HIFN  spectrum mask for SISO measurements and bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskSISOSegmentsXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:SEGM:FREQ:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the limit check results of the X-positions of the transmit
/// HIFN  spectrum mask for SISO measurements and bandwidths with two segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskSISOSegmentsXLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:TSM:SEGM:FREQ:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and return the X-positions of the
/// HIFN  limit line margin values of the transmit spectrum mask for MIMO
/// HIFN  measurements, antenna/stream number <n>, bandwidths with one segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskMIMOXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:MIMO%ld:FREQ:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the X-positions of the limit line margin values of the transmit
/// HIFN  spectrum mask for MIMO measurements, antenna/stream number <n>,
/// HIFN  bandwidths with one segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskMIMOXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:MIMO%ld:FREQ:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the limit check results of the X-positions of the transmit
/// HIFN  spectrum mask for MIMO measurements, antenna/stream number <n> and
/// HIFN  bandwidths with one segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMultiEvalTransmitSpectrumMaskMIMOXLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:TSM:MIMO%ld:FREQ:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and return the X-positions of the
/// HIFN  limit line margin values of the transmit spectrum mask for MIMO
/// HIFN  measurements, antenna/stream number <n>, bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskMIMOSegmentsXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:MIMO%ld:SEGM:FREQ:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the X-positions of the limit line margin values of the transmit
/// HIFN  spectrum mask for MIMO measurements, antenna/stream number <n>,
/// HIFN  bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskMIMOSegmentsXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:MIMO%ld:SEGM:FREQ:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the limit check results of the X-positions of the transmit
/// HIFN  spectrum mask for MIMO measurements, antenna/stream number <n> and
/// HIFN  bandwidths with two segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMultiEvalTransmitSpectrumMaskMIMOSegmentsXLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:TSM:MIMO%ld:SEGM:FREQ:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and return the limit line margin
/// HIFN  values of the transmit spectrum mask for SISO measurements and
/// HIFN  bandwidths with one segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskSISOYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the limit line margin values of the transmit spectrum mask for
/// HIFN  SISO measurements and bandwidths with one segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskSISOYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the limit check results of the transmit spectrum mask for SISO
/// HIFN  measurements and bandwidths with one segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasTransmitSpectrumMaskSISOYLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:TSM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and return the limit line margin
/// HIFN  values of the transmit spectrum mask for SISO measurements and
/// HIFN  bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskSISOSegmentsYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:SEGM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the limit line margin values of the transmit spectrum mask for
/// HIFN  SISO measurements and bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskSISOSegmentsYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:SEGM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the limit check results of the transmit spectrum mask for SISO
/// HIFN  measurements and bandwidths with two segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasTransmitSpectrumMaskSISOSegmentsYLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:TSM:SEGM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and return the limit line margin
/// HIFN  values of the transmit spectrum mask for MIMO measurements,
/// HIFN  antenna/stream number <n>, bandwidths with one segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskMIMOYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:MIMO%ld:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the limit line margin values of the transmit spectrum mask for
/// HIFN  MIMO measurements, antenna/stream number <n>, bandwidths with one
/// HIFN  segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskMIMOYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:MIMO%ld:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the limit check results of the transmit spectrum mask for MIMO
/// HIFN  measurements, antenna/stream number <n> and bandwidths with one
/// HIFN  segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasTransmitSpectrumMaskMIMOYLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:TSM:MIMO%ld:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Starts a new single shot measurement and return the limit line margin
/// HIFN  values of the transmit spectrum mask for MIMO measurements,
/// HIFN  antenna/stream number <n>, bandwidths with two segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskMIMOSegmentsYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TSM:MIMO%ld:SEGM:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the limit line margin values of the transmit spectrum mask for
/// HIFN  MIMO measurements, antenna/stream number <n>, bandwidths with two
/// HIFN  segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskMIMOSegmentsYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TSM:MIMO%ld:SEGM:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the limit check results of the transmit spectrum mask for MIMO
/// HIFN  measurements, antenna/stream number <n> and bandwidths with two
/// HIFN  segment.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR stream/Select the MIMO
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_QueryMultiEvalTransmitSpectrumMaskMIMOSegmentsYLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, stream, 1, 8),
           5, "Stream");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CALC:WLAN:MEAS%ld:MEV:TSM:MIMO%ld:SEGM:%s?", instance, stream, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetLimitCheck(instrSession, cmd, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the value signaled for the channel in HE-SIG-B common field
/// HIFN  for multi user MIMO.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the field type.
/// HIPAR channel/Select the channel index
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoChannelFieldMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   channel,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViReal64* decimalValue)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CFIELD_CRC, RSCMWWLM_VAL_RESULT_CFIELD_TAIL),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, 2),
           5, "Channel");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:SINF:HEB:CHAN%ld:CFI:%s?", instance, channel, resultTypeCFieldArr[resultType]);

   checkErr(rscmwwlm_GetBinaryAndDoubleValue(instrSession, cmd, arraySize, reliability, binaryValue, decimalValue));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Returns the value signaled for the channel and user in HE-SIG-B common field
/// HIFN  for multi user MIMO.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the field type.
/// HIPAR channel/Select the channel index
/// HIPAR user/Select the user index
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoUserFieldMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   channel,
                            ViInt32   user,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViInt32*  decimalValue)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_UFIELD_CODING, RSCMWWLM_VAL_RESULT_UFIELD_TXB),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, 2),
           5, "Channel");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, user, 1, 74),
           5, "User");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:SINF:HEB:CHAN%ld:UFI%ld:%s?", instance, channel, user, resultTypeUFieldArr[resultType]);

   checkErr(rscmwwlm_GetBinaryAndDecimalValue(instrSession, cmd, arraySize, reliability, binaryValue, decimalValue));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Returns the value signaled for the channel and user in HE-SIG-B common field
/// HIFN  for multi user MIMO.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the field type.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoHEMUMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViInt32*  decimalValue)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_HEMU_BDCM, RSCMWWLM_VAL_RESULT_HEMU_ULDL),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:SINF:HEMU:%s?", instance, resultTypeHEMUFieldArr[resultType]);

   checkErr(rscmwwlm_GetBinaryAndDecimalValue(instrSession, cmd, arraySize, reliability, binaryValue, decimalValue));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Returns the value signaled in HE signal field for single user MIMO (HE-SIG-A).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the field type.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoHESUMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViInt32*  decimalValue)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_HESU_BEAMCHANGE, RSCMWWLM_VAL_RESULT_HESU_ULDL),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:SINF:HESU:%s?", instance, resultTypeHESUFieldArr[resultType]);

   checkErr(rscmwwlm_GetBinaryAndDecimalValue(instrSession, cmd, arraySize, reliability, binaryValue, decimalValue));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Returns the value signaled in HE signal field for trigger based uplink single
/// HIFN  user MIMO (HE-SIG-A).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the field type.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoHETBMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViInt32*  decimalValue)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_HETB_BSSCOL, RSCMWWLM_VAL_RESULT_HETB_TXOP),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:SINF:HETB:%s?", instance, resultTypeHETBFieldArr[resultType]);

   checkErr(rscmwwlm_GetBinaryAndDecimalValue(instrSession, cmd, arraySize, reliability, binaryValue, decimalValue));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Returns the value signaled in high throughput signal field for IEEE 802.11n
/// HIFN  signal (HT-SIG).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the field type.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoHTSIGMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViInt32*  decimalValue)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_HTSIG_AGGR, RSCMWWLM_VAL_RESULT_HTSIG_TAIL),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:SINF:HTS:%s?", instance, resultTypeHTSIGFieldArr[resultType]);

   checkErr(rscmwwlm_GetBinaryAndDecimalValue(instrSession, cmd, arraySize, reliability, binaryValue, decimalValue));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Returns the value signaled in legacy signal field for NON_HT signal (LSIG).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the field type.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoLegacySignalMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViInt32*  decimalValue)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_LSIG_LENGTH, RSCMWWLM_VAL_RESULT_LSIG_TAIL),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:SINF:LSIG:%s?", instance, resultTypeLSIGFieldArr[resultType]);

   checkErr(rscmwwlm_GetBinaryAndDecimalValue(instrSession, cmd, arraySize, reliability, binaryValue, decimalValue));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Returns the value signaled in very high throughput signal field for
/// HIFN  IEEE 802.11ac signal (VHT-SIG).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the field type.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoVeryHighThroughputSignal(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViInt32*  decimalValue)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_VHTSIG_BEAMFORMED, RSCMWWLM_VAL_RESULT_VHTSIG_TXOP),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:SINF:VHTS:%s?", instance, resultTypeVHTSIGFieldArr[resultType]);

   checkErr(rscmwwlm_GetBinaryAndDecimalValue(instrSession, cmd, arraySize, reliability, binaryValue, decimalValue));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Starts a new single shot measurement and returns the value signaled in very high
/// HIFN  throughput signal field for IEEE 802.11ac signal (VHT-SIG).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the result type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasEVMSymbolTrace(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   resultType,
                                                       ViInt32   arraySize,
                                                       ViInt32*  reliability,
                                                       ViReal64  results[],
                                                       ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:EVM:SYMB:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Returns the value signaled in very high throughput signal field for
/// HIFN  IEEE 802.11ac signal (VHT-SIG).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the result type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result; see Reliability Indicator.
/// HIPAR results/Returns result values.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasEVMSymbolTrace(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   resultType,
                                                        ViInt32   arraySize,
                                                        ViInt32*  reliability,
                                                        ViReal64  results[],
                                                        ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:EVM:SYMB:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval List Mode OFDM All Segments Values
 * Purpose:  Returns the modulation results of all segments for OFDM signals
 *           in list mode.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMAllSegmentsValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   segmentReliability[],
                            ViInt32   numberOfBursts[],
                            ViInt32   modulationType[],
                            ViReal64  results[],
                            ViInt32   guardInterval[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViInt32  numberOfSegments = 0;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   checkErr(rscmwwlm_GetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE_NUMBER_OF_SEGMENTS, &numberOfSegments));

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:OFDM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetOFDMSegmentResults(instrSession, cmd, numberOfSegments, arraySize,
      reliability, segmentReliability, numberOfBursts,
      modulationType, ofdmModulationArr, results,
      guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval List Mode OFDM All Segments Standard Deviation
 * Purpose:  Returns the standard deviation of all segments for OFDM signals
 *           in list mode.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMAllSegmentsStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   segmentReliability[],
                            ViInt32   numberOfBursts[],
                            ViInt32   modulationType[],
                            ViReal64  results[],
                            ViInt32   guardInterval[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViInt32  numberOfSegments = 0;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   checkErr(rscmwwlm_GetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE_NUMBER_OF_SEGMENTS, &numberOfSegments));

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:OFDM:SDEV?", instance);
   checkErr(rscmwwlm_GetOFDMSegmentResults(instrSession, cmd, numberOfSegments, arraySize,
      reliability, segmentReliability, numberOfBursts,
      modulationType, ofdmModulationArr, results,
      guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval List Mode OFDM One Segment Values
 * Purpose:  Returns the modulation single value results (OFDM signal) for
 *           segment <nr> in list mode.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMOneSegmentValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViInt32*  numberOfBursts,
                            ViInt32*  modulationType,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 100),
           4, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:MOD:OFDM:%s?", instance, segment, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetOFDMSegmentResults(instrSession, cmd, 1, arraySize,
      reliability, segmentReliability, numberOfBursts,
      modulationType, ofdmModulationArr, results,
      guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval List Mode OFDM One Segment Standard Deviation
 * Purpose:  Returns the standard deviation single value results (OFDM
 *           signal) for segment <nr> in list mode.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMOneSegmentStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViInt32*  numberOfBursts,
                            ViInt32*  modulationType,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 100),
           3, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:MOD:OFDM:SDEV?", instance, segment);
   checkErr(rscmwwlm_GetOFDMSegmentResults(instrSession, cmd, 1, arraySize,
      reliability, segmentReliability, numberOfBursts,
      modulationType, ofdmModulationArr, results,
      guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the burst power results for OFDM/OFDMA signals in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the burst power results for OFDM/OFDMA signals in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMBurstPower(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:BPOW:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the crest factor results in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the crest factor results in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMCrestFactor(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:CFAC:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the center frequency error results for OFDM/OFDMA signals in
/// HIFN  list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the center frequency error results for OFDM/OFDMA signals in
/// HIPAR results/list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:CFER:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the power results of DC subcarriers in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the power results of DC subcarriers in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMDCPower(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:DCP:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the power results of data portion of the burst in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the power results of data portion of the burst in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMDataPortionPower(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:DPOW:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the EVM results for OFDM/OFDMA signals for data carriers in
/// HIFN  list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the EVM results for OFDM/OFDMA signals for data carriers in
/// HIPAR results/list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMEVMData(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:EVMD:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the EVM results for OFDM/OFDMA signals for pilot carrier in
/// HIFN  list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the EVM results for OFDM/OFDMA signals for pilot carrier in
/// HIPAR results/list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMEVMPilot(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:EVMP:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the EVM results for OFDM/OFDMA signals for all carriers in list
/// HIFN  mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the EVM results for OFDM/OFDMA signals for all carriers in list
/// HIPAR results/mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMEVMAll(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   resultType,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  results[],
                                                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:EVM:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the gain imbalance results for OFDM/OFDMA signals in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the gain imbalance results for OFDM/OFDMA signals in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMGainImbalance(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:GIMB:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the IQ offset results for OFDM/OFDMA signals in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the IQ offset results for OFDM/OFDMA signals in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMIQOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:IQOF:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the power results of LTF portion of the burst in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the power results of LTF portion of the burst in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMLTFPower(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:LTFP:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the quadrature error results for OFDM/OFDMA in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the quadrature error results for OFDM/OFDMA in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMQuadratureError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:QERR:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the symbol clock error results in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the symbol clock error results in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:SCER:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval List Mode DSSS All Segments Values
 * Purpose:  Returns the modulation results of all segments for DSSS signals
 *           in list mode.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSAllSegmentsValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   segmentReliability[],
                            ViInt32   numberOfBursts[],
                            ViInt32   modulationType[],
                            ViInt32   PLCPType[],
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViInt32  numberOfSegments = 0;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   checkErr(rscmwwlm_GetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE_NUMBER_OF_SEGMENTS, &numberOfSegments));

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:DSSS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetDSSSSegmentResults(instrSession, cmd, numberOfSegments, arraySize,
      reliability, segmentReliability, numberOfBursts,
      modulationType, dsssModulationArr, PLCPType,
      burstTypeArr, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval List Mode DSSS All Segments Standard Deviation
 * Purpose:  Returns the standard deviation of all segments for DSSS signals
 *           in list mode.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSAllSegmentsStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   segmentReliability[],
                            ViInt32   numberOfBursts[],
                            ViInt32   modulationType[],
                            ViInt32   PLCPType[],
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
   ViInt32  numberOfSegments = 0;

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   checkErr(rscmwwlm_GetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE_NUMBER_OF_SEGMENTS, &numberOfSegments));

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:DSSS:SDEV?", instance);
   checkErr(rscmwwlm_GetDSSSSegmentResults(instrSession, cmd, numberOfSegments, arraySize,
      reliability, segmentReliability, numberOfBursts,
      modulationType, dsssModulationArr, PLCPType,
      burstTypeArr, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval List Mode DSSS One Segment Values
 * Purpose:  Returns modulation single value results (DSSS signal) for
 *           segment <nr> in list mode.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSOneSegmentValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViInt32*  numberOfBursts,
                            ViInt32*  modulationType,
                            ViInt32*  PLCPType,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 100),
           4, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:MOD:DSSS:%s?", instance, segment, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetDSSSSegmentResults(instrSession, cmd, 1, arraySize,
      reliability, segmentReliability, numberOfBursts,
      modulationType, dsssModulationArr, PLCPType,
      burstTypeArr, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval List Mode DSSS One Segment Standard Deviation
 * Purpose:  Returns standard deviation single value results (DSSS signal)
 *           for segment <nr> in list mode.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSOneSegmentStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViInt32*  numberOfBursts,
                            ViInt32*  modulationType,
                            ViInt32*  PLCPType,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 100),
           3, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:MOD:DSSS:SDEV?", instance, segment);
   checkErr(rscmwwlm_GetDSSSSegmentResults(instrSession, cmd, 1, arraySize,
      reliability, segmentReliability, numberOfBursts,
      modulationType, dsssModulationArr, PLCPType,
      burstTypeArr, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return the burst power results for DSSS signals in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the burst power results for DSSS signals in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSBurstPower(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:DSSS:BPOW:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the chip clock error results for DSSS signals in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the chip clock error results for DSSS signals in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSChipClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:DSSS:CCER:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the center frequency error results for DSSS signals in list
/// HIFN  mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the center frequency error results for DSSS signals in list
/// HIPAR results/mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:DSSS:CFER:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the current, average, minimum, maximum and standard deviation
/// HIFN  EVM results for DSSS signals in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the current, average, minimum, maximum and standard deviation
/// HIPAR results/EVM results for DSSS signals in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSEVMPeak(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:DSSS:EVMP:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the current, average, minimum, maximum and standard deviation
/// HIFN  EVM results for DSSS signals in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the current, average, minimum, maximum and standard deviation
/// HIPAR results/EVM results for DSSS signals in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSEVMRMS(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   resultType,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  results[],
                                                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:DSSS:EVMR:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the gain imbalance results for DSSS signals in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the gain imbalance results for DSSS signals in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSGainImbalance(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:DSSS:GIMB:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the IQ offset results for DSSS signals in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the IQ offset results for DSSS signals in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSIQOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:DSSS:IQOF:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the quadrature error results for DSSS in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the quadrature error results for DSSS in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSQuadratureError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:DSSS:QERR:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the power backoff results in list mode.
/// HIFN
/// HIFN     The power backoff displays the minimum distance of signal power to
/// HIFN  reference level over all segments since the start of the measurement.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the power backoff results in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModePowerBackoff(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:PBAC?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the peak power results of the burst in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the peak power results of the burst in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModePeakPower(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   resultType,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  results[],
                                                           ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_SDEV),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:PPOW:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Returns the expired statistic counts for modulation results over all
/// HIFN  segments in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Returns the expired statistic counts for modulation results over all
/// HIPAR results/segments in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeExpiredStatisticCounts(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:MOD:SCO?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Returns the segment reliability for all measured list mode segments.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Returns the expired statistic counts for modulation results over all
/// HIPAR results/segments in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeSegmentsReliability(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:SREL?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Returns the expired statistic counts for transmit spectrum mask
/// HIFN  results over all segments in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Returns the expired statistic counts for transmit spectrum mask
/// HIPAR results/results over all segments in list mode.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeTSMaskExpiredStatisticCounts(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:TSM:SCO?", instance);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 0, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval List Mode Transmit Spectrum Mask OFDM All Segments Values
 * Purpose:  Returns the transmit spectrum mask results of all segments for
             OFDM signals in list mode.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeTransmitSpectrumMaskOFDMAllSegmentsValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   OFDMSignal,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   segmentReliability[],
                            ViInt32   numberOfBursts[],
                            ViReal64  results[],
                            ViReal64  outOfTolerance[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViInt32  numberOfSegments = 100;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, OFDMSignal, RSCMWWLM_VAL_OFDM_802_11_AG, RSCMWWLM_VAL_OFDM_802_11_N),
           3, "OFDM Signal");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           4, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:TSM:%s:%s?", instance, OFDMSignalArr[OFDMSignal], resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetTSMOFDMMeasResults(instrSession, cmd, numberOfSegments, arraySize,
      reliability, segmentReliability, numberOfBursts,
      results, outOfTolerance, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval List Mode Transmit Spectrum Mask OFDM One Segment Values
 * Purpose:  Returns the transmit spectrum mask results for segment <nr> for
             OFDM signals in list mode.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeTransmitSpectrumMaskOFDMOneSegmentValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   OFDMSignal,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViInt32*  numberOfBursts,
                            ViReal64  results[],
                            ViReal64* outOfTolerance,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, OFDMSignal, RSCMWWLM_VAL_OFDM_802_11_AG, RSCMWWLM_VAL_OFDM_802_11_N),
           3, "OFDM Signal");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           4, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:TSM:%s:%s?", instance, segment, OFDMSignalArr[OFDMSignal], resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetTSMOFDMMeasResults(instrSession, cmd, 1, arraySize, reliability,
      segmentReliability, numberOfBursts,
      results, outOfTolerance, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval List Mode Transmit Spectrum Mask DSSS All Segments Values
 * Purpose:  Returns the transmit spectrum mask limit line margin results
             (DSSS signal) of all segments for OFDM signals in list mode.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeTransmitSpectrumMaskDSSSAllSegmentsValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   segmentReliability[],
                            ViInt32   numberOfBursts[],
                            ViReal64  results[],
                            ViReal64  outOfTolerance[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
   ViInt32  numberOfSegments = 100;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:TSM:DSSS:%s?", instance, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetTSMDSSSMeasResults(instrSession, cmd, numberOfSegments, arraySize,
      reliability, segmentReliability, numberOfBursts,
      results, outOfTolerance, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Fetch Multi Eval List Mode Transmit Spectrum Mask DSSS One Segment Values
 * Purpose:  Returns the transmit spectrum mask limit line margin results
             (DSSS signal) for segment <nr> for OFDM signals in list mode.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeTransmitSpectrumMaskDSSSOneSegmentValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViInt32*  numberOfBursts,
                            ViReal64  results[],
                            ViReal64* outOfTolerance,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MAX),
           4, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:TSM:DSSS:%s?", instance, segment, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetTSMDSSSMeasResults(instrSession, cmd, 0, arraySize, reliability,
      segmentReliability, numberOfBursts,
      results, outOfTolerance, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/// HIFN  Return OFDM/OFDMA modulation single value results for segment <no> in
/// HIFN  list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR segment/Sets the segment number.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR modulationType/Returns modulation type.
/// HIPAR results/Returns result values.
/// HIPAR guardInterval/Returns the guard interval.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalListModeOFDMSegment(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   segment,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViInt32*  modulationType,
                                                             ViReal64  results[],
                                                             ViInt32*  guardInterval,
                                                             ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, 0, 2),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:MOD:%s?", instance, segment, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetOFDMResults(instrSession, cmd, 10000, (arraySize > 24) ? 24 : arraySize, reliability, modulationType, ofdmModulationArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Return limit line margin results for segment <no> in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR segment/Sets the segment number.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR modulationType/Returns modulation type.
/// HIPAR results/Returns result values.
/// HIPAR guardInterval/Returns the guard interval.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalListModeOFDMSegmentMask(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, 0, 2),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:TSM:%s?", instance, segment, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetOFDMResults(instrSession, cmd, 10000, (arraySize > 24) ? 24 : arraySize, reliability, modulationType, ofdmModulationArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Return the X-positions of the limit line margins of the transmit
/// HIFN  spectrum mask for list mode, segment <no>.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR segment/Sets the segment number.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR modulationType/Returns modulation type.
/// HIPAR results/Returns result values.
/// HIPAR guardInterval/Returns the guard interval.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalListModeOFDMSegmentMaskFrequency(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, 0, 2),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:TSM:FREQ:%s?", instance, segment, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetOFDMResults(instrSession, cmd, 10000, (arraySize > 24) ? 24 : arraySize, reliability, modulationType, ofdmModulationArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Return the current, average, minimum, maximum and standard deviation
/// HIFN  single value results for DSSS signals for segment <no> in list mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR segment/Sets the segment number.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR modulationType/Returns modulation type.
/// HIPAR results/Returns result values.
/// HIPAR guardInterval/Returns the guard interval.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalListModeDSSSSegment(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   segment,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViInt32*  modulationType,
                                                             ViReal64  results[],
                                                             ViInt32*  guardInterval,
                                                             ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, 0, 2),
           3, "Result Type");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:LIST:SEGM%ld:MODE:DSSS:%s?", instance, segment, resultTypeArr[resultType]);
   checkErr(rscmwwlm_GetOFDMResults(instrSession, cmd, 10000, (arraySize > 24) ? 24 : arraySize, reliability, modulationType, ofdmModulationArr, results, guardInterval, guardIntervalArr, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}


/// HIFN  Return the values of the EVM vs. subcarrier traces for MIMO
/// HIFN  connections. The results of the current, average, minimum and maximum
/// HIFN  traces can be retrieved.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR antenna/Sets the MIMO Antenna.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the values of the EVM vs. subcarrier traces for MIMO
/// HIPAR results/connections. The results of the current, average, minimum and maximum
/// HIPAR results/traces can be retrieved.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasEVMvsSubcarrierMIMO(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   resultType,
                                                            ViInt32   antenna,
                                                            ViInt32   start,
                                                            ViInt32   count,
                                                            ViInt32   decimation,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  results[],
                                                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:EVM:CARR:MIMO%ld:%s? %ld, %ld, %ld",
           instance, antenna, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the values of the EVM vs. subcarrier traces for MIMO
/// HIFN  connections. The results of the current, average, minimum and maximum
/// HIFN  traces can be retrieved.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR antenna/Sets the MIMO Antenna.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the values of the EVM vs. subcarrier traces for MIMO
/// HIPAR results/connections. The results of the current, average, minimum and maximum
/// HIPAR results/traces can be retrieved.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasEVMvsSubcarrierMIMO(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   antenna,
                                                             ViInt32   start,
                                                             ViInt32   count,
                                                             ViInt32   decimation,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:EVM:CARR:MIMO%ld:%s? %ld, %ld, %ld",
           instance, antenna, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the values of the EVM vs. subcarrier traces for 80+80 MHz, MIMO
/// HIFN  connections. The results of the current, average, minimum and maximum
/// HIFN  traces can be retrieved.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR antenna/Sets the MIMO Antenna.
/// HIPAR segment/Sets the Segment.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the values of the EVM vs. subcarrier traces for 80+80 MHz, MIMO
/// HIPAR results/connections. The results of the current, average, minimum and maximum
/// HIPAR results/traces can be retrieved.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasEVMvsSubcarrierSegmentMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           5, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:EVM:CARR:MIMO%ld:SEGM%ld:%s? %ld, %ld, %ld", instance, antenna, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the values of the EVM vs. subcarrier traces for 80+80 MHz, MIMO
/// HIFN  connections. The results of the current, average, minimum and maximum
/// HIFN  traces can be retrieved.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR antenna/Sets the MIMO Antenna.
/// HIPAR segment/Sets the Segment.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the values of the EVM vs. subcarrier traces for 80+80 MHz, MIMO
/// HIPAR results/connections. The results of the current, average, minimum and maximum
/// HIPAR results/traces can be retrieved.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasEVMvsSubcarrierSegmentMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antenna, 1, 8),
           4, "Antenna");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           5, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:EVM:CARR:MIMO%ld:SEGM%ld:%s? %ld, %ld, %ld", instance, antenna, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the values of the EVM vs. subcarrier traces for 80+80 MHz, SISO
/// HIFN  connections. The results of the current, average, minimum and maximum
/// HIFN  traces can be retrieved.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR segment/Sets the Segment.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the values of the EVM vs. subcarrier traces for 80+80 MHz, SISO
/// HIPAR results/connections. The results of the current, average, minimum and maximum
/// HIPAR results/traces can be retrieved.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasEVMvsSubcarrierSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           4, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:MEV:TRAC:EVM:CARR:SEGM%ld:%s? %ld, %ld, %ld",
           instance, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}


/// HIFN  Return the values of the EVM vs. subcarrier traces for 80+80 MHz, SISO
/// HIFN  connections. The results of the current, average, minimum and maximum
/// HIFN  traces can be retrieved.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR resultType/Denotes the statistics type.
/// HIPAR segment/Sets the Segment.
/// HIPAR start/This control limits the returned array to the segment beginning with
/// HIPAR start/position.
/// HIPAR count/This control limits the segment to <Count> values.
/// HIPAR decimation/It decimates the segment <Start> ... <Start>+<Count>- 1 by returning
/// HIPAR decimation/only every n'th value (<decimation> = n).
/// HIPAR arraySize/Sets the number of values allocated for result array.
/// HIPAR reliability/Integer value of the reliability indicator for the entire measurement
/// HIPAR reliability/result. To translate this code into human-readable string, use the
/// HIPAR reliability/rscmwwlm_ReliabilityIndicator.
/// HIPAR results/Return the values of the EVM vs. subcarrier traces for 80+80 MHz, SISO
/// HIPAR results/connections. The results of the current, average, minimum and maximum
/// HIPAR results/traces can be retrieved.
/// HIPAR returnedValues/Returns number of results returned from the instrument.
ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasEVMvsSubcarrierSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, resultType, RSCMWWLM_VAL_RESULT_CURRENT, RSCMWWLM_VAL_RESULT_MIN),
           3, "Result Type");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, segment, 1, 2),
           4, "Segment");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:MEV:TRAC:EVM:CARR:SEGM%ld:%s? %ld, %ld, %ld",
           instance, segment, resultTypeArr[resultType], start, count, decimation);
   checkErr(rscmwwlm_GetMeasResults(instrSession, cmd, 10000, arraySize, reliability, results, returnedValues));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure CMIMO Training Mode Enable
 * Purpose:  Allows to switch from the Measurement Mode to the Training Mode
             and back.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureCMIMOTrainingModeEnable(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   mode)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_CMIMO_TRAINING_MODE_ENABLE, mode),
           3, "Mode");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Configure Training Data TX Antenna Number
 * Purpose:  Gets/Sets the number of TX antennas contibuting to the MIMO
             training signal.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureTrainingDataTXAntennaNumber(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   numberOfAntennas)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViInt32(instrSession, repCap, RSCMWWLM_ATTR_TRAINING_DATA_TX_ANTENNA_NUMBER, numberOfAntennas),
           3, "Number Of Antennas");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Training Data Acquisition Init
 * Purpose:  Starts the training data acquisition for the designated antenna.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_TrainingDataAcquisitionInit(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   antennas)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap_instance[RS_REPCAP_BUF_SIZE] = "";
   ViChar   repCap_antenna[RS_REPCAP_BUF_SIZE] = "";
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap_instance));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antennas, 1, 4),
           3, "Antennas");
   viCheckParm(RsCore_GetAttributeRepCapName(instrSession, RSCMWWLM_ATTR_TRAINING_DATA_ACQUISITION_INITIATION,
           "Antenna", antennas , RS_REPCAP_BUF_SIZE, repCap_antenna),
           3, "Antennas");

   strcpy(repCap, repCap_instance);
   strcat(repCap, ",");
   strcat(repCap, repCap_antenna);

   checkErr(rscmwwlm_SetAttributeViString(instrSession, repCap, RSCMWWLM_ATTR_TRAINING_DATA_ACQUISITION_INITIATION, NULL));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Training Data Acquisition Abort
 * Purpose:  Aborts the current MIMO training data acquisition.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_TrainingDataAcquisitionAbort(ViSession instrSession,
                                                        ViInt32   instance)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViString(instrSession, repCap, RSCMWWLM_ATTR_TRAINING_DATA_ACQUISITION_ABORT, NULL),
           3, "Acquisition Abort");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Training Data Acquisition Save
 * Purpose:  Saves the current Training Data to a file or queries the file
             name of the last saved Training Data file.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_TrainingDataAcquisitionSave(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViString  fileName)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViString(instrSession, repCap, RSCMWWLM_ATTR_TRAINING_DATA_ACQUISITION_SAVE, fileName),
           3, "File Name");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Training Data Acquisition Date
 * Purpose:  Returns the last modified date of the last saved training data
             ("mif") file, if any.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_TrainingDataAcquisitionDate(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   bufferSize,
                                                       ViChar    fileDate[])
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_GetAttributeViString(instrSession, repCap, RSCMWWLM_ATTR_TRAINING_DATA_ACQUISITION_DATE,
           bufferSize, fileDate),
           4, "File Date");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Training Data Acquisition Clear
 * Purpose:  Clears the current training results and resets the internal data
             of the Training Mode.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_TrainingDataAcquisitionClear(ViSession instrSession,
                                                        ViInt32   instance)
{
   ViStatus error = VI_SUCCESS;
   ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_instanceRepCap(instrSession, instance, repCap));

   viCheckParm(rscmwwlm_SetAttributeViString(instrSession, repCap, RSCMWWLM_ATTR_TRAINING_DATA_ACQUISITION_CLEAR, NULL),
           3, "Acquisition Clear");

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function:Read Training Data Acquisition Results
 * Purpose: Return information about the training data acquired on the
            designated antenna and the decode status of the received signal.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReadTrainingDataAcquisitionResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antennas,
                            ViInt32*  reliability,
                            ViInt32*  decodeStatus,
                            ViReal64* MCS,
                            ViReal64* power,
                            ViReal64* pilotEVM)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antennas, 1, 4),
           3, "Antennas");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:MEAS%ld:TMODe:ANTenna%ld?", instance, antennas);
   checkErr(rscmwwlm_GetDataAcquisitionResult(instrSession, cmd, 10000, reliability, decodeStatus, MCS, power, pilotEVM));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function:Fetch Training Data Acquisition Results
 * Purpose: Returns information about the training data acquired on the
            designated antenna and the decode status of the received signal.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_FetchTrainingDataAcquisitionResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antennas,
                            ViInt32*  reliability,
                            ViInt32*  decodeStatus,
                            ViReal64* MCS,
                            ViReal64* power,
                            ViReal64* pilotEVM)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
           2, "Instance");
   viCheckParm(RsCore_InvalidViInt32Range(instrSession, antennas, 1, 4),
           3, "Antennas");

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:MEAS%ld:TMOD:ANT%ld?", instance, antennas);
   checkErr(rscmwwlm_GetDataAcquisitionResult(instrSession, cmd, 0, reliability, decodeStatus, MCS, power, pilotEVM));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: rscmwwlm_SetAttribute<type> Functions
 * Purpose:  These functions enable the instrument driver user to set
 *           attribute values directly.  There are typesafe versions for
 *           ViInt32, ViReal64, ViString, ViBoolean, and ViSession datatypes.
 *****************************************************************************/
 /* ViInt32 */
ViStatus _VI_FUNC rscmwwlm_SetAttributeViInt32(ViSession instrSession,
                                               ViString  repeatedCapabilityName,
                                               ViAttr    attributeId,
                                               ViInt32   attributeValue)
{
   ViStatus error = VI_SUCCESS;

   (void)RsCore_LockSession(instrSession);

   error = RsCore_SetAttributeViInt32(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/* ViReal64 */
ViStatus _VI_FUNC rscmwwlm_SetAttributeViReal64(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViReal64  attributeValue)
{
   ViStatus error = VI_SUCCESS;

   (void)RsCore_LockSession(instrSession);

   error = RsCore_SetAttributeViReal64(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/* ViString */
ViStatus _VI_FUNC rscmwwlm_SetAttributeViString(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViString  attributeValue)
{
   ViStatus error = VI_SUCCESS;

   (void)RsCore_LockSession(instrSession);

   error = RsCore_SetAttributeViString(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/* ViBoolean */
ViStatus _VI_FUNC rscmwwlm_SetAttributeViBoolean(ViSession instrSession,
                                                 ViString  repeatedCapabilityName,
                                                 ViAttr    attributeId,
                                                 ViBoolean attributeValue)
{
   ViStatus error = VI_SUCCESS;

   (void)RsCore_LockSession(instrSession);

   error = RsCore_SetAttributeViBoolean(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: rscmwwlm_GetAttribute<type> Functions
 * Purpose:  These functions enable the instrument driver user to get
 *           attribute values directly.  There are typesafe versions for
 *           ViInt32, ViReal64, ViString, ViBoolean, and ViSession attributes.
 *****************************************************************************/

 /* ViInt32 */
ViStatus _VI_FUNC rscmwwlm_GetAttributeViInt32(ViSession instrSession,
                                               ViString  repeatedCapabilityName,
                                               ViAttr    attributeId,
                                               ViInt32*  attributeValue)
{
   ViStatus error = VI_SUCCESS;

   (void)RsCore_LockSession(instrSession);
   error = RsCore_GetAttributeViInt32(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/* ViReal64 */
ViStatus _VI_FUNC rscmwwlm_GetAttributeViReal64(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViReal64* attributeValue)
{
   ViStatus error = VI_SUCCESS;

   (void)RsCore_LockSession(instrSession);

   error = RsCore_GetAttributeViReal64(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/* ViString */
ViStatus _VI_FUNC rscmwwlm_GetAttributeViString(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViInt32   bufferSize,
                                                ViChar    attributeValue[])
{
   ViStatus error = VI_SUCCESS;

   (void)RsCore_LockSession(instrSession);

   error = RsCore_GetAttributeViString(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, bufferSize, attributeValue);

   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/* ViBoolean */
ViStatus _VI_FUNC rscmwwlm_GetAttributeViBoolean(ViSession  instrSession,
                                                 ViString   repeatedCapabilityName,
                                                 ViAttr     attributeId,
                                                 ViBoolean* attributeValue)
{
   ViStatus error = VI_SUCCESS;

   (void)RsCore_LockSession(instrSession);

   error = RsCore_GetAttributeViBoolean(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Rs_GetAttributeRepCapNameId
 * Purpose:  This function returns the repeated capability id(s) that
 *           belongs to the attribute you specify. More then one id is listed
 *           in comma separated string.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                             ViAttr    attributeId,
                                                             ViInt32   bufferSize,
                                                             ViChar    repeatedCapabilityIds[])
{
   ViStatus error = VI_SUCCESS;

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, RS_MAX_SHORT_MESSAGE_BUF_SIZE),
           3, "Buffer Size");

   checkErr(RsCore_GetAttributeRepCapNameIds(instrSession, attributeId, bufferSize, repeatedCapabilityIds));

Error:
   return error;
}

/*****************************************************************************
 * Function: Get Attribute Repeated Capability Id Name(s)
 * Purpose:  This function returns the repeated capability name(s) that
 *           belongs to the attribute and single repeated capability id you
 *           may specify. More then one name is listed in comma separated
 *           string.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViAttr    attributeId,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdNames[])
{
   ViStatus error = VI_SUCCESS;

   viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, RS_MAX_SHORT_MESSAGE_BUF_SIZE),
           4, "Buffer Size");

   checkErr(RsCore_GetAttributeRepCapNamesAll(instrSession,
      attributeId,
      repeatedCapabilityId,
      bufferSize,
      repeatedCapabilityIdNames));

Error:
   return error;
}

/// HIFN Function used by Hi-level functions to obtain a repCap name from:
/// HIFN - attributeID
/// HIFN - repCapNameID
/// HIFN - 0-based index in the repCapNames
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR repCapNameId/RepCap Name ID.
/// HIPAR index/Zero based index in the repCapNames.
/// HIPAR bufferSize/Pass the number of bytes in the string you allocate for the repCapName.
/// HIPAR repCapName/String returning RepCap name
ViStatus _VI_FUNC rscmwwlm_GetAttributeRepCapName(ViSession instrSession,
                                                  ViAttr    attributeId,
                                                  ViString  repCapNameId,
                                                  ViInt32   index,
                                                  ViInt32   bufferSize,
                                                  ViChar    repCapName[])
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   checkErr(RsCore_GetAttributeRepCapName(instrSession, attributeId, repCapNameId, index, bufferSize, repCapName));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Reset
 * Purpose:  This function resets the instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_reset(ViSession instrSession)
{
   ViStatus error = VI_SUCCESS;
   ViInt32  OPC = -1;

   checkErr(RsCore_LockSession(instrSession));

   if (RsCore_Simulating(instrSession) == VI_FALSE)
   {
      checkErr(rscmwwlm_ClearStatus(instrSession));
      checkErr(RsCore_Write(instrSession, "*RST")); // IGNORE: Check double write
      checkErr(rscmwwlm_QueryOPC(instrSession, &OPC));
   }

   checkErr(rscmwwlm_DefaultInstrSetup(instrSession));
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);

   return error;
}

/*****************************************************************************
 * Function: Self Test
 * Purpose:  This function executes the instrument self-test and returns the
 *           result.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_self_test(ViSession instrSession,
                                     ViInt16*  testResult,
                                     ViChar    testMessage[])
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidNullPointer(instrSession, testResult), 2, "Null address for Test Result");
   viCheckParm(RsCore_InvalidNullPointer(instrSession, testMessage), 3, "Null address for Test Message");

   checkErr(RsCore_SelfTest(instrSession, testResult, 48, testMessage));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Self Test Results
 * Purpose:  This function executes the instrument self-test and returns the
 *           result.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_SelfTestResults(ViSession instrSession,
                                           ViInt32   bufferSize,
                                           ViChar    results[])
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   checkErr(RsCore_QueryViStringUnknownLengthToUserBuffer(instrSession, "DIAG:SERV:STES:RES?", bufferSize, results, NULL));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Revision Query
 * Purpose:  This function returns the driver and instrument revisions.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_revision_query(ViSession instrSession,
                                          ViChar    instrumentDriverRevision[],
                                          ViChar    firmwareRevision[])
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidNullPointer(instrSession, instrumentDriverRevision), 2, "Null address for Instrument Driver Revision");
   viCheckParm(RsCore_InvalidNullPointer(instrSession, firmwareRevision), 3, "Null address for Instrument Revision");

   checkErr(RsCore_GetAttributeViString(instrSession, NULL, RS_ATTR_SPECIFIC_DRIVER_REVISION, 0, 256, instrumentDriverRevision));
   checkErr(RsCore_GetAttributeViString(instrSession, NULL, RS_ATTR_INSTRUMENT_FIRMWARE_REVISION, 0, 256, firmwareRevision));
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function:    System Version
 * Purpose:     This function queries the number of the SCPI version, which
 *              is relevant for the instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_SystemVersion(ViSession instrSession,
                                         ViInt32   length,
                                         ViChar    systemVersion[])
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(rscmwwlm_GetAttributeViString(instrSession, "", RSCMWWLM_ATTR_SYSTEM_VERSION,
           length, systemVersion),
           2, "System Version");
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Error Query
 * Purpose:  This function queries the instrument error queue and returns
 *           the result.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_error_query(ViSession instrSession,
                                       ViInt32*  errorCode,
                                       ViChar    errorMessage[])
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidNullPointer(instrSession, errorCode), 2, "Null address for Error Code");
   viCheckParm(RsCore_InvalidNullPointer(instrSession, errorMessage), 3, "Null address for Error Message");

   checkErr(RsCore_ErrorQueryAll(instrSession, errorCode, 1024, errorMessage));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Error List
 * Purpose:  This function reads all system messages and returns a list of
 *           comma separated strings.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ErrorList(ViSession instrSession,
                                     ViInt32   bufferSize,
                                     ViChar    errors[])
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, bufferSize, 0), 2, "Buffer Size");
   viCheckParm(RsCore_InvalidNullPointer(instrSession, errors), 3, "Null address for Errors");

   checkErr(rscmwwlm_GetAttributeViString(instrSession, "", RSCMWWLM_ATTR_SYSTEM_ALL_ERRORS,
      bufferSize, errors));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Error Message
 * Purpose:  This function translates the error codes returned by this
 *           instrument driver into user-readable strings.
 *
 *           Note:  The caller can pass NULL for the vi parameter.  This
 *           is useful if one of the init functions fail.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_error_message(ViSession instrSession,
                                         ViStatus  errorCode,
                                         ViChar    errorMessage[])
{
   return rscmwwlm_utility_error_message(instrSession, errorCode, errorMessage);
}

/*****************************************************************************
 * Function: Configure Error Checking
 * Purpose:  Specifies whether the instrument driver queries the instrument
*            status after each end-user operation.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureErrorChecking(ViSession instrSession,
                                                  ViBoolean enabled)
{
   ViStatus         error = VI_SUCCESS;
   RsCoreSessionPtr rsSession = NULL;

   checkErr(RsCore_GetRsSession(instrSession, &rsSession));
   checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_QUERY_INSTRUMENT_STATUS, 0, enabled));

Error:
   return error;
}

/*****************************************************************************
 * Function: Configure Range Checking
 * Purpose:  This function switches ON/OFF range checkings performed inside
 *             of the driver.
*****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ConfigureRangeChecking(ViSession instrSession,
                                                  ViBoolean enabled)
{  
// TODO: ERROR!!! Missing Lock / Unlock
   ViStatus         error = VI_SUCCESS;
   RsCoreSessionPtr rsSession = NULL;

   checkErr(RsCore_GetRsSession(instrSession, &rsSession));
   checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_RANGE_CHECK, 0, enabled));

Error:
   return error;
}

/*****************************************************************************
 * Function: Reliability Indicator
 * Purpose:  This function converts a reliability code returned by an
 *           instrument driver function into a user-readable string.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_ReliabilityIndicator(ViSession instrSession,
                                                ViInt32   reliabilityCode,
                                                ViChar    reliabilityMessage[])
{
   ViStatus  error = VI_SUCCESS;
   ViInt16   cnt = 0;
   ViBoolean found = VI_FALSE;

   static RsCoreStringValueTable reliabilityTable =
   {
       {0, "OK"},
       {1, "Measurement Timeout"},
       {2, "Capture Buffer Overflow"},
       {3, "Overdriven"},
       {4, "Underdriven"},
       {6, "Trigger Timeout"},
       {7, "Acquisition Error"},
       {8, "Sync Error"},
       {9, "Uncal"},
       {15, "Reference Frequency Error"},
       {16, "RF Not Available"},
       {17, "RF Level not Settled"},
       {18, "RF Frequency not Settled"},
       {19, "Call not Established"},
       {20, "Call Type not Usable"},
       {21, "Call Lost"},
       {23, "Missing Option"},
       {24, "Invalid RF Setting"},
       {26, "Resource Conflict"},
       {27, "No Sensor Connected"},
       {28, "Unexpected Parameter Change"},
       {30, "File not Found"},
       {31, "No DTM reply"},
       {32, "ACL Disconnected"},
       {40, "ARB File CRC Error"},
       {42, "ARB Header Tag Invalid"},
       {43, "ARB Segment Overflow"},
       {44, "ARB File not Found"},
       {45, "ARB Memory Overflow"},
       {46, "ARB Sample Rate out of Range"},
       {47, "ARB Cycles out of Range"},
       {50, "Startup Error"},
       {51, "No Reply"},
       {52, "Connection Error"},
       {53, "Configuration Error"},
       {54, "Filesystem Error"},
       {60, "Invalid RF-Connector Setting"},
       {93, "OCXO Oven Temperature too low"},
       {101, "Firmware Error"},
       {102, "Unidentified Error"},
       {103, "Parameter Error"},
       {104, "Not Functional"},
       {0, NULL}
   };

   (void)RsCore_LockSession(instrSession);

   for (cnt = 0; reliabilityTable[cnt].string; cnt++)
   {
      if (reliabilityTable[cnt].value == reliabilityCode)
      {
         sprintf(reliabilityMessage, "%s", reliabilityTable[cnt].string);
         if (reliabilityCode)
            error = RSCMWWLM_ERROR_RELIABILITY_INDICATOR;
         found = VI_TRUE;
      }
   }

   if (!found)
   {
      sprintf(reliabilityMessage, "Unrecognized reliability indicator! Report problem to R&S support!");
      error = RS_WARN_UNKNOWN_INSTRUMENT_STATUS;
   }

   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Preset
 * Purpose:  This function initiates an instrument reset.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_Preset(ViSession instrSession)
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_SetAttributeViString(instrSession, "", RSCMWWLM_ATTR_SYSTEM_PRESET, NULL));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  This function clears status.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rscmwwlm_ClearStatus(ViSession instrSession)
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   checkErr(RsCore_ClearStatus(instrSession));
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  This function returns the ID Query response string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR IDQueryResponse/Returns the ID Query response string.
ViStatus _VI_FUNC rscmwwlm_IDQueryResponse(ViSession instrSession,
                                           ViChar    IDQueryResponse[])
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   checkErr(RsCore_QueryViStringUnknownLengthToUserBuffer(instrSession, "*IDN?", 256, IDQueryResponse, NULL));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  Stops further command processing until all commands sent before
/// HIFN  *WAI have been executed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rscmwwlm_ProcessAllPreviousCommands(ViSession instrSession)
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_WriteInstrData(instrSession, "*WAI"));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  This function queries the OPC.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR OPC/Queries the OPC.
ViStatus _VI_FUNC rscmwwlm_QueryOPC(ViSession instrSession,
                                    ViInt32*  OPC)
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   checkErr(rscmwwlm_QueryViInt32(instrSession, "*OPC?", OPC));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  This function sets the OPC timeout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR opcTimeout/This control sets the timeout value.
ViStatus _VI_FUNC rscmwwlm_SetOPCTimeout(ViSession instrSession,
                                         ViUInt32  timeout)
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   checkErr(RsCore_SetAttributeViInt32(instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, (ViInt32)timeout));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN  This function returns the OPC timeout.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwlm_init or
/// HIPAR instrSession/rscmwwlm_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR timeout/This control returns the timeout value.
ViStatus _VI_FUNC rscmwwlm_GetOPCTimeout(ViSession instrSession,
                                         ViUInt32* timeout)
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   checkErr(RsCore_GetAttributeViInt32(instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, (ViInt32*)timeout));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN This function specifies the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsspecan_init or
/// HIPAR instrSession/rsspecan_InitWithOptions function.
/// HIPAR VISATimeout/This control sets the timeout value.
ViStatus _VI_FUNC rscmwwlm_SetVISATimeout(ViSession instrSession,
                                          ViUInt32  VISATimeout)
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   checkErr(RsCore_SetVisaTimeout(instrSession, VISATimeout));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN This function returns the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsspecan_init or
/// HIPAR instrSession/rsspecan_InitWithOptions function.
/// HIPAR VISATimeout/This control gets the timeout value.
ViStatus _VI_FUNC rscmwwlm_GetVISATimeout(ViSession instrSession,
                                          ViUInt32* VISATimeout)
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   checkErr(RsCore_GetVisaTimeout(instrSession, VISATimeout));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
/// HIFN Use the function rscmwdau_GetError afterwards to get the detailed information about the instrument error(s).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwdau_init or
/// HIPAR instrSession/rscmwdau_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoSystErrQuery/If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
ViStatus _VI_FUNC rscmwwlm_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                       ViBoolean autoSystErrQuery)
{
   ViStatus         error = VI_SUCCESS;
   RsCoreSessionPtr rsSession = NULL;

   checkErr(RsCore_GetRsSession(instrSession, &rsSession));
   rsSession->autoSystErrQuery = autoSystErrQuery;

Error:
   return error;
}

/// HIFN Session-related mutex switch.
/// HIFN If TRUE (default after init is FALSE), the driver sets a mutual-exclusion mechanism for every driver's hi-level function and attribute access.
/// HIFN Set this value to TRUE if you plan to use one session in more than one thread.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwlm_init or
/// HIPAR instrSession/rscmwlm_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR multiThreadLocking/Session-related mutex switch
ViStatus _VI_FUNC rscmwwlm_ConfigureMultiThreadLocking(ViSession instrSession,
                                                       ViBoolean multiThreadLocking)
{
   ViStatus         error = VI_SUCCESS;
   RsCoreSessionPtr rsSession = NULL;

   checkErr(RsCore_GetRsSession(instrSession, &rsSession));
   rsSession->multiThreadLocking = multiThreadLocking;

Error:
   return error;
}

/*****************************************************************************
 * Function: Get Error and Clear Error Functions
 * Purpose:  These functions enable the instrument driver user to
 *           get or clear the error information the driver associates with the
 *           RS session.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_GetError(ViSession instrSession,
                                    ViStatus* errorCode,
                                    ViInt32   bufferSize,
                                    ViChar    description[])
{
   ViStatus error = VI_SUCCESS;

   // Lock Session - do not jump to the end, even with invalid instrSession the function continues further
   (void)(RsCore_LockSession(instrSession));

   // Test for nulls and acquire error data
   viCheckParm(RsCore_InvalidNullPointer(instrSession, errorCode), 2, "Null address for Error");
   viCheckParm(RsCore_InvalidNullPointer(instrSession, description), 4, "Null address for Description");

   checkErr(RsCore_GetErrorCompleteDescription(instrSession, &rscmwwlm_utility_error_message, errorCode, bufferSize, description));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

ViStatus _VI_FUNC rscmwwlm_ClearError(ViSession instrSession)
{
   return RsCore_ClearErrorInfo(instrSession);
}

/// HIFN This function is used to read data from the instrument and write
/// HIFN it to a user specified file on the host computer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from instrument
/// HIPAR source/to control computer.
/// HIPAR destination/This control defines destination file to which the data transfer
/// HIPAR destination/from instrument to control computer applies.
ViStatus _VI_FUNC rscmwwlm_ReadToFileFromInstrument(ViSession instrSession,
                                                    ViString  source,
                                                    ViString  destination)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

   checkErr(RsCore_LockSession(instrSession));

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DATA? '%s'", source);
   checkErr(RsCore_QueryBinaryDataBlockToFile(instrSession, cmd, destination, RS_VAL_TRUNCATE));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/// HIFN This function is used to read data from the host computer and
/// HIFN write it to a user specified file in the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from control
/// HIPAR source/computer to instrument.
/// HIPAR destination/This control defines destination file to which the data transfer
/// HIPAR destination/from control computer to instrument applies.
ViStatus _VI_FUNC rscmwwlm_WriteFromFileToInstrument(ViSession instrSession,
                                                     ViString  source,
                                                     ViString  destination)
{
   ViStatus error = VI_SUCCESS;
   ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

   checkErr(RsCore_LockSession(instrSession));

   snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DATA '%s',", destination);
   checkErr(RsCore_WriteBinaryDataFromFile(instrSession, cmd, source));
   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: WriteInstrData and ReadInstrData Functions
 * Purpose:  These functions enable the instrument driver user to
 *           write and read commands directly to and from the instrument.
 *
 *           Note:  These functions bypass the RS attribute state caching.
 *                  WriteInstrData invalidates the cached values for all
 *                  attributes.
 *****************************************************************************/

ViStatus _VI_FUNC rscmwwlm_WriteInstrData(ViSession instrSession,
                                          ViString  writeBuffer)
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   error = RsCore_Write(instrSession, writeBuffer);

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

ViStatus _VI_FUNC rscmwwlm_ReadInstrData(ViSession instrSession,
                                         ViInt32   numBytes,
                                         ViChar    rdBuf[],
                                         ViUInt32* bytesRead)
{
   ViStatus error = VI_SUCCESS;
   ViChar*  responseString = NULL;

   checkErr(RsCore_LockSession(instrSession));

   checkErr(RsCore_ReadViStringUnknownLength(instrSession, &responseString));
   checkErr(RsCore_CopyToUserBufferAsciiData(rdBuf, numBytes, responseString));
   *bytesRead = (ViUInt32)strlen(responseString);

Error:
   if (responseString)
      free(responseString);

   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Query ViBoolean
 * Purpose:  This function queries the ViBoolean value.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryViBoolean(ViSession  instrSession,
                                          ViString   cmd,
                                          ViBoolean* value)
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidStringLength(instrSession, cmd, 1, -1), 2, "Command (null string length)");
   viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

   checkErr(RsCore_QueryViBoolean(instrSession, cmd, value));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Query ViInt32
 * Purpose:  This function queries the ViInt32 value.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryViInt32(ViSession instrSession,
                                        ViString  cmd,
                                        ViInt32*  value)
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidStringLength(instrSession, cmd, 1, -1), 2, "Command (null string length)");
   viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

   checkErr(RsCore_QueryViInt32(instrSession, cmd, value));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Query ViReal64
 * Purpose:  This function queries the ViReal64 value.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryViReal64(ViSession instrSession,
                                         ViString  cmd,
                                         ViReal64* value)
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidStringLength(instrSession, cmd, 1, -1), 2, "Command (null string length)");
   viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

   checkErr(RsCore_QueryViReal64(instrSession, cmd, value));

   checkErr(rscmwwlm_CheckStatus(instrSession));

Error:
   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: Query ViString
 * Purpose:  This function queries the ViString value.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_QueryViString(ViSession instrSession,
                                         ViString  cmd,
                                         ViInt32   bufferSize,
                                         ViChar    value[])
{
   ViStatus error = VI_SUCCESS;
   ViChar*  extBuf = NULL;

   checkErr(RsCore_LockSession(instrSession));

   viCheckParm(RsCore_InvalidStringLength(instrSession, cmd, 1, -1), 2, "Command (null string length)");
   viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

   checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &extBuf));

   checkErr(rscmwwlm_CheckStatus(instrSession));

   checkErr(RsCore_CopyToUserBufferAsciiData(value, bufferSize, extBuf));

Error:
   if (extBuf)
      free(extBuf);

   (void)RsCore_UnlockSession(instrSession);
   return error;
}

/*****************************************************************************
 * Function: rscmwwlm_close
 * Purpose:  This function closes the instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_close(ViSession instrSession)
{
   ViStatus error = VI_SUCCESS;

   checkErr(RsCore_LockSession(instrSession));

   checkErr(RsCore_ViClose(instrSession));

Error:
   (void)RsCore_Dispose(instrSession);
   (void)RsCore_UnlockSession(instrSession);
   return error;
}
