/*****************************************************************************
 *  Rohde&Schwarz CMW500 Wideband Radio Communication Tester instrument driver
 *  WLAN Measurements
 *  VXIpnp Instrument Driver
 *****************************************************************************/

#ifndef __RSCMWWLM_HEADER
#define __RSCMWWLM_HEADER

#include "rscore.h"
#include "rscmwwlm_attributes.h"
#include "rscmwwlm_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSCMWWLM_CLASS_DRIVER_DESCRIPTION           ""
#define RSCMWWLM_CLASS_DRIVER_PREFIX                ""
#define RSCMWWLM_CLASS_DRIVER_VENDOR                ""
#define RSCMWWLM_CLASS_DRIVER_REVISION              ""
#define RSCMWWLM_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSCMWWLM_CLASS_SPEC_MINOR_VERSION           0L    /* Class specification minor version */

/* Driver Identification */

#define RSCMWWLM_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSCMWWLM_SPECIFIC_DRIVER_PREFIX             "RSCMWWLM"
#define RSCMWWLM_SPECIFIC_DRIVER_LOCATOR            ""
#define RSCMWWLM_SPECIFIC_DRIVER_VENDOR             ""
#define RSCMWWLM_MAJOR_VERSION                      4L    /* Instrument driver major version          */
#define RSCMWWLM_MINOR_VERSION                      0L    /* Instrument driver minor version          */
#define RSCMWWLM_MINOR_MINOR_VERSION                200L   /* Instrument driver minor minor version    */

/* Driver Capabilities */

#define RSCMWWLM_SUPPORTED_INSTRUMENT_MODELS        "CMW"    /* Instrument driver supported model(s)     */
#define RSCMWWLM_GROUP_CAPABILITIES                 ""
#define RSCMWWLM_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *------------------------------ Useful Macros -----------------------------*
 ****************************************************************************/

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define RSCMWWLM_SIMULATION_ID_QUERY      "Rohde&Schwarz,CMW,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSCMWWLM_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSCMWWLM_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSCMWWLM_OPC_TIMEOUT              10000L   /* Maximum time to wait for OPC in milliseconds */

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

/*- Inherent Instrument Specific Attributes ----------------------------*/

/* User Options */

#define RSCMWWLM_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSCMWWLM_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSCMWWLM_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSCMWWLM_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSCMWWLM_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSCMWWLM_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSCMWWLM_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSCMWWLM_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

/* Class Driver Identification */

#define RSCMWWLM_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSCMWWLM_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSCMWWLM_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSCMWWLM_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSCMWWLM_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSCMWWLM_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

/* Driver Identification */

#define RSCMWWLM_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSCMWWLM_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSCMWWLM_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSCMWWLM_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSCMWWLM_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSCMWWLM_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSCMWWLM_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

/* Driver Capabilities */

#define RSCMWWLM_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSCMWWLM_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSCMWWLM_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSCMWWLM_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

/* Driver Setup */

#define RSCMWWLM_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

/* Instrument Identification */

#define RSCMWWLM_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSCMWWLM_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSCMWWLM_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

/* Advanced Session Information */

#define RSCMWWLM_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSCMWWLM_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

/*- Instrument-Specific Attributes -------------------------------------*/

//#define RSCMWWLM_ATTR_ID_QUERY_RESPONSE                                     (RS_SPECIFIC_PUBLIC_ATTR_BASE + 1L)                     /* ViString (Read Only)              */

/* BEGIN GENERATE */
#define RSCMWWLM_ATTR_INPUT_CONNECTOR                                                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 1
#define RSCMWWLM_ATTR_INPUT_EXTERNAL_ATTENUATION                                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 2
#define RSCMWWLM_ATTR_QUERY_INPUT_POSSIBLE_SCENARIOS                                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 234
#define RSCMWWLM_ATTR_ANALYZER_COMBINED_SIGNAL_PATH_SCENARIO                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 70
#define RSCMWWLM_ATTR_ANALYZER_NUMBER_OF_SMIMO_ANTENNAS                                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 77
#define RSCMWWLM_ATTR_ANALYZER_NUMBER_OF_MIMO_ANTENNAS                                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 216
#define RSCMWWLM_ATTR_ANALYZER_USE_SEPARATE_ANTENNAS_FOR_80_PLUS_80_MHZ                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 186
#define RSCMWWLM_ATTR_ANALYZER_CONNECTOR_TUPLE                                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 184
#define RSCMWWLM_ATTR_ANALYZER_SMIMO_CONNECTOR_TUPLE                                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 217
#define RSCMWWLM_ATTR_ANALYZER_EXPECTED_NOMINAL_POWER                                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 3
#define RSCMWWLM_ATTR_ANALYZER_USER_MARGIN                                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 4
#define RSCMWWLM_ATTR_ANALYZER_CENTER_FREQUENCY                                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 5
#define RSCMWWLM_ATTR_ANALYZER_MIXER_LEVEL_OFFSET                                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 6
#define RSCMWWLM_ATTR_ANALYZER_FREQUENCY_OFFSET                                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 78
#define RSCMWWLM_ATTR_ANALYZER_SECOND_CHANNEL_POSITION                                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 71
#define RSCMWWLM_ATTR_ANALYZER_DISPLAY_MODE                                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 218
#define RSCMWWLM_ATTR_ANALYZER_MASK_DISPLAY_MODE                                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 235
#define RSCMWWLM_ATTR_ANALYZER_EXTERNAL_ATTENUATION_ON_RF_CONNECTOR                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 187
#define RSCMWWLM_ATTR_ANALYZER_RF_ROUTING_ANTENNA_CONNECTOR                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 188
#define RSCMWWLM_ATTR_ANALYZER_RF_ROUTING_ANTENNA_EXTERNAL_ATTENUATION                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 236
#define RSCMWWLM_ATTR_ANALYZER_RF_ROUTING_ANTENNA_EXPECTED_PEAK_ENVELOP_POWER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 237
#define RSCMWWLM_ATTR_ANALYZER_RF_ROUTING_ANTENNA_MIXER_LEVEL_OFFSET                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 238
#define RSCMWWLM_ATTR_INPUT_SIGNAL_STANDARD                                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 7
#define RSCMWWLM_ATTR_INPUT_SIGNAL_BURST                                                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 8
#define RSCMWWLM_ATTR_INPUT_SIGNAL_EVALUATION_LENGTH                                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 9
#define RSCMWWLM_ATTR_INPUT_SIGNAL_EVALUATION_LENGTH_SYMBOLS_OFDM                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 189
#define RSCMWWLM_ATTR_INPUT_SIGNAL_BANDWIDTH                                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 10
#define RSCMWWLM_ATTR_INPUT_SIGNAL_RECEIVE_MODE                                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 185
#define RSCMWWLM_ATTR_INPUT_SIGNAL_CHANNEL_DISTANCE                                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 190
#define RSCMWWLM_ATTR_INPUT_SIGNAL_FREQUENCY_BAND                                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 72
#define RSCMWWLM_ATTR_INPUT_SOURCE_SIGNAL_TRAINING_DATA_SOURCE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 54
#define RSCMWWLM_ATTR_LOAD_TRAINING_DATA_FILE_DATE                                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 55
#define RSCMWWLM_ATTR_INPUT_SIGNAL_IQ_SWAP_STATE                                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 120
#define RSCMWWLM_ATTR_INPUT_SIGNAL_MODULATION_FILTER_BURSTS                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 160
#define RSCMWWLM_ATTR_INPUT_SIGNAL_POWER_CLASS                                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 121
#define RSCMWWLM_ATTR_INPUT_SIGNAL_FREQUENCY_CHANNEL                                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 79
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_REPETITION_MODE                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 11
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_STOP_CONDITION                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 12
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_RESULTS_REJECTION                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 13
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_STATISTIC_COUNT                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 14
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_PHASE_TRACKING                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 15
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TIMING_TRACKING                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 16
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LEVEL_TRACKING                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 17
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_CHANNEL_ESTIMATION                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 18
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_FFT_DEMODULATION_OFFSET                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 76
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_DSSS_EVM_METHOD                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 191
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TS_MASK_STATISTIC_COUNT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 19
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TS_MASK_TRIGGER_OFFSET_TIME                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 20
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TS_MASK_AVERAGE_FFT_NUMBER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 21
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_ASSIGN_VIEWS                                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 22
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_EVM_VS_CHIP_VIEW                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 161
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_EVM_VS_SYMBOL_VIEW                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 162
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_EVM_VS_CARRIER_VIEW                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 163
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_IQ_CONSTELLATION_VIEW                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 164
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_MODULATION_SCALAR_VIEW                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 165
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TRANSMIT_SPECTRUM_MASK_VIEW                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 166
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SPECTRUM_FLATNESS_VIEW                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 167
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_UNUSED_TONE_ERROR_VIEW                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 219
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_VS_TIME                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 56
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_VS_TIME_RISING_EDGE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 168
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_VS_TIME_FALLING_EDGE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 169
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_VS_TIME_BURST                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 57
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_VS_TIME_RESULT_ENABLE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 58
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_VS_TIME_STATISTIC_COUNT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 192
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_VS_TIME_TE_PERCENTAGE_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 239
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_VS_TIME_TE_PERCENTAGE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 240
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_DSSS_AVERAGE_LENGTH                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 73
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_DSSS_REFERENCE_POWER                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 74
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TIMEOUT                                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 49
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_MASK_SPECTRUM_SELECTION                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 122
#define RSCMWWLM_ATTR_CONFIGURE_MULTI_EVAL_MEASUREMENT_OCCUPIED_BANDWIDTH_ENABLE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 158
#define RSCMWWLM_ATTR_CONFIGURE_MULTI_EVAL_MEASUREMENT_OCCUPIED_BANDWIDTH_VALUE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 159
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_SOURCE                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 23
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_SLOPE                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 24
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_THRESHOLD                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 25
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_TIMEOUT                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 26
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_TRIGGER_IF_MIN_GAP                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 27
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE_STATE                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 28
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE_NUMBER_OF_SEGMENTS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 29
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE_CAPTURE_TIME                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 30
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE_CHANNEL_FILTER_ESTIMATION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 31
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIST_MODE_CONNECTOR                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 241
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_POWER_VS_TIME_LIMIT_ENABLE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 59
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_RISE_TIME_LIMIT_ENABLE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 170
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_FALL_TIME_LIMIT_ENABLE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 171
#define RSCMWWLM_ATTR_MULTI_EVAL_POWER_VS_TIME_LIMIT                                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 60
#define RSCMWWLM_ATTR_MULTI_EVAL_POWER_VS_TIME_RISE_TIME_LIMIT                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 172
#define RSCMWWLM_ATTR_MULTI_EVAL_POWER_VS_TIME_FALL_TIME_LIMIT                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 173
#define RSCMWWLM_ATTR_MULTI_EVAL_POWER_VS_TIME_UPPER_LIMIT_ERROR                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 193
#define RSCMWWLM_ATTR_MULTI_EVAL_POWER_VS_TIME_UPPER_LIMIT_ERROR_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 194
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SYNC_MODE                                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 242
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_HE_TB_PPDU_BANDWIDTH                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 243
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_HE_TB_PPDU_MCS                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 244
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_BURST_TYPE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 245
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_BANDWIDTH                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 246
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_CONNECTOR                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 247
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_ENP                                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 248
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_FREQUENCY                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 249
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_MEASUREMENT_OFFSET                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 250
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_MEASUREMENT_TIME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 251
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_STANDARD                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 252
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_SEGMENT_TIME                                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 253
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_EVM_PILOT_ENABLE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 80
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_EVM_PILOT_LIMIT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 81
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_IQ_OFFSET_ENABLE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 82
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_IQ_OFFSET_LIMIT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 83
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_CFERROR_ENABLE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 84
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_CFERROR_LIMIT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 85
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_SCERROR_ENABLE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 86
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211NSMIMO_SCERROR_LIMIT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 87
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_EVM_PILOT_ENABLE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 88
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_EVM_PILOT_LIMIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 89
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_IQ_OFFSET_ENABLE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 90
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_IQ_OFFSET_LIMIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 91
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_CFERROR_ENABLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 92
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_CFERROR_LIMIT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 93
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_SCERROR_ENABLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 94
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AC_SCERROR_LIMIT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 95
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_CENTER_FREQUENCY_ERROR_ENABLE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 123
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_CENTER_FREQUENCY_ERROR_LIMIT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 124
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_EVM_PILOT_ENABLE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 125
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_EVM_PILOT_LIMIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 126
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_IQ_OFFSET_ENABLE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 127
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_IQ_OFFSET_LIMIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 128
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_SYMBOL_CLOCK_ERROR_ENABLE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 129
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM_80211P_SYMBOL_CLOCK_ERROR_LIMIT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 130
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_EVM_PILOT_ENABLE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 220
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_EVM_PILOT_LIMIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 221
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_EVM_PILOT_TBHIGH_ENABLE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 222
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_EVM_PILOT_TBHIGH_LIMIT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 223
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_EVM_PILOT_TBLOW_ENABLE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 224
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_EVM_PILOT_TBLOW_LIMIT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 225
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_IQ_OFFSET_ENABLE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 226
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_IQ_OFFSET_LIMIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 227
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_CFERROR_ENABLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 228
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_CFERROR_LIMIT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 229
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_SCERROR_ENABLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 230
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_SCERROR_LIMIT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 231
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_UTE_POWER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 232
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_MODULATION_OFDM80211AX_UTE_LIMIT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 233
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_DSSS_ENABLE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 34
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_DSSS_LEVEL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 35
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_DSSS_AB_LEVEL                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 174
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_DSSS_CD_LEVEL                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 175
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_ENABLE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 36
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_LEVEL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 37
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_LEVEL_A                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 176
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_LEVEL_B                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 177
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_LEVEL_C                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 178
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_LEVEL_D                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 179
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11N_ENABLE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 39
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11N_LEVEL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 40
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_ABSOLUTE_11N_LIMIT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 38
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_FORTY_ENABLE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 61
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_FORTY_LEVEL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 62
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_FORTY_ABSOLUTE_LIMIT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 63
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO20MHZ_ENABLE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 96
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO20MHZ_A_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 97
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO20MHZ_B_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 98
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO20MHZ_C_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 99
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO20MHZ_D_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 100
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_ABSOLUTE_11ACSISO20MHZ_LIMIT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 101
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO40MHZ_ENABLE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 102
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO40MHZ_A_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 103
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO40MHZ_B_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 104
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO40MHZ_C_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 105
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO40MHZ_D_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 106
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_ABSOLUTE_11ACSISO40MHZ_LIMIT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 107
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO80MHZ_ENABLE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 108
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO80MHZ_A_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 109
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO80MHZ_B_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 110
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO80MHZ_C_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 111
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_11ACSISO80MHZ_D_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 112
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_MASK_OFDM_ABSOLUTE_11ACSISO80MHZ_LIMIT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 113
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AC_ENABLE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 150
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AC_LEVEL_A                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 151
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AC_LEVEL_B                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 152
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AC_LEVEL_C                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 153
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AC_LEVEL_D                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 154
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AC_ABSOLUTE_LIMIT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 155
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_ENABLE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 131
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_ABSOLUTE_LEVEL_A                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 132
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_ABSOLUTE_LEVEL_B                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 133
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_ABSOLUTE_LEVEL_C                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 134
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_ABSOLUTE_LEVEL_D                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 135
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_ABSOLUTE_LEVEL_E                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 136
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_ABSOLUTE_LEVEL_F                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 137
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_A_RELATIVE_LEVEL_A                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 138
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_A_RELATIVE_LEVEL_B                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 139
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_A_RELATIVE_LEVEL_C                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 140
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_A_RELATIVE_LEVEL_D                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 141
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_A_RELATIVE_LEVEL_E                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 142
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_B_RELATIVE_LEVEL_A                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 143
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_B_RELATIVE_LEVEL_B                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 144
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_B_RELATIVE_LEVEL_C                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 145
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_B_RELATIVE_LEVEL_D                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 146
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_CLASS_B_RELATIVE_LEVEL_E                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 147
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_USER_DEFINED_POWER_CLASS_RELATIVE_LEVEL_A RS_SPECIFIC_PUBLIC_ATTR_BASE + 195
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_USER_DEFINED_POWER_CLASS_RELATIVE_LEVEL_B RS_SPECIFIC_PUBLIC_ATTR_BASE + 196
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_USER_DEFINED_POWER_CLASS_RELATIVE_LEVEL_C RS_SPECIFIC_PUBLIC_ATTR_BASE + 197
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_USER_DEFINED_POWER_CLASS_RELATIVE_LEVEL_D RS_SPECIFIC_PUBLIC_ATTR_BASE + 198
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211P_USER_DEFINED_POWER_CLASS_RELATIVE_LEVEL_E RS_SPECIFIC_PUBLIC_ATTR_BASE + 199
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AX_ENABLE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 200
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AX_LEVEL_A                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 201
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AX_LEVEL_B                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 202
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AX_LEVEL_C                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 203
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AX_LEVEL_D                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 204
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211AX_ABSOLUTE_LIMIT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 205
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211N_ENABLE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 206
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211N_LEVEL_A                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 207
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211N_LEVEL_B                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 208
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211N_LEVEL_C                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 209
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211N_LEVEL_D                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 210
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TRANSMIT_SPECTRUM_MASK_OFDM_80211N_ABSOLUTE_LIMIT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 211
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM_ENABLE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 50
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM_UPPER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 51
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211P_ENABLE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 148
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211P_UPPER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 149
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM80211ACSISO20MHZ_ENABLE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 114
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM80211ACSISO20MHZ_UPPER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 115
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM80211ACSISO40MHZ_ENABLE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 116
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM80211ACSISO40MHZ_UPPER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 117
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM80211ACSISO80MHZ_ENABLE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 118
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM80211ACSISO80MHZ_UPPER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 119
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211AC_ENABLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 156
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211AC_UPPER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 157
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211AX_ENABLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 212
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211AX_UPPER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 213
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211N_ENABLE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 214
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_SPECTRUM_FLATNESS_OFDM_80211N_UPPER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 215
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM80211N_ENABLE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 52
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_20MHZ_OFDM80211N_ENABLE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 180
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_40MHZ_OFDM80211N_ENABLE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 181
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_OFDM11N_UPPER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 53
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_20MHZ_OFDM80211N_UPPER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 182
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_LIMITS_TS_FLATNESS_40MHZ_OFDM80211N_UPPER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 183
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_INIT                                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 41
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_ABORT                                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 42
#define RSCMWWLM_ATTR_MULTI_EVAL_MEASUREMENT_STOP                                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 43
#define RSCMWWLM_ATTR_CMIMO_TRAINING_MODE_ENABLE                                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 64
#define RSCMWWLM_ATTR_TRAINING_DATA_TX_ANTENNA_NUMBER                                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 65
#define RSCMWWLM_ATTR_TRAINING_DATA_ACQUISITION_INITIATION                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 66
#define RSCMWWLM_ATTR_TRAINING_DATA_ACQUISITION_ABORT                                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 67
#define RSCMWWLM_ATTR_TRAINING_DATA_ACQUISITION_SAVE                                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 68
#define RSCMWWLM_ATTR_TRAINING_DATA_ACQUISITION_DATE                                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 75
#define RSCMWWLM_ATTR_TRAINING_DATA_ACQUISITION_CLEAR                                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 69
#define RSCMWWLM_ATTR_SYSTEM_VERSION                                                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 44
#define RSCMWWLM_ATTR_SYSTEM_ERROR                                                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 45
#define RSCMWWLM_ATTR_SYSTEM_ALL_ERRORS                                                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 46
#define RSCMWWLM_ATTR_SYSTEM_PRESET                                                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 47
#define RSCMWWLM_ATTR_ID_QUERY_RESPONSE                                                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 48

// rscmwwlm_rngInputConnector
#define RSCMWWLM_VAL_CONN_RF1C                                              1
#define RSCMWWLM_VAL_CONN_RF2C                                              2

// rscmwwlm_rngRepMode
#define RSCMWWLM_VAL_REPETITION_SINGLE                                      0
#define RSCMWWLM_VAL_REPETITION_CONT                                        1

// rscmwwlm_rngStopCond
#define RSCMWWLM_VAL_NONE                                                   0
#define RSCMWWLM_VAL_LIM_FAIL                                               1

// rscmwwlm_rngTrigSlope
#define RSCMWWLM_VAL_TRIGSLOPE_RISING                                       0
#define RSCMWWLM_VAL_TRIGSLOPE_FALLING                                      1

// rscmwwlm_rngInputSignalStandard
#define RSCMWWLM_VAL_STD_BDSS                                               0
#define RSCMWWLM_VAL_STD_GOFD                                               1
#define RSCMWWLM_VAL_STD_GDSS                                               2
#define RSCMWWLM_VAL_STD_AOFD                                               3
#define RSCMWWLM_VAL_STD_NOFD                                               4
#define RSCMWWLM_VAL_STD_CMIMO                                              5
#define RSCMWWLM_VAL_STD_SMIMO                                              6
#define RSCMWWLM_VAL_STD_ACSISO                                             7
#define RSCMWWLM_VAL_STD_POFDM                                              8
#define RSCMWWLM_VAL_STD_DSSS                                               9
#define RSCMWWLM_VAL_STD_LOFD                                               10
#define RSCMWWLM_VAL_STD_HTOF                                               11
#define RSCMWWLM_VAL_STD_VHT                                                12
#define RSCMWWLM_VAL_STD_HEOF                                               13

// rscmwwlm_rngInputSignalBurstType
#define RSCMWWLM_VAL_BURST_MIXED                                            0
#define RSCMWWLM_VAL_BURST_GREEN                                            1
#define RSCMWWLM_VAL_BURST_DLIN                                             2
#define RSCMWWLM_VAL_BURST_AUTO                                             3

// rscmwwlm_rngEvaluationLength
#define RSCMWWLM_VAL_EVAL_LENGTH_WHOLE                                      0
#define RSCMWWLM_VAL_EVAL_LENGTH_REDUCED                                    1

// rscmwwlm_rngChannelEstimation
#define RSCMWWLM_VAL_CEST_PAYLOAD                                           0
#define RSCMWWLM_VAL_CEST_PREAMBLE                                          1

// rscmwwlm_rngListModeEstimation
#define RSCMWWLM_VAL_FILTER_OPS                                             0
#define RSCMWWLM_VAL_FILTER_ALL                                             1

// rscmwwlm_rngBandwidth
#define RSCMWWLM_VAL_INPUT_SIGNAL_BW_20MHZ                                  0
#define RSCMWWLM_VAL_INPUT_SIGNAL_BW_40MHZ                                  1
#define RSCMWWLM_VAL_INPUT_SIGNAL_BW_80MHZ                                  2
#define RSCMWWLM_VAL_INPUT_SIGNAL_BW_160MHZ                                 3
#define RSCMWWLM_VAL_INPUT_SIGNAL_BW_5MHZ                                   4
#define RSCMWWLM_VAL_INPUT_SIGNAL_BW_10MHZ                                  5
#define RSCMWWLM_VAL_INPUT_SIGNAL_BW_88MHZ                                  6

// rscmwwlm_rngTrainingMode
#define RSCMWWLM_VAL_TMOD                                                   0
#define RSCMWWLM_VAL_MMOD                                                   1

// rscmwwlm_rngAnalyzerSecondChannelPosition
#define RSCMWWLM_VAL_ANALYZER_POSITION_POSITIVE                             0
#define RSCMWWLM_VAL_ANALYZER_POSITION_NEGATIVE                             1

// rscmwwlm_rngInputSignalFrequencyBand
#define RSCMWWLM_VAL_INPUT_SIGNAL_BAND_24GHZ                                0
#define RSCMWWLM_VAL_INPUT_SIGNAL_BAND_5GHZ                                 1
#define RSCMWWLM_VAL_INPUT_SIGNAL_BAND_4GHZ                                 2

// rscmwwlm_rngMultiEvalMeasurementDSSSReferencePower
#define RSCMWWLM_VAL_POWER_MAXIMUM                                          0
#define RSCMWWLM_VAL_POWER_MEAN                                             1

// rscmwwlm_rngMultiEvalMeasurementFFTDemodulationOffset
#define RSCMWWLM_VAL_FFT_DEMOD_OFFSET_AUTO                                  0
#define RSCMWWLM_VAL_FFT_DEMOD_OFFSET_CENTER                                1
#define RSCMWWLM_VAL_FFT_DEMOD_OFFSET_PEAK                                  2

// rscmwwlm_rngInputSignalPowerClass
#define RSCMWWLM_VAL_INPUT_SIGNAL_POWER_CLASS_A                             0
#define RSCMWWLM_VAL_INPUT_SIGNAL_POWER_CLASS_B                             1
#define RSCMWWLM_VAL_INPUT_SIGNAL_POWER_CLASS_C_OR_D                        2
#define RSCMWWLM_VAL_INPUT_SIGNAL_POWER_CLASS_USER                          3

// rscmwwlm_rngMultiEvalMeasurementMaskSpectrumSelection
#define RSCMWWLM_VAL_SPECTRUM_MASK_IEEE                                     0
#define RSCMWWLM_VAL_SPECTRUM_MASK_ETSI                                     1
#define RSCMWWLM_VAL_SPECTRUM_MASK_ARIB                                     2

// rscmwwlm_rngInputSignalModulationFilterBursts
#define RSCMWWLM_VAL_MODULATION_FILTER_OFDM_ALL                             0
#define RSCMWWLM_VAL_MODULATION_FILTER_OFDM_BPSK                            1
#define RSCMWWLM_VAL_MODULATION_FILTER_OFDM_QPSK                            2
#define RSCMWWLM_VAL_MODULATION_FILTER_OFDM_QAM16                           3
#define RSCMWWLM_VAL_MODULATION_FILTER_OFDM_QAM64                           4
#define RSCMWWLM_VAL_MODULATION_FILTER_DSSS_DBPSK                           5
#define RSCMWWLM_VAL_MODULATION_FILTER_DSSS_DQPSK                           6
#define RSCMWWLM_VAL_MODULATION_FILTER_DSSS_CCK55                           7
#define RSCMWWLM_VAL_MODULATION_FILTER_DSSS_CCK11                           8
#define RSCMWWLM_VAL_MODULATION_FILTER_OFDM_QAM256                          9
#define RSCMWWLM_VAL_MODULATION_FILTER_OFDM_QAM1024                         10

// rscmwwlm_rngInputSignalReceiveMode
#define RSCMWWLM_VAL_RECEIVE_SISO                                           0
#define RSCMWWLM_VAL_RECEIVE_CMIM                                           1
#define RSCMWWLM_VAL_RECEIVE_SMIM                                           2

// rscmwwlm_rngAnalyzerConnectorTuple
#define RSCMWWLM_VAL_MIMO_CT12                                              0
#define RSCMWWLM_VAL_MIMO_CT34                                              1
#define RSCMWWLM_VAL_MIMO_CT56                                              2
#define RSCMWWLM_VAL_MIMO_CT78                                              3
#define RSCMWWLM_VAL_MIMO_CT14                                              4
#define RSCMWWLM_VAL_MIMO_CT58                                              5
#define RSCMWWLM_VAL_MIMO_CT18                                              6

// rscmwwlm_rngConnector
#define RSCMWWLM_VAL_ANALYZER_CONN_R11                                      6
#define RSCMWWLM_VAL_ANALYZER_CONN_R12                                      7
#define RSCMWWLM_VAL_ANALYZER_CONN_R13                                      8
#define RSCMWWLM_VAL_ANALYZER_CONN_R14                                      9
#define RSCMWWLM_VAL_ANALYZER_CONN_R15                                      10
#define RSCMWWLM_VAL_ANALYZER_CONN_R16                                      11
#define RSCMWWLM_VAL_ANALYZER_CONN_R17                                      12
#define RSCMWWLM_VAL_ANALYZER_CONN_R18                                      13
#define RSCMWWLM_VAL_ANALYZER_CONN_R21                                      14
#define RSCMWWLM_VAL_ANALYZER_CONN_R22                                      15
#define RSCMWWLM_VAL_ANALYZER_CONN_R23                                      16
#define RSCMWWLM_VAL_ANALYZER_CONN_R24                                      17
#define RSCMWWLM_VAL_ANALYZER_CONN_R25                                      18
#define RSCMWWLM_VAL_ANALYZER_CONN_R26                                      19
#define RSCMWWLM_VAL_ANALYZER_CONN_R27                                      20
#define RSCMWWLM_VAL_ANALYZER_CONN_R28                                      21
#define RSCMWWLM_VAL_ANALYZER_CONN_R31                                      22
#define RSCMWWLM_VAL_ANALYZER_CONN_R32                                      23
#define RSCMWWLM_VAL_ANALYZER_CONN_R33                                      24
#define RSCMWWLM_VAL_ANALYZER_CONN_R34                                      25
#define RSCMWWLM_VAL_ANALYZER_CONN_R35                                      26
#define RSCMWWLM_VAL_ANALYZER_CONN_R36                                      27
#define RSCMWWLM_VAL_ANALYZER_CONN_R37                                      28
#define RSCMWWLM_VAL_ANALYZER_CONN_R38                                      29
#define RSCMWWLM_VAL_ANALYZER_CONN_R41                                      46
#define RSCMWWLM_VAL_ANALYZER_CONN_R42                                      47
#define RSCMWWLM_VAL_ANALYZER_CONN_R43                                      48
#define RSCMWWLM_VAL_ANALYZER_CONN_R44                                      49
#define RSCMWWLM_VAL_ANALYZER_CONN_R45                                      50
#define RSCMWWLM_VAL_ANALYZER_CONN_R46                                      51
#define RSCMWWLM_VAL_ANALYZER_CONN_R47                                      52
#define RSCMWWLM_VAL_ANALYZER_CONN_R48                                      53
#define RSCMWWLM_VAL_ANALYZER_CONN_RA1                                      30
#define RSCMWWLM_VAL_ANALYZER_CONN_RA2                                      31
#define RSCMWWLM_VAL_ANALYZER_CONN_RA3                                      32
#define RSCMWWLM_VAL_ANALYZER_CONN_RA4                                      33
#define RSCMWWLM_VAL_ANALYZER_CONN_RA5                                      34
#define RSCMWWLM_VAL_ANALYZER_CONN_RA6                                      35
#define RSCMWWLM_VAL_ANALYZER_CONN_RA7                                      36
#define RSCMWWLM_VAL_ANALYZER_CONN_RA8                                      37
#define RSCMWWLM_VAL_ANALYZER_CONN_RB1                                      38
#define RSCMWWLM_VAL_ANALYZER_CONN_RB2                                      39
#define RSCMWWLM_VAL_ANALYZER_CONN_RB3                                      40
#define RSCMWWLM_VAL_ANALYZER_CONN_RB4                                      41
#define RSCMWWLM_VAL_ANALYZER_CONN_RB5                                      42
#define RSCMWWLM_VAL_ANALYZER_CONN_RB6                                      43
#define RSCMWWLM_VAL_ANALYZER_CONN_RB7                                      44
#define RSCMWWLM_VAL_ANALYZER_CONN_RB8                                      45

// rscmwwlm_rngMultiEvalMeasurementDSSSEVMMethod
#define RSCMWWLM_VAL_DSSS_EVM_METHOD_ST_1999                                0
#define RSCMWWLM_VAL_DSSS_EVM_METHOD_ST_2007                                1
#define RSCMWWLM_VAL_DSSS_EVM_METHOD_ST_2016                                2

// rscmwwlm_rngUTEPower
#define RSCMWWLM_VAL_UTEPOWER_LOW                                           0
#define RSCMWWLM_VAL_UTEPOWER_HIGH                                          1

// rscmwwlm_rngAnalyzerSMIMOConnectorTuple
#define RSCMWWLM_VAL_SMIMO_CT12                                             0
#define RSCMWWLM_VAL_SMIMO_CT34                                             1
#define RSCMWWLM_VAL_SMIMO_CT56                                             2
#define RSCMWWLM_VAL_SMIMO_CT78                                             3
#define RSCMWWLM_VAL_SMIMO_CT14                                             4
#define RSCMWWLM_VAL_SMIMO_CT58                                             5
#define RSCMWWLM_VAL_SMIMO_CT18                                             6

// rscmwwlm_rngAbsRel
#define RSCMWWLM_VAL_ABS                                                    0
#define RSCMWWLM_VAL_REL                                                    1

// rscmwwlm_rngListModeConnector
#define RSCMWWLM_VAL_LIST_MODE_CONNECTOR_GLOBAL                             0
#define RSCMWWLM_VAL_LIST_MODE_CONNECTOR_LIST                               1

// rscmwwlm_rngMultiEvalMeasSyncMode
#define RSCMWWLM_VAL_MEVAL_SYNC_MODE_NORMAL                                 0
#define RSCMWWLM_VAL_MEVAL_SYNC_MODE_TOLERANT                               1

// rscmwwlm_rngHETBPPDUMCS
#define RSCMWWLM_VAL_HE_TB_PPDU_MCS_MCS                                     0
#define RSCMWWLM_VAL_HE_TB_PPDU_MCS_MCS1                                    1
#define RSCMWWLM_VAL_HE_TB_PPDU_MCS_MCS2                                    2
#define RSCMWWLM_VAL_HE_TB_PPDU_MCS_MCS3                                    3
#define RSCMWWLM_VAL_HE_TB_PPDU_MCS_MCS4                                    4
#define RSCMWWLM_VAL_HE_TB_PPDU_MCS_MCS5                                    5
#define RSCMWWLM_VAL_HE_TB_PPDU_MCS_MCS6                                    6
#define RSCMWWLM_VAL_HE_TB_PPDU_MCS_MCS7                                    7
#define RSCMWWLM_VAL_HE_TB_PPDU_MCS_MCS8                                    8
#define RSCMWWLM_VAL_HE_TB_PPDU_MCS_MCS9                                    9
#define RSCMWWLM_VAL_HE_TB_PPDU_MCS_MCS10                                   10
#define RSCMWWLM_VAL_HE_TB_PPDU_MCS_MCS11                                   11

// rscmwwlm_rngSegmentBurstType
#define RSCMWWLM_VAL_SEGMENT_BURST_TYPE_MIXED                               0
#define RSCMWWLM_VAL_SEGMENT_BURST_TYPE_GREENFIELD                          1

// rscmwwlm_rngSegmentBandwidth
#define RSCMWWLM_VAL_SEGMENT_BW_BW05                                        0
#define RSCMWWLM_VAL_SEGMENT_BW_BW10                                        1
#define RSCMWWLM_VAL_SEGMENT_BW_BW16                                        2
#define RSCMWWLM_VAL_SEGMENT_BW_BW20                                        3
#define RSCMWWLM_VAL_SEGMENT_BW_BW40                                        4
#define RSCMWWLM_VAL_SEGMENT_BW_BW80                                        5

// rscmwwlm_rngSegmentStandard
#define RSCMWWLM_VAL_SEGMENT_STANDARD_DSSS                                  0
#define RSCMWWLM_VAL_SEGMENT_STANDARD_LOFDM                                 1
#define RSCMWWLM_VAL_SEGMENT_STANDARD_POFDM                                 2
#define RSCMWWLM_VAL_SEGMENT_STANDARD_HTOFDM                                3
#define RSCMWWLM_VAL_SEGMENT_STANDARD_VHTOFDM                               4
#define RSCMWWLM_VAL_SEGMENT_STANDARD_HEOFDM                                5

//repcap instance
#define RSCMWWLM_REPCAP_INSTANCE_I1                                         1
#define RSCMWWLM_REPCAP_INSTANCE_I2                                         2
#define RSCMWWLM_REPCAP_INSTANCE_I3                                         3
#define RSCMWWLM_REPCAP_INSTANCE_I4                                         4
#define RSCMWWLM_REPCAP_INSTANCE_I5                                         5
#define RSCMWWLM_REPCAP_INSTANCE_I6                                         6
#define RSCMWWLM_REPCAP_INSTANCE_I7                                         7
#define RSCMWWLM_REPCAP_INSTANCE_I8                                         8
#define RSCMWWLM_REPCAP_INSTANCE_I9                                         9
#define RSCMWWLM_REPCAP_INSTANCE_I10                                        10
#define RSCMWWLM_REPCAP_INSTANCE_I11                                        11
#define RSCMWWLM_REPCAP_INSTANCE_I12                                        12
#define RSCMWWLM_REPCAP_INSTANCE_I13                                        13
#define RSCMWWLM_REPCAP_INSTANCE_I14                                        14
#define RSCMWWLM_REPCAP_INSTANCE_I15                                        15
#define RSCMWWLM_REPCAP_INSTANCE_I16                                        16
#define RSCMWWLM_REPCAP_INSTANCE_I17                                        17
#define RSCMWWLM_REPCAP_INSTANCE_I18                                        18
#define RSCMWWLM_REPCAP_INSTANCE_I19                                        19
#define RSCMWWLM_REPCAP_INSTANCE_I20                                        20
#define RSCMWWLM_REPCAP_INSTANCE_I21                                        21
#define RSCMWWLM_REPCAP_INSTANCE_I22                                        22
#define RSCMWWLM_REPCAP_INSTANCE_I23                                        23
#define RSCMWWLM_REPCAP_INSTANCE_I24                                        24
#define RSCMWWLM_REPCAP_INSTANCE_I25                                        25
#define RSCMWWLM_REPCAP_INSTANCE_I26                                        26
#define RSCMWWLM_REPCAP_INSTANCE_I27                                        27
#define RSCMWWLM_REPCAP_INSTANCE_I28                                        28
#define RSCMWWLM_REPCAP_INSTANCE_I29                                        29
#define RSCMWWLM_REPCAP_INSTANCE_I30                                        30
#define RSCMWWLM_REPCAP_INSTANCE_I31                                        31
#define RSCMWWLM_REPCAP_INSTANCE_I32                                        32

//repcap measurement
#define RSCMWWLM_REPCAP_MEASUREMENT_MEASEVM                                 0
#define RSCMWWLM_REPCAP_MEASUREMENT_MEASEVMS                                1
#define RSCMWWLM_REPCAP_MEASUREMENT_MEASEVMC                                2
#define RSCMWWLM_REPCAP_MEASUREMENT_MEASIQC                                 3
#define RSCMWWLM_REPCAP_MEASUREMENT_MEASMSC                                 4
#define RSCMWWLM_REPCAP_MEASUREMENT_MEASTSM                                 5
#define RSCMWWLM_REPCAP_MEASUREMENT_MEASSFL                                 6

//repcap Segment
#define RSCMWWLM_REPCAP_SEGMENT_SEG1                                        1
#define RSCMWWLM_REPCAP_SEGMENT_SEG2                                        2
#define RSCMWWLM_REPCAP_SEGMENT_SEG3                                        3
#define RSCMWWLM_REPCAP_SEGMENT_SEG4                                        4
#define RSCMWWLM_REPCAP_SEGMENT_SEG5                                        5
#define RSCMWWLM_REPCAP_SEGMENT_SEG6                                        6
#define RSCMWWLM_REPCAP_SEGMENT_SEG7                                        7
#define RSCMWWLM_REPCAP_SEGMENT_SEG8                                        8
#define RSCMWWLM_REPCAP_SEGMENT_SEG9                                        9
#define RSCMWWLM_REPCAP_SEGMENT_SEG10                                       10
#define RSCMWWLM_REPCAP_SEGMENT_SEG11                                       11
#define RSCMWWLM_REPCAP_SEGMENT_SEG12                                       12
#define RSCMWWLM_REPCAP_SEGMENT_SEG13                                       13
#define RSCMWWLM_REPCAP_SEGMENT_SEG14                                       14
#define RSCMWWLM_REPCAP_SEGMENT_SEG15                                       15
#define RSCMWWLM_REPCAP_SEGMENT_SEG16                                       16
#define RSCMWWLM_REPCAP_SEGMENT_SEG17                                       17
#define RSCMWWLM_REPCAP_SEGMENT_SEG18                                       18
#define RSCMWWLM_REPCAP_SEGMENT_SEG19                                       19
#define RSCMWWLM_REPCAP_SEGMENT_SEG20                                       20
#define RSCMWWLM_REPCAP_SEGMENT_SEG21                                       21
#define RSCMWWLM_REPCAP_SEGMENT_SEG22                                       22
#define RSCMWWLM_REPCAP_SEGMENT_SEG23                                       23
#define RSCMWWLM_REPCAP_SEGMENT_SEG24                                       24
#define RSCMWWLM_REPCAP_SEGMENT_SEG25                                       25
#define RSCMWWLM_REPCAP_SEGMENT_SEG26                                       26
#define RSCMWWLM_REPCAP_SEGMENT_SEG27                                       27
#define RSCMWWLM_REPCAP_SEGMENT_SEG28                                       28
#define RSCMWWLM_REPCAP_SEGMENT_SEG29                                       29
#define RSCMWWLM_REPCAP_SEGMENT_SEG30                                       30
#define RSCMWWLM_REPCAP_SEGMENT_SEG31                                       31
#define RSCMWWLM_REPCAP_SEGMENT_SEG32                                       32
#define RSCMWWLM_REPCAP_SEGMENT_SEG33                                       33
#define RSCMWWLM_REPCAP_SEGMENT_SEG34                                       34
#define RSCMWWLM_REPCAP_SEGMENT_SEG35                                       35
#define RSCMWWLM_REPCAP_SEGMENT_SEG36                                       36
#define RSCMWWLM_REPCAP_SEGMENT_SEG37                                       37
#define RSCMWWLM_REPCAP_SEGMENT_SEG38                                       38
#define RSCMWWLM_REPCAP_SEGMENT_SEG39                                       39
#define RSCMWWLM_REPCAP_SEGMENT_SEG40                                       40
#define RSCMWWLM_REPCAP_SEGMENT_SEG41                                       41
#define RSCMWWLM_REPCAP_SEGMENT_SEG42                                       42
#define RSCMWWLM_REPCAP_SEGMENT_SEG43                                       43
#define RSCMWWLM_REPCAP_SEGMENT_SEG44                                       44
#define RSCMWWLM_REPCAP_SEGMENT_SEG45                                       45
#define RSCMWWLM_REPCAP_SEGMENT_SEG46                                       46
#define RSCMWWLM_REPCAP_SEGMENT_SEG47                                       47
#define RSCMWWLM_REPCAP_SEGMENT_SEG48                                       48
#define RSCMWWLM_REPCAP_SEGMENT_SEG49                                       49
#define RSCMWWLM_REPCAP_SEGMENT_SEG50                                       50
#define RSCMWWLM_REPCAP_SEGMENT_SEG51                                       51
#define RSCMWWLM_REPCAP_SEGMENT_SEG52                                       52
#define RSCMWWLM_REPCAP_SEGMENT_SEG53                                       53
#define RSCMWWLM_REPCAP_SEGMENT_SEG54                                       54
#define RSCMWWLM_REPCAP_SEGMENT_SEG55                                       55
#define RSCMWWLM_REPCAP_SEGMENT_SEG56                                       56
#define RSCMWWLM_REPCAP_SEGMENT_SEG57                                       57
#define RSCMWWLM_REPCAP_SEGMENT_SEG58                                       58
#define RSCMWWLM_REPCAP_SEGMENT_SEG59                                       59
#define RSCMWWLM_REPCAP_SEGMENT_SEG60                                       60
#define RSCMWWLM_REPCAP_SEGMENT_SEG61                                       61
#define RSCMWWLM_REPCAP_SEGMENT_SEG62                                       62
#define RSCMWWLM_REPCAP_SEGMENT_SEG63                                       63
#define RSCMWWLM_REPCAP_SEGMENT_SEG64                                       64
#define RSCMWWLM_REPCAP_SEGMENT_SEG65                                       65
#define RSCMWWLM_REPCAP_SEGMENT_SEG66                                       66
#define RSCMWWLM_REPCAP_SEGMENT_SEG67                                       67
#define RSCMWWLM_REPCAP_SEGMENT_SEG68                                       68
#define RSCMWWLM_REPCAP_SEGMENT_SEG69                                       69
#define RSCMWWLM_REPCAP_SEGMENT_SEG70                                       70
#define RSCMWWLM_REPCAP_SEGMENT_SEG71                                       71
#define RSCMWWLM_REPCAP_SEGMENT_SEG72                                       72
#define RSCMWWLM_REPCAP_SEGMENT_SEG73                                       73
#define RSCMWWLM_REPCAP_SEGMENT_SEG74                                       74
#define RSCMWWLM_REPCAP_SEGMENT_SEG75                                       75
#define RSCMWWLM_REPCAP_SEGMENT_SEG76                                       76
#define RSCMWWLM_REPCAP_SEGMENT_SEG77                                       77
#define RSCMWWLM_REPCAP_SEGMENT_SEG78                                       78
#define RSCMWWLM_REPCAP_SEGMENT_SEG79                                       79
#define RSCMWWLM_REPCAP_SEGMENT_SEG80                                       80
#define RSCMWWLM_REPCAP_SEGMENT_SEG81                                       81
#define RSCMWWLM_REPCAP_SEGMENT_SEG82                                       82
#define RSCMWWLM_REPCAP_SEGMENT_SEG83                                       83
#define RSCMWWLM_REPCAP_SEGMENT_SEG84                                       84
#define RSCMWWLM_REPCAP_SEGMENT_SEG85                                       85
#define RSCMWWLM_REPCAP_SEGMENT_SEG86                                       86
#define RSCMWWLM_REPCAP_SEGMENT_SEG87                                       87
#define RSCMWWLM_REPCAP_SEGMENT_SEG88                                       88
#define RSCMWWLM_REPCAP_SEGMENT_SEG89                                       89
#define RSCMWWLM_REPCAP_SEGMENT_SEG90                                       90
#define RSCMWWLM_REPCAP_SEGMENT_SEG91                                       91
#define RSCMWWLM_REPCAP_SEGMENT_SEG92                                       92
#define RSCMWWLM_REPCAP_SEGMENT_SEG93                                       93
#define RSCMWWLM_REPCAP_SEGMENT_SEG94                                       94
#define RSCMWWLM_REPCAP_SEGMENT_SEG95                                       95
#define RSCMWWLM_REPCAP_SEGMENT_SEG96                                       96
#define RSCMWWLM_REPCAP_SEGMENT_SEG97                                       97
#define RSCMWWLM_REPCAP_SEGMENT_SEG98                                       98
#define RSCMWWLM_REPCAP_SEGMENT_SEG99                                       99
#define RSCMWWLM_REPCAP_SEGMENT_SEG100                                      100

//repcap DSSSLevel
#define RSCMWWLM_REPCAP_DSSSLEVEL_DSSSAB                                    0
#define RSCMWWLM_REPCAP_DSSSLEVEL_DSSSCD                                    1

//repcap OFDMLevel
#define RSCMWWLM_REPCAP_OFDMLEVEL_OFDMA                                     0
#define RSCMWWLM_REPCAP_OFDMLEVEL_OFDMB                                     1
#define RSCMWWLM_REPCAP_OFDMLEVEL_OFDMC                                     2
#define RSCMWWLM_REPCAP_OFDMLEVEL_OFDMD                                     3

//repcap Bandwidth
#define RSCMWWLM_REPCAP_BANDWIDTH_BW20                                      0
#define RSCMWWLM_REPCAP_BANDWIDTH_BW40                                      1

//repcap Edge
#define RSCMWWLM_REPCAP_EDGE_MEVREDG                                        0
#define RSCMWWLM_REPCAP_EDGE_MEVFEDG                                        1

//repcap Antenna
#define RSCMWWLM_REPCAP_ANTENNA_A1                                          1
#define RSCMWWLM_REPCAP_ANTENNA_A2                                          2
#define RSCMWWLM_REPCAP_ANTENNA_A3                                          3
#define RSCMWWLM_REPCAP_ANTENNA_A4                                          4
#define RSCMWWLM_REPCAP_ANTENNA_A5                                          5
#define RSCMWWLM_REPCAP_ANTENNA_A6                                          6
#define RSCMWWLM_REPCAP_ANTENNA_A7                                          7
#define RSCMWWLM_REPCAP_ANTENNA_A8                                          8

//repcap Channel
#define RSCMWWLM_REPCAP_CHANNEL_CHANNEL1                                    1
#define RSCMWWLM_REPCAP_CHANNEL_CHANNEL2                                    2
#define RSCMWWLM_REPCAP_CHANNEL_CHANNEL3                                    3
#define RSCMWWLM_REPCAP_CHANNEL_CHANNEL4                                    4
#define RSCMWWLM_REPCAP_CHANNEL_CHANNEL5                                    5
#define RSCMWWLM_REPCAP_CHANNEL_CHANNEL6                                    6
#define RSCMWWLM_REPCAP_CHANNEL_CHANNEL7                                    7
#define RSCMWWLM_REPCAP_CHANNEL_CHANNEL8                                    8

//repcap Band
#define RSCMWWLM_REPCAP_BAND_B20                                            0
#define RSCMWWLM_REPCAP_BAND_B40                                            1
#define RSCMWWLM_REPCAP_BAND_B80                                            2
#define RSCMWWLM_REPCAP_BAND_B160                                           3
#define RSCMWWLM_REPCAP_BAND_B5                                             4
#define RSCMWWLM_REPCAP_BAND_B10                                            5
#define RSCMWWLM_REPCAP_BAND_B8080                                          6

//repcap Connector
#define RSCMWWLM_REPCAP_CONNECTOR_C1                                        1
#define RSCMWWLM_REPCAP_CONNECTOR_C2                                        2
#define RSCMWWLM_REPCAP_CONNECTOR_C3                                        3
#define RSCMWWLM_REPCAP_CONNECTOR_C4                                        4

//repcap FreqBand
#define RSCMWWLM_REPCAP_FREQBAND_BAND2_4GHZ                                 0
#define RSCMWWLM_REPCAP_FREQBAND_BAND5GHZ                                   1

//repcap Station
#define RSCMWWLM_REPCAP_STATION_S1                                          1
#define RSCMWWLM_REPCAP_STATION_S2                                          2
#define RSCMWWLM_REPCAP_STATION_S3                                          3
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSCMWWLM_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSCMWWLM_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSCMWWLM_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSCMWWLM_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *------------------------ Attribute Value Defines -------------------------*
 ****************************************************************************/

/*- Instrument specific attribute value definitions --------------------*/
#define RSCMWWLM_VAL_RESULT_CURRENT 0
#define RSCMWWLM_VAL_RESULT_AVERAGE 1
#define RSCMWWLM_VAL_RESULT_MAX     2
#define RSCMWWLM_VAL_RESULT_MIN     3
#define RSCMWWLM_VAL_RESULT_SDEV    4

#define RSCMWWLM_VAL_RESULT_CFIELD_CRC     0
#define RSCMWWLM_VAL_RESULT_CFIELD_CRU     1
#define RSCMWWLM_VAL_RESULT_CFIELD_RUALLOC 2
#define RSCMWWLM_VAL_RESULT_CFIELD_TAIL    3

#define RSCMWWLM_VAL_RESULT_UFIELD_CODING         0
#define RSCMWWLM_VAL_RESULT_UFIELD_CRC             1
#define RSCMWWLM_VAL_RESULT_UFIELD_DCM             2
#define RSCMWWLM_VAL_RESULT_UFIELD_MCS             3
#define RSCMWWLM_VAL_RESULT_UFIELD_NSTS            4
#define RSCMWWLM_VAL_RESULT_UFIELD_RESERVED     5
#define RSCMWWLM_VAL_RESULT_UFIELD_SPACONF         6
#define RSCMWWLM_VAL_RESULT_UFIELD_STAID         7
#define RSCMWWLM_VAL_RESULT_UFIELD_TAIL            8
#define RSCMWWLM_VAL_RESULT_UFIELD_TXB            9

#define RSCMWWLM_VAL_RESULT_HEMU_BDCM            0
#define RSCMWWLM_VAL_RESULT_HEMU_BMCS            1
#define RSCMWWLM_VAL_RESULT_HEMU_BSSCOL          2
#define RSCMWWLM_VAL_RESULT_HEMU_BW             3
#define RSCMWWLM_VAL_RESULT_HEMU_CRC            4
#define RSCMWWLM_VAL_RESULT_HEMU_DOPPLER        5
#define RSCMWWLM_VAL_RESULT_HEMU_GILTFSIZE      6
#define RSCMWWLM_VAL_RESULT_HEMU_LDPC           7
#define RSCMWWLM_VAL_RESULT_HEMU_NLTFSYMB       8
#define RSCMWWLM_VAL_RESULT_HEMU_NSBSYMB        9
#define RSCMWWLM_VAL_RESULT_HEMU_PEDISAMBIG    10
#define RSCMWWLM_VAL_RESULT_HEMU_PFECPADDING   11
#define RSCMWWLM_VAL_RESULT_HEMU_RESERVED      12
#define RSCMWWLM_VAL_RESULT_HEMU_SBCOMPRESS    13
#define RSCMWWLM_VAL_RESULT_HEMU_SPATIALREUSE  14
#define RSCMWWLM_VAL_RESULT_HEMU_STBC           15
#define RSCMWWLM_VAL_RESULT_HEMU_TAIL           16
#define RSCMWWLM_VAL_RESULT_HEMU_TXOP           17
#define RSCMWWLM_VAL_RESULT_HEMU_ULDL           18

#define RSCMWWLM_VAL_RESULT_HESU_BEAMCHANGE        0
#define RSCMWWLM_VAL_RESULT_HESU_BSSCOL            1
#define RSCMWWLM_VAL_RESULT_HESU_BW                2
#define RSCMWWLM_VAL_RESULT_HESU_CODING            3
#define RSCMWWLM_VAL_RESULT_HESU_CRC            4
#define RSCMWWLM_VAL_RESULT_HESU_DCM            5
#define RSCMWWLM_VAL_RESULT_HESU_DOPPLER        6
#define RSCMWWLM_VAL_RESULT_HESU_FORMAT            7
#define RSCMWWLM_VAL_RESULT_HESU_GILTFSIZE        8
#define RSCMWWLM_VAL_RESULT_HESU_LDPC            9
#define RSCMWWLM_VAL_RESULT_HESU_MCS           10
#define RSCMWWLM_VAL_RESULT_HESU_NSTS           11
#define RSCMWWLM_VAL_RESULT_HESU_PEDISAMBIG       12
#define RSCMWWLM_VAL_RESULT_HESU_PFECPADDING   13
#define RSCMWWLM_VAL_RESULT_HESU_RESERVED_A1   14
#define RSCMWWLM_VAL_RESULT_HESU_RESERVED_A2   15
#define RSCMWWLM_VAL_RESULT_HESU_SPATIALREUSE  16
#define RSCMWWLM_VAL_RESULT_HESU_STBC           17
#define RSCMWWLM_VAL_RESULT_HESU_TAIL           18
#define RSCMWWLM_VAL_RESULT_HESU_TXBF           19
#define RSCMWWLM_VAL_RESULT_HESU_TXOP           20
#define RSCMWWLM_VAL_RESULT_HESU_ULDL           21

#define RSCMWWLM_VAL_RESULT_HETB_BSSCOL          0
#define RSCMWWLM_VAL_RESULT_HETB_BW                 1
#define RSCMWWLM_VAL_RESULT_HETB_CRC             2
#define RSCMWWLM_VAL_RESULT_HETB_FORMAT             3
#define RSCMWWLM_VAL_RESULT_HETB_RESERVED1         4
#define RSCMWWLM_VAL_RESULT_HETB_RESERVED2         5
#define RSCMWWLM_VAL_RESULT_HETB_SPATIALREUSE1   6
#define RSCMWWLM_VAL_RESULT_HETB_SPATIALREUSE2   7
#define RSCMWWLM_VAL_RESULT_HETB_SPATIALREUSE3   8
#define RSCMWWLM_VAL_RESULT_HETB_SPATIALREUSE4   9
#define RSCMWWLM_VAL_RESULT_HETB_TAIL            10
#define RSCMWWLM_VAL_RESULT_HETB_TXOP            11

#define RSCMWWLM_VAL_RESULT_HTSIG_AGGR            0
#define RSCMWWLM_VAL_RESULT_HTSIG_CBW            1
#define RSCMWWLM_VAL_RESULT_HTSIG_CRC            2
#define RSCMWWLM_VAL_RESULT_HTSIG_FECCODING        3
#define RSCMWWLM_VAL_RESULT_HTSIG_HTLENGTH        4
#define RSCMWWLM_VAL_RESULT_HTSIG_MCS            5
#define RSCMWWLM_VAL_RESULT_HTSIG_NESS            6
#define RSCMWWLM_VAL_RESULT_HTSIG_NSOUNDING        7
#define RSCMWWLM_VAL_RESULT_HTSIG_RESERVED        8
#define RSCMWWLM_VAL_RESULT_HTSIG_SHORTGI        9
#define RSCMWWLM_VAL_RESULT_HTSIG_SMOOTHING       10
#define RSCMWWLM_VAL_RESULT_HTSIG_STBCODING       11
#define RSCMWWLM_VAL_RESULT_HTSIG_TAIL           12

#define RSCMWWLM_VAL_RESULT_LSIG_LENGTH        0
#define RSCMWWLM_VAL_RESULT_LSIG_PARITY        1
#define RSCMWWLM_VAL_RESULT_LSIG_RATE        2
#define RSCMWWLM_VAL_RESULT_LSIG_RESERVED   3
#define RSCMWWLM_VAL_RESULT_LSIG_TAIL        4

#define RSCMWWLM_VAL_RESULT_VHTSIG_BEAMFORMED        0
#define RSCMWWLM_VAL_RESULT_VHTSIG_BW               1
#define RSCMWWLM_VAL_RESULT_VHTSIG_CRC              2
#define RSCMWWLM_VAL_RESULT_VHTSIG_FECCODING        3
#define RSCMWWLM_VAL_RESULT_VHTSIG_GID              4
#define RSCMWWLM_VAL_RESULT_VHTSIG_LDPC             5
#define RSCMWWLM_VAL_RESULT_VHTSIG_PAID             6
#define RSCMWWLM_VAL_RESULT_VHTSIG_RESERVED1        7
#define RSCMWWLM_VAL_RESULT_VHTSIG_RESERVED2        8
#define RSCMWWLM_VAL_RESULT_VHTSIG_RESERVED3        9
#define RSCMWWLM_VAL_RESULT_VHTSIG_SDISAMBIG       10
#define RSCMWWLM_VAL_RESULT_VHTSIG_SGI               11
#define RSCMWWLM_VAL_RESULT_VHTSIG_SMCS               12
#define RSCMWWLM_VAL_RESULT_VHTSIG_STBC               13
#define RSCMWWLM_VAL_RESULT_VHTSIG_SUNSTS           14
#define RSCMWWLM_VAL_RESULT_VHTSIG_TAIL               15
#define RSCMWWLM_VAL_RESULT_VHTSIG_TXOP               16

#define RSCMWWLM_VAL_TYPE_RMS  0
#define RSCMWWLM_VAL_TYPE_PEAK 1

#define RSCMWWLM_VAL_LIMIT_OFF   0
#define RSCMWWLM_VAL_LIMIT_ON    1
#define RSCMWWLM_VAL_LIMIT_VALUE 2

#define RSCMWWLM_VAL_CODE_RATE_14   0
#define RSCMWWLM_VAL_CODE_RATE_38   1
#define RSCMWWLM_VAL_CODE_RATE_12   2
#define RSCMWWLM_VAL_CODE_RATE_23   3
#define RSCMWWLM_VAL_CODE_RATE_34   4
#define RSCMWWLM_VAL_CODE_RATE_56    5

#define RSCMWWLM_VAL_MODULATION_BPM6  0
#define RSCMWWLM_VAL_MODULATION_BPM9  1
#define RSCMWWLM_VAL_MODULATION_QM12  2
#define RSCMWWLM_VAL_MODULATION_QM18  3
#define RSCMWWLM_VAL_MODULATION_Q1M24 4
#define RSCMWWLM_VAL_MODULATION_Q1M36 5
#define RSCMWWLM_VAL_MODULATION_Q6M48 6
#define RSCMWWLM_VAL_MODULATION_Q6M54 7
#define RSCMWWLM_VAL_MODULATION_BR12  8
#define RSCMWWLM_VAL_MODULATION_QR12  9
#define RSCMWWLM_VAL_MODULATION_QR34  10
#define RSCMWWLM_VAL_MODULATION_Q1R12 11
#define RSCMWWLM_VAL_MODULATION_Q1R34 12
#define RSCMWWLM_VAL_MODULATION_Q6R23 13
#define RSCMWWLM_VAL_MODULATION_Q6R34 14
#define RSCMWWLM_VAL_MODULATION_Q6R56 15

#define RSCMWWLM_VAL_MODULATION_DSSS_DBPS1 0
#define RSCMWWLM_VAL_MODULATION_DSSS_DBPS2 1
#define RSCMWWLM_VAL_MODULATION_DSSS_CCK5  2
#define RSCMWWLM_VAL_MODULATION_DSSS_CCK11 3

#define RSCMWWLM_VAL_CONV_RX1   1

#define RSCMWWLM_VAL_RES_EVM  0
#define RSCMWWLM_VAL_RES_EVMS 1
#define RSCMWWLM_VAL_RES_EVMC 2
#define RSCMWWLM_VAL_RES_IQC  3
#define RSCMWWLM_VAL_RES_MSC  4
#define RSCMWWLM_VAL_RES_TSM  5
#define RSCMWWLM_VAL_RES_SFL  6
#define RSCMWWLM_VAL_RES_UTER 7

#define RSCMWWLM_VAL_MOD_TYPE_BPM6   0
#define RSCMWWLM_VAL_MOD_TYPE_BPM9   1
#define RSCMWWLM_VAL_MOD_TYPE_QM12   2
#define RSCMWWLM_VAL_MOD_TYPE_QM18   3
#define RSCMWWLM_VAL_MOD_TYPE_Q1M24  4
#define RSCMWWLM_VAL_MOD_TYPE_Q1M36  5
#define RSCMWWLM_VAL_MOD_TYPE_Q6M48  6
#define RSCMWWLM_VAL_MOD_TYPE_Q6M54  7
#define RSCMWWLM_VAL_MOD_TYPE_BR12   8
#define RSCMWWLM_VAL_MOD_TYPE_QR12   9
#define RSCMWWLM_VAL_MOD_TYPE_QR34   10
#define RSCMWWLM_VAL_MOD_TYPE_Q1R12  11
#define RSCMWWLM_VAL_MOD_TYPE_Q1R34  12
#define RSCMWWLM_VAL_MOD_TYPE_Q6R23  13
#define RSCMWWLM_VAL_MOD_TYPE_Q5R34  14
#define RSCMWWLM_VAL_MOD_TYPE_Q6R34  14
#define RSCMWWLM_VAL_MOD_TYPE_Q6R56  15
#define RSCMWWLM_VAL_MOD_TYPE_DBPSK1 16
#define RSCMWWLM_VAL_MOD_TYPE_DBPSK2 17
#define RSCMWWLM_VAL_MOD_TYPE_DQPSK2 17
#define RSCMWWLM_VAL_MOD_TYPE_CCK5   18
#define RSCMWWLM_VAL_MOD_TYPE_CCK11  19

#define RSCMWWLM_VAL_BURST_SHORT 2
#define RSCMWWLM_VAL_BURST_LONG  3

#define RSCMWWLM_VAL_GINT_SHORT 0
#define RSCMWWLM_VAL_GINT_LONG  1
#define RSCMWWLM_VAL_GINT_NCAP  2
#define RSCMWWLM_VAL_GINT_GI08  3
#define RSCMWWLM_VAL_GINT_GI16  4
#define RSCMWWLM_VAL_GINT_GI32  5

#define RSCMWWLM_VAL_OFDM_802_11_AG 0
#define RSCMWWLM_VAL_OFDM_802_11_N  1

#define RSCMWWLM_VAL_ANALYZER_CONN_RF1C 0
#define RSCMWWLM_VAL_ANALYZER_CONN_RF2C 1
#define RSCMWWLM_VAL_ANALYZER_CONN_RF3C 2
#define RSCMWWLM_VAL_ANALYZER_CONN_RF4C 3
#define RSCMWWLM_VAL_ANALYZER_CONN_RFAC 4
#define RSCMWWLM_VAL_ANALYZER_CONN_RFBC 5
#define RSCMWWLM_VAL_ANALYZER_CONN_RF1O 6
#define RSCMWWLM_VAL_ANALYZER_CONN_RF3O 7
#define RSCMWWLM_VAL_ANALYZER_CONN_RFAO 8

#define RSCMWWLM_VAL_ANALYZER_SAL_CONV_RX1 0
#define RSCMWWLM_VAL_ANALYZER_SAL_CONV_RX2 1
#define RSCMWWLM_VAL_ANALYZER_SAL_CONV_RX3 2
#define RSCMWWLM_VAL_ANALYZER_SAL_CONV_RX4 3

#define RSCMWWLM_VAL_ANALYZER_CONN_TX1 0
#define RSCMWWLM_VAL_ANALYZER_CONN_TX2 1
#define RSCMWWLM_VAL_ANALYZER_CONN_TX3 2
#define RSCMWWLM_VAL_ANALYZER_CONN_TX4 3

#define RSCMWWLM_VAL_REDG                  0
#define RSCMWWLM_VAL_FEDG                  1

#define RSCMWWLM_VAL_MEASUREMENT_OFF       0
#define RSCMWWLM_VAL_MEASUREMENT_ON        1
#define RSCMWWLM_VAL_MEASUREMENT_VALUE     2

/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
ViStatus _VI_FUNC rscmwwlm_init(ViRsrc     resourceName,
                                ViBoolean  IDQuery,
                                ViBoolean  resetDevice,
                                ViSession* instrSession);

ViStatus _VI_FUNC rscmwwlm_InitWithOptions(ViRsrc     resourceName,
                                           ViBoolean  IDQuery,
                                           ViBoolean  resetDevice,
                                           ViString   optionString,
                                           ViSession* instrSession);

ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerStandAloneScenario(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   RXConnector,
                            ViInt32   RFConverter);

ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerSwitchedMIMOScenario(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   MIMO,
                            ViInt32   connectorTuple);

ViStatus _VI_FUNC rscmwwlm_QuerySignalRoutingSettings(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32*  scenario,
                                                      ViChar    controller[],
                                                      ViInt32*  RXConnector,
                                                      ViInt32*  RXConverter);

ViStatus _VI_FUNC rscmwwlm_QuerySignalRoutingSwitchedMIMOSettings(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32*  scenario,
                            ViChar    controller[],
                            ViInt32*  RXConnector1,
                            ViInt32*  RXConverter1,
                            ViInt32*  RXConnector2,
                            ViInt32*  RXConverter2,
                            ViInt32*  RXConnector3,
                            ViInt32*  RXConverter3,
                            ViInt32*  RXConnector4,
                            ViInt32*  RXConverter4);

ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerCombinedSignalPathScenario(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViString  master);

ViStatus _VI_FUNC rscmwwlm_QuerySignalRoutingSwitchedMIMOScenario(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   connector,
                            ViInt32   RXConnector[],
                            ViInt32   RXConverter[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureNumberOfPathsTMIMOScenario(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   numberOfPaths);

ViStatus _VI_FUNC rscmwwlm_ConfigureNumberOfMIMOAntennas(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   numberOfAntennas);

ViStatus _VI_FUNC rscmwwlm_ConfigureUseSeparateAntennasFor80Plus80MHz(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean separateAntennas);

ViStatus _VI_FUNC rscmwwlm_ConfigureRFRoutingAntennaConnector(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antennaNumber,
                            ViInt32   connector);

ViStatus _VI_FUNC rscmwwlm_ConfigureRFRoutingAntenna(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32   antennaNumber,
                                                     ViReal64  externalAttenuation,
                                                     ViReal64  EPEP,
                                                     ViReal64  mixerLevelOffset);

ViStatus _VI_FUNC rscmwwlm_ConfigureRFRoutingExternalAttenuation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   connector,
                            ViReal64  externalAttenuation);

ViStatus _VI_FUNC rscmwwlm_ConfigureExternalAttenuation(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViReal64  externalAttenuation);

ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzer(ViSession instrSession,
                                             ViInt32   instance,
                                             ViReal64  expectedNominalPower,
                                             ViReal64  margin,
                                             ViReal64  centerFrequency);

ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerMixerLevelOffset(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViReal64  mixerLevelOffset);

ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerFrequencyOffset(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViReal64  frequencyOffset);

ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerSecondChannelPosition(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   secondaryChannel);

ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerDisplayMode(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   displayMode);

ViStatus _VI_FUNC rscmwwlm_ConfigureAnalyzerMaskDisplayMode(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   displayMode);

ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignal(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32   standard,
                                                ViInt32   burstType,
                                                ViInt32   evaluationLength);

ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalBandwidth(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   bandwidth);

ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalReceiveMode(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   receiveMode);

ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalChannelDistance(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  channelDistance);

ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalFrequencyBand(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   band);

ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalFrequencyChannel(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channel,
                            ViInt32   channelValue);

ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalTrainingDataSource(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViString  standard);

ViStatus _VI_FUNC rscmwwlm_GetLoadedTraningDataFileDate(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   bufferSize,
                                                        ViChar    fileDate[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalIQSwapState(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViBoolean IQSwap);

ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalModulationFilterBursts(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   modulationFilter);

ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalPowerClass(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   powerClass);

ViStatus _VI_FUNC rscmwwlm_ConfigureInputSignalEvaluationLength(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   measuredChips,
                            ViBoolean skipPreambleAndHeader,
                            ViInt32   measuredSymbols);

ViStatus _VI_FUNC rscmwwlm_QueryInputSignalPossibleScenarios(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   arraySize,
                                                             ViChar    possibleScenarios[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasStatistics(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   repetition,
                                                        ViInt32   stopCondition);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasStatisticsCount(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   statisticCount);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasParameters(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViBoolean measureOnException);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasModulationTracking(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean phase,
                            ViBoolean timing,
                            ViBoolean level);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasChannelEstimation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channelEstimation);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasFFTDemodulationOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   FFTDemodulationOffset);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasDSSSTxFilterEstimation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean state,
                            ViInt32   taps);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasDSSSEVMMethod(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   DSSSEVMMethod);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasSkipOFDMSymbols(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   head,
                                                             ViInt32   tail);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasTransmitSpectrumMask(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   statisticCount,
                            ViReal64  triggerOffsetTime,
                            ViInt32   averageFFTNumber);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasAssignViews(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   measurement,
                                                         ViBoolean state);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasAssignViewsAll(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViBoolean modulationScalar,
                                                            ViBoolean powerVsTime,
                                                            ViBoolean EVMvsChip,
                                                            ViBoolean EVMvsSymbol,
                                                            ViBoolean EVMvsCarrier,
                                                            ViBoolean iQConstellationDiagram,
                                                            ViBoolean spectrumFlatness,
                                                            ViBoolean transmitSpectrumMask,
                                                            ViBoolean unusedToneError);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementPVT(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   edge,
                                                        ViBoolean edgeEnable,
                                                        ViBoolean burst,
                                                        ViBoolean PVTEnable);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementDSSSAverageLength(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   averageLength);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementDSSSReferencePower(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   referencePower);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementTimeout(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   timeout);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementMaskSpectrumSelection(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   maskSelection);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementOccupiedBandwidth(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   measurementStatus,
                            ViReal64  occupiedBandwidth);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementOFDMTEPercentage(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   measurementStatus,
                            ViReal64  TE);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementSyncMode(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   mode);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementHETBPPDUBandwidth(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementHETBPPDUMCS(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   station,
                            ViInt32   MCS);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementSegmentStandard(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   standard);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementSegmentConnector(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   connector);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementSegmentBurstType(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   burstType);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalMeasurementSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   bandwidth,
                            ViReal64  ENP,
                            ViReal64  frequency,
                            ViReal64  measurementOffset,
                            ViReal64  measurementTime,
                            ViReal64  time);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasTrigger(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViString  source,
                                                     ViInt32   slope,
                                                     ViReal64  threshold,
                                                     ViReal64  timeout,
                                                     ViReal64  IFMinGAP);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasTriggerSourceCatalog(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViChar    catalog[]);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasTriggerSourceCatalogEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean fullList,
                            ViInt32   arraySize,
                            ViChar    catalog[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeState(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViBoolean listMode);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeConnector(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   connector);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeNumberOfSegments(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   numberOfSegments);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeCaptureTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  captureTime);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeChannelFilterEstimation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channelFilterEstimation);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeStatisticalLength(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   statistics,
                            ViBoolean EVMEnable);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeTransmitSpectrumMask(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   statistics,
                            ViBoolean transmitSpectrumMaskEnable);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasListModeBurst(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   segment,
                                                           ViInt32   burstsInSegment,
                                                           ViInt32   standard,
                                                           ViInt32   modulationType,
                                                           ViInt32   burstType);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasListModeBurst(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   segment,
                                                       ViInt32*  burstsInSegment,
                                                       ViInt32*  standard,
                                                       ViInt32*  modulationType,
                                                       ViInt32*  burstType);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeTSMask(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   statistics,
                            ViBoolean TSMEnable);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViReal64  segmentTime,
                            ViReal64  measTime,
                            ViReal64  measOffset,
                            ViReal64  level,
                            ViReal64  frequency,
                            ViInt32   standard,
                            ViInt32   bandwidth);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeBurstTypes(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   burstTypes[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeBandwidths(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   bandwidths[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeConnectors(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   connectors[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeENPs(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViReal64  ENPs[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeFrequencies(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViReal64  frequencies[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeOffsets(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViReal64  offsets[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeTimes(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViReal64  times[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeStandards(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   standards[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeSegmentTimes(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViReal64  times[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeSegmentEnabled(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViBoolean modulation,
                            ViBoolean SEM);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeSegmentRetriggers(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   arraySize,
                            ViBoolean retriggers[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeSegmentStatCount(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   modulation,
                            ViInt32   SEM);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViBoolean modulation[],
                            ViBoolean transmitSpectrumMask[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeRetriggers(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViBoolean retriggers[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalMeasurementListModeStatCountsSEM(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   statCounts[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalPVTDSSSLimits(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   edge,
                                                           ViBoolean enable,
                                                           ViReal64  limit);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalPVTTimingErrorUpperLimit(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   limitStatus,
                            ViReal64  limitValue);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDMEVM(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViReal64  limitValues[],
                                                       ViInt32   limitStatus[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDMEVMPilot(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViReal64  limitValue,
                                                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDMIQOffset(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViReal64  limitValue,
                                                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDMCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDMSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pErrorVectorMagnitude(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValues[],
                            ViInt32   limitStatus[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pEVMPilot(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pIQOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pSpectrumFlatness(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean enable,
                            ViReal64  center,
                            ViReal64  side,
                            ViReal64  upper);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsDSSSEVM(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   type,
                                                       ViInt32   limitStatus,
                                                       ViReal64  limitValue);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsDSSSIQOffset(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViReal64  limitValue,
                                                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsDSSSCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsDSSSSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NEVM(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViReal64  limitValues[],
                                                             ViInt32   limitStatus[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NEVMPilot(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NIQOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NMIMOEVM(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValues[],
                            ViInt32   limitStatus[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NMIMOEVMPilot(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NMIMOIQOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NMIMOCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211NMIMOSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211ACEVM(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValues[],
                            ViInt32   limitStatus[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211ACEVMPilot(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211ACIQOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViReal64  relativeLimitValue,
                            ViInt32   relativeLimitStatus,
                            ViReal64  absoluteLimitValue,
                            ViInt32   absoluteLimitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211ACCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211ACSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXEVM(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValues[],
                            ViInt32   limitStatus[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXEVMTBCodeRate(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   codingRates[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXEVMTBHigh(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValues[],
                            ViInt32   limitStatus[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXEVMTBLow(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValues[],
                            ViInt32   limitStatus[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXEVMPilot(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXEVMPilotTBHigh(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXEVMPilotTBLow(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXIQOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViReal64  relativeLimitValue,
                            ViInt32   relativeLimitStatus,
                            ViReal64  absoluteLimitValue,
                            ViInt32   absoluteLimitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  limitValue,
                            ViInt32   limitStatus);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXUTEPower(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   UTEPower);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsOFDM80211AXIQOffsetUTELimit(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean UTELimit);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskDSSS(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean DSSSEnable,
                            ViReal64  ABLevel,
                            ViReal64  CDLevel);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskOFDM(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean OFDMEnable,
                            ViReal64  aLevel,
                            ViReal64  bLevel,
                            ViReal64  cLevel,
                            ViReal64  dLevel);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumFlatnessOFDM(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean enable,
                            ViReal64  center,
                            ViReal64  side,
                            ViReal64  upper);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskOFDM80211N(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean OFDMEnable,
                            ViReal64  aLevel,
                            ViReal64  bLevel,
                            ViReal64  cLevel,
                            ViReal64  dLevel,
                            ViReal64  absolute11nLimit);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskOFDM80211NEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean OFDMEnable,
                            ViReal64  aLevel[],
                            ViReal64  bLevel[],
                            ViReal64  cLevel[],
                            ViReal64  dLevel[],
                            ViReal64  absolute11nLimit);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumFlatnessEnableOFDM80211N(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean enable);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLowerLimitsTransmitSpectrumFlatnessOFDM80211N(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViReal64  center,
                            ViReal64  side);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalUpperLimitsTransmitSpectrumFlatnessOFDM80211N(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViReal64  upper);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMask40MHz(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean enable,
                            ViReal64  aLevel,
                            ViReal64  bLevel,
                            ViReal64  cLevel,
                            ViReal64  dLevel,
                            ViReal64  absolute11nLimit);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMask40MHzEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean enable,
                            ViReal64  aLevel[],
                            ViReal64  bLevel[],
                            ViReal64  cLevel[],
                            ViReal64  dLevel[],
                            ViReal64  absolute11nLimit);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumFlatnessOFDM80211N(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean enable,
                            ViReal64  center,
                            ViReal64  side,
                            ViReal64  upper);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskBandOFDM80211N(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViInt32   frequencyBand,
                            ViBoolean OFDMEnable,
                            ViReal64  aLevel,
                            ViReal64  bLevel,
                            ViReal64  cLevel,
                            ViReal64  dLevel,
                            ViReal64  absolute11nLimit);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskOFDM80211AC(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean OFDMEnable,
                            ViReal64  aLevel,
                            ViReal64  bLevel,
                            ViReal64  cLevel,
                            ViReal64  dLevel,
                            ViReal64  absolute11ac);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskOFDM80211ACEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean OFDMEnable,
                            ViReal64  aLevel,
                            ViReal64  bLevel,
                            ViReal64  cLevel,
                            ViReal64  dLevel,
                            ViReal64  absolute11ac);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumFlatnessOFDM80211AC(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean enable,
                            ViReal64  center,
                            ViReal64  side,
                            ViReal64  upper);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumFlatnessOFDM80211ACEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean enable,
                            ViReal64  center,
                            ViReal64  side,
                            ViReal64  upper);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pTransmitSpectrumMaskState(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean enable);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pAbsoluteEmissionLimits(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViReal64  absoluteLevelA,
                            ViReal64  absoluteLevelB,
                            ViReal64  absoluteLevelC,
                            ViReal64  absoluteLevelD,
                            ViReal64  absoluteLevelE,
                            ViReal64  absoluteLevelF);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiEvalLimitsOFDM80211pSpectralDensityLimits(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViInt32   powerClass,
                            ViReal64  relativeLevelA,
                            ViReal64  relativeLevelB,
                            ViReal64  relativeLevelC,
                            ViReal64  relativeLevelD,
                            ViReal64  relativeLevelE);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumMaskOFDM80211AX(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean OFDMEnable,
                            ViReal64  aLevel,
                            ViReal64  bLevel,
                            ViReal64  cLevel,
                            ViReal64  dLevel,
                            ViReal64  absolute11ax);

ViStatus _VI_FUNC rscmwwlm_ConfigureMEvalLimitsTransmitSpectrumFlatnessOFDM80211AX(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   bandwidth,
                            ViBoolean enable,
                            ViReal64  center,
                            ViReal64  side,
                            ViReal64  upper);

ViStatus _VI_FUNC rscmwwlm_MEvalMeasInit(ViSession instrSession,
                                         ViInt32   instance);

ViStatus _VI_FUNC rscmwwlm_MEvalMeasAbort(ViSession instrSession,
                                          ViInt32   instance);

ViStatus _VI_FUNC rscmwwlm_MEvalMeasStop(ViSession instrSession,
                                         ViInt32   instance);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasurementStatus(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32*  mainState,
                                                       ViInt32*  syncState,
                                                       ViInt32*  resourcesState);

ViStatus _VI_FUNC rscmwwlm_QueryOFDMAInformation(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32*  reliability,
                                                 ViInt32*  numberOfUsers,
                                                 ViInt32*  numberOfResourceUnits);

ViStatus _VI_FUNC rscmwwlm_FetchOFDMAUserInformation(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32   user,
                                                     ViInt32   arraySize,
                                                     ViInt32*  reliability,
                                                     ViInt32   results[],
                                                     ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMValues(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   resultType,
                                                   ViInt32   arraySize,
                                                   ViInt32*  reliability,
                                                   ViInt32*  modulationType,
                                                   ViReal64  results[],
                                                   ViInt32*  guardInterval,
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMValues(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   resultType,
                                                    ViInt32   arraySize,
                                                    ViInt32*  reliability,
                                                    ViInt32*  modulationType,
                                                    ViReal64  results[],
                                                    ViInt32*  guardInterval,
                                                    ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViInt32   results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMStandardDeviationLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViInt32   results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMTransmitSpectrumMaskLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMEVMCarrierTrace(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   resultType,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  results[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMEVMCarrierTrace(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMEVMCarrierTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMEVMCarrierTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMSpectrumFlatnessTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSpectrumFlatnessTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMSpectrumFlatnessTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSpectrumFlatnessTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMTraceCFOErrors(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   start,
                                                           ViInt32   count,
                                                           ViInt32   decimation,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  results[],
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMTraceCFOErrors(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   start,
                                                            ViInt32   count,
                                                            ViInt32   decimation,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  results[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMCFO(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32   arraySize,
                                                ViInt32*  reliability,
                                                ViReal64  results[],
                                                ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMCFO(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32   arraySize,
                                                 ViInt32*  reliability,
                                                 ViReal64  results[],
                                                 ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMultiEvalOFDMCFOLimitCheckResult(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMTE(ViSession instrSession,
                                               ViInt32   instance,
                                               ViInt32   arraySize,
                                               ViInt32*  reliability,
                                               ViReal64  results[],
                                               ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMTE(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32   arraySize,
                                                ViInt32*  reliability,
                                                ViReal64  results[],
                                                ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMultiEvalOFDMTELimitCheckResult(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMCommonInformation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDM80211NEVMCarrierTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDM80211NEVMCarrierTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDM80211NEVMCarrierTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDM80211NEVMCarrierTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDM80211NTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDM80211NTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDM80211NTransmitSpectrumMaskLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDM80211ACValues(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   resultType,
                                                          ViInt32   arraySize,
                                                          ViInt32*  reliability,
                                                          ViReal64  results[],
                                                          ViInt32*  guardInterval,
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDM80211ACValues(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   resultType,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  results[],
                                                           ViInt32*  guardInterval,
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDM80211ACLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDM80211ACStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues,
                            ViInt32*  guardInterval);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDM80211ACStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues,
                            ViInt32*  guardInterval);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDM80211ACStandardDeviationLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDM80211ACTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDM80211ACTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDM80211ACTransmitSpectrumMaskLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasDSSSValues(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   resultType,
                                                   ViInt32   arraySize,
                                                   ViInt32*  reliability,
                                                   ViInt32*  modulationType,
                                                   ViInt32*  PLCPType,
                                                   ViReal64  results[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasDSSSValues(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   resultType,
                                                    ViInt32   arraySize,
                                                    ViInt32*  reliability,
                                                    ViInt32*  modulationType,
                                                    ViInt32*  PLCPType,
                                                    ViReal64  results[],
                                                    ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasDSSSLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViInt32*  PLCPType,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasDSSSStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViInt32*  PLCPType,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasDSSSStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViInt32*  PLCPType,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasDSSSStandardDeviationLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViInt32*  PLCPType,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasDSSSTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasDSSSTransmitSpectrumMaskValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasDSSSTransmitSpectrumMaskLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasDSSSEVMTrace(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32   resultType,
                                                     ViInt32   arraySize,
                                                     ViInt32*  reliability,
                                                     ViReal64  results[],
                                                     ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasDSSSEVMTrace(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32   resultType,
                                                      ViInt32   arraySize,
                                                      ViInt32*  reliability,
                                                      ViReal64  results[],
                                                      ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasDSSSEVMTraceEnhanced(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   start,
                                                             ViInt32   count,
                                                             ViInt32   decimation,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasDSSSEVMTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMMIMOValues(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   resultType,
                                                   ViInt32   arraySize,
                                                   ViInt32   stream,
                                                   ViInt32*  reliability,
                                                   ViInt32*  modulationScheme,
                                                   ViReal64  results[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMMIMOValues(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   resultType,
                                                    ViInt32   arraySize,
                                                    ViInt32   stream,
                                                    ViInt32*  reliability,
                                                    ViInt32*  modulationScheme,
                                                    ViReal64  results[],
                                                    ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMMIMOLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMMIMOStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMMIMOStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMMIMOStandardDeviationLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMMIMOSegments80Plus80Values(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMMIMOSegments80Plus80Values(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMMIMOSegments80Plus80LimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMMIMOSegments80Plus80StandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMMIMOSegments80Plus80StandardDeviationLimitCheckResult(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMMIMOSegments80Plus80StandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMMIMOSpectrumFlatnessValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMMIMOSpectrumFlatnessValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMMIMOSpectrumFlatnessMarginPositionsValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMMIMOSpectrumFlatnessMarginPositionsValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMMIMOSpectrumFlatnessLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   stream,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMSpectrumFlatnessRxAntennaTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   stream,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSpectrumFlatnessRxAntennaTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   stream,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMSpectrumFlatnessRxAntennaLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   stream,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMSpectrumFlatnessRxAntennaSegmentTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   stream,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSpectrumFlatnessRxAntennaSegmentTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   stream,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMSFLRxAntennaSegmentLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   stream,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMCMIMOPowerSTS(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32   resultType,
                                                      ViInt32   arraySize,
                                                      ViInt32*  reliability,
                                                      ViReal64  results[],
                                                      ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMCMIMOPowerSTS(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   resultType,
                                                       ViInt32   arraySize,
                                                       ViInt32*  reliability,
                                                       ViReal64  results[],
                                                       ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMSMIMOValues(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   resultType,
                                                    ViInt32   arraySize,
                                                    ViInt32*  reliability,
                                                    ViReal64  results[],
                                                    ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMSMIMOValues(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32   resultType,
                                                     ViInt32   arraySize,
                                                     ViInt32*  reliability,
                                                     ViReal64  results[],
                                                     ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMSMIMOLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMSMIMOStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMSMIMOStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMSMIMOStandardDeviationLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalSpectrumFlatnessOFDMSISO(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalSpectrumFlatnessOFDMSISO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalSpectrumFlatnessOFDMSISOLimitCheck(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalSpectrumFlatnessSubcarrierIndices(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalSpectrumFlatnessSubcarrierIndices(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMSISOValues(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   resultType,
                                                       ViInt32   arraySize,
                                                       ViInt32*  reliability,
                                                       ViInt32*  modulationScheme,
                                                       ViReal64  results[],
                                                       ViInt32*  guardInterval,
                                                       ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSISOValues(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   resultType,
                                                        ViInt32   arraySize,
                                                        ViInt32*  reliability,
                                                        ViInt32*  modulationScheme,
                                                        ViReal64  results[],
                                                        ViInt32*  guardInterval,
                                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMSISOLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViInt32   results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMSISOStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSISOStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMSISOStandardDeviationLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationScheme,
                            ViInt32   results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMSegments80Plus80Values(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMSegments80Plus80Values(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMSegments80Plus80LimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalOFDMSegments80Plus80StandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalOFDMSegments80Plus80StandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalOFDMSegments80Plus80StandardDeviationLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSISOEVMValues(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   resultType,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  results[],
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSISOEVMUserValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   user,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSISOEVMUserStreamValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   user,
                            ViInt32   stream,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasOFDMSISOSpectrumFlatnessSegmentTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasOFDMSISOSpectrumFlatnessSegmentTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasOFDMSISOSpectrumFlatnessSegmentLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTBurstTraceResults(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   start,
                                                             ViInt32   count,
                                                             ViInt32   decimation,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTBurstTraceResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalPVTDSSSStatisticalEdge(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   edge,
                                                           ViInt32   resultType,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  results[],
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalPVTDSSSStatisticalEdge(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   edge,
                                                            ViInt32   resultType,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  results[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMultiEvalPVTDSSSLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceResults(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   edge,
                                                            ViInt32   resultType,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  results[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceResults(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   edge,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceTime(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   arraySize,
                                                         ViInt32*  reliability,
                                                         ViReal64  results[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceTime(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   arraySize,
                                                          ViInt32*  reliability,
                                                          ViReal64  results[],
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceMIMOResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceMIMOResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceMIMOEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceMIMOEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceMIMOTime(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   antenna,
                                                             ViInt32   start,
                                                             ViInt32   count,
                                                             ViInt32   decimation,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceMIMOTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antenna,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceMIMOSegmentEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceMIMOSegmentEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceSegmentResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceSegmentResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceSegmentEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceSegmentEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceSegmentMIMOResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceSegmentMIMOResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalPVTRampTraceResultsEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalPVTRampTraceResultsEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasPVTRampTraceMIMOSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasPVTRampTraceMIMOSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasPVTRampTraceMIMOTime(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   edge,
                                                             ViInt32   antenna,
                                                             ViInt32   start,
                                                             ViInt32   count,
                                                             ViInt32   decimation,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasPVTRampTraceMIMOTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   antenna,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasPVTRampTraceSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasPVTRampTraceSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   edge,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasPVTRampTraceTime(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   edge,
                                                         ViInt32   start,
                                                         ViInt32   count,
                                                         ViInt32   decimation,
                                                         ViInt32   arraySize,
                                                         ViInt32*  reliability,
                                                         ViReal64  results[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasPVTRampTraceTime(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   edge,
                                                          ViInt32   start,
                                                          ViInt32   count,
                                                          ViInt32   decimation,
                                                          ViInt32   arraySize,
                                                          ViInt32*  reliability,
                                                          ViReal64  results[],
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasPVTRampMIMOSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasPVTRampMIMOSegmentTime(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTraceTimingError(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   start,
                                                         ViInt32   count,
                                                         ViInt32   decimation,
                                                         ViInt32   arraySize,
                                                         ViInt32*  reliability,
                                                         ViReal64  results[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTraceTimingError(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   start,
                                                          ViInt32   count,
                                                          ViInt32   decimation,
                                                          ViInt32   arraySize,
                                                          ViInt32*  reliability,
                                                          ViReal64  results[],
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalPVTTimingErrorResults(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   resultType,
                                                          ViInt32*  reliability,
                                                          ViReal64* timingError);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalPVTTimingErrorResults(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   resultType,
                                                           ViInt32*  reliability,
                                                           ViReal64* timingError);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalPVTTimingErrorLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32*  reliability,
                            ViInt32*  timingError);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalPVRUResults(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32   resultType,
                                                 ViInt32   resourceUnit,
                                                 ViInt32*  reliability,
                                                 ViReal64* powerVsRU);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalPVRURXAntennaResults(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   resultType,
                                                          ViInt32   resourceUnit,
                                                          ViInt32   antenna,
                                                          ViInt32*  reliability,
                                                          ViReal64* powerVsAntennaVsRU);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalPowerRXAntennaResults(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   resultType,
                                                           ViInt32   antenna,
                                                           ViInt32*  reliability,
                                                           ViReal64* powerVsAntenna);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasConstellationDiagramITrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasConstellationDiagramITrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasConstellationDiagramQTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasConstellationDiagramQTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasUTERTrace(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViInt32   resultType,
                                                  ViInt32   antenna,
                                                  ViInt32   arraySize,
                                                  ViInt32*  reliability,
                                                  ViReal64  results[],
                                                  ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasUTERTrace(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   resultType,
                                                   ViInt32   antenna,
                                                   ViInt32   arraySize,
                                                   ViInt32*  reliability,
                                                   ViReal64  results[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasUTERTraceLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasUTERLimits(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   antenna,
                                                   ViInt32   arraySize,
                                                   ViInt32*  reliability,
                                                   ViReal64  results[],
                                                   ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasUTERLimits(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   antenna,
                                                    ViInt32   arraySize,
                                                    ViInt32*  reliability,
                                                    ViReal64  results[],
                                                    ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasUTERLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antenna,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasUTERMarginValues(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   resultType,
                                                         ViInt32   antenna,
                                                         ViInt32   arraySize,
                                                         ViInt32*  reliability,
                                                         ViReal64  results[],
                                                         ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasUTERMarginValues(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   resultType,
                                                          ViInt32   antenna,
                                                          ViInt32   arraySize,
                                                          ViInt32*  reliability,
                                                          ViReal64  results[],
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasUTERMarginLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTrace(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceEnhanced(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   stream,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   stream,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceMIMOSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   stream,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceMIMOSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   stream,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceFrequency(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceFrequency(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceMask(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceMask(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceMaskSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceMaskSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceMaskMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceMaskMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskTraceMaskMIMOSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskTraceMaskMIMOSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalTransmitSpectrumMaskOccupiedBandwidthResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalTransmitSpectrumMaskOccupiedBandwidthResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalTransmitSpectrumMaskOccupiedBandwidthSegmentResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalTransmitSpectrumMaskOccupiedBandwidthSegmentResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalTransmitSpectrumMaskOccupiedBandwidthMIMOResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalTransmitSpectrumMaskOccupiedBandwidthMIMOResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMultiEvalTransmitSpectrumMaskOccupiedBandwidthMIMOSegmentResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalTransmitSpectrumMaskOccupiedBandwidthMIMOSegmentResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stream,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskSISOXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskSISOXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasTransmitSpectrumMaskSISOXLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskSISOSegmentsXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskSISOSegmentsXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskSISOSegmentsXLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskMIMOXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskMIMOXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMultiEvalTransmitSpectrumMaskMIMOXLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskMIMOSegmentsXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskMIMOSegmentsXValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMultiEvalTransmitSpectrumMaskMIMOSegmentsXLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskSISOYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskSISOYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasTransmitSpectrumMaskSISOYLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskSISOSegmentsYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskSISOSegmentsYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasTransmitSpectrumMaskSISOSegmentsYLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskMIMOYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskMIMOYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMEvalMeasTransmitSpectrumMaskMIMOYLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasTransmitSpectrumMaskMIMOSegmentsYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasTransmitSpectrumMaskMIMOSegmentsYValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_QueryMultiEvalTransmitSpectrumMaskMIMOSegmentsYLimitCheckResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32   stream,
                            ViInt32*  reliability,
                            ViInt32   results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoChannelFieldMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   channel,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViReal64* decimalValue);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoUserFieldMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   channel,
                            ViInt32   user,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViInt32*  decimalValue);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoHEMUMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViInt32*  decimalValue);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoHESUMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViInt32*  decimalValue);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoHETBMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViInt32*  decimalValue);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoHTSIGMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViInt32*  decimalValue);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoLegacySignalMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViInt32*  decimalValue);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasSignalFieldsInfoVeryHighThroughputSignal(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViChar    binaryValue[],
                            ViInt32*  decimalValue);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasEVMSymbolTrace(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   resultType,
                                                       ViInt32   arraySize,
                                                       ViInt32*  reliability,
                                                       ViReal64  results[],
                                                       ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasEVMSymbolTrace(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   resultType,
                                                        ViInt32   arraySize,
                                                        ViInt32*  reliability,
                                                        ViReal64  results[],
                                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMAllSegmentsValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   segmentReliability[],
                            ViInt32   numberOfBursts[],
                            ViInt32   modulationType[],
                            ViReal64  results[],
                            ViInt32   guardInterval[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMAllSegmentsStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   segmentReliability[],
                            ViInt32   numberOfBursts[],
                            ViInt32   modulationType[],
                            ViReal64  results[],
                            ViInt32   guardInterval[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMOneSegmentValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViInt32*  numberOfBursts,
                            ViInt32*  modulationType,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMOneSegmentStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViInt32*  numberOfBursts,
                            ViInt32*  modulationType,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMBurstPower(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMCrestFactor(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMDCPower(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMDataPortionPower(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMEVMData(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMEVMPilot(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMEVMAll(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   resultType,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  results[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMGainImbalance(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMIQOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMLTFPower(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMQuadratureError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeOFDMSymbolClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSAllSegmentsValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   segmentReliability[],
                            ViInt32   numberOfBursts[],
                            ViInt32   modulationType[],
                            ViInt32   PLCPType[],
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSAllSegmentsStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   segmentReliability[],
                            ViInt32   numberOfBursts[],
                            ViInt32   modulationType[],
                            ViInt32   PLCPType[],
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSOneSegmentValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViInt32*  numberOfBursts,
                            ViInt32*  modulationType,
                            ViInt32*  PLCPType,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSOneSegmentStandardDeviation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViInt32*  numberOfBursts,
                            ViInt32*  modulationType,
                            ViInt32*  PLCPType,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSBurstPower(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSChipClockError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSCenterFrequencyError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSEVMPeak(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSEVMRMS(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   resultType,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  results[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSGainImbalance(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSIQOffset(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeDSSSQuadratureError(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModePowerBackoff(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModePeakPower(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   resultType,
                                                           ViInt32   arraySize,
                                                           ViInt32*  reliability,
                                                           ViReal64  results[],
                                                           ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeExpiredStatisticCounts(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeSegmentsReliability(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeTSMaskExpiredStatisticCounts(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeTransmitSpectrumMaskOFDMAllSegmentsValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   OFDMSignal,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   segmentReliability[],
                            ViInt32   numberOfBursts[],
                            ViReal64  results[],
                            ViReal64  outOfTolerance[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeTransmitSpectrumMaskOFDMOneSegmentValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   OFDMSignal,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViInt32*  numberOfBursts,
                            ViReal64  results[],
                            ViReal64* outOfTolerance,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeTransmitSpectrumMaskDSSSAllSegmentsValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32   segmentReliability[],
                            ViInt32   numberOfBursts[],
                            ViReal64  results[],
                            ViReal64  outOfTolerance[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasListModeTransmitSpectrumMaskDSSSOneSegmentValues(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  segmentReliability,
                            ViInt32*  numberOfBursts,
                            ViReal64  results[],
                            ViReal64* outOfTolerance,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalListModeOFDMSegment(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   segment,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViInt32*  modulationType,
                                                             ViReal64  results[],
                                                             ViInt32*  guardInterval,
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalListModeOFDMSegmentMask(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalListModeOFDMSegmentMaskFrequency(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   segment,
                            ViInt32   resultType,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViInt32*  modulationType,
                            ViReal64  results[],
                            ViInt32*  guardInterval,
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMultiEvalListModeDSSSSegment(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   segment,
                                                             ViInt32   resultType,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViInt32*  modulationType,
                                                             ViReal64  results[],
                                                             ViInt32*  guardInterval,
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasEVMvsSubcarrierMIMO(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   resultType,
                                                            ViInt32   antenna,
                                                            ViInt32   start,
                                                            ViInt32   count,
                                                            ViInt32   decimation,
                                                            ViInt32   arraySize,
                                                            ViInt32*  reliability,
                                                            ViReal64  results[],
                                                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasEVMvsSubcarrierMIMO(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   resultType,
                                                             ViInt32   antenna,
                                                             ViInt32   start,
                                                             ViInt32   count,
                                                             ViInt32   decimation,
                                                             ViInt32   arraySize,
                                                             ViInt32*  reliability,
                                                             ViReal64  results[],
                                                             ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasEVMvsSubcarrierSegmentMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasEVMvsSubcarrierSegmentMIMO(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   antenna,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ReadMEvalMeasEVMvsSubcarrierSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_FetchMEvalMeasEVMvsSubcarrierSegment(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   resultType,
                            ViInt32   segment,
                            ViInt32   start,
                            ViInt32   count,
                            ViInt32   decimation,
                            ViInt32   arraySize,
                            ViInt32*  reliability,
                            ViReal64  results[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rscmwwlm_ConfigureCMIMOTrainingModeEnable(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   mode);

ViStatus _VI_FUNC rscmwwlm_ConfigureTrainingDataTXAntennaNumber(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   numberOfAntennas);

ViStatus _VI_FUNC rscmwwlm_TrainingDataAcquisitionInit(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   antennas);

ViStatus _VI_FUNC rscmwwlm_TrainingDataAcquisitionAbort(ViSession instrSession,
                                                        ViInt32   instance);

ViStatus _VI_FUNC rscmwwlm_TrainingDataAcquisitionSave(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViString  fileName);

ViStatus _VI_FUNC rscmwwlm_TrainingDataAcquisitionDate(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   bufferSize,
                                                       ViChar    fileDate[]);

ViStatus _VI_FUNC rscmwwlm_TrainingDataAcquisitionClear(ViSession instrSession,
                                                        ViInt32   instance);

ViStatus _VI_FUNC rscmwwlm_ReadTrainingDataAcquisitionResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antennas,
                            ViInt32*  reliability,
                            ViInt32*  decodeStatus,
                            ViReal64* MCS,
                            ViReal64* power,
                            ViReal64* pilotEVM);

ViStatus _VI_FUNC rscmwwlm_FetchTrainingDataAcquisitionResults(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antennas,
                            ViInt32*  reliability,
                            ViInt32*  decodeStatus,
                            ViReal64* MCS,
                            ViReal64* power,
                            ViReal64* pilotEVM);

ViStatus _VI_FUNC rscmwwlm_SetAttributeViInt32(ViSession instrSession,
                                               ViString  repeatedCapabilityName,
                                               ViAttr    attributeId,
                                               ViInt32   attributeValue);

ViStatus _VI_FUNC rscmwwlm_SetAttributeViReal64(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViReal64  attributeValue);

ViStatus _VI_FUNC rscmwwlm_SetAttributeViString(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViString  attributeValue);

ViStatus _VI_FUNC rscmwwlm_SetAttributeViBoolean(ViSession instrSession,
                                                 ViString  repeatedCapabilityName,
                                                 ViAttr    attributeId,
                                                 ViBoolean attributeValue);

ViStatus _VI_FUNC rscmwwlm_GetAttributeRepCapName(ViSession instrSession,
                                                  ViAttr    attributeId,
                                                  ViString  repCapNameID,
                                                  ViInt32   index,
                                                  ViInt32   bufferSize,
                                                  ViChar    repCapName[]);

ViStatus _VI_FUNC rscmwwlm_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                             ViAttr    attributeId,
                                                             ViInt32   bufferSize,
                                                             ViChar    repeatedCapabilityIds[]);

ViStatus _VI_FUNC rscmwwlm_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViAttr    attributeID,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdNames[]);

ViStatus _VI_FUNC rscmwwlm_GetAttributeViInt32(ViSession instrSession,
                                               ViString  repeatedCapabilityName,
                                               ViAttr    attributeId,
                                               ViInt32*  attributeValue);

ViStatus _VI_FUNC rscmwwlm_GetAttributeViReal64(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViReal64* attributeValue);

ViStatus _VI_FUNC rscmwwlm_GetAttributeViString(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViInt32   bufferSize,
                                                ViChar    attributeValue[]);

ViStatus _VI_FUNC rscmwwlm_GetAttributeViBoolean(ViSession  instrSession,
                                                 ViString   repeatedCapabilityName,
                                                 ViAttr     attributeId,
                                                 ViBoolean* attributeValue);

ViStatus _VI_FUNC rscmwwlm_reset(ViSession instrSession);

ViStatus _VI_FUNC rscmwwlm_self_test(ViSession instrSession,
                                     ViInt16*  selfTestResult,
                                     ViChar    selfTestMessage[]);

ViStatus _VI_FUNC rscmwwlm_SelfTestResults(ViSession instrSession,
                                           ViInt32   bufferSize,
                                           ViChar    results[]);

ViStatus _VI_FUNC rscmwwlm_revision_query(ViSession instrSession,
                                          ViChar    instrumentDriverRevision[],
                                          ViChar    firmwareRevision[]);

ViStatus _VI_FUNC rscmwwlm_SystemVersion(ViSession instrSession,
                                         ViInt32   length,
                                         ViChar    systemVersion[]);

ViStatus _VI_FUNC rscmwwlm_error_query(ViSession instrSession,
                                       ViInt32*  errorCode,
                                       ViChar    errorMessage[]);

ViStatus _VI_FUNC rscmwwlm_ErrorList(ViSession instrSession,
                                     ViInt32   bufferSize,
                                     ViChar    errors[]);

ViStatus _VI_FUNC rscmwwlm_error_message(ViSession instrSession,
                                         ViStatus  errorCode,
                                         ViChar    errorMessage[]);

ViStatus _VI_FUNC rscmwwlm_ConfigureErrorChecking(ViSession instrSession,
                                                  ViBoolean enabled);

ViStatus _VI_FUNC rscmwwlm_ConfigureRangeChecking(ViSession instrSession,
                                                  ViBoolean enabled);

ViStatus _VI_FUNC rscmwwlm_ReliabilityIndicator(ViSession instrSession,
                                                ViInt32   reliabilityCode,
                                                ViChar    reliabilityMessage[]);

ViStatus _VI_FUNC rscmwwlm_Preset(ViSession instrSession);

ViStatus _VI_FUNC rscmwwlm_ClearStatus(ViSession instrSession);

ViStatus _VI_FUNC rscmwwlm_IDQueryResponse(ViSession instrSession,
                                           ViChar    IDQueryResponse[]);

ViStatus _VI_FUNC rscmwwlm_ProcessAllPreviousCommands(ViSession instrSession);

ViStatus _VI_FUNC rscmwwlm_QueryOPC(ViSession instrSession,
                                    ViInt32*  OPC);

ViStatus _VI_FUNC rscmwwlm_SetOPCTimeout(ViSession instrSession,
                                         ViUInt32  OPCTimeout);

ViStatus _VI_FUNC rscmwwlm_GetOPCTimeout(ViSession instrSession,
                                         ViUInt32* OPCTimeout);

ViStatus _VI_FUNC rscmwwlm_SetVISATimeout(ViSession instrSession,
                                          ViUInt32  VISATimeout);

ViStatus _VI_FUNC rscmwwlm_GetVISATimeout(ViSession instrSession,
                                          ViUInt32* VISATimeout);

ViStatus _VI_FUNC rscmwwlm_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                       ViBoolean autoSystErrQuery);

ViStatus _VI_FUNC rscmwwlm_ConfigureMultiThreadLocking(ViSession instrSession,
                                                       ViBoolean multiThreadLocking);

ViStatus _VI_FUNC rscmwwlm_GetError(ViSession instrSession,
                                    ViStatus* code,
                                    ViInt32   bufferSize,
                                    ViChar    description[]);

ViStatus _VI_FUNC rscmwwlm_ClearError(ViSession instrSession);

ViStatus _VI_FUNC rscmwwlm_ReadToFileFromInstrument(ViSession instrSession,
                                                    ViString  source,
                                                    ViString  destination);

ViStatus _VI_FUNC rscmwwlm_WriteFromFileToInstrument(ViSession instrSession,
                                                     ViString  source,
                                                     ViString  destination);

ViStatus _VI_FUNC rscmwwlm_WriteInstrData(ViSession instrSession,
                                          ViString  writeBuffer);

ViStatus _VI_FUNC rscmwwlm_ReadInstrData(ViSession instrSession,
                                         ViInt32   numberOfBytesToRead,
                                         ViChar    readBuffer[],
                                         ViUInt32* numBytesRead);

ViStatus _VI_FUNC rscmwwlm_QueryViBoolean(ViSession  instrSession,
                                          ViString   command,
                                          ViBoolean* value);

ViStatus _VI_FUNC rscmwwlm_QueryViInt32(ViSession instrSession,
                                        ViString  command,
                                        ViInt32*  value);

ViStatus _VI_FUNC rscmwwlm_QueryViReal64(ViSession instrSession,
                                         ViString  command,
                                         ViReal64* value);

ViStatus _VI_FUNC rscmwwlm_QueryViString(ViSession instrSession,
                                         ViString  command,
                                         ViInt32   bufferSize,
                                         ViChar    value[]);

ViStatus _VI_FUNC rscmwwlm_close(ViSession instrSession);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSCMWWLM_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSCMWWLM_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSCMWWLM_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSCMWWLM_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSCMWWLM_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)
#define RSCMWWLM_ERROR_RELIABILITY_INDICATOR  (RS_SPECIFIC_ERROR_BASE + 0x0004L)

#define RSCMWWLM_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSCMWWLM_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSCMWWLM_ERRMSG_INCORRECT_STATE     "Instrument in incorrect state"
#define RSCMWWLM_ERRMSG_INCORRECT_RESPONSE      "Response incorrect; report problem to R&S support!"
#define RSCMWWLM_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"
#define RSCMWWLM_ERRMSG_RELIABILITY_INDICATOR "Reliability Indicator error"

#define RSCMWWLM_ERROR_CODES_AND_MSGS \
    {RSCMWWLM_WARN_MEASURE_UNCALIBRATED,  RSCMWWLM_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSCMWWLM_WARN_OVER_RANGE,            RSCMWWLM_WARNMSG_OVER_RANGE},\
    {RSCMWWLM_ERROR_INCORRECT_STATE ,   RSCMWWLM_ERRMSG_INCORRECT_STATE },\
    {RSCMWWLM_ERROR_INCORRECT_RESPONSE,     RSCMWWLM_ERRMSG_INCORRECT_RESPONSE},\
    {RSCMWWLM_ERROR_MAX_TIME_EXCEEDED,    RSCMWWLM_ERRMSG_MAX_TIME_EXCEEDED},\
    {RSCMWWLM_ERROR_RELIABILITY_INDICATOR, RSCMWWLM_ERRMSG_RELIABILITY_INDICATOR}

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSCMWWLM_HEADER */
