/*****************************************************************************
 *  Rohde&Schwarz CMW500 Wideband Radio Communication Tester instrument driver
 *  WLAN Signaling
 *  Original Release: March 2012
 *  By: Jiri Kominek
 *
 *  Should you have any technical questions please contact the hotline of
 *  Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
 *
 *  e-mail: CustomerSupport@rohde-schwarz.com
 *
 *  Modification History:
 *     see ChangeLog
 *
 *****************************************************************************/
#include "rscmwwls.h"
#include "rscmwwls_internal.h"

//#include "time.h"
#if (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__))
#define ANSI
#endif
#ifndef ANSI                /* UNIX compatible */
    #include <sys/timeb.h>
    #include <sys/types.h>
    #include <unistd.h>
    #define Sleep sleep
#else                       /* ANSI compatible */
#include <windows.h>
#endif

#if defined (_CVI_)
    #include <utility.h>
#endif

/*****************************************************************************
 *- Value Definition and Range Tables ---------------------------------------*
 *****************************************************************************/
//static ViString switchArr[] = {"OFF","ON", NULL};
static ViString rfInputConnectorArr[] = {
    "RF1C", "RF2C", "RF3C", "RF4C", "RFAC", "RFBC",
    "R11C", "R12C", "R13C", "R14C", "R21C", "R22C",
    "R23C", "R24C", "R31C", "R32C", "R33C", "R34C",
    "R41C", "R42C", "R43C", "R44C", NULL
};
static ViString rfInputConverterArr[] = {
    "RX1", "RX2", "RX3", "RX4", "RX11", "RX12",
    "RX13", "RX14", "RX21", "RX22", "RX23", "RX24",
    "RX31", "RX32", "RX33", "RX34", "RX41", "RX42", "RX43", "RX44", NULL
};
static ViString rfOutputConnectorArr[] = {
    "RF1C", "RF2C", "RF3C", "RF4C", "RF1O", "RF3O", "RFAC", "RFAO", "RFBC",
    "R11C", "R12C", "R13C", "R14C", "R21C", "R22C", "R23C", "R24C",
    "R31C", "R32C", "R33C", "R34C", "R41C", "R42C", "R43C", "R44C",
    "R11O", "R13O", "R21O", "R23O", "R31O", "R33O", "R41O", "R43O",NULL
};
static ViString rfOutputConverterArr[] = {
    "TX1", "TX2", "TX3", "TX4", "TX11", "TX12", "TX13", "TX14", "TX21", "TX22", "TX23", "TX24",
    "TX31", "TX32", "TX33", "TX34", "TX41", "TX42", "TX43", "TX44", NULL
};
static ViString routingScenarioArr[] = {"STAN", "MIMO", NULL};
static ViString switchArr[] = {"OFF", "ON", NULL};
static ViString stateArr[] = {"DIS", "ENAB", NULL};
static ViString rateArr[] = {
    "D1MB", "D2MB", "C55M", "C11M", "BR12", "BR34", "QR12", "QR34",
    "Q1M12", "Q1M34", "Q6M23", "Q6M34", "MCS", "MCS1", "MCS2",
    "MCS3", "MCS4", "MCS5", "MCS6", "MCS7", "MCS8", "MCS9", "MCS10", "MCS11",
    "MCS12", "MCS13", "MCS14", "MCS15", NULL
};
static ViString modulationCodingRateArr[] = {
    "BR12", "BR34", "QR12", "QR34", "Q1M12", "Q1M34", "Q6M23", "Q6M34",
    "MCS", "MCS1", "MCS2", "MCS3", "MCS4", "MCS5", "MCS6", "MCS7", "D1MB", "D2MB", "C55M",
    "C11M", "MCS8", "MCS9", "MCS10", "MCS11", "MCS12", "MCS13", "MCS14", "MCS15", NULL
};
static ViString rateStateArr[] = {"DIS", "MAND", "OPT", NULL};
static ViString mcsStateArr[] = {"NOTS", "SUPP", NULL};
static ViString ipVersionArr[] = {"ipv4", "ipv6", NULL};
static ViString networkTypeArr[] = {"PNET", "PNWG", "CPN", "FPN", "PDN", "ESON", "TOEX", "WILD", NULL};
static ViString venueGroupArr[] = {
    "UNSP", "ASS", "BUS", "EDUC", "FAIN", "INST", "MERC", "RES", "STOR",
    "UAM", "VEH", "OUTD",NULL
};

static ViString ipV6AddressFieldArr[] = {"ATN", "ATAV", "AATN",NULL};
static ViString ipV4AddressFieldArr[] = {"ATN", "PIA", "PRI", "SNP", "DNP", "PSN", "PDN", "AATN",NULL};
static ViString eapTypeArr[] = {"SIM", "TTLS", "AKA", "APR", "TLS",NULL};
static ViString networkAuthenticationArr[] = {"ATC", "OES", "HRED", "DRED",NULL};
static ViString tonesArr[] = {"", "KTON", "KTTW", "KTTH", NULL};
static ViString algorithmArr[] = {"MIL", "XOR", NULL};
static ViString mncLengthArr[] = {"TWD", "THD", NULL};

static ViString signUnitArr[] = {"SUU", "SUA", NULL};
static ViString frameFormatArr[] = {"NHT", "HTM", "HTG", "VHT", "HES", "HEM", NULL};
static ViString frameFormatDataRateArr[] = {"NHT", "HT", "VHT", "HESU", "HEMU", "HETB", NULL};
static ViString guardIntervalArr[] = {"SHOR", "LONG", "GI08", "GI16", "GI32", NULL};
static ViString channelBandwidthArr[] = {"BW20", "BW40", "BW80", "BW88", "BW160", NULL};
static ViString addressPoolIndexArr[] = {"", "IP1", "IP2", "IP3", NULL};
static ViString dataRateArr[] = {
    "", "MB1", "MB2", "MB5", "MB6", "MB9", "MB12",
    "MB18", "MB24", "MB36", "MB48", "MB54", "MCS0",
    "MCS1", "MCS2", "MCS3", "MCS4", "MCS5", "MCS6",
    "MCS7", "MCS8", "MCS9", "MCS10", "MCS11",
    "MCS12", "MCS13", "MCS14", "MCS15", NULL
};
static ViString spatialStreamArr[] = {"", "NSS1", "NSS2", "NSS3", "NSS4", "NSS5", "NSS6", "NSS7", "NSS8", NULL};
static ViString deviceClassArr[] = {"A", "B", NULL};
static ViString dynamicFragmentationArr[] = {"N0", "L1", "L2", "L3", NULL};
static ViString noYesArr[] = {"NO", "YES", NULL};
static ViString ltfTypeArr[] = {"X1", "X2", "X4", NULL};
static ViString peDurationArr[] = {"AUTO", "PE0", "PE4", "PE8", "PE12", "PE16", NULL};
static ViString codingTypeArr[] = {"LDPC", "BCC", NULL};
static ViString streamArr[] = {"", "STR1", "STR2", NULL};
static ViString subfieldArr[] = {
    "A000", "A001", "A002", "A003", "A004", "A005",
    "A006", "A007", "A008", "A009", "A010", "A011",
    "A012", "A013", "A014", "A015", "A016", "A024",
    "A032", "A040", "A048", "A056", "A064", "A072",
    "A080", "A088", "A096", "A112", "A113", "A114",
    "A115", "A116", "A120", "A128", "A192", "A200",
    "A208", "A216", "A224", NULL
};

static ViString userMappingArr[] = {"OFF", "USR1", "DMY1", "DMY2", "DMY3", NULL};
static ViString sizeArr[] = {"T26", "T52", "T106", "T242", "T484", "T996", "T2X9", NULL};
static ViString flowTypeArr[] = {"ANN", "UNAN", NULL};
static ViString parameterSetArr[] = {"EDCA", "MUED", NULL};
static ViString accessCategoryArr[] = {"ACBE", "ACBK", "ACVI", "ACVO", NULL};
static ViString powerIndicatorArr[] = {"UND", "RANG", "OVER", NULL};
static ViString tidXArr[] = {
    "TID0", "TID1", "TID2", "TID3", "TID4",
    "TID5", "TID6", "TID7", NULL
};
static ViString disableEnableArr[] = {"DIS", "ENAB", NULL};

/*****************************************************************************
 *- User-Callable Functions (Exportable Functions) --------------------------*
 *****************************************************************************/

/*****************************************************************************
 * Function: rscmwwls_init
 * Purpose:  VXIplug&play required function. Calls the
 *           rscmwwls_InitWithOptions function.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_init(ViRsrc resourceName, ViBoolean IDQuery,
                                ViBoolean resetDevice, ViSession* newInstrSession)
{
    ViStatus error = VI_SUCCESS;

    if (newInstrSession == NULL)
    {
        (void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER,
                                  VI_ERROR_PARAMETER4, "Null address for Instrument Handle");

        checkErr(RS_ERROR_INVALID_PARAMETER);
    }

    checkErr(rscmwwls_InitWithOptions (resourceName, IDQuery, resetDevice, "", newInstrSession));

Error:
    return error;
}

/*****************************************************************************
 * Function: rscmwwls_InitWithOptions
 * Purpose:  This function creates a new RS session and calls the
 *           RsInit function.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_InitWithOptions(
    ViRsrc resourceName,
    ViBoolean IDQuery,
    ViBoolean resetDevice,
    ViString optionString,
    ViSession* newInstrSession
)
{
    ViStatus error = VI_SUCCESS;
    RsCoreAttributePtr* attrList = NULL;
    ViSession instrSession = 0;
    RsCoreSessionPtr sessionProperties = NULL;

    if (newInstrSession == NULL)
    {
        (void)RsCore_SetErrorInfo(0, VI_FALSE, RS_ERROR_INVALID_PARAMETER, VI_ERROR_PARAMETER5,
                                  "Null address for Instrument Handle");
        checkErr(RS_ERROR_INVALID_PARAMETER);
    }

    attrList = (RsCoreAttributePtr*)rscmwwls_RsCoreAttributeList;

    *newInstrSession = 0;

    checkErr(RsCore_NewSpecificDriver(
        resourceName, // VISA Resource Name
        "rscmwwls", // driver prefix
        optionString, // Init Options string, is applied to the session settings
        attrList, // List of all attributes from the rscmwwls_RsCoreAttributeList
        rscmwwls_RsCoreAttributeListLength, // Length of attributes list
        VI_FALSE, //idnModelFullName Model has the full *IDN? query name e.g. true: "CMW100A", VI_FALSE: "CMW" Used in CheckInstrument()
        0, // WriteDelay
        0, // ReadDelay
        100000, // IO Segment Size
        RS_VAL_OPCWAIT_STBPOLLING, // OPC Wait Mode
        RSCMWWLS_OPC_TIMEOUT, // OPC timeout
        15000, // VISA Timeout
        600000, // Self-test timeout
        RS_VAL_BIN_FLOAT_FORMAT_SINGLE_4BYTES, // BinaryFloatNumbersFormat
        RS_VAL_BIN_INTEGER_FORMAT_INT32_4BYTES, // binaryIntegerNumbersFormat
        &instrSession));

    // Minimal allowed rscore version is 4.3.0
    checkErr(RsCore_CheckMinimalEngineVersion(instrSession, 4, 3, 0));

    checkErr(RsCore_GetRsSession(instrSession, &sessionProperties));

    // No SCPI command has been sent yet.
    // Call viClear before sending any SCPI command
    checkErr(RsCore_ViClear(instrSession));

    /* --- Here perform settings that are default for this driver,
    but can be overwritten by the optionsString settings */

    sessionProperties->autoSystErrQuery = VI_FALSE;

    // Parse option string and optionally sets the initial state of the following session attributes
    checkErr(RsCore_ApplyOptionString(instrSession, optionString));
    checkErr(RsCore_BuildRepCapTable(instrSession, rscmwwls_RsCoreRepCapTable, rscmwwls_RsCoreRepCapTableCount));

    // Query *IDN? string, parse it and set the following attributes:
    // -RS_ATTR_INSTRUMENT_MANUFACTURER
    // - RS_ATTR_INSTRUMENT_MODEL - based on the idnModelFullName true: "CMW100A", false : "CMW"
    // - RS_ATTR_INSTRUMENT_FIRMWARE_REVISION
    checkErr(RsCore_QueryAndParseIDNstring(instrSession, RSCMWWLS_SIMULATION_ID_QUERY, NULL));

    // Query *OPT? string, parse the options, remove the duplicates, sort them and store the result string to RS_ATTR_OPTIONS_LIST
    checkErr(RsCore_QueryAndParseOPTstring(instrSession, RSCMWWLS_SIMULATION_OPT_QUERY, RS_VAL_OPTIONS_PARSING_AUTO));

    // Default Instrument Setup + optional *RST
    if (resetDevice == VI_TRUE)
    {
        checkErr(rscmwwls_reset(instrSession));
    }
    else
    {
        checkErr(rscmwwls_DefaultInstrSetup(instrSession));
    }

    if (IDQuery == VI_TRUE)
    {
        checkErr(RsCore_FitsIDNpattern(instrSession, RSCMWWLS_VALID_ID_RESPONSE_STRING, NULL));
    }

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    if (error < VI_SUCCESS)
    {
        if (error == RS_ERROR_INSTRUMENT_STATUS && sessionProperties->autoSystErrQuery == VI_FALSE)
        {
            sessionProperties->autoSystErrQuery = VI_TRUE;
            (void)rscmwwls_CheckStatus(instrSession);
            sessionProperties->autoSystErrQuery = VI_FALSE;
        }

        if (instrSession != 0)
            (void)RsCore_ViClose(instrSession);
    }
    else
    {
        *newInstrSession = instrSession;
    }

    return error;
}

/// HIFN Enables the setup of a connection between the signaling unit and
/// HIFN the Data Application Unit (DAU), required for IP-based data
/// HIFN tests involving the DAU.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR endToEnd/Enables the setup of a connection between the signaling unit and DAU
ViStatus _VI_FUNC rscmwwls_ConfigureEndToEnd(ViSession instrSession,
                                             ViInt32   instance,
                                             ViBoolean endToEnd)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_SIGNALING_END_TO_END, endToEnd),
            3, "End To End");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Configures an entry of the routes list. The routes list defines
/// HIFN destination addresses for
/// HIFN which the DAU shall route packets to the DUT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR routeAddress/Sets the route address of the list.
/// HIPAR state/Activates or deactivates entry.
/// HIPAR IP4Octet1/First octet of the IPv4 destination address
/// HIPAR IP4Octet2/Second octet of the IPv4 destination address
/// HIPAR IP4Octet3/Third octet of the IPv4 destination address
/// HIPAR IP4Octet4/Fourth octet of the IPv4 destination address
/// HIPAR IP4Netmask/Number of subnet bits for the IPv4 address
/// HIPAR IP6Prefix/IPv6 prefix as string.
/// HIPAR IP6Netmask/Number of subnet bits for the IPv6 address
ViStatus _VI_FUNC rscmwwls_ConfigureIPRoutesList(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32   routeAddress,
                                                 ViBoolean state,
                                                 ViInt32   IP4Octet1,
                                                 ViInt32   IP4Octet2,
                                                 ViInt32   IP4Octet3,
                                                 ViInt32   IP4Octet4,
                                                 ViInt32   IP4Netmask,
                                                 ViString  IP6Prefix,
                                                 ViInt32   IP6Netmask)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, routeAddress, 1, 5),
            3, "Route Address");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, IP4Octet1, 0, 255),
            5, "IP4 Octet 1");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, IP4Octet2, 0, 255),
            6, "IP4 Octet 2");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, IP4Octet3, 0, 255),
            7, "IP4 Octet 3");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, IP4Octet4, 0, 255),
            8, "IP4 Octet 4");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, IP4Netmask, 1, 32),
            9, "IP4 Netmask");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, IP6Netmask, 1, 128),
            11, "IP6Netmask");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:ETOE:IRL:IPR%ld %s,%ld,%ld,%ld,%ld,%ld,'%s',%ld", instance, routeAddress,
             switchArr[state ? 1 : 0],
             IP4Octet1, IP4Octet2, IP4Octet3, IP4Octet4, IP4Netmask,
             IP6Prefix, IP6Netmask);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function defines the standard RX and TX routing (no MIMO).
 /// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR signalingUnit/Selects the signaling unit.
/// HIPAR signalingUnitNumber/Selects the signaling unit number.
/// HIPAR RFInputConnector/Defines the RF input connector.
/// HIPAR RFInputConverter/Defines the RF input converter.
/// HIPAR RFOutputConnector/Selects the RF output connector.
/// HIPAR RFOutputConverter/Defines the RF output converter.
ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalRoutingStandardCell(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   signalingUnit,
                            ViInt32   signalingUnitNumber,
                            ViInt32   RFInputConnector,
                            ViInt32   RFInputConverter,
                            ViInt32   RFOutputConnector,
                            ViInt32   RFOutputConverter)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, signalingUnit, RSCMWWLS_VAL_SUU, RSCMWWLS_VAL_SUA),
            3, "Signaling Unit");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, signalingUnitNumber, 1, 478),
            4, "Signaling Unit Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFInputConnector, RSCMWWLS_VAL_CONN_RF1C, RSCMWWLS_VAL_CONN_RF4C),
            5, "RF Input Connector");
    if (RFInputConverter != RSCMWWLS_VAL_CONV_RX1)
    {
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, RFInputConverter),
                    6, "RF Input Converter");
    }
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFOutputConnector, RSCMWWLS_VAL_TX_CONN_RF1C, RSCMWWLS_VAL_TX_CONN_RF3O),
            7, "RF Output Connector");
    if (RFOutputConverter != RSCMWWLS_VAL_CONV_TX1)
    {
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, RFOutputConverter),
                    8, "RF Output Converter");
    }

    if (signalingUnit == RSCMWWLS_VAL_SUA)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:WLAN:SIGN%ld:SCEN:SCEL:FLEX %s%03ld,%s,%s,%s,%s", instance,
                 signUnitArr[signalingUnit], signalingUnitNumber,
                 rfInputConnectorArr[RFInputConnector],
                 rfInputConverterArr[RFInputConverter],
                 rfOutputConnectorArr[RFOutputConnector],
                 rfOutputConverterArr[RFOutputConverter]);
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:WLAN:SIGN%ld:SCEN:SCEL:FLEX %s%ld,%s,%s,%s,%s", instance,
                 signUnitArr[signalingUnit], signalingUnitNumber,
                 rfInputConnectorArr[RFInputConnector],
                 rfInputConverterArr[RFInputConverter],
                 rfOutputConnectorArr[RFOutputConnector],
                 rfOutputConverterArr[RFOutputConverter]);
    }

    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the RX and TX routing for the MIMO Scenario.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR cmwNumber/Selects the CMW number as the base band unit.
/// HIPAR signalingUnit/Selects the signaling unit.
/// HIPAR signalingUnitNumber/Selects the signaling unit number.
/// HIPAR RFInputConnector/Defines the RF input connector.
/// HIPAR RFInputConverter/Defines the RF input converter.
/// HIPAR RFOutputConnector/Selects the RF output connector for all paths.
/// HIPAR RFOutputConverter/Defines the RF output converter for all paths.
ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalRoutingMIMO(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   cmwNumber,
                                                        ViInt32   signalingUnit,
                                                        ViInt32   signalingUnitNumber,
                                                        ViInt32   RFInputConnector[],
                                                        ViInt32   RFInputConverter[],
                                                        ViInt32   RFOutputConnector[],
                                                        ViInt32   RFOutputConverter[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    if (signalingUnit == RSCMWWLS_VAL_SUA)
    {
        viCheckParm(RsCore_InvalidViInt32Range(instrSession, cmwNumber, 0, 4),
                3, "CMWNumber");
    }
    else
    {
        viCheckParm(RsCore_InvalidViInt32Range(instrSession, cmwNumber, 1, 4),
                3, "CMWNumber");
    }

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, signalingUnit, RSCMWWLS_VAL_SUU, RSCMWWLS_VAL_SUA),
            4, "Signaling Unit");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, signalingUnitNumber, 1, 78),
            5, "Signaling Unit Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFInputConnector[0], RSCMWWLS_VAL_CONN_RF1C, RSCMWWLS_VAL_CONN_R44C),
            6, "RF Input Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFInputConverter[0], RSCMWWLS_VAL_CONV_RX1, RSCMWWLS_VAL_CONV_RX44),
            7, "RF Input Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFInputConnector[1], RSCMWWLS_VAL_CONN_RF1C, RSCMWWLS_VAL_CONN_R44C),
            6, "RF Input Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFInputConverter[1], RSCMWWLS_VAL_CONV_RX1, RSCMWWLS_VAL_CONV_RX44),
            7, "RF Input Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFOutputConnector[0], RSCMWWLS_VAL_TX_CONN_RF1C, RSCMWWLS_VAL_TX_CONN_R43O),
            8, "RF Output Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFOutputConverter[0], RSCMWWLS_VAL_CONV_TX1, RSCMWWLS_VAL_CONV_TX44),
            9, "RF Output Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFOutputConnector[1], RSCMWWLS_VAL_TX_CONN_RF1C, RSCMWWLS_VAL_TX_CONN_R43O),
            8, "RF Output Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFOutputConverter[1], RSCMWWLS_VAL_CONV_TX1, RSCMWWLS_VAL_CONV_TX44),
            9, "RF Output Converter");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:WLAN:SIGN%ld:SCEN:MIMO:FLEX %s%ld%ld,%s,%s,%s,%s,%s,%s,%s,%s", instance,
             signUnitArr[signalingUnit], cmwNumber, signalingUnitNumber,
             rfInputConnectorArr[RFInputConnector[0]],
             rfInputConverterArr[RFInputConverter[0]],
             rfOutputConnectorArr[RFOutputConnector[0]],
             rfOutputConverterArr[RFOutputConverter[0]],
             rfOutputConnectorArr[RFOutputConnector[1]],
             rfOutputConverterArr[RFOutputConverter[1]],
             rfInputConnectorArr[RFInputConnector[1]],
             rfInputConverterArr[RFInputConverter[1]]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query RF Signal Routing Settings
 * Purpose:  Queries the active test scenario and connector assignment.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_QueryRFSignalRoutingSettings(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32*  scenario,
                                                        ViChar    master[],
                                                        ViInt32*  RXConnector,
                                                        ViInt32*  RXConverter,
                                                        ViInt32*  TXConnector,
                                                        ViInt32*  TXConverter,
                                                        ViInt32*  TXConnector2,
                                                        ViInt32*  TXConverter2,
                                                        ViInt32*  RXConnector2,
                                                        ViInt32*  RXConverter2)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "ROUT:WLAN:SIGN%ld?", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwls_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    checkErr(rscmwwls_GetIndexOfToken(p2buf, routingScenarioArr, scenario));

    p2buf = strtok(NULL, ",");
    sscanf(p2buf, "\"%[^\"]", master);

    p2buf = strtok(NULL, ",");
    checkErr(rscmwwls_GetIndexOfToken(p2buf, rfInputConnectorArr, RXConnector));

    p2buf = strtok(NULL, ",");
    checkErr(rscmwwls_GetIndexOfToken(p2buf, rfInputConverterArr, RXConverter));

    p2buf = strtok(NULL, ",");
    checkErr(rscmwwls_GetIndexOfToken(p2buf, rfOutputConnectorArr, TXConnector));

    p2buf = strtok(NULL, ",");
    checkErr(rscmwwls_GetIndexOfToken(p2buf, rfOutputConverterArr, TXConverter));

    p2buf = strtok(NULL, ",");
    if (p2buf != NULL)
    {
        // only for MIMO
        checkErr(rscmwwls_GetIndexOfToken(p2buf, rfOutputConnectorArr, TXConnector2));

        p2buf = strtok(NULL, ",");
        checkErr(rscmwwls_GetIndexOfToken(p2buf, rfOutputConverterArr, TXConverter2));

        p2buf = strtok(NULL, ",");
        checkErr(rscmwwls_GetIndexOfToken(p2buf, rfInputConnectorArr, RXConnector2));

        p2buf = strtok(NULL, ",");
        checkErr(rscmwwls_GetIndexOfToken(p2buf, rfInputConverterArr, RXConverter2));
    }

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/*****************************************************************************
 * Function: Configure RF Signal Frequency
 * Purpose:  Sets the center frequency of the single supported 20 MHz
             channel.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalFrequency(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViReal64  frequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_RF_SIGNAL_FREQUENCY, frequency),
            3, "Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Sets the current 802.11 a/b/g/n channel number.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR channel/Sets the current 802.11 a/b/g/n channel number.
ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalChannel(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_RF_SIGNAL_CHANNEL, channel),
            3, "Channel");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specifies a positive or negative frequency offset to be added to the
/// HIFN  configured center frequency.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR frequencyOffset/Specifies a positive or negative frequency offset to be added to the
/// HIPAR frequencyOffset/configured center frequency.
ViStatus _VI_FUNC rscmwwls_ConfigureRFFrequencyOffset(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32   frequencyOffset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_RF_FREQUENCY_OFFSET, frequencyOffset),
            3, "Frequency Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the position of the primary 20-MHz channel, for a signal with
/// HIFN  more than 20 MHz channel bandwidth.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR np20Index/Selects the position of the primary 20-MHz channel, for a signal with
/// HIPAR np20Index/more than 20 MHz channel bandwidth. This setting is displayed for
/// HIPAR np20Index/signals with 40 MHz bandwidth.
ViStatus _VI_FUNC rscmwwls_ConfigureRFNp20Index(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32   np20Index)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_RF_NP20_INDEX, np20Index),
            3, "Np20 Index");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the center frequency of the primary 20-MHz channel, for a signal
/// HIFN  with more than 20 MHz bandwidth. This setting is displayed for signals
/// HIFN  with 40 MHz bandwidth.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR frequency/Sets the center frequency of the primary 20-MHz channel, for a signal
/// HIPAR frequency/with more than 20 MHz bandwidth. This setting is displayed for signals
/// HIPAR frequency/with 40 MHz bandwidth.
ViStatus _VI_FUNC rscmwwls_ConfigureRFNp20Frequency(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViReal64  frequency)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_RF_NP20_FREQUENCY, frequency),
            3, "Frequency");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the channel number of the primary 20-MHz channel, for a signal
/// HIFN  with more than 20 MHz bandwidth. This setting is displayed for signals
/// HIFN  with 40 MHz bandwidth.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR channel/Sets the channel number of the primary 20-MHz channel, for a signal
/// HIPAR channel/with more than 20 MHz bandwidth. This setting is displayed for signals
/// HIPAR channel/with 40 MHz bandwidth.
ViStatus _VI_FUNC rscmwwls_ConfigureRFNp20Channel(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViInt32   channel)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_RF_NP20_CHANNEL, channel),
            3, "Channel");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the operating channel bandwidth.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR channelBandwidth/Sets the operating channel bandwidth.
ViStatus _VI_FUNC rscmwwls_ConfigureRFOperatingChannelWidth(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   channelBandwidth)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_RF_OPERATING_CHANNEL_WIDTH, channelBandwidth),
            3, "Channel Bandwidth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the active scenario.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR activeScenario/Returns the active scenario.
ViStatus _VI_FUNC rscmwwls_QueryRFActiveScenario(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32*  activeScenario)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_GetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_QUERY_ACTIVE_SCENARIO, activeScenario),
            3, "Active Scenario");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the operating band sub 6 GHz or 6 GHz band.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR RFBand/Selects the operating band sub 6 GHz or 6 GHz band.
ViStatus _VI_FUNC rscmwwls_ConfigureRFBand(ViSession instrSession,
                                           ViInt32   instance,
                                           ViInt32   RFBand)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_RF_BAND, RFBand),
            3, "RF Band");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure RF Signal Burst Power Downlink
 * Purpose:  Sets the TX burst power of the DL signal.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalBurstPowerDownlink(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViReal64  TXBurstPower)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_RF_SIGNAL_BURST_POWER_DOWNLINK, TXBurstPower),
            3, "TX Burst Power");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the "MIMO 2x2 Fading" scenario and selects the signal paths.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR cmwNumber/Selects the CMW number as the base band unit.
/// HIPAR signalingUnit/Selects the signaling unit.
/// HIPAR signalingUnitNumber/Selects the signaling unit number.
/// HIPAR RFInputConnector/Defines the RF input connector.
/// HIPAR RFInputConverter/Defines the RF input converter.
/// HIPAR RFOutputConnector/Selects the RF output connector.
/// HIPAR RFOutputConverter/Defines the RF output converter.
/// HIPAR internalFader/Defines the internal fader.
ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalRoutingStandardCellFading(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   CMWNumber,
                            ViInt32   signalingUnit,
                            ViInt32   signalingUnitNumber,
                            ViInt32   RFInputConnector,
                            ViInt32   RFInputConverter,
                            ViInt32   RFOutputConnector,
                            ViInt32   RFOutputConverter,
                            ViInt32   internalFader)
{
    ViStatus error = VI_SUCCESS;
    ViChar   params[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    if (signalingUnit == RSCMWWLS_VAL_SUA)
    {
        viCheckParm(RsCore_InvalidViInt32Range(instrSession, CMWNumber, 0, 4),
                3, "CMWNumber");
    }
    else
    {
        viCheckParm(RsCore_InvalidViInt32Range(instrSession, CMWNumber, 1, 4),
                3, "CMWNumber");
    }

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, signalingUnit, RSCMWWLS_VAL_SUU, RSCMWWLS_VAL_SUA),
            4, "Signaling Unit");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, signalingUnitNumber, 1, 78),
            5, "Signaling Unit Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFInputConnector, RSCMWWLS_VAL_CONN_RF1C, RSCMWWLS_VAL_CONN_R44C),
            6, "RF Input Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFInputConverter, RSCMWWLS_VAL_CONV_RX1, RSCMWWLS_VAL_CONV_RX44),
            7, "RF Input Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFOutputConnector, RSCMWWLS_VAL_TX_CONN_RF1C, RSCMWWLS_VAL_TX_CONN_R43O),
            8, "RF Output Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFOutputConverter, RSCMWWLS_VAL_CONV_TX1, RSCMWWLS_VAL_CONV_TX44),
            9, "RF Output Converter");

    snprintf(params, RS_MAX_MESSAGE_BUF_SIZE, "%s%ld%ld,%s,%s,%s,%s,FAD%03ld", signUnitArr[signalingUnit], CMWNumber, signalingUnitNumber,
             rfInputConnectorArr[RFInputConnector],
             rfInputConverterArr[RFInputConverter],
             rfOutputConnectorArr[RFOutputConnector],
             rfOutputConverterArr[RFOutputConverter],
             internalFader);

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_RF_SIGNAL_ROUTING_STANDARD_CELL_FADING, params));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Activates the "MIMO 2x2 Fading" scenario and selects the signal paths.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR cmwNumber/Selects the CMW number as the base band unit.
/// HIPAR signalingUnit/Selects the signaling unit.
/// HIPAR signalingUnitNumber/Selects the signaling unit number.
/// HIPAR RFInputConnector/Defines the RF input connector.
/// HIPAR RFInputConverter/Defines the RF input converter.
/// HIPAR RFOutputConnector/Selects the RF output connector for all paths.
/// HIPAR RFOutputConverter/Defines the RF output converter for all paths.
/// HIPAR internalFader/Defines the internal fader.
ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalRoutingMIMO2x2Fading(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   CMWNumber,
                            ViInt32   signalingUnit,
                            ViInt32   signalingUnitNumber,
                            ViInt32   RFInputConnector[],
                            ViInt32   RFInputConverter[],
                            ViInt32   RFOutputConnector[],
                            ViInt32   RFOutputConverter[],
                            ViInt32   internalFader)
{
    ViStatus error = VI_SUCCESS;
    ViChar   params[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    if (signalingUnit == RSCMWWLS_VAL_SUA)
    {
        viCheckParm(RsCore_InvalidViInt32Range(instrSession, CMWNumber, 0, 4),
                3, "CMWNumber");
    }
    else
    {
        viCheckParm(RsCore_InvalidViInt32Range(instrSession, CMWNumber, 1, 4),
                3, "CMWNumber");
    }

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, signalingUnit, RSCMWWLS_VAL_SUU, RSCMWWLS_VAL_SUA),
            4, "Signaling Unit");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, signalingUnitNumber, 1, 78),
            5, "Signaling Unit Number");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFInputConnector[0], RSCMWWLS_VAL_CONN_RF1C, RSCMWWLS_VAL_CONN_R44C),
            6, "RF Input Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFInputConverter[0], RSCMWWLS_VAL_CONV_RX1, RSCMWWLS_VAL_CONV_RX44),
            7, "RF Input Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFInputConnector[1], RSCMWWLS_VAL_CONN_RF1C, RSCMWWLS_VAL_CONN_R44C),
            6, "RF Input Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFInputConverter[1], RSCMWWLS_VAL_CONV_RX1, RSCMWWLS_VAL_CONV_RX44),
            7, "RF Input Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFOutputConnector[0], RSCMWWLS_VAL_TX_CONN_RF1C, RSCMWWLS_VAL_TX_CONN_R43O),
            8, "RF Output Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFOutputConverter[0], RSCMWWLS_VAL_CONV_TX1, RSCMWWLS_VAL_CONV_TX44),
            9, "RF Output Converter");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFOutputConnector[1], RSCMWWLS_VAL_TX_CONN_RF1C, RSCMWWLS_VAL_TX_CONN_R43O),
            8, "RF Output Connector");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, RFOutputConverter[1], RSCMWWLS_VAL_CONV_TX1, RSCMWWLS_VAL_CONV_TX44),
            9, "RF Output Converter");

    snprintf(params, RS_MAX_MESSAGE_BUF_SIZE, "%s%ld%ld,%s,%s,%s,%s,%s,%s,%s,%s,FAD%03ld", signUnitArr[signalingUnit], CMWNumber, signalingUnitNumber,
             rfInputConnectorArr[RFInputConnector[0]],
             rfInputConverterArr[RFInputConverter[0]],
             rfOutputConnectorArr[RFOutputConnector[0]],
             rfOutputConverterArr[RFOutputConverter[0]],
             rfOutputConnectorArr[RFOutputConnector[1]],
             rfOutputConverterArr[RFOutputConverter[1]],
             rfInputConnectorArr[RFInputConnector[1]],
             rfInputConverterArr[RFInputConverter[1]],
             internalFader);

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_RF_SIGNAL_ROUTING_MIMO_2X2_FADING, params));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure RF TX MIMO Mode
 * Purpose:  Sets the TX MIMO mode in MIMO scenario.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureRFTXMIMOMode(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32   TXMIMOMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_RF_TX_MIMO_MODE, TXMIMOMode),
            3, "TX MIMO Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure RF Signal TX Power Ratio
 * Purpose:  Sets the power ratio between TX1 and TX2.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureRFSignalTXPowerRatio(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViReal64  TX2TX1PowerRatio)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_RF_TX2_TX1_POWER_RATIO, TX2TX1PowerRatio),
            3, "TX2/TX1 Power Ratio");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specifies the external attenuation for the specified antenna in the analyzer path.
/// HIFN  Antenna 2 is only available in a MIMO scenario with two input paths.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR antenna/Selects repcap antenna.
/// HIPAR nominalPower/Specifies the expected peak envelope power of the specified antenna
/// HIPAR nominalPower/at the I/Q input. Antenna 2 is only available in MIMO scenarios with
/// HIPAR nominalPower/two input paths. The correct DUT range to be set is (-20 dBm +
/// HIPAR nominalPower/external attenuation) to (55 dBm + external attenuation).
/// HIPAR levelOffset/Varies the input level of the mixer for the specified antenna in the
/// HIPAR levelOffset/analyzer path. Antenna 2 is only available in MIMO scenarios with
/// HIPAR levelOffset/two input paths.
ViStatus _VI_FUNC rscmwwls_ConfigureRFRoutingAntennas(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32   antenna,
                                                      ViReal64  nominalPower,
                                                      ViReal64  levelOffset)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,a%ld", instance, antenna);

    viCheckParm(rscmwwls_SetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_ANTENNA_EXPECTED_NOMINAL_POWER, nominalPower),
            4, "Nominal Power");

    viCheckParm(rscmwwls_SetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_ANTENNA_MIXER_LEVEL_OFFSET, levelOffset),
            5, "Level Offset");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specifies the external attenuation for the specified antenna in the analyzer path.
/// HIFN  Antenna 2 is only available in a MIMO scenario with two input paths.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR antenna/Selects repcap antenna.
/// HIPAR path/Selects the path.
/// HIPAR externalAttenuation/Defines an external attenuation (or gain, if the value is
/// HIPAR externalAttenuation/negative), to be applied to the selected RF input or output
/// HIPAR externalAttenuation/connector.
ViStatus _VI_FUNC rscmwwls_ConfigureRFRoutingAntennasAttenuation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antenna,
                            ViInt32   path,
                            ViReal64  externalAttenuation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, path, RSCMWWLS_VAL_PATH_INPUT, RSCMWWLS_VAL_PATH_OUTPUT),
            3, "Path");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,a%ld", instance, antenna);

    if (path == RSCMWWLS_VAL_PATH_INPUT)
    {
        viCheckParm(rscmwwls_SetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_INPUT_ANTENNA_EXTERNAL_ATTENUATION, externalAttenuation),
                5, "External Attenuation");
    }
    else
    {
        viCheckParm(rscmwwls_SetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_OUTPUT_ANTENNA_EXTERNAL_ATTENUATION, externalAttenuation),
                5, "External Attenuation");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the approximate RX burst power per individual antenna, calculated from the
/// HIFN  expected PEP and the configured standard. Antenna 2 is only available in a MIMO scenario.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR antenna/Selects repcap antenna.
/// HIPAR approximateBurstPower/Queries the approximate RX burst power per individual antenna,
/// HIPAR approximateBurstPower/calculated from the expected PEP and the configured standard.
/// HIPAR approximateBurstPower/Antenna 2 is only available in a MIMO scenario.
ViStatus _VI_FUNC rscmwwls_QueryRFRoutingAntennaApproximateBurstPower(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   antenna,
                            ViReal64* approximateBurstPower)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   repCap2[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    snprintf(repCap2, RS_REPCAP_BUF_SIZE, "%s,a%ld", repCap, antenna);

    viCheckParm(rscmwwls_GetAttributeViReal64(instrSession, repCap2, RSCMWWLS_ATTR_ANTENNA_APPROXIMATE_BURST_POWER, approximateBurstPower),
            3, "Approximate Burst Power");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures external DAU.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR state/Enables usage of an external DAU.
/// HIPAR segmentNumber/Specifies the network segment of the instrument where the external DAU
/// HIPAR segmentNumber/is installed.
/// HIPAR nodeID/Specifies the subnet node ID of the instrument where the external DAU
/// HIPAR nodeID/is installed.
ViStatus _VI_FUNC rscmwwls_ConfigureDAU(ViSession instrSession,
                                        ViInt32   instance,
                                        ViBoolean state,
                                        ViInt32   segmentNumber,
                                        ViInt32   nodeID)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_EXTERNAL_DAU_ENABLED, state),
            3, "State");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_EXTERNAL_DAU_SEGMENT_NUMBER, segmentNumber),
            4, "Segment Number");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_EXTERNAL_DAU_NODE_ID, nodeID),
            5, "Node ID");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Allows to specify the IPv4 address the DAU shall assign to the DUT via
/// HIFN  DHCP.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR state/Activates or deactivates IPv4 address.
/// HIPAR octet1/The dotted decimal representation byte by byte.
/// HIPAR octet2/The dotted decimal representation byte by byte.
/// HIPAR octet3/The dotted decimal representation byte by byte.
/// HIPAR octet4/The dotted decimal representation byte by byte.
ViStatus _VI_FUNC rscmwwls_ConfigureDAUIPv4Address(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViBoolean state,
                                                   ViInt32   octet1,
                                                   ViInt32   octet2,
                                                   ViInt32   octet3,
                                                   ViInt32   octet4)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, octet1, 0, 255),
            4, "Octet 1");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, octet2, 0, 255),
            5, "Octet 2");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, octet3, 0, 255),
            6, "Octet 3");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, octet4, 0, 255),
            7, "Octet 4");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:ETOE:DUIP %s,%ld,%ld,%ld,%ld",
            instance, switchArr[state], octet1, octet2, octet3, octet4);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Main State
 * Purpose:  Sets the main state of the AP implemented by the R&S CMW.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureMainState(ViSession instrSession,
                                              ViInt32   instance,
                                              ViBoolean enable)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_SIGNALING_MAIN_STATE, enable),
            3, "Enable");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Signaling State
 * Purpose:  This function returns main state of the AP implemented by the
             R&S CMW and the synchronization state of the DUT.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_QuerySignalingState(ViSession  instrSession,
                                               ViInt32    instance,
                                               ViBoolean* mainState,
                                               ViInt32*   syncState,
                                               ViInt32*   dut1,
                                               ViInt32*   dut2,
                                               ViInt32*   dut3)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViString mainStateArr[] = {"OFF", "ON",NULL};
    ViString syncStateArr[] = {"PEND", "ADJ",NULL};
    ViString dutStateArr[] = {"IDLE", "AUTH", "ASS", "DEA", "DIS", "CTIM", NULL};
    ViChar*  ext_buf = NULL;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SOUR:WLAN:SIGN%ld:STAT:ALL?", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwls_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        return RSCMWWLS_ERROR_INCORRECT_STATE;
    *mainState = (ViBoolean)RsCore_FindStringIndex(mainStateArr, p2buf);

    p2buf = strtok(NULL, ",\n");
    if (p2buf == NULL)
        return RSCMWWLS_ERROR_INCORRECT_STATE;
    *syncState = RsCore_FindStringIndex(syncStateArr, p2buf);
    if (*syncState < 0)
        return RSCMWWLS_ERROR_INCORRECT_STATE;

    p2buf = strtok(NULL, ",\n");
    if (p2buf == NULL)
        return RSCMWWLS_ERROR_INCORRECT_STATE;
    *dut1 = RsCore_FindStringIndex(dutStateArr, p2buf);

    p2buf = strtok(NULL, ",\n");
    if (p2buf == NULL)
        return RSCMWWLS_ERROR_INCORRECT_STATE;
    *dut2 = RsCore_FindStringIndex(dutStateArr, p2buf);

    p2buf = strtok(NULL, "\n");
    if (p2buf == NULL)
        return RSCMWWLS_ERROR_INCORRECT_STATE;
    *dut3 = RsCore_FindStringIndex(dutStateArr, p2buf);

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connect
 * Purpose:  In station mode (see RSCMWWLS_ATTR_CONNECTION_OPERATION_MODE)
 *           this function initiates an association.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureConnect(ViSession instrSession,
                                            ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_CONNECT, NULL),
            2, "Connect");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure DUT Disconnection
 * Purpose:  Disassociates and deauthenticates the DUT by sending a
             deauthentication frame.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureDUTDisconnection(ViSession instrSession,
                                                     ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_DUT_DISCONNECTION, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specifies the color code of basic service set (BSS).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR bssColor/Specifies the color code of basic service set (BSS).
ViStatus _VI_FUNC rscmwwls_ConfigureBSSColor(ViSession instrSession,
                                             ViInt32   instance,
                                             ViInt32   bssColor)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_BSS_COLOR, bssColor),
            3, "bssColor");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Specifies the range of IDs to be assigned by the access point to the
/// HIFN  connected DUTs.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR start/Start of the range.
/// HIPAR stop/Stop of the range
ViStatus _VI_FUNC rscmwwls_ConfigureAssociationIDRange(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   start,
                                                       ViInt32   stop)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, start, 1, 2007),
            3, "Start");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, stop, 1, 2007),
            4, "Stop");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:AID %ld,%ld", instance, start, stop);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the county code settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR enable/Enables/disables broadcast of regulatory domain information ("country
/// HIPAR enable/code") in beacon frames.
/// HIPAR countryCode/"Country Code" identifies the country or non-country entity in which
/// HIPAR countryCode/the station is operating; see standard IEEE 802.11-2007 for details.
/// HIPAR firstChannel/Defines the range of channels to be used.
/// HIPAR numberOfChannels/Defines the range of channels to be used.
/// HIPAR maxTXPower/Defines the maximum transmit power in dBm.
ViStatus _VI_FUNC rscmwwls_ConfigureCountryCode(ViSession instrSession,
                                                ViInt32   instance,
                                                ViBoolean enable,
                                                ViString  countryCode,
                                                ViInt32   firstChannel,
                                                ViInt32   numberOfChannels,
                                                ViInt32   maxTXPower)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, firstChannel, 0, 255),
            5, "First Channel");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, numberOfChannels, 0, 255),
            6, "Number Of Channels");
    viCheckParm(RsCore_InvalidViReal64Range(instrSession, maxTXPower, -40.0, 40.0), 7, "Max TX Power");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap,
                    RSCMWWLS_ATTR_COUNTRY_CODE_STATE, (ViInt32) enable), 3, "Enable");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:CCOD:CCC '%s',%ld,%ld,%ld",
             instance, countryCode, firstChannel, numberOfChannels, maxTXPower);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables and configures the user-defined frame rate control for
/// HIFN  management frames.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR userDefined/Disables/enables the user-defined frame rate control
/// HIPAR frameFormat/Selects the frame format
/// HIPAR rate/This control selects rate for respective frame type.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionManagementFrameRateControl(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean userDefined,
                            ViInt32   frameFormat,
                            ViInt32   rate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, frameFormat, RSCMWWLS_VAL_FRAME_FORMAT_NHT, RSCMWWLS_VAL_FRAME_FORMAT_HEM),
            4, "Frame Format");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rate, RSCMWWLS_VAL_RATE_DSSS_1M, RSCMWWLS_VAL_RATE_MCS15), 5, "Rate")

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:MFD %s,%s,%s", instance,
             stateArr[userDefined ? 1 : 0],
             frameFormatArr[frameFormat],
             rateArr[rate]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables and configures the user-defined frame rate control for data
/// HIFN  frames.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR userDefined/Disables/enables the user-defined frame rate control
/// HIPAR frameFormat/Selects the frame format
/// HIPAR channelBandwidth/Selects the channel bandwidth. The value must not exceed the operating
/// HIPAR channelBandwidth/channel bandwidth.
/// HIPAR rate/This control selects rate for respective frame type.
/// HIPAR guardInterval/Long or short guard interval, only relevant for DSSS.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataFrame(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViBoolean userDefined,
                                                        ViInt32   frameFormat,
                                                        ViInt32   channelBandwidth,
                                                        ViInt32   rate,
                                                        ViInt32   guardInterval)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, frameFormat, RSCMWWLS_VAL_FRAME_FORMAT_NHT, RSCMWWLS_VAL_FRAME_FORMAT_VHT),
            4, "Frame Format");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channelBandwidth, RSCMWWLS_VAL_BANDWIDTH_20_MHZ, RSCMWWLS_VAL_BANDWIDTH_80_MHZ),
            5, "Channel Bandwidth");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rate, RSCMWWLS_VAL_RATE_DSSS_1M, RSCMWWLS_VAL_RATE_MCS15), 6, "Rate")
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, guardInterval, RSCMWWLS_VAL_GUARD_INTERVAL_SHORT, RSCMWWLS_VAL_GUARD_INTERVAL_LONG), 7, "Guard Interval")

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:DFD %s,%s,%s,%s,%s", instance,
             stateArr[userDefined ? 1 : 0],
             frameFormatArr[frameFormat],
             channelBandwidthArr[channelBandwidth],
             rateArr[rate],
             guardIntervalArr[guardInterval]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables and configures the user-defined frame rate control for data
/// HIFN  frames.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR userDefined/Disables/enables the user-defined frame rate control
/// HIPAR frameFormat/Selects the frame format
/// HIPAR channelBandwidth/Selects the channel bandwidth. The value must not exceed the operating
/// HIPAR channelBandwidth/channel bandwidth.
/// HIPAR rate/This control selects rate for respective frame type.
/// HIPAR guardInterval/Long or short guard interval, only relevant for DSSS.
/// HIPAR ltfType/Long or short guard interval, only relevant for DSSS.
/// HIPAR peDuration/Additional receive processing time of x s signaled in packet
/// HIPAR peDuration/extension (PE) field (only for IEEE 802.11ax).
/// HIPAR codingType/Selects the coding type.
/// HIPAR streams/Number of streams.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataFrameExtended(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean userDefined,
                            ViInt32   frameFormat,
                            ViInt32   channelBandwidth,
                            ViInt32   rate,
                            ViInt32   guardInterval,
                            ViInt32   ltfType,
                            ViInt32   peDuration,
                            ViInt32   codingType,
                            ViInt32   streams)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  station = 1;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, frameFormat, RSCMWWLS_VAL_FRAME_FORMAT_NHT, RSCMWWLS_VAL_FRAME_FORMAT_HEM),
            4, "Frame Format");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channelBandwidth, RSCMWWLS_VAL_BANDWIDTH_20_MHZ, RSCMWWLS_VAL_BANDWIDTH_160_MHZ),
            5, "Channel Bandwidth");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, rate, RSCMWWLS_VAL_RATE_DSSS_1M, RSCMWWLS_VAL_RATE_MCS15),
            6, "Rate");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, guardInterval, RSCMWWLS_VAL_GUARD_INTERVAL_SHORT, RSCMWWLS_VAL_GUARD_INTERVAL_GI32),
            7, "Guard Interval");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, ltfType, RSCMWWLS_VAL_LTF_X1, RSCMWWLS_VAL_LTF_X4),
            8, "LFT Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, peDuration, RSCMWWLS_VAL_PE_DURATION_AUTO, RSCMWWLS_VAL_PE_DURATION_PE16),
            9, "PE Duration");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codingType, RSCMWWLS_CODING_TYPE_LDPC, RSCMWWLS_CODING_TYPE_BCC),
            10, "Coding Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, streams, RSCMWWLS_VAL_STREAM1, RSCMWWLS_VAL_STREAM2),
            11, "Streams");

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_DATA_FRAME_SELECTED_STATION, &station));
    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:STA%ld:CONN:DFD %s,%s,%s,%s,%s,%s,%s,%s,%s", instance, station,
             stateArr[userDefined ? 1 : 0],
             frameFormatArr[frameFormat],
             channelBandwidthArr[channelBandwidth],
             rateArr[rate],
             guardIntervalArr[guardInterval],
             ltfTypeArr[ltfType],
             peDurationArr[peDuration],
             codingTypeArr[codingType],
             streamArr[streams]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets 8-bit indices for resource unit (RU) allocation for the selected
/// HIFN  channel. The <Subfield> parameter specifies the number of RUs, their
/// HIFN  position and size.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR channel/Channel number.
/// HIPAR subfield/Specifies the number of RUs, their position and size.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataHEMUFrameRUAllocationSubfield(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channel,
                            ViInt32   subfield)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  station = 1;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, 4),
            3, "Channel");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, subfield, RSCMWWLS_VAL_SUBFIELD_A000, RSCMWWLS_VAL_SUBFIELD_A224),
            4, "Subfield");

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_DATA_FRAME_SELECTED_STATION, &station));
    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:STA%ld:DFR:HEMU:ALSF CHA%ld,%s", instance, station,
             channel, subfieldArr[subfield]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures allocations for specified channel and resource unit (RU).
/// HIFN  Maps a user to the RU, sets the size of allocation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR channel/Channel number.
/// HIPAR resourceUnit/Resource unit selection.
/// HIPAR userMapping/User mapping for to the corresponding RU.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataHEMUFrameRUAllocation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channel,
                            ViInt32   resourceUnit,
                            ViInt32   userMapping)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  station = 1;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, 4),
            3, "Channel");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, resourceUnit, RSCMWWLS_VAL_RU1, RSCMWWLS_VAL_RU9),
            4, "Resource unit");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, userMapping, RSCMWWLS_VAL_USER_MAPPING_OFF, RSCMWWLS_VAL_USER_MAPPING_DMY3),
            4, "User Mapping");

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_DATA_FRAME_SELECTED_STATION, &station));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:STA%ld:DFR:HEMU:RUAL CHA%ld,RU%ld,%s", instance, station,
             channel, resourceUnit, userMappingArr[userMapping]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the allocation state and size of an entire 20MHz block for the
/// HIFN  specified channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR channel/Channel number.
/// HIPAR arraySize/Size allocated for output arrays.
/// HIPAR userMapping/User mapping for to the corresponding RU. Array of 9 values, <RU1> to
/// HIPAR userMapping/<RU9>.
/// HIPAR size/RU size. Array of 9 values, <Size1> to <Size9>.
/// HIPAR returnedValues/Number of values returned from instrument.
ViStatus _VI_FUNC rscmwwls_QueryConnectionDataHEMUFrameRUAllocation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channel,
                            ViInt32   arraySize,
                            ViInt32   userMapping[],
                            ViInt32   size[],
                            ViInt32*  returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;
    ViInt32  station = 1;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, 4),
            3, "Channel");

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_DATA_FRAME_SELECTED_STATION, &station));
    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:STA%ld:DFR:HEMU:BLAL? CHA%ld", instance, station, channel);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwls_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");

    while (ext_buf != NULL && i < arraySize)
    {
        userMapping[i] = RsCore_FindStringIndex(userMappingArr, p2buf);
        p2buf = strtok(NULL, ",");
        size[i++] = RsCore_FindStringIndex(sizeArr, p2buf);
        p2buf = strtok(NULL, ",");
    }

    *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures user data assigned to the DUT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR user/User nr.
/// HIPAR mcs/Sets the modulation and coding scheme for user 1 (user data assigned
/// HIPAR mcs/to the DUT).
/// HIPAR codingType/Selects the coding type related to a user for HE MU PPDU.
/// HIPAR streams/Sets the number of streams used by the user for MIMO connections.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataHEMUFrameUser(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   user,
                            ViInt32   mcs,
                            ViInt32   codingType,
                            ViInt32   streams)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, user, 1, 1),
            3, "User");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,user%ld", instance, user);

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_DATA_HEMU_FRAME_USER_MCS, mcs),
            4, "MCS");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_DATA_HEMU_FRAME_USER_CODING_TYPE, codingType),
            5, "Coding Type");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_DATA_HEMU_FRAME_USER_STREAMS, streams),
            6, "Streams");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures allocations for the user in HE MU PPDU. Maps the user to a
/// HIFN  resource unit (RU).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR user/User nr.
/// HIPAR channel/Channel number.
/// HIPAR resourceUnit/Resource unit selection.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataHEMUFrameUserAllocation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   user,
                            ViInt32   channel,
                            ViInt32   resourceUnit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  station = 1;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, user, 1, 1),
            3, "User");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, 4),
            4, "Channel");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, resourceUnit, RSCMWWLS_VAL_RU1, RSCMWWLS_VAL_RU9),
            5, "Resource unit");

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_DATA_FRAME_SELECTED_STATION, &station));
    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:STA%ld:DFR:HEMU:USER%ld:ALL CHA%ld,RU%ld", instance, station,
             user, channel, resourceUnit);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the modulation and coding scheme for the corresponding dummy
/// HIFN  user.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mcs/Sets the modulation and coding scheme for user 1 (user data assigned
/// HIPAR mcs/to the DUT).
/// HIPAR instance/No. of generator firmware application.
/// HIPAR user/Dummy user nr.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataHEMUFrameDummyUserMCS(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   user,
                            ViInt32   mcs)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, user, 1, 3),
            3, "User");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,user%ld", instance, user);

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_DATA_HEMU_FRAME_DUMMY_USER_MCS, mcs),
            4, "MCS");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures allocations for specified channel and resource unit (RU). Maps a user to the
/// HIFN  RU, sets the size of allocation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR CH20Index/Sets the CH20 index
/// HIPAR resourceUnitIndex/Sets the resource unit index
/// HIPAR allocState/User mapping for to the selected RU
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDataHEMUFrameResourceUnitAllocation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   CH20Index,
                            ViInt32   resourceUnitIndex,
                            ViInt32   allocState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   params[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, CH20Index, 1, 4),
            3, "CH20 Index");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, resourceUnitIndex, 1, 9),
            4, "Resource Unit Index");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, allocState, 0, 4),
            5, "Alloc State");

    snprintf(params, RS_MAX_MESSAGE_BUF_SIZE, "CHA%ld,RU%ld,%s", CH20Index, resourceUnitIndex, userMappingArr[allocState]);

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_DATA_HEMU_FRAME_RU_ALLOCATION, params));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the DTIM (Delivery Traffic Indication Message) period.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR DTIMPeriod/Sets the number of beacon intervals between successive DTIMs.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionDTIMPeriod(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   DTIMPeriod)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_CONNECTION_DTIM_PERIOD, DTIMPeriod),
            3, "DTIM Period");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Security
 * Purpose:  Enables and configures the connection security - mode,
 *           encryption type and passphrase.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionSecurity(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   mode,
                                                       ViInt32   encryptionType,
                                                       ViString  passphrase)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar*  p2securityType;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, mode, RSCMWWLS_VAL_SECURITY_TYPE_DISABLED, RSCMWWLS_VAL_SECURITY_TYPE_WPA3_ENTERPRISE),
            3, "Mode");

    checkErr(RsCore_FindRangeTableDiscreteCmdString(instrSession, &rscmwwls_rngSecurityType, mode, &p2securityType));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:SEC:PASS %s,'%s'", instance
             , p2securityType
             , passphrase
    );
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_SECURITY_ENCRYPTION, encryptionType),
            4, "Encryption Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Selects the WLAN security mechanism to be used and defines the last
/// HIFN  character of the passphrase for WPA/WPA2/WPA3 personal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR securityType/Selects the security type.
/// HIPAR lastPassphraseCharacter/Last passphrase character as string
/// HIPAR instance/No. of generator firmware application.
ViStatus _VI_FUNC rscmwwls_ConfigureSecurityMode(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32   securityType,
                                                 ViString  lastPassphraseCharacter)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar*  p2securityTypeString;
    ViChar   param[RS_MAX_MESSAGE_LEN] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &rscmwwls_rngSecurityType, securityType, &p2securityTypeString),
        3, "Security Type");

    snprintf(param, RS_MAX_MESSAGE_LEN, "%s,\"%s\"", p2securityTypeString, lastPassphraseCharacter);

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_HIDDEN_SECURITY_MODE, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects, whether the protection management frames are unsupported,
/// HIFN  supported or required. Applies to WPA2, WPA3 in AP operation mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR protectionManagmentFrames/Selects, whether the protection management frames are unsupported,
/// HIPAR protectionManagmentFrames/supported or required. Applies to WPA2, WPA3 in AP operation mode.
ViStatus _VI_FUNC rscmwwls_ConfigureSecurityProtectionManagmentFrames(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   protectionManagmentFrames)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_PROTECTION_MANAGMENT_FRAMES, protectionManagmentFrames),
            3, "Protection Managment Frames");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Selects authentication and key management mechanism supported by the
/// HIFN  R&S CMW.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR saeAuthentication/Selects authentication and key management mechanism supported by the
/// HIPAR saeAuthentication/R&S CMW.
ViStatus _VI_FUNC rscmwwls_ConfigureSecuritySAEAuthentication(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   saeAuthentication)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_SAE_AUTHENTICATION, saeAuthentication),
            3, "SAE Authentification");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Specifies the group transform for WPA3 personal security mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function. The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR groupTransform/Specifies the group transform for WPA3 personal security mode.
ViStatus _VI_FUNC rscmwwls_ConfigureSecurityGroupTransform(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   groupTransform)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_GROUP_TRANSFORM, groupTransform),
            3, "Group Transform");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the private security key for WPA3 personal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR keyMode/Selects the mode for private key assignment.
/// HIPAR privateSecurityKey/Sets private security key. Only when Fixed mode is seleted.
ViStatus _VI_FUNC rscmwwls_ConfigureSecurityPrivateKey(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   keyMode,
                                                       ViString  privateSecurityKey)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar*  p2keyModeString;
    ViChar   param[RS_MAX_MESSAGE_LEN] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_FindRangeTableDiscreteCmdString(instrSession, &rscmwwls_rngKeyMode, keyMode, &p2keyModeString),
        3, "Key Mode");

    if(keyMode == RSCMWWLS_VAL_KEY_MODE_RANDOM)
        snprintf(param, RS_MAX_MESSAGE_LEN, "%s", p2keyModeString);
    else
        snprintf(param, RS_MAX_MESSAGE_LEN, "%s,\"%s\"", p2keyModeString, privateSecurityKey);

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_HIDDEN_PRIVATE_SECURITY_KEY, param));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines whether an internal or external RADIUS server shall be used in
/// HIFN  WPA/WPA2.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR mode/Defines whether an internal or external RADIUS server shall be used in
/// HIPAR mode/WPA/WPA2.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionSecurityRadiusServerMode(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   mode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_SECURITY_RSERVER_MODE, mode),
            3, "Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Security Radius Server
 * Purpose:  Defines connection parameters for the RADIUS server and the
 *           shared secret the RADIUS server uses to obfuscate passwords.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionSecurityRadiusServer(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViString  IPAddress,
                            ViInt32   portNumber,
                            ViString  sharedKey)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViChar   addr[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    strncpy(addr, IPAddress, RS_MAX_MESSAGE_BUF_SIZE);

    do
    {
        p2buf = strchr(addr, '.');
        if (p2buf != NULL)
            *p2buf = ',';
    }
    while (p2buf != NULL);

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:SEC:RSER:ICON %s", instance, addr);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_SECURITY_RSERVER_PORT_NUMBER, portNumber),
            4, "Port Number");

    viCheckParm(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_SECURITY_RSERVER_SKEY, sharedKey),
            5, "Shared Key");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Security EAP-SIM Radius Server
 * Purpose:  Defines the triplets for the EAP-SIM authentication in the
 *           internal radius server.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionSecurityEAPSIMRadiusServer(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   tones,
                            ViString  rand,
                            ViString  SRES,
                            ViString  KC)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, tones, RSCMWWLS_VAL_TONE_ONE, RSCMWWLS_VAL_TONE_THREE),
            2, "Tones");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:SEC:ESIM:%s '%s', '%s', '%s'",
             instance, tonesArr[tones], rand, SRES, KC);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Security EAP-AKA Radius Server
 * Purpose:  Defines keys and authentication algorithm for EAP-AKA on the
 *           internal RADIUS Server.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionSecurityEAPAKARadiusServer(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViString  ki,
                            ViString  opc,
                            ViString  rand,
                            ViInt32   algorithm)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, algorithm, RSCMWWLS_VAL_ALGORITHM_MILENAGE, RSCMWWLS_VAL_ALGORITHM_XOR),
            2, "Algorithm");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:SEC:EAKA:KALG '%s','%s','%s', %s",
             instance, ki, opc, rand, algorithmArr[algorithm]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection IP Version Support
 * Purpose:  Defines the required IP version support.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionIPVersionSupport(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   IPVersionSupport)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_IP_VERSION_SUPPORT, IPVersionSupport),
            3, "IP Version Support");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Indicates to the receiver whether the frequency-domain smoothing is
/// HIFN  recommended for channel estimation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR htSmoothing/Indicates to the receiver whether the frequency-domain smoothing is
/// HIPAR htSmoothing/recommended for channel estimation.
/// HIPAR instance/No. of generator firmware application.
ViStatus _VI_FUNC rscmwwls_ConfigureHTSmoothing(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32   htSmoothing)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_HT_SMOOTHING, htSmoothing),
            3, "HT Smoothing");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Connection Mode
 * Purpose:  In station mode (see RSCMWWLS_ATTR_CONNECTION_OPERATION_MODE)
 *           this determines the connection mode of the R&S CMW.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionMode(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   connectionMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_CONNECTION_MODE, connectionMode),
            3, "Connection Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure SSID Connection
 * Purpose:  In station mode (see RSCMWWLS_ATTR_CONNECTION_OPERATION_MODE)
 *           this determines the WLANs the R&S CMW is allowed to connect to.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureSSIDConnection(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   SSIDConnection)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_SSID_CONNECTION, SSIDConnection),
            3, "SSID Connection");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines basic parameters of the Hotspot 2.0 operation mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR accessNetworkType/This control selects the Access Network Type.
/// HIPAR venueGroup/Sets the venue group.
/// HIPAR venueType/Downlink speed in bits per second.
/// HIPAR hessid/Homogeneous Extended Service Set Identifier.
/// HIPAR venueName/Venue name.
/// HIPAR mcc/Mobile Country Code.
/// HIPAR mcc/Mobile Network Code.
/// HIPAR domainName/Domain name of the network operator
/// HIPAR operatorFriendlyName/Friendly name of the network operator
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHotspotBasic(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   accessNetworkType,
                                                           ViInt32   venueGroup,
                                                           ViInt32   venueType,
                                                           ViString  hessid,
                                                           ViString  venueName,
                                                           ViString  mcc,
                                                           ViString  mnc,
                                                           ViString  domainName,
                                                           ViString  operatorFriendlyName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, accessNetworkType, RSCMWWLS_VAL_NETWORK_TYPE_PNET, RSCMWWLS_VAL_NETWORK_TYPE_WILD),
            3, "Access Network Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, venueGroup, RSCMWWLS_VAL_VENUE_GROUP_UNSP, RSCMWWLS_VAL_VENUE_GROUP_OUTD),
            4, "Venue Group");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, venueType, 0, 255),
            5, "Venue Type");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:HOTS:HSP %s,%s,%ld,#H%s,'%s',%s,%s,'%s','%s'",
             instance, networkTypeArr[accessNetworkType], venueGroupArr[venueGroup],
             venueType, hessid, venueName, mcc, mnc,
             domainName, operatorFriendlyName);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines basic parameters of the Hotspot 2.0 operation mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR downlinkSpeed/Downlink speed in bits per second.
/// HIPAR uplinkSpeed/Uplink speed in bits per second.
/// HIPAR ipV6AddressField/This control selects the availability of an IPv6 address field.
/// HIPAR ipV4AddressField/This control selects the availability of an IPv6 address field.
/// HIPAR realmName/Realm name.
/// HIPAR eapType/Sets the Extensible Authorization Protocol type.
/// HIPAR internetAccess/Specifies whether this hotspot provides Internet access.
/// HIPAR networkAuthentication/Sets the network authentication type indication.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHotspotSuplement(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   downlinkSpeed,
                            ViInt32   uplinkSpeed,
                            ViInt32   ipV6AddressField,
                            ViInt32   ipV4AddressField,
                            ViString  realmName,
                            ViInt32   eapType,
                            ViBoolean internetAccess,
                            ViInt32   networkAuthentication)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, downlinkSpeed, 0, 300000),
            3, "Downlink Speed");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, uplinkSpeed, 0, 300000),
            4, "Uplink Speed");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, ipV6AddressField, RSCMWWLS_VAL_IPV6_AVAILABILITY_ATN, RSCMWWLS_VAL_IPV6_AVAILABILITY_AATN),
            5, "Ip V6 Address Field");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, ipV4AddressField, RSCMWWLS_VAL_IPV4_AVAILABILITY_ATN, RSCMWWLS_VAL_IPV4_AVAILABILITY_AATN),
            6, "Ip V4 Address Field");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, eapType, RSCMWWLS_VAL_EAP_TYPE_SIM, RSCMWWLS_VAL_EAP_TYPE_TLS),
            8, "EAP Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, networkAuthentication, RSCMWWLS_VAL_NETWORK_AUTHENTICATION_ATC, RSCMWWLS_VAL_NETWORK_AUTHENTICATION_DRED),
            10, "Network Authentication");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:HOTS:HSSP %ld,%ld,%s,%s,'%s',%s,%s,%s",
             instance, downlinkSpeed, uplinkSpeed, ipV6AddressFieldArr[ipV6AddressField],
             ipV4AddressFieldArr[ipV4AddressField], realmName, eapTypeArr[eapType],
             switchArr[internetAccess], networkAuthenticationArr[networkAuthentication]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the length of the Mobile Network Code in Hotspot 2.0 operation
/// HIFN  mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR numberOfDigits/This control defines the length of the Mobile Network Code.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHotspotNumberOfDigit(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   numberOfDigits)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_CONNECTION_HOTSPOT_NUMBER_OF_DIGITS, numberOfDigits),
            3, "Number Of Digits");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the domain name list in Hotspot 2.0 operation mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR listItem/List item no.
/// HIPAR state/Removes or adds the related item to the list.
/// HIPAR domainName/Sets domain name.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHotspotDomainName(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   listItem,
                            ViBoolean state,
                            ViString  domainName)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, listItem, 1, 5),
            3, "List Item");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:HOTS:DNAM%ld %s,\"%s\"", instance, listItem, switchArr[state], domainName);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the PLMN list in Hotspot 2.0 operation mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR listItem/List item no.
/// HIPAR state/Removes or adds the related item to the list.
/// HIPAR mcc/Mobile country code.
/// HIPAR mnc/Mobile network code.
/// HIPAR mncLength/Length of the MNC.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHotspotPLMN(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   listItem,
                                                          ViBoolean state,
                                                          ViInt32   mcc,
                                                          ViInt32   mnc,
                                                          ViInt32   mncLength)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, listItem, 1, 5),
            3, "List Item");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, mncLength, RSCMWWLS_VAL_DIGITS_TWO, RSCMWWLS_VAL_DIGITS_THREE),
            7, "MNC Length");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:HOTS:PLMN%ld %s,%ld,%ld,%s",
            instance, listItem, switchArr[state], mcc, mnc, mncLengthArr[mncLength]);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the realm list in Hotspot 2.0 operation mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR listItem/List item no.
/// HIPAR state/Removes or adds the related item to the list.
/// HIPAR realmName/Realm name.
/// HIPAR sim/The related realm supports EAP-SIM.
/// HIPAR tls/The related realm supports EAP-TLS.
/// HIPAR ttls/The related realm supports EAP-TTLS.
/// HIPAR aka/The related realm supports EAP-AKA.
/// HIPAR akaPrime/The related realm supports EAP-AKA Prime.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHotspotRealmName(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   listItem,
                            ViBoolean state,
                            ViString  realmName,
                            ViBoolean sim,
                            ViBoolean tls,
                            ViBoolean ttls,
                            ViBoolean aka,
                            ViBoolean akaPrime)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, listItem, 1, 5),
            3, "List Item");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:HOTS:REAL%ld %s,\"%s\",%s,%s,%s,%s,%s", instance, listItem, switchArr[state],
             realmName, switchArr[sim], switchArr[tls], switchArr[ttls], switchArr[aka], switchArr[akaPrime]);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Configures the contents of the BSS load element.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR stationCount/Number of stations that are currently associated with the BSS.
/// HIPAR channelUtilization/Percentage of time, that the access point sensed the primary
/// HIPAR channelUtilization/channel was busy.
/// HIPAR admissionCapacity/Remaining time available via explicit admission control, in
/// HIPAR admissionCapacity/units of 32 �s/s.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHotspotBSSLoadElement(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   stationCount,
                            ViInt32   channelUtilization,
                            ViInt32   admissionCapacity)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, stationCount, 1, 65535),
            3, "Station Count");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channelUtilization, 0, 100),
            4, "Channel Utilization");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, admissionCapacity, 0, 31250),
            5, "Admission Capacity");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:HOTS:CUT %ld,%ld,%ld", instance, stationCount, channelUtilization, admissionCapacity);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures aggregate MPDUs (A-MPDU).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR enable/Enables/ disables the A-MPDUs.
/// HIPAR multiTID/Enables/ disables multi-TID A-MPDU
/// HIPAR maxLength/The maximal length of A-MPDU subframe.
ViStatus _VI_FUNC rscmwwls_ConfigureAMPDU(ViSession instrSession,
                                          ViInt32   instance,
                                          ViBoolean enable,
                                          ViBoolean multiTID,
                                          ViInt32   maxLength)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  station = 1;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, maxLength, 50, 131071),
            5, "Max Length");

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_DATA_FRAME_SELECTED_STATION, &station));
    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:STA%ld:CONN:AMPD %s,%s,%ld", instance, station,
             disableEnableArr[enable], disableEnableArr[multiTID], maxLength);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables/ disables broadcast target wake time (TWT) operation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR enabled/Enables/ disables broadcast target wake time (TWT) operation.
ViStatus _VI_FUNC rscmwwls_ConfigureBroadcastTWTState(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViBoolean enabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_TWT_BROADCAST_ENABLE, enabled),
            3, "Enabled");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures Flow ID.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR flowID/Flow ID number.
/// HIPAR enabled/Enables/disables particular schedule period.
/// HIPAR flowType/Specifies the broadcast TWT flow type for the specified schedule
/// HIPAR flowType/period.
/// HIPAR startTime/Specifies the offset of the specified schedule period from beacon.
/// HIPAR triggerEnabled/Enables/disables the broadcast TWT trigger for the specified schedule
/// HIPAR triggerEnabled/period.
ViStatus _VI_FUNC rscmwwls_ConfigureBroadcastTWTFlowID(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   flowID,
                                                       ViBoolean enabled,
                                                       ViInt32   flowType,
                                                       ViReal64  startTime,
                                                       ViBoolean triggerEnabled)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, flowType, RSCMWWLS_VAL_FLOW_TYPE_ANNOUNCED, RSCMWWLS_VAL_FLOW_TYPE_UNANNOUNCED),
            3, "Flow Type");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:BTWT:SCH:ENAB %ld,%s", instance,
             flowID, switchArr[enabled]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:BTWT:SCH:FTYP %ld,%s", instance,
             flowID, flowTypeArr[flowType]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:BTWT:SCH:STIM %ld,%lf", instance,
             flowID, startTime);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:BTWT:SCH:TEN %ld,%s", instance,
             flowID, switchArr[triggerEnabled]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specifies the minimum wake duration for the specified scheduled period.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR flowID/Specifies the Flow ID
/// HIPAR minimumWakeDuration/Specifies the minimum wake duration for the specified scheduled period.
ViStatus _VI_FUNC rscmwwls_ConfigureBroadcastTWTMinimumWakeDuration(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   flowID,
                            ViReal64  minimumWakeDuration)
{
    ViStatus error = VI_SUCCESS;
    ViChar   params[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    snprintf(params, RS_MAX_MESSAGE_BUF_SIZE, "%ld,%lf", flowID, minimumWakeDuration);

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_TWT_MINIMUM_WAKE_DURATION, params));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Indicates, whether the R&S CMW supports the buffer status report (BSR).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR BSRSupport/Indicates, whether the R&S CMW supports the buffer status report (BSR).
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionHEMACBSRSupport(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean BSRSupport)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_HEMAC_BSR_SUPPORT, BSRSupport),
            3, "BSR Support");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables you to associate an 802.11b device using 802.11ac or ax standard. Also, it
/// HIFN  enables you to use non-HT management frames within 802.11ac and ax.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR supportDSSS/Enables you to associate an 802.11b device using 802.11ac or ax standard.
/// HIPAR supportDSSS/Also, it enables you to use non-HT management frames within 802.11ac and ax.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionSupportDSSS(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViBoolean supportDSSS)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_SUPPORT_DSSS, supportDSSS),
            3, "Support DSSS");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines basic parameters of the Hotspot 2.0 operation mode.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR parameterSet/This control selects the parameter set.
/// HIPAR accessCategory/Selects the category.
/// HIPAR aifsn/Arbitration inter-frame space number.
/// HIPAR minContentionWindow/Minimal contention window.
/// HIPAR maxContentionWindow/Maximal contention window.
/// HIPAR txOpportunityLimit/Traffic opportunity limit.
ViStatus _VI_FUNC rscmwwls_ConfigureEDCA(ViSession instrSession,
                                         ViInt32   instance,
                                         ViInt32   parameterSet,
                                         ViInt32   accessCategory,
                                         ViInt32   aifsn,
                                         ViInt32   minContentionWindow,
                                         ViInt32   maxContentionWindow,
                                         ViInt32   txOpportunityLimit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, parameterSet, RSCMWWLS_VAL_EDCA, RSCMWWLS_VAL_MU_EDCA),
            3, "Parameter Set");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, accessCategory, RSCMWWLS_VAL_AC_BE, RSCMWWLS_VAL_AC_VO),
            4, "Access Category");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:%s:%s %ld,%ld,%ld,%ld", instance,
             parameterSetArr[parameterSet],
             accessCategoryArr[accessCategory],
             aifsn, minContentionWindow,
             maxContentionWindow, txOpportunityLimit);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the TID value to be used for the end-to-end connection using DAU.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR e2eData/Sets the TID value to be used for the end-to-end connection using DAU.
/// HIPAR per/Sets the TID value to be used for PER measurements.
/// HIPAR prioritizationMode/Prioritization mode selects the transmission sequence for packet
/// HIPAR prioritizationMode/generators.
ViStatus _VI_FUNC rscmwwls_ConfigureQOSTID(ViSession instrSession,
                                           ViInt32   instance,
                                           ViInt32   e2eData,
                                           ViInt32   per,
                                           ViInt32   prioritizationMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_QOS_TID_E2E_DATA, e2eData),
            3, "E2E Data");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_QOS_TID_PER, per),
            4, "PER");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_QOS_TID_PRIORITIZATION_MODE, prioritizationMode),
            5, "Prioritization Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets the method of block acknowledgment request (BAR).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR barMethod/Sets the method of block acknowledgment request (BAR).
/// HIPAR instance/No. of generator firmware application.
ViStatus _VI_FUNC rscmwwls_ConfigureQOSTIDBARMethod(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   barMethod)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld", instance);

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_QOS_TID_BAR_METHOD, barMethod),
            3, "Bar Method");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Enables/ disables broadcast target wake time (TWT) operation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR enabled/Enables/ disables a block ack session for the specified TID. Array of
/// HIPAR enabled/8 values.
ViStatus _VI_FUNC rscmwwls_ConfigureQOSTIDBlockAck(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViBoolean enabled[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  station = 1;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_QOS_TID_SELECTED_STATION, &station));
    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:STA%ld:CONN:QOS:BLAC %s,%s,%s,%s,%s,%s,%s,%s", instance, station,
             switchArr[enabled[0]], switchArr[enabled[1]],
             switchArr[enabled[2]], switchArr[enabled[3]],
             switchArr[enabled[4]], switchArr[enabled[5]],
             switchArr[enabled[6]], switchArr[enabled[7]]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specifies the trigger common info.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR triggerType/Specifies the trigger type as specified in the Common Info field.
/// HIPAR numberOfSymbols/Specifies the length of the HE TB PPDU.
/// HIPAR csRequired/Specifies, whether the check of medium status is required before
/// HIPAR csRequired/responding.
/// HIPAR bandwidth/Specifies the channel bandwidth of the HE TB PPDU.
/// HIPAR giLTF/Specifies the guard interval and LTF type of the HE TB PPDU.
/// HIPAR muMIMOLTF/Sets MU-MIMO long training fields (LTF).
/// HIPAR ldcpExtraSymbol/Specifies the support of LDPC extra symbol segment.
ViStatus _VI_FUNC rscmwwls_ConfigureTriggerFrameCommonInfo(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   triggerType,
                                                           ViInt32   numberOfSymbols,
                                                           ViBoolean csRequired,
                                                           ViInt32   bandwidth,
                                                           ViInt32   giLTF,
                                                           ViInt32   muMIMOLTF,
                                                           ViBoolean ldcpExtraSymbol)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_TRIGGER_TYPE, triggerType),
            3, "Trigger Type");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_NUMBER_OF_SYMBOLS, numberOfSymbols),
            4, "Number Of Symbols");

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_CS_REQUIRED, csRequired),
            5, "CS Required");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_BANDWIDTH, bandwidth),
            6, "Bandwidth");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_GI_LTF, giLTF),
            7, "GI LTF");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_MU_MIMO_LTF, muMIMOLTF),
            8, "MU MIMO LTF");

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_LDCP_EXTRA_SYMBOL, ldcpExtraSymbol),
            9, "LDCP Extra Symbol");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the power at which the R&S CMW transmits trigger frames.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR index/Tx Power index.
/// HIPAR value/Tx Power value in dBm.
ViStatus _VI_FUNC rscmwwls_QueryTriggerFrameAPTxPower(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32*  index,
                                                      ViReal64* value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViReal64 real64arr[2];
    ViInt32  returnedValues;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:HETF:APTX?", instance);
    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, 2, real64arr, &returnedValues));
    checkErr(rscmwwls_CheckStatus(instrSession));

    *index = (ViInt32)real64arr[0];
    *value = real64arr[1];

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Specifies the trigger frame user info.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR ruAllocation/Specifies the RU used by the HE TB PPDU.
/// HIPAR codingType/Specifies the coding used by the HE TB PPDU.
/// HIPAR mcs/Specifies the modulation and coding scheme (MCS) used by the HE TB
/// HIPAR mcs/PPDU.
/// HIPAR dcm/Specifies whether the HE TB response uses dual carrier modulation
/// HIPAR dcm/(DCM).
ViStatus _VI_FUNC rscmwwls_ConfigureTriggerFrameUserInfo(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   ruAllocation,
                                                         ViInt32   codingType,
                                                         ViInt32   mcs,
                                                         ViBoolean dcm)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_RU_ALLOCATION, ruAllocation),
            3, "RU Allocation");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_CODING_TYPE, codingType),
            4, "Coding Type");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_MCS, mcs),
            5, "MCS");

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_DCM, dcm),
            6, "DCM");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the spatial stream info.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR startingSpatialStream/Queries the starting spatial stream for the HE TB PPDU.
/// HIPAR numberOfSpatialStreams/Queries the number of HE TB PPDU spatial streams.
ViStatus _VI_FUNC rscmwwls_QueryTriggerFrameSpatialStream(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32*  startingSpatialStream,
                                                          ViInt32*  numberOfSpatialStreams)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_GetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_STARTING_SPATIAL_STREAM, startingSpatialStream),
            3, "Starting Spatial Stream");

    viCheckParm(rscmwwls_GetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_NUMBER_OF_SPATIAL_STREAMS, numberOfSpatialStreams),
            4, "Number Of Spatial Streams");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the trigger frame target RSSI.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mode/Specifies the trigger frame power control mode.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR control/Specifies the value Target RSSI Control for adjustment to the
/// HIPAR control/Target_RSSI. This parameter is only relevant in manual mode for target
/// HIPAR control/RSSI calculation.
ViStatus _VI_FUNC rscmwwls_ConfigureTriggerFrameTargetRSSI(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   mode,
                                                           ViReal64  control)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_TARGET_RSSI_MODE, mode),
            3, "mode");

    if (mode == RSCMWWLS_VAL_MODE_MANUAL)
    {
        viCheckParm(rscmwwls_SetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_TARGET_RSSI_CONTROL, control),
                4, "control");
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the expected Rx power of HE TB PPDU transmission as a response
/// HIFN  to trigger frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR index/Target RSSI index.
/// HIPAR value/Target_RSSI value in dBm.
ViStatus _VI_FUNC rscmwwls_QueryTriggerFrameTargetRSSI(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32*  index,
                                                       ViReal64* value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViReal64 real64arr[2];
    ViInt32  returnedValues;
    ViInt32  station = 1;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_TRIGGER_FRAME_SELECTED_STATION, &station));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:STA%ld:CONN:HETF:TRSS?", instance, station);
    checkErr(RsCore_QueryFloatArrayToUserBuffer(instrSession, cmd, 2, real64arr, &returnedValues));
    checkErr(rscmwwls_CheckStatus(instrSession));

    *index = (ViInt32)real64arr[0];
    *value = real64arr[1];

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Transmits the trigger frame once.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
ViStatus _VI_FUNC rscmwwls_TriggerFrameTransmissionSingleShot(
                            ViSession instrSession,
                            ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_TRANSMISSION_SINGLE_SHOT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures the periodical trigger frame transmission.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR enabled/Enables/disables the periodical trigger frame.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR periodicalInterval/Sets the interval for periodical trigger frame.
ViStatus _VI_FUNC rscmwwls_ConfigureTriggerFrameTransmissionPeriodical(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean enabled,
                            ViReal64  periodicalInterval)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_TRANSMISSION_PERIODICAL_ENABLED, enabled),
            3, "Enabled");

    viCheckParm(rscmwwls_SetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_FRAME_TRANSMISSION_PERIODICAL_INTERVAL, periodicalInterval),
            4, "Periodical Interval");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Enables/disables user-defined supported rates.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR state/Enables/disables user-defined supported rates.
ViStatus _VI_FUNC rscmwwls_ConfigureUserDefinedSupportedRatesState(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   state)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_USER_DEFINED_SUPPORTED_RATES, state),
            3, "State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Definition of DSSS/CCK supported rates for standards comprising 802.11b.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR state/Definition of DSSS/CCK supported rates for standards comprising 802.11b.
ViStatus _VI_FUNC rscmwwls_ConfigureUserDefinedDSSSSupportedRates(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   state[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  i = 0;
    ViChar*  p2buf = cmd;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:SRAT:DSSS ", instance);

    for (i = 0; i < 4; i++)
    {
        viCheckParm(RsCore_InvalidViInt32Range(instrSession, state[i], 0, 2),
                3, "State");
        p2buf += sprintf(p2buf, "%s,", rateStateArr[state[i]]);
    }

    *--p2buf = '\0';

    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Definition of OFDM supported rates for standards comprising 802.11a or 802.11g.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR state/Definition of OFDM supported rates for standards comprising 802.11a or 802.11g.
ViStatus _VI_FUNC rscmwwls_ConfigureUserDefinedOFDMSupportedRates(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   state[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  i = 0;
    ViChar*  p2buf = cmd;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:SRAT:OFDM ", instance);

    for (i = 0; i < 8; i++)
    {
        viCheckParm(RsCore_InvalidViInt32Range(instrSession, state[i], 0, 2),
                3, "State");
        p2buf += sprintf(p2buf, "%s,", rateStateArr[state[i]]);
    }

    *--p2buf = '\0';

    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Supported OFDM modulation and coding schemes (MCS) for standards
/// HIFN comprising 802.11n (20 MHz SISO).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR state/Supported OFDM modulation and coding schemes (MCS) for standards comprising 802.11n (20 MHz SISO).
ViStatus _VI_FUNC rscmwwls_ConfigureUserDefinedOFDMSupportedModulationSchemes(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   state[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViInt32  i = 0;
    ViChar*  p2buf = cmd;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    p2buf += snprintf(p2buf, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:CONN:SRAT:OMCS ", instance);

    for (i = 0; i < 8; i++)
    {
        viCheckParm(RsCore_InvalidViInt32Range(instrSession, state[i], 0, 1),
                3, "State");
        p2buf += sprintf(p2buf, "%s,", mcsStateArr[state[i]]);
    }

    *--p2buf = '\0';

    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Definition of supported OFDM VHT modulation and coding schemes (MCS).
/// HIFN  These settings apply only if user-defined supported rates are enabled
/// HIFN  with rscmwwls_ConfigureUserDefinedSupportedRatesState function.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR MCS/Definition of supported OFDM VHT modulation and coding schemes (MCS).
ViStatus _VI_FUNC rscmwwls_ConfigureUserDefinedVHTSupportedRates(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   MCS)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_USED_DEFINED_VHT_SUPPORTED_RATES, MCS),
            3, "MCS");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Selects the STA to which the NDP sounding applies. This parameter is visible,
/// HIFN if Multi STA is enabled.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR station/Selects the STA to which the NDP sounding applies. This parameter
/// HIPAR station/is visible, if Multi STA is enabled.
ViStatus _VI_FUNC rscmwwls_ConfigureNDPSoundingStation(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   station)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_NDP_SOUNDING_STATION, station),
            3, "Station");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures NDP sounding settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR feedbackMethod/Sets the feedback method for NDP sounding procedure.
/// HIPAR bandwidth/Selects the channel bandwidth for NDP sounding procedure.
/// HIPAR spatialStreams/Selects the number of spatial streams for NDP sounding procedure.
/// HIPAR GILTF/Selects the GI / LTF combination for NDP sounding procedure.
/// HIPAR reportType/Selects the report type for NDP sounding procedure. All types of
/// HIPAR reportType/feedback are returned via the HE Compressed Beamforming/CQI Frame.
/// HIPAR RUStartIndex/Specifies the 26-tone RU marking the beginning of the measured
/// HIPAR RUStartIndex/bandwidth (RU start index) for NDP sounding procedure.
/// HIPAR RUEndIndex/Specifies the last 26-tone RU to be measured (RU end index)
/// HIPAR RUEndIndex/during NDP sounding procedure.
/// HIPAR codebookSize/Sets the codebook size for HE TB sounding: 0 or 1.
/// HIPAR numberOfColumns/Sets the number of columns value Nc for HE TB sounding.
/// HIPAR subcarrierGrouping/Sets the subcarrier grouping value Ng for HE TB sounding.
ViStatus _VI_FUNC rscmwwls_ConfigureNDPSounding(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32   feedbackMethod,
                                                ViInt32   bandwidth,
                                                ViInt32   spatialStreams,
                                                ViInt32   GILTF,
                                                ViInt32   reportType,
                                                ViInt32   RUStartIndex,
                                                ViInt32   RUEndIndex,
                                                ViInt32   codebookSize,
                                                ViInt32   numberOfColumns,
                                                ViInt32   subcarrierGrouping)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_NDP_SOUNDING_FEEDBACK_METHOD, feedbackMethod),
            3, "Feedback Method");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_NDP_SOUNDING_BANDWIDTH, bandwidth),
            4, "Bandwidth");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_NDP_SOUNDING_SPATIAL_STREAMS, spatialStreams),
            5, "Spatial Streams");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_NDP_SOUNDING_GI_LTF, GILTF),
            6, "GILTF");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_NDP_SOUNDING_REPORT_TYPE, reportType),
            7, "Report Type");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_NDP_SOUNDING_RU_START_INDEX, RUStartIndex),
            8, "RU Start Index");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_NDP_SOUNDING_RU_END_INDEX, RUEndIndex),
            9, "RU End Index");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_NDP_SOUNDING_CODEBOOK_SIZE, codebookSize),
            10, "Codebook Size");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_NDP_SOUNDING_NUMBER_OF_COLUMNS, numberOfColumns),
            11, "Number Of Columns");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_NDP_SOUNDING_SUBCARRIER_GROUPING, subcarrierGrouping),
            12, "Subcarrier Grouping");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Triggers the single-shot transmission for NDP sounding procedure.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
ViStatus _VI_FUNC rscmwwls_NDPSoundingTransmissionSingleShot(ViSession instrSession,
                                                             ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_NDP_SOUNDING_TRANSMISSION_SINGLE_SHOT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures NDP sounding transmission.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR transmissionState/Switches on or off the periodic transmission for NDP sounding procedure.
/// HIPAR interval/Selects the periodic transmission interval for NDP sounding procedure.
ViStatus _VI_FUNC rscmwwls_ConfigureNDPSoundingTransmission(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViBoolean transmissionState,
                                                            ViReal64  interval)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_NDP_SOUNDING_TRANSMISSION_STATE, transmissionState),
            3, "Transmission State");

    viCheckParm(rscmwwls_SetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_NDP_SOUNDING_TRANSMISSION_INTERVAL, interval),
            4, "Interval");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Clean Event Log
 * Purpose:  Clears the event log.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_CleanEventLog(ViSession instrSession,
                                         ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_CLEAN_EVENT_LOG, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the fading module AWGN.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR enabled/Enables or disables AWGN insertion via the fading module.
/// HIPAR bandwidthRatio/Specifies the minimum ratio between the noise bandwidth and
/// HIPAR bandwidthRatio/the channel bandwidth.
/// HIPAR signalNoiseRatio/Specifies the signal to noise ratio for the AWGN inserted on
/// HIPAR signalNoiseRatio/the internal fading module.
ViStatus _VI_FUNC rscmwwls_ConfigureFadingModuleAWGN(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViBoolean enabled,
                                                     ViReal64  bandwidthRatio,
                                                     ViReal64  signalNoiseRatio)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_FADING_AWGN_ENABLED, enabled),
            3, "Enabled");

    viCheckParm(rscmwwls_SetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_FADING_AWGN_BANDWIDTH_RATIO, bandwidthRatio),
            4, "Bandwidth Ratio");

    viCheckParm(rscmwwls_SetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_FADING_AWGN_SIGNAL_NOISE_RATIO, signalNoiseRatio),
            5, "Signal Noise Ratio");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configureses the fading simulator settings.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR enabled/Enables/disables the fading simulator.
/// HIPAR profile/Selects a propagation condition profile for fading.
ViStatus _VI_FUNC rscmwwls_ConfigureFadingSimulator(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViBoolean enabled,
                                                    ViInt32   profile)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_FADING_SIMULATOR_ENABLED, enabled),
            3, "Enabled");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_FADING_SIMULATOR_PROFILE, profile),
            4, "Profile");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the insertion loss for the fading simulator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR insertionLoss/Gets the insertion loss for the fading simulator.
ViStatus _VI_FUNC rscmwwls_QueryFadingSimulatorInsertionLoss(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViReal64* insertionLoss)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_GetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_FADING_SIMULATOR_INSERTION_LOSS, insertionLoss),
            3, "Insertion Loss");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Trigger Settings
 * Purpose:  Set the general settings of the trigger.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureTriggerSettings(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   triggerType,
                                                    ViInt32   triggerSlope,
                                                    ViInt32   pulseLength,
                                                    ViReal64  value)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, triggerType, RSCMWWLS_VAL_TRIGGER_TX, RSCMWWLS_VAL_TRIGGER_RX),
            3, "Trigger Type");

    switch (triggerType)
    {
    case RSCMWWLS_VAL_TRIGGER_TX:

        viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_TX_TRIGGER_SLOPE, triggerSlope),
                3, "Trigger Slope");

        viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_TX_TRIGGER_PULSE_LENGTH, pulseLength),
                4, "Pulse Length");

        if (pulseLength == RSCMWWLS_VAL_PULSE_LENGTH_UDEF)
        {
            viCheckParm(rscmwwls_SetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_TX_TRIGGER_PULSE_LENGTH_VALUE, value),
                    5, "Value");
        }
        break;

    case RSCMWWLS_VAL_TRIGGER_RX:

        viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_RX_TRIGGER_SLOPE, triggerSlope),
                3, "Trigger Slope");

        viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_RX_TRIGGER_PULSE_LENGTH, pulseLength),
                4, "Pulse Length");

        if (pulseLength == RSCMWWLS_VAL_PULSE_LENGTH_UDEF)
        {
            viCheckParm(rscmwwls_SetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_RX_TRIGGER_PULSE_LENGTH_VALUE, value),
                    5, "Value");
        }
        break;

    default:
        viCheckParm(RsCore_InvalidViInt32Value(instrSession, triggerType), 3, "triggerType");
        break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Trigger Mode
 * Purpose:  Selects the mode (All Bursts/OFDM Bursts/DSSS/CCK Bursts) of the RX frame trigger pulses.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureTriggerMode(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32   triggerMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_TRIGGER_MODE, triggerMode),
            3, "Trigger Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines for which bandwidth of received bursts a trigger pulse is
/// HIFN  generated for the RX frame trigger signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR bandwidth/Defines for which bandwidth of received bursts a trigger pulse is
/// HIPAR bandwidth/generated for the RX frame trigger signal.
ViStatus _VI_FUNC rscmwwls_ConfigureRXTriggerBandwidth(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   bandwidth)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_RX_TRIGGER_BANDWIDTH, bandwidth),
            3, "Bandwidth");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines for which rate of received bursts a trigger pulse is generated
/// HIFN  for the RX frame trigger signal.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR rate/Defines for which rate of received bursts a trigger pulse is generated
/// HIPAR rate/for the RX frame trigger signal.
ViStatus _VI_FUNC rscmwwls_ConfigureRXTriggerRate(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViInt32   rate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_RX_TRIGGER_RATE, rate),
            3, "Rate");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the trigger delay type burst (automatic configuration) or constant delay
/// HIFN  of 200 us for RX frame trigger, OFDM.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR delayType/Sets the trigger delay type burst (automatic configuration) or constant
/// HIPAR delayType/delay of 200 us for RX frame trigger, OFDM.
ViStatus _VI_FUNC rscmwwls_ConfigureRXTriggerDelayType(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   delayType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_RX_TRIGGER_DELAY_TYPE, delayType),
            3, "Delay Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Enables or disables the rate control of the DUT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR rateRestriction/Enables or disables the rate control of the DUT.
ViStatus _VI_FUNC rscmwwls_ConfigureRXTriggerRateRestriction(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViBoolean rateRestriction)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_RX_TRIGGER_RATE_RESTRICTION, rateRestriction),
            3, "Rate Restriction");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the spatial streams for RX frame trigger for MIMO connections.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR spatialStreams/
ViStatus _VI_FUNC rscmwwls_ConfigureRXTriggerSpatialStreams(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   spatialStreams)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_RX_TRIGGER_SPATIAL_STREAMS, spatialStreams),
            3, "Spatial Streams");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  For trigger mode OFDM Bursts and DSSS/CCK Bursts (see
/// HIFN  rscmwwls_ConfigureTriggerMode) this defines the number of symbols/bytes
/// HIFN  that need to be received before the trigger event is generated.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR mode/Select user defined to set the required <Length> manually.
/// HIPAR length/In user defined mode this defines the number of symbols/bytes
ViStatus _VI_FUNC rscmwwls_ConfigureTriggerMinLength(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32   mode,
                                                     ViInt32   length)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, mode, RSCMWWLS_VAL_TRIGGER_MIN_LENGTH_DEFAULT, RSCMWWLS_VAL_TRIGGER_MIN_LENGTH_USER),
            3, "Mode");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, length, 16, 1500),
            4, "Length");

    if (mode == RSCMWWLS_VAL_TRIGGER_MIN_LENGTH_DEFAULT)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "TRIG:WLAN:SIGN%ld:RX:MACF:MLEN DEF", instance);
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "TRIG:WLAN:SIGN%ld:RX:MACF:MLEN UDEF,%ld", instance, length);
    }
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Defines the minimum length for the all OFDM RX frame trigger modes
/// HIFN  (all modes except All Bursts and DSSS/CCK Bursts).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR mode/Select user defined to set the required <Length> manually.
/// HIPAR length/In user defined mode this defines the number of symbols/bytes
ViStatus _VI_FUNC rscmwwls_ConfigureTriggerOFDMMinLength(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   mode,
                                                         ViInt32   length)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, mode, RSCMWWLS_VAL_TRIGGER_MIN_LENGTH_DEFAULT, RSCMWWLS_VAL_TRIGGER_MIN_LENGTH_USER),
            3, "Mode");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, length, 16, 1500),
            4, "Length");

    if (mode == RSCMWWLS_VAL_TRIGGER_MIN_LENGTH_DEFAULT)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "TRIG:WLAN:SIGN%ld:RX:MACF:OFML DEF", instance);
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "TRIG:WLAN:SIGN%ld:RX:MACF:OFML UDEF,%ld", instance, length);
    }
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Defines the minimum length for the RX frame trigger mode DSSS/CCK
/// HIFN  Bursts.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR mode/Select user defined to set the required <Length> manually.
/// HIPAR length/In user defined mode this defines the number of symbols/bytes
ViStatus _VI_FUNC rscmwwls_ConfigureTriggerDSSMinLength(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   mode,
                                                        ViInt32   length)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, mode, RSCMWWLS_VAL_TRIGGER_MIN_LENGTH_DEFAULT, RSCMWWLS_VAL_TRIGGER_MIN_LENGTH_USER),
            3, "Mode");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, length, 16, 1500),
            4, "Length");

    if (mode == RSCMWWLS_VAL_TRIGGER_MIN_LENGTH_DEFAULT)
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "TRIG:WLAN:SIGN%ld:RX:MACF:DSML DEF", instance);
    }
    else
    {
        snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "TRIG:WLAN:SIGN%ld:RX:MACF:DSML UDEF,%ld", instance, length);
    }
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the parameters of the packet generator.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR state/Disables/enables the packet generator
/// HIPAR interval/The time interval between packet transmissions measured in time
/// HIPAR payloadType/The payload type of the generated; either the (implementation
/// HIPAR payloadSize/The size of the generated packets.
ViStatus _VI_FUNC rscmwwls_ConfigurePacketGenerator(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   index,
                                                    ViBoolean state,
                                                    ViInt32   interval,
                                                    ViInt32   payloadSize,
                                                    ViInt32   payloadType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViString payloadTypeArr[] = {"DEF", "AZER", "AON", "BP01", "BP10", "PRAN", NULL};

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, index, 1, 3),
            3, "Index");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, interval, 1, 10000),
            5, "interval");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, payloadSize, 0, 1472),
            6, "payloadSize");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, payloadType, RSCMWWLS_VAL_PAYLOAD_TYPE_DEFAULT, RSCMWWLS_VAL_PAYLOAD_TYPE_PSEUDO_RANDOM),
            7, "payloadType");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:PGEN%ld:CONF %s,%ld,%ld,%s",
            instance, index, switchArr[state], interval, payloadSize, payloadTypeArr[payloadType]);
    checkErr(RsCore_Write(instrSession, cmd));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Configure Packet Generator IP Version
/// HIFN Sets the IP version to be used for generating packets.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR IPVersion/Selects the version of IP address to query.
ViStatus _VI_FUNC rscmwwls_ConfigurePacketGeneratorIPVersion(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   index,
                                                             ViInt32   IPVersion)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, index, 1, 3),
            3, "Index");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,index%ld", instance, index);

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_PACKET_GENERATOR_IP_VERSION, IPVersion),
            4, "IP Version");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Configures the active protocol of the packet generator and
/// HIFN configures UDP source and destination ports.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR protocol/Sets the active protocol of the packet generator.
/// HIPAR UDPSourcePort/Defines source port for UDP protocol.
/// HIPAR UDPDestinationPort/Defines destination port for UDP protocol.
ViStatus _VI_FUNC rscmwwls_ConfigurePacketGeneratorProtocol(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   index,
                                                            ViInt32   protocol,
                                                            ViInt32   UDPSourcePort,
                                                            ViInt32   UDPDestinationPort)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, index, 1, 3),
            3, "Index");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,index%ld", instance, index);

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_PACKET_GENERATOR_PROTOCOL, protocol),
            4, "Protocol");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:PGEN%ld:UPOR %ld,%ld", instance,
             index, UDPSourcePort, UDPDestinationPort);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Specifies the STA to which the packets are addressed to. This parameter is
/// HIFN visible, if Multi STA is enabled.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR index/Generator index.
/// HIPAR destination/Specifies the STA to which the packets are addressed to.
/// HIPAR This parameter is visible, if Multi STA is enabled.
ViStatus _VI_FUNC rscmwwls_ConfigurePacketGeneratorDestination(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   index,
                            ViInt32   destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, index, 1, 3),
            3, "Index");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,index%ld", instance, index);

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_PACKET_GENERATOR_DESTINATION, destination),
            4, "Destination");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the connection status of the DUT for station two.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR secondState/Returns the connection status of the DUT for station two.
ViStatus _VI_FUNC rscmwwls_QuerySecondState(ViSession instrSession,
                                            ViInt32   instance,
                                            ViInt32*  secondState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_GetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_QUERY_SECOND_STATE, secondState),
            3, "Second State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the connection status of the DUT for station three.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR thirdState/Returns the connection status of the DUT for station three.
ViStatus _VI_FUNC rscmwwls_QueryThirdState(ViSession instrSession,
                                           ViInt32   instance,
                                           ViInt32*  thirdState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_GetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_QUERY_THIRD_STATE, thirdState),
            3, "Third State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query Packet Switched State
 * Purpose:  Returns the connection status of the DUT.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_QueryPacketSwitchedState(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32*  connectionStatus)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_GetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_QUERY_PACKET_SWITCHED_STATE, connectionStatus),
            3, "Connection Status");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the current state of the EAP connection in Hotspot 2.0
/// HIFN  operation mode
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR bufferSize/Sets the buffer size.
/// HIPAR state/Queries the current state of the EAP connection in Hotspot 2.0
/// HIPAR state/operation mode
/// HIPAR type/Authentication stage.
ViStatus _VI_FUNC rscmwwls_QueryEAPConnectionState(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   bufferSize,
                                                   ViChar    state[],
                                                   ViChar    type[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  ext_buf = NULL;
    ViChar*  ptoken;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:WLAN:SIGN%ld:SINF:EAPS?", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwls_CheckStatus(instrSession));

    ptoken = strtok(ext_buf, ",");
    if (ptoken != NULL)
    {
        memset(state, 0, bufferSize);
        strncpy(state, ptoken, bufferSize - 1);
    }
    ptoken = strtok(NULL, ",");
    if (ptoken != NULL)
    {
        memset(type, 0, bufferSize);
        strncpy(type, ptoken, bufferSize - 1);
    }

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Returns the SSID of the associated access point. The command is only relevant in operation mode "Station".
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR bufferSize/
/// HIPAR stationSSID/
ViStatus _VI_FUNC rscmwwls_QueryStationSSID(ViSession instrSession,
                                            ViInt32   instance,
                                            ViInt32   bufferSize,
                                            ViChar    stationSSID[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_QUERY_STATION_SSID,
            bufferSize, stationSSID),
            4, "Station SSID");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the Rx burst power and evaluates the quality of the RX signal
/// HIFN  from the connected DUT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR powerValue/Returns Rx burst power in dBm.
/// HIPAR powerIndicator/Evaluates the quality of the RX signal from the connected DUT.
ViStatus _VI_FUNC rscmwwls_QueryRXPowerIndicator(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32   antenna,
                                                 ViReal64* powerValue,
                                                 ViInt32*  powerIndicator)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   response[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,a%ld", instance, antenna);

    checkErr(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_QUERY_RX_POWER_INDICATOR,
        RS_MAX_MESSAGE_BUF_SIZE, response));

    p2buf = strtok(response, ",");
    *powerValue = RsCore_Convert_String_To_ViReal64(p2buf);

    p2buf = strtok(NULL, ",");
    *powerIndicator = RsCore_FindStringIndex(powerIndicatorArr, p2buf);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query UE Capability MAC Address
 * Purpose:  Queries the MAC address of an associated DUT.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_QueryUECapabilityMACAddress(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   bufferSize,
                                                       ViChar    MACAddress[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_QUERY_UE_CAPABILITY_MAC_ADDRESS,
            bufferSize, MACAddress),
            4, "MAC Address");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Reconnect
 * Purpose:  In station mode (see RSCMWWLS_ATTR_CONNECTION_OPERATION_MODE)
 *           this function requests to reestablish an association and has the
 *           same effect as a Disconnect, immediately followed by a Connect.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureReconnect(ViSession instrSession,
                                              ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_RECONNECT, NULL),
            3, "Connect");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the connection association - MAC address, disasociation, preemption and station priority.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR station/Selects repcap station.
/// HIPAR reservation/Specifies reservation
/// HIPAR reserveMACAddress/Specifies the Reserve MAC address.
/// HIPAR automaticDisassociationState/Enables or disables automatic STA disassociation.
/// HIPAR automaticDisassociation/Specifies the automatic STA disassociation timeout.
/// HIPAR allowPreemption/If enabled, then the existing association possible with any MAC addresses
/// HIPAR allowPreemption/is replaced by a new incoming one.
/// HIPAR stationPriority/Specifies how the stack prioritizes one STA over another in
/// HIPAR stationPriority/multi-STA connections.
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionAssociation(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   station,
                                                          ViInt32   reservation,
                                                          ViString  reserveMACAddress,
                                                          ViBoolean automaticDisassociationState,
                                                          ViInt32   automaticDisassociation,
                                                          ViBoolean allowPreemption,
                                                          ViInt32   stationPriority)
{
    ViStatus error = VI_SUCCESS;
    ViChar   params[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViString reservationArr[] = {"OFF", "ANY", "SET", NULL};

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, station, 1, 3),
            3, "Station");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, reservation, 0, 2),
            4, "Reservation");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, automaticDisassociation, 1, 3600),
            7, "Automatic Disassociation");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, stationPriority, 0, 1),
            9, "Station Priority");

    snprintf(params, RS_MAX_MESSAGE_BUF_SIZE, "%s,\"%s\"", reservationArr[reservation], reserveMACAddress);

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_ASSOCIATION_RESERVE_MAC_ADDRESS, params));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    snprintf(params, RS_MAX_MESSAGE_BUF_SIZE, "%s,%ld", automaticDisassociationState ? "ON" : "OFF", automaticDisassociation);

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_ASSOCIATION_AUTOMATIC_DISASSOCIATION, params));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_ASSOCIATION_ALLOW_PREEMPTION, allowPreemption),
            8, "Allow Preemption");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_ASSOCIATION_STATION_PRIORITY, stationPriority),
            9, "Station Priority");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures aggregate MPDUs (A-MPDU).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR station/Selects repcap station.
/// HIPAR TXEnable/Enables/ disables the A-MPDUs
/// HIPAR multiTID/Enables/ disables multi-TID A-MPDU
/// HIPAR maxLength/The maximal length of entire A-MPDU
ViStatus _VI_FUNC rscmwwls_ConfigureConnectionAMPDUSettings(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   station,
                                                            ViBoolean TXEnable,
                                                            ViBoolean multiTID,
                                                            ViInt32   maxLength)
{
    ViStatus error = VI_SUCCESS;
    ViChar   params[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, station, 1, 3),
            3, "Station");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,s%ld", instance, station);

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, maxLength, 50, 131071),
            6, "Max Length");

    snprintf(params, RS_MAX_MESSAGE_BUF_SIZE, "%s,%s,%ld", TXEnable ? "ENAB" : "DIS", multiTID ? "ENAB" : "DIS", maxLength);

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_AMPDU_TX_ENABLED, params));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Operation Mode
 * Purpose:  Selects the operation mode of the WLAN Signaling application.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureOperationMode(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViInt32   operationMode)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_CONNECTION_OPERATION_MODE, operationMode),
            3, "Operation Mode");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure Multi Station
 * Purpose:  Enables or disables the support of multi-station connection.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureMultiStation(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViBoolean multiStation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_CONNECTION_MULTI_STATION, multiStation),
            3, "Multi Station");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure AP Connection Settings
 * Purpose:  Define the upper layer IBSS properties of the AP.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigureAPConnectionSettings(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   standard,
                                                         ViInt32   beaconInterval,
                                                         ViString  MACAddress_BSSID,
                                                         ViString  SSID)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_CONNECTION_STANDARD, standard),
            3, "Standard");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_BEACON_INTERVAL, beaconInterval),
            4, "Beacon Interval");

    viCheckParm(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_BASIC_SERVICE_SET_IDENTIFIER, MACAddress_BSSID),
            5, "MAC Address BSSID");

    viCheckParm(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_SERVICE_SET_IDENTIFIER, SSID),
            6, "SSID");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query UE Capability MAC Version
 * Purpose:  Queries the MAC layer version of an attached DUT, indicating the
             supported WLAN standards
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_QueryUECapabilityMACVersion(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32*  MACVersion)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_GetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_QUERY_UE_CAPABILITY_MAC_VERSION, MACVersion),
            3, "MAC Version");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN If "Data End to End" is enabled, the DUT gets its IPv4 and IPv6
/// HIFN configuration from the DAU. This function queries the assigned
/// HIFN IPv4 address and IPv6 address prefix.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR bufferSize/Sets the buffer size.
/// HIPAR assignedIPAddress/assigned IPv4 address and IPv6 address prefix.
/// HIPAR IPVersion/Selects the version of IP address to query.
ViStatus _VI_FUNC rscmwwls_QueryUECapabilityAssignedAddress(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   IPVersion,
                                                            ViInt32   bufferSize,
                                                            ViChar    assignedIPAddress[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, IPVersion, RSCMWWLS_VAL_IPV4, RSCMWWLS_VAL_IPV6),
            3, "IPVersion");

    strcat(repCap, ",");
    strcat(repCap, ipVersionArr[IPVersion]);

    viCheckParm(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_QUERY_UE_ASSIGNED_IP_ADDRESS,
            bufferSize, assignedIPAddress),
            5, "Assigned IP Address");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the average power of the last burst received from the DUT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR rxBurstPower/Queries the average power of the last burst received from the DUT.
ViStatus _VI_FUNC rscmwwls_QueryUECapabilityRXBurstPower(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViReal64* rxBurstPower)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  station = 1;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_UE_CAPABILITY_SELECTED_STATION, &station));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,s%ld", instance, station);

    viCheckParm(rscmwwls_GetAttributeViReal64(instrSession, repCap, RSCMWWLS_ATTR_QUERY_UE_RX_BURST_POWER, rxBurstPower),
            3, "RX Burst Power");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries information related to the data rate of the DUT signal, for example the
/// HIFN  frame format, the modulation and coding scheme, the channel bandwidth and the number of
/// HIFN  spatial streams. The display of this information requires an SUA.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR frameFormat/Returns the frame format
/// HIPAR rate/Returns the data rate in Mbit/s or modulation and coding scheme.
/// HIPAR channelBandwidth/Returns the channel bandwidth.
/// HIPAR spatialStreams/Returns the number of spatial streams.
ViStatus _VI_FUNC rscmwwls_QueryUECapabilityDataRate(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32*  frameFormat,
                                                     ViInt32*  rate,
                                                     ViInt32*  channelBandwidth,
                                                     ViInt32*  spatialStreams)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  station = 1;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_UE_CAPABILITY_SELECTED_STATION, &station));
    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:WLAN:SIGN%ld:STA%ld:UES:DRAT?", instance, station);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwls_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    *frameFormat = RsCore_FindStringIndex(frameFormatDataRateArr, p2buf);

    p2buf = strtok(NULL, ",");
    *rate = RsCore_FindStringIndex(dataRateArr, p2buf);

    p2buf = strtok(NULL, ",");
    *channelBandwidth = RsCore_FindStringIndex(channelBandwidthArr, p2buf);

    p2buf = strtok(NULL, ",\n");
    *spatialStreams = RsCore_FindStringIndex(spatialStreamArr, p2buf);

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Indicates reported buffered data for a UE supporting a HE buffer
/// HIFN  status report (BSR) control field.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR total/Maximum of all reports received in preceding interval.
/// HIPAR bufferedDataTID/Maximum of all QoS control reports.
/// HIPAR tidx/Indication of TID, for which the buffer status Buffered Data TID is
/// HIPAR tidx/reported.
/// HIPAR bufferedDataAC/Maximum AC-specific queue size of all AC control reports.
/// HIPAR acx/Indication of access category (ACI bitmap subfield) for which the
/// HIPAR acx/buffer status Buffered Data AC is reported.
ViStatus _VI_FUNC rscmwwls_QueryUECapabilityBufferedData(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32*  total,
                                                         ViInt32*  bufferedDataTID,
                                                         ViInt32*  tidx,
                                                         ViInt32*  bufferedDataAC,
                                                         ViInt32*  acx)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  station = 1;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_UE_CAPABILITY_SELECTED_STATION, &station));
    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:WLAN:SIGN%ld:STA%ld:UES:ABSR?", instance, station);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwls_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    *total = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok(NULL, ",");
    *bufferedDataTID = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok(NULL, ",");
    *tidx = RsCore_FindStringIndex(tidXArr, p2buf);

    p2buf = strtok(NULL, ",");
    *bufferedDataAC = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok(NULL, ",\n");
    *acx = RsCore_FindStringIndex(accessCategoryArr, p2buf);

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the reported UE HE capabilities.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR deviceClass/Returns the device class for a non-AP STA.
/// HIPAR dynamicFragmentation/Returns the fragmentation support including supported level.
/// HIPAR aBSR/Returns the support of an asynchronous buffer status report (BSR) control field.
/// HIPAR broadcastTWT/Returns the support of broadcast target wake time (TWT) operation.
/// HIPAR OFDMARandomAccess/Returns the support of OFDMA random access procedure.
ViStatus _VI_FUNC rscmwwls_QueryUEHECapabilities(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32*  deviceClass,
                                                 ViInt32*  dynamicFragmentation,
                                                 ViInt32*  aBSR,
                                                 ViInt32*  broadcastTWT,
                                                 ViInt32*  OFDMARandomAccess)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  station = 1;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_UE_CAPABILITY_SELECTED_STATION, &station));
    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:WLAN:SIGN%ld:STA%ld:UEC:HE?", instance, station);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwls_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    *deviceClass = RsCore_FindStringIndex(deviceClassArr, p2buf);

    p2buf = strtok(NULL, ",");
    *dynamicFragmentation = RsCore_FindStringIndex(dynamicFragmentationArr, p2buf);

    p2buf = strtok(NULL, ",");
    *aBSR = RsCore_FindStringIndex(noYesArr, p2buf);

    p2buf = strtok(NULL, ",");
    *broadcastTWT = RsCore_FindStringIndex(noYesArr, p2buf);

    p2buf = strtok(NULL, ",\n");
    *OFDMARandomAccess = RsCore_FindStringIndex(noYesArr, p2buf);

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Configure IPv4 Settings
/// HIFN Configures the IPv4 parameters.
/// HIFN IPv4 address and IPv6 address prefix.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR IPAddressStack/Defines the IP address of the built-in IPv4 stack.
/// HIPAR IPAddressDestination/Specifies the IPv4 address of the WLAN DUT.
/// HIPAR subnetMask/Specifies the subnet mask of the built-in IPv4 stack.
/// HIPAR defaultGatway/Provides the IPv4 address of the default gateway to the built-in IPv4 stack.
/// HIPAR DNS/Provides the IPv4 address of a DNS server to the built-in IPv4 stack.
/// HIPAR DHCP/Enables or disables the built-in DHCP server.
ViStatus _VI_FUNC rscmwwls_ConfigureIPv4Settings(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViString  IPAddressStack,
                                                 ViString  IPAddressDestination,
                                                 ViString  subnetMask,
                                                 ViString  defaultGatway,
                                                 ViString  DNS,
                                                 ViBoolean DHCP)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViChar*  buffer = NULL;
    size_t   length = 0;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));
    length = (strlen(IPAddressStack) > strlen(IPAddressDestination)) ? strlen(IPAddressStack) : strlen(IPAddressDestination);
    length = (length > strlen(subnetMask)) ? length : strlen(subnetMask);
    length = (length > strlen(defaultGatway)) ? length : strlen(defaultGatway);
    length = (length > strlen(DNS)) ? length : strlen(DNS);

    buffer = (ViChar*)malloc(length + 1);
    strncpy(buffer, subnetMask, length + 1);

    do
    {
        p2buf = strchr(buffer, '.');
        if (p2buf != NULL)
            *p2buf = ',';
    }
    while (p2buf != NULL);

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:IPVF:STAT:SMAS %s", instance, buffer);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

    buffer[0] = '\0';

    strncpy(buffer, defaultGatway, length + 1);

    do
    {
        p2buf = strchr(buffer, '.');
        if (p2buf != NULL)
            *p2buf = ',';
    }
    while (p2buf != NULL);

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:IPVF:STAT:IPAD:GAT %s", instance, buffer);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

    buffer[0] = '\0';

    strncpy(buffer, DNS, length + 1);

    do
    {
        p2buf = strchr(buffer, '.');
        if (p2buf != NULL)
            *p2buf = ',';
    }
    while (p2buf != NULL);

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:IPVF:STAT:IPAD:DNS %s", instance, buffer);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_IP_VERSION_4_DHCP, DHCP),
            3, "DHCP");

Error:
    if (buffer) free(buffer);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Configures the the static IP V4 address of the R&S CMW. The setting is relevant for
/// HIFN instruments without a DAU.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR CMWIPAddress/Defines the static IP V4 address of the R&S CMW. The setting is
/// HIPAR CMWIPAddress/relevant for instruments without a DAU.
ViStatus _VI_FUNC rscmwwls_ConfigureIPv4CMWIPAddress(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViString  CMWIPAddress)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_IPV4_CMW, CMWIPAddress),
            3, "CMW IP Address");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Configures the static IP V4 address of the DUT. The setting is only relevant for access
/// HIFN point and instruments without a DAU.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR stationIPAddress/Defines the static IP V4 address of the DUT. The setting is
/// HIPAR stationIPAddress/only relevant for access point and instruments without a DAU.
ViStatus _VI_FUNC rscmwwls_ConfigureIPv4StationIPAddress(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViString  stationIPAddress)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_IPV4_IP_ADDRESS, stationIPAddress),
            3, "Station IP Address");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Configure IPv6 Settings
/// HIFN Defines the IPv6 prefix of the built-in IPv6 stack.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR prefix/Defines the IPv6 prefix of the built-in IPv6 stack.
ViStatus _VI_FUNC rscmwwls_ConfigureIPv6Settings(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViString  prefix)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_IP_VERSION_6_PREFIX, prefix),
            3, "Prefix");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Gets the MAC address of an associated DUT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR bufferSize/Size of output array.
/// HIPAR MACAddress/Gets the MAC address of an associated DUT.
ViStatus _VI_FUNC rscmwwls_QueryDUTUEMAC(ViSession instrSession,
                                         ViInt32   instance,
                                         ViInt32   bufferSize,
                                         ViChar    MACAddress[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  station = 1;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_DUT_SELECTED_STATION, &station));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,s%ld", instance, station);

    viCheckParm(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_DUT_UE_MAC,
            bufferSize, MACAddress),
            4, "MAC Address");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Gets the detected IPv4 / IPv6 addresses of the connected DUT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR IPVersion/Selects the version of IP address to query.
/// HIPAR bufferSize/Size of output array.
/// HIPAR IPAddress/Queries the detected IPv4 / IPv6 addresses of the connected DUT.
ViStatus _VI_FUNC rscmwwls_QueryDUTUEIPAddress(ViSession instrSession,
                                               ViInt32   instance,
                                               ViInt32   IPVersion,
                                               ViInt32   bufferSize,
                                               ViChar    IPAddress[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  station = 1;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_DUT_SELECTED_STATION, &station));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,s%ld", instance, station);

    switch (IPVersion)
    {
    case RSCMWWLS_VAL_IPV4:
        viCheckParm(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_DUT_UE_IP4_ADDRESS,
                bufferSize, IPAddress),
                5, "IP Address");
        break;
    case RSCMWWLS_VAL_IPV6:
        viCheckParm(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_DUT_UE_IP6_ADDRESS,
                bufferSize, IPAddress),
                5, "IP Address");
        break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Gets the IP address of the R&S CMW.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR IPVersion/Selects the version of IP address to query.
/// HIPAR bufferSize/Sets the buffer size.
/// HIPAR CMWIPAddress/Queries the IP address of the R&S CMW.
ViStatus _VI_FUNC rscmwwls_QueryDUTUECMWIPAddress(ViSession instrSession,
                                                  ViInt32   instance,
                                                  ViInt32   IPVersion,
                                                  ViInt32   bufferSize,
                                                  ViChar    CMWIPAddress[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViInt32  station = 1;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_DUT_SELECTED_STATION, &station));

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,s%ld", instance, station);

    switch (IPVersion)
    {
    case RSCMWWLS_VAL_IPV4:
        viCheckParm(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_DUT_CMW_IP4_ADDRESS,
                bufferSize, CMWIPAddress),
                5, "CMW IP Address");
        break;
    case RSCMWWLS_VAL_IPV6:
        viCheckParm(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_DUT_CMW_IP6_ADDRESS,
                bufferSize, CMWIPAddress),
                5, "CMW IP Address");
        break;
    }

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries actual information related to uplink power headroom (UPH) control.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR burstPower/Indication of HE TB burst power.
/// HIPAR UPH/Indication of UL power headroom.
/// HIPAR minTXPowerFlag/Indication whether the HE TB bursts are sent at the minimum
/// HIPAR minTXPowerFlag/transmit power of the station.
ViStatus _VI_FUNC rscmwwls_QueryHETBUPHInfo(ViSession  instrSession,
                                            ViInt32    instance,
                                            ViReal64*  burstPower,
                                            ViInt32*   UPH,
                                            ViBoolean* minTXPowerFlag)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   response[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViInt32  station;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_HE_TB_SELECTED_STATION, &station));
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,s%ld", instance, station);

    checkErr(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_HE_TB_UPH_INFO,
        RS_MAX_MESSAGE_BUF_SIZE, response));

    p2buf = strtok(response, ",");
    *burstPower = RsCore_Convert_String_To_ViReal64(p2buf);

    p2buf = strtok(NULL, ",");
    *UPH = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok(NULL, ",");
    *minTXPowerFlag = RsCore_Convert_String_To_Boolean(p2buf);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries actual information related to uplink power headroom (UPH) control.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR deviceClass/Returns the device class.
/// HIPAR dynamicFragmentation/Returns the dynamic fragmentation not supported, or dynamic
/// HIPAR dynamicFragmentation/fragmentation supported with level 1 to 3.
/// HIPAR ABSR/Indicates support of a buffer status report (BSR) control field.
/// HIPAR broadcastTWT/Indicates support of broadcast target wake time (TWT) operation.
/// HIPAR OFDMARandomAccess/Indicates support of OFDMA random access procedure.
ViStatus _VI_FUNC rscmwwls_QueryHETBUECapability(ViSession instrSession,
                                                 ViInt32   instance,
                                                 ViInt32*  deviceClass,
                                                 ViInt32*  dynamicFragmentation,
                                                 ViInt32*  ABSR,
                                                 ViInt32*  broadcastTWT,
                                                 ViInt32*  OFDMARandomAccess)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   response[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;
    ViInt32  station;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_GetAttributeViInt32(instrSession, "", RSCMWWLS_ATTR_HE_TB_SELECTED_STATION, &station));
    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,s%ld", instance, station);

    checkErr(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_HE_TB_UE_CAPABILITY,
        RS_MAX_MESSAGE_BUF_SIZE, response));

    p2buf = strtok(response, ",");
    *deviceClass = RsCore_FindStringIndex(deviceClassArr, p2buf);

    p2buf = strtok(NULL, ",\n");
    *dynamicFragmentation = RsCore_FindStringIndex(dynamicFragmentationArr, p2buf);

    p2buf = strtok(NULL, ",\n");
    *ABSR = RsCore_FindStringIndex(noYesArr, p2buf);

    p2buf = strtok(NULL, ",\n");
    *broadcastTWT = RsCore_FindStringIndex(noYesArr, p2buf);

    p2buf = strtok(NULL, "\n");
    *OFDMARandomAccess = RsCore_FindStringIndex(noYesArr, p2buf);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the event log for events fo the selected category
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR bufferSize/Sets the buffer size.
/// HIPAR entries/Displays description.
ViStatus _VI_FUNC rscmwwls_QueryEventLog(ViSession instrSession,
                                         ViInt32   instance,
                                         ViInt32   bufferSize,
                                         ViChar    entries[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 16),
            2, "Instance");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "SENS:WLAN:SIGN%ld:ELOG:ALL?", instance);
    checkErr(RsCore_QueryViStringUnknownLengthToUserBuffer(instrSession, cmd, bufferSize, entries, NULL));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function configures the IPv4 connection to an R&S CMWmars
/// HIFN  instance and to enable the message replication.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR addWLANSignalingtologging/Enables or disables message monitoring for the WLAN signaling
/// HIPAR addWLANSignalingtologging/application.
/// HIPAR loggingPCIPv4Address/Selects the IP address to which signaling messages are sent for
/// HIPAR loggingPCIPv4Address/message monitoring. The address pool is configured globally via
/// HIPAR loggingPCIPv4Address/CONFigure:BASE:MMONitor:IPADdress<n>.
ViStatus _VI_FUNC rscmwwls_ConfigureMessageMonitoring(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViBoolean addWLANSignalingtologging,
                                                      ViInt32   loggingPCIPv4Address)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_MESSAGE_MONITORING_ADD_WLAN_SIGNALING_TO_LOGGING, addWLANSignalingtologging),
            3, "ADD WLAN Signaling To Logging");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_MESSAGE_MONITORING_LOGGING_PC_IPV4_ADDRESS, loggingPCIPv4Address),
            4, "Logging PC IPv4 Address");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function returns both the current index and the resulting IP
/// HIFN  address to which signaling messages are sent for message monitoring.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR addressPoolIndex/Returns the current address pool index.
/// HIPAR ipAddress/Returns the used IP address.
/// HIPAR bufferSize/Sets the buffer size for the IP Address control.
ViStatus _VI_FUNC rscmwwls_QueryMessageMonitoringLoggingPCIPv4Address(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32*  addressPoolIndex,
                            ViInt32   bufferSize,
                            ViChar    ipAddress[])
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  ext_buf = NULL;
    ViChar*  ptoken;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:MMON:IPAD?", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwls_CheckStatus(instrSession));

    ptoken = strtok(ext_buf, ",");
    if (ptoken != NULL)
    {
        checkErr(rscmwwls_GetIndexOfToken(ptoken, addressPoolIndexArr, addressPoolIndex));
    }
    ptoken = strtok(NULL, ",");
    if (ptoken != NULL)
    {
        memset(ipAddress, 0, bufferSize);
        strncpy(ipAddress, ptoken, bufferSize - 1);
    }

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the total trigger frames received and the number of trigger frames directed to the station, i.e. R&S CMW.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR totalTriggerFrames/Queries the total trigger frames.
/// HIPAR stationTriggerFrames/Queries the number of trigger frames directed to the station, i.e. R&S CMW.
ViStatus _VI_FUNC rscmwwls_QueryRXTriggerFrames(ViSession instrSession,
                                                ViInt32   instance,
                                                ViInt32*  totalTriggerFrames,
                                                ViInt32*  stationTriggerFrames)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   response[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_QUERY_RX_TRIGGER_FRAMES,
        RS_MAX_MESSAGE_BUF_SIZE, response));

    p2buf = strtok(response, ",");
    *totalTriggerFrames = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok(NULL, ",");
    *stationTriggerFrames = RsCore_Convert_String_To_ViInt32(p2buf);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Clears entries in all statistic tables concerning user data traffic.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
ViStatus _VI_FUNC rscmwwls_ResetStatistics(ViSession instrSession,
                                           ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_RESET_STATISTICS, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets reporting interval and time span used for enhanced statistics of user data traffic.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR reportingInterval/Sets reporting interval used for enhanced statistics of user data traffic.
/// HIPAR timeSpan/Sets time span used for enhanced statistics of user data traffic.
ViStatus _VI_FUNC rscmwwls_ConfigureStatisticsSettings(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViReal64  reportingInterval,
                                                       ViInt32   timeSpan)
{
    ViStatus error = VI_SUCCESS;
    ViChar   params[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(RsCore_InvalidViReal64Range(instrSession, reportingInterval, 0.2, 5), 3, "Reporting Interval");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, timeSpan, 1, 1500),
            4, "Time Span");

    snprintf(params, RS_MAX_MESSAGE_BUF_SIZE, "%.12lG,%ld", reportingInterval, timeSpan);

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_STATISTICS_SETTINGS, params));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries statistics on RX traffic data for the following IEEE 802.11 frame formats:
/// HIFN  very high throughput format (VHT)
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwgs_init or
/// HIPAR instrSession/rscmwgs_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR frameFormat/Selects the frame format.
/// HIPAR dataRate/Returns the data frame.
/// HIPAR bandwidth/Returns the channel bandwidth.
/// HIPAR numberOfSpatialStreams/Returns the number of spatial streams.
/// HIPAR framesCurrent/Returns the number of recieved frames: current number.
/// HIPAR framesTotal/Returns the number of recieved frames: expectetd total number of frames
/// HIPAR bytesCurrent/Returns the volume of recieved user data: current number of bytes
/// HIPAR bytesTotal/Returns the volume of recieved user data: expectetd total number of bytes.
/// HIPAR mbpsCurrent/Returns the data rate: current value
/// HIPAR mbpsTotal/Returns the data rate: average (total) value over the time span
/// HIPAR powerCurrent/Returns the RX power: current value
/// HIPAR powerTotal/Returns the RX power: average (total) value over the time span
ViStatus _VI_FUNC rscmwwls_QueryStatisticsRXTrafficData(ViSession instrSession,
                                                        ViInt32   instance,
                                                        ViInt32   frameFormat,
                                                        ViInt32*  dataRate,
                                                        ViInt32*  bandwidth,
                                                        ViInt32*  numberOfSpatialStreams,
                                                        ViInt32*  framesCurrent,
                                                        ViInt32*  framesTotal,
                                                        ViReal64* bytesCurrent,
                                                        ViReal64* bytesTotal,
                                                        ViReal64* mbpsCurrent,
                                                        ViReal64* mbpsTotal,
                                                        ViReal64* powerCurrent,
                                                        ViReal64* powerTotal)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
    ViChar   response[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    switch (frameFormat)
    {
    case RSCMWWLS_VAL_STAT_FRAME_FORMAT_HEMU:
        checkErr(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_STATISTICS_RX_PSDU_HEMU,
            RS_MAX_MESSAGE_BUF_SIZE, response));
        break;
    case RSCMWWLS_VAL_STAT_FRAME_FORMAT_HESU:
        checkErr(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_STATISTICS_RX_PSDU_HESU,
            RS_MAX_MESSAGE_BUF_SIZE, response));
        break;
    case RSCMWWLS_VAL_STAT_FRAME_FORMAT_HETB:
        checkErr(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_STATISTICS_RX_PSDU_HETB,
            RS_MAX_MESSAGE_BUF_SIZE, response));
        break;
    case RSCMWWLS_VAL_STAT_FRAME_FORMAT_HT:
        checkErr(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_STATISTICS_RX_PSDU_HT,
            RS_MAX_MESSAGE_BUF_SIZE, response));
        break;
    case RSCMWWLS_VAL_STAT_FRAME_FORMAT_NHT:
        checkErr(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_STATISTICS_RX_PSDU_NHT,
            RS_MAX_MESSAGE_BUF_SIZE, response));
        break;
    case RSCMWWLS_VAL_STAT_FRAME_FORMAT_VHT:
        checkErr(rscmwwls_GetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_STATISTICS_RX_PSDU_VHT,
            RS_MAX_MESSAGE_BUF_SIZE, response));
        break;
    }

    p2buf = strtok(response, ",");
    *dataRate = RsCore_FindStringIndex(dataRateArr, p2buf);

    p2buf = strtok(NULL, ",");
    *bandwidth = RsCore_FindStringIndex(channelBandwidthArr, p2buf);

    p2buf = strtok(NULL, ",");
    *numberOfSpatialStreams = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok(NULL, ",");
    *framesCurrent = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok(NULL, ",");
    *framesTotal = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok(NULL, ",");
    *bytesCurrent = RsCore_Convert_String_To_ViReal64(p2buf);

    p2buf = strtok(NULL, ",");
    *bytesTotal = RsCore_Convert_String_To_ViReal64(p2buf);

    p2buf = strtok(NULL, ",");
    *mbpsCurrent = RsCore_Convert_String_To_ViReal64(p2buf);

    p2buf = strtok(NULL, ",");
    *mbpsTotal = RsCore_Convert_String_To_ViReal64(p2buf);

    p2buf = strtok(NULL, ",");
    *powerCurrent = RsCore_Convert_String_To_ViReal64(p2buf);

    p2buf = strtok(NULL, ",");
    *powerTotal = RsCore_Convert_String_To_ViReal64(p2buf);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure PER Acknowledgement Type
 * Purpose:  Sets the acknowledgement type that is used for PER evaluation.
             Currently only the standard frame ACKnowledgement is available.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigurePERAcknowledgementType(ViSession instrSession,
                                                           ViInt32   instance,
                                                           ViInt32   ackType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_PER_ACKNOWLEDGEMENT_TYPE, ackType),
            3, "ack Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure PER Data Pattern
 * Purpose:  Selects the data that the R&S CMW transfers to the DUT in order
             to evaluate the Packet Error Rate (PER).
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigurePERDataPattern(ViSession instrSession,
                                                   ViInt32   instance,
                                                   ViInt32   dataPattern)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_PER_DATA_PATTERN, dataPattern),
            3, "Data Pattern");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Configure PER Packet Settings
 * Purpose:  This function sets the data packets parameters.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ConfigurePERPacketSettings(ViSession instrSession,
                                                      ViInt32   instance,
                                                      ViInt32   numberOfPackets,
                                                      ViInt32   dataInterval,
                                                      ViInt32   payloadSize,
                                                      ViReal64  PERLimit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";
             PERLimit;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_PER_NUMBER_OF_PACKETS, numberOfPackets),
            3, "Number Of Packets");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_PER_DATA_INTERVAL, dataInterval),
            4, "Data Interval");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_PER_PAYLOAD_SIZE, payloadSize),
            5, "Payload Size");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the downlink data frames, especially the coding rate.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwls_init or
/// HIPAR instrSession/rscmwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR frameFormat/Selects the frame format
/// HIPAR channelBandwidth/Selects the channel bandwidth. The value must not exceed the operating
/// HIPAR channelBandwidth/channel bandwidth.
/// HIPAR modulationCodingRate/Defines the modulation coding rate.
/// HIPAR guardInterval/Long or short guard interval, only relevant for DSSS.
ViStatus _VI_FUNC rscmwwls_ConfigurePERTrafficBurst(ViSession instrSession,
                                                    ViInt32   instance,
                                                    ViInt32   frameFormat,
                                                    ViInt32   channelBandwidth,
                                                    ViInt32   modulationCodingRate,
                                                    ViInt32   guardInterval)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, frameFormat, RSCMWWLS_VAL_FRAME_FORMAT_NHT, RSCMWWLS_VAL_FRAME_FORMAT_HEM),
            3, "Frame Format");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channelBandwidth, RSCMWWLS_VAL_BANDWIDTH_20_MHZ, RSCMWWLS_VAL_BANDWIDTH_80_MHZ),
            4, "Channel Bandwidth");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, modulationCodingRate, RSCMWWLS_VAL_PER_CODE_RATE_BR12, RSCMWWLS_VAL_PER_CODE_RATE_MCS15), 5, "Modulation Coding Rate")

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, guardInterval, RSCMWWLS_VAL_GUARD_INTERVAL_SHORT, RSCMWWLS_VAL_GUARD_INTERVAL_LONG), 6, "Guard Interval")

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:PER:FDEF %s,%s,%s,%s", instance,
             frameFormatArr[frameFormat],
             channelBandwidthArr[channelBandwidth],
             modulationCodingRateArr[modulationCodingRate],
             guardIntervalArr[guardInterval]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Configures the downlink data frames, especially the coding rate.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR frameFormat/Selects the frame format
/// HIPAR channelBandwidth/Selects the channel bandwidth. The value must not exceed the operating
/// HIPAR channelBandwidth/channel bandwidth.
/// HIPAR modulationCodingRate/Defines the modulation coding rate.
/// HIPAR guardInterval/Long or short guard interval, only relevant for DSSS.
/// HIPAR ltfType/Long or short guard interval.
/// HIPAR peDuration/Additional receive processing time of x s signaled in packet
/// HIPAR peDuration/extension (PE) field (only for IEEE 802.11ax).
/// HIPAR codingType/Selects the coding type.
ViStatus _VI_FUNC rscmwwls_ConfigurePERTrafficBurstExtended(ViSession instrSession,
                                                            ViInt32   instance,
                                                            ViInt32   frameFormat,
                                                            ViInt32   channelBandwidth,
                                                            ViInt32   modulationCodingRate,
                                                            ViInt32   guardInterval,
                                                            ViInt32   ltfType,
                                                            ViInt32   peDuration,
                                                            ViInt32   codingType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, frameFormat, RSCMWWLS_VAL_FRAME_FORMAT_NHT, RSCMWWLS_VAL_FRAME_FORMAT_HEM),
            3, "Frame Format");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channelBandwidth, RSCMWWLS_VAL_BANDWIDTH_20_MHZ, RSCMWWLS_VAL_BANDWIDTH_160_MHZ),
            4, "Channel Bandwidth");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, modulationCodingRate, RSCMWWLS_VAL_PER_CODE_RATE_BR12, RSCMWWLS_VAL_PER_CODE_RATE_MCS15), 5, "Modulation Coding Rate")
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, guardInterval, RSCMWWLS_VAL_GUARD_INTERVAL_SHORT, RSCMWWLS_VAL_GUARD_INTERVAL_GI32), 6, "Guard Interval")
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, ltfType, RSCMWWLS_VAL_LTF_X1, RSCMWWLS_VAL_LTF_X4),
            7, "LFT Type");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, peDuration, RSCMWWLS_VAL_PE_DURATION_AUTO, RSCMWWLS_VAL_PE_DURATION_PE16),
            8, "PE Duration");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, codingType, RSCMWWLS_CODING_TYPE_LDPC, RSCMWWLS_CODING_TYPE_BCC),
            9, "Coding Type");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:PER:FDEF %s,%s,%s,%s,%s,%s,%s", instance,
             frameFormatArr[frameFormat],
             channelBandwidthArr[channelBandwidth],
             modulationCodingRateArr[modulationCodingRate],
             guardIntervalArr[guardInterval],
             ltfTypeArr[ltfType],
             peDurationArr[peDuration],
             codingTypeArr[codingType]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Specify the station for which the traffic is measured. This parameter
/// HIFN  is visible, if Multi STA is enabled.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR destinationStation/
ViStatus _VI_FUNC rscmwwls_ConfigurePERDestinationStation(ViSession instrSession,
                                                          ViInt32   instance,
                                                          ViInt32   destinationStation)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_PER_DESTINATION_STATION, destinationStation),
            3, "Destination Station");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  If enabled, the PER measurements use identical settings as configured
/// HIFN  in the signaling application.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR linkToSIGFrame/If enabled, the PER measurements use identical settings as configured
/// HIPAR linkToSIGFrame/in the signaling application.
/// HIPAR instance/No. of generator firmware application.
ViStatus _VI_FUNC rscmwwls_ConfigurePERLinkToSIGFrameSettings(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViBoolean linkToSIGFrame)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViBoolean(instrSession, repCap, RSCMWWLS_ATTR_PER_LINK_TO_SIG_FRAME_SETTINGS, linkToSIGFrame),
            3, "Link To SIG Frame");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Sets 8-bit indices for resource unit (RU) allocation for the selected
/// HIFN  channel. The <Subfield> parameter specifies the number of RUs, their
/// HIFN  position and size.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR channel/Channel number.
/// HIPAR subfield/Specifies the number of RUs, their position and size.
ViStatus _VI_FUNC rscmwwls_ConfigurePERDataHEMUFrameRUAllocationSubfield(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channel,
                            ViInt32   subfield)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, 4),
            3, "Channel");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, subfield, RSCMWWLS_VAL_SUBFIELD_A000, RSCMWWLS_VAL_SUBFIELD_A224),
            4, "Subfield");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:PER:DFR:HEMU:ALSF CHA%ld,%s", instance,
             channel, subfieldArr[subfield]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures allocations for specified channel and resource unit (RU).
/// HIFN  Maps a user to the RU, sets the size of allocation.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR channel/Channel number.
/// HIPAR resourceUnit/Resource unit selection.
/// HIPAR userMapping/User mapping for to the corresponding RU.
ViStatus _VI_FUNC rscmwwls_ConfigurePERDataHEMUFrameRUAllocation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   channel,
                            ViInt32   resourceUnit,
                            ViInt32   userMapping)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, 4),
            3, "Channel");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, resourceUnit, RSCMWWLS_VAL_RU1, RSCMWWLS_VAL_RU9),
            4, "Resource unit");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, userMapping, RSCMWWLS_VAL_USER_MAPPING_OFF, RSCMWWLS_VAL_USER_MAPPING_DMY3),
            4, "User Mapping");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:PER:DFR:HEMU:RUAL CHA%ld,RU%ld,%s", instance,
             channel, resourceUnit, userMappingArr[userMapping]);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Queries the allocation state and size of an entire 20MHz block for the
/// HIFN  specified channel.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR channel/Channel number.
/// HIPAR arraySize/Size allocated for output arrays.
/// HIPAR userMapping/User mapping for to the corresponding RU. Array of 9 values, <RU1> to
/// HIPAR userMapping/<RU9>.
/// HIPAR size/RU size. Array of 9 values, <Size1> to <Size9>.
/// HIPAR returnedValues/Number of values returned from instrument.
ViStatus _VI_FUNC rscmwwls_QueryPERDataHEMUFrameRUAllocation(ViSession instrSession,
                                                             ViInt32   instance,
                                                             ViInt32   channel,
                                                             ViInt32   arraySize,
                                                             ViInt32   userMapping[],
                                                             ViInt32   size[],
                                                             ViInt32*  returnedValues)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, 4),
            3, "Channel");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:PER:DFR:HEMU:BLAL? CHA%ld", instance, channel);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwls_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");

    while (ext_buf != NULL && i < arraySize)
    {
        userMapping[i] = RsCore_FindStringIndex(userMappingArr, p2buf);
        p2buf = strtok(NULL, ",");
        size[i++] = RsCore_FindStringIndex(sizeArr, p2buf);
        p2buf = strtok(NULL, ",");
    }

    *returnedValues = i;

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures user data assigned to the DUT.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR user/User nr.
/// HIPAR mcs/Sets the modulation and coding scheme for user 1 (user data assigned
/// HIPAR mcs/to the DUT).
/// HIPAR codingType/Selects the coding type related to a user for HE MU PPDU.
ViStatus _VI_FUNC rscmwwls_ConfigurePERDataHEMUFrameUser(ViSession instrSession,
                                                         ViInt32   instance,
                                                         ViInt32   user,
                                                         ViInt32   mcs,
                                                         ViInt32   codingType)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, user, 1, 1),
            3, "User");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,user%ld", instance, user);

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_PER_DATA_HEMU_FRAME_USER_MCS, mcs),
            4, "MCS");

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_PER_DATA_HEMU_FRAME_USER_CODING_TYPE, codingType),
            5, "Coding Type");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/// HIFN  Configures allocations for the user in HE MU PPDU. Maps the user to a
/// HIFN  resource unit (RU).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR user/User nr.
/// HIPAR channel/Channel number.
/// HIPAR resourceUnit/Resource unit selection.
ViStatus _VI_FUNC rscmwwls_ConfigurePERDataHEMUFrameUserAllocation(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   user,
                            ViInt32   channel,
                            ViInt32   resourceUnit)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, user, 1, 1),
            3, "User");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, channel, 1, 4),
            4, "Channel");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, resourceUnit, RSCMWWLS_VAL_RU1, RSCMWWLS_VAL_RU9),
            5, "Resource unit");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "CONF:WLAN:SIGN%ld:PER:DFR:HEMU:USER%ld:ALL CHA%ld,RU%ld", instance,
             user, channel, resourceUnit);
    checkErr(RsCore_Write(instrSession, cmd));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the number of streams for PER measurements used by the user for
/// HIFN  MIMO connections.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mcs/Sets the modulation and coding scheme for user 1 (user data assigned
/// HIPAR mcs/to the DUT).
/// HIPAR instance/No. of generator firmware application.
/// HIPAR user/Dummy user nr.
/// HIPAR streams/Sets the number of streams for PER measurements used by the user for
/// HIPAR streams/MIMO connections.
ViStatus _VI_FUNC rscmwwls_ConfigurePERDataHEMUFrameUserStreams(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   user,
                            ViInt32   streams)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, user, 1, 3),
            3, "User");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,user%ld", instance, user);

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_PER_DATA_HEMU_FRAME_USER_STREAMS, streams),
            4, "Streams");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Sets the modulation and coding scheme for the corresponding dummy
/// HIFN  user.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR mcs/Sets the modulation and coding scheme for user 1 (user data assigned
/// HIPAR mcs/to the DUT).
/// HIPAR instance/No. of generator firmware application.
/// HIPAR user/Dummy user nr.
ViStatus _VI_FUNC rscmwwls_ConfigurePERDataHEMUFrameDummyUserMCS(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   user,
                            ViInt32   mcs)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");
    viCheckParm(RsCore_InvalidViInt32Range(instrSession, user, 1, 3),
            3, "User");

    snprintf(repCap, RS_REPCAP_BUF_SIZE, "i%ld,user%ld", instance, user);

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_DATA_HEMU_FRAME_DUMMY_USER_MCS, mcs),
            4, "MCS");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: PER Measurement Init
 * Purpose:  Starts or restarts the measurement. the R&S CMW enters the "RUN"
             state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_PERMeasurementInit(ViSession instrSession,
                                              ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_PER_MEASUREMENT_INITIATE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: PER Measurement Abort
 * Purpose:  This function causes a running measurement to stop immediately;
             the R&S CMW enters the "OFF" state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_PERMeasurementAbort(ViSession instrSession,
                                               ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_PER_MEASUREMENT_ABORT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: PER Measurement Stop
 * Purpose:  This function causes a running measurement to stop after the
             current evaluation period is terminated and valid results are
             available; the R&S CMW enters the "RDY" state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_PERMeasurementStop(ViSession instrSession,
                                              ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_PER_MEASUREMENT_STOP, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query PER Measurement Status
 * Purpose:  Queries the main measurement state and the measurement
             substates. Both measurement substates are relevant for running
             measurements only.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_QueryPERMeasurementStatus(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32*  mainState,
                                                     ViInt32*  syncState,
                                                     ViInt32*  resourcesState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:SIGN%ld:PER:STAT:ALL?", instance);
    checkErr(rscmwwls_QueryMeasStatus(instrSession, cmd, mainState, syncState, resourcesState));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Read PER Results
 * Purpose:  Starts a new single shot measurement PER and returns current
             single value results.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ReadPERResults(ViSession instrSession,
                                          ViInt32   instance,
                                          ViInt32*  reliability,
                                          ViReal64* PER,
                                          ViInt32*  packets,
                                          ViInt32*  packetsLost,
                                          ViReal64* RXBurstPower)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "READ:WLAN:SIGN%ld:PER?", instance);
    checkErr(RsCore_QueryViStringUnknownLengthWithOpc(instrSession, cmd, 15000, &ext_buf));
    checkErr(rscmwwls_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLS_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");

    *PER = RsCore_Convert_String_To_ViReal64(p2buf);

    p2buf = strtok(NULL, ",\n");

    *packets = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok(NULL, ",\n");

    *packetsLost = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok(NULL, ",\n");

    *RXBurstPower = RsCore_Convert_String_To_ViReal64(p2buf);

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Fetch PER Results
 * Purpose:  Returns current single value results for PER.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_FetchPERResults(ViSession instrSession,
                                           ViInt32   instance,
                                           ViInt32*  reliability,
                                           ViReal64* PER,
                                           ViInt32*  packets,
                                           ViInt32*  packetsLost,
                                           ViReal64* RXBurstPower)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:SIGN%ld:PER?", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwls_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");
    if (p2buf == NULL)
        checkErr(RSCMWWLS_ERROR_INCORRECT_RESPONSE);
    if (reliability != NULL)
        *reliability = atol(p2buf);

    p2buf = strtok(NULL, ",\n");

    *PER = RsCore_Convert_String_To_ViReal64(p2buf);

    p2buf = strtok(NULL, ",\n");

    *packets = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok(NULL, ",\n");

    *packetsLost = RsCore_Convert_String_To_ViInt32(p2buf);

    p2buf = strtok(NULL, ",\n");

    *RXBurstPower = RsCore_Convert_String_To_ViReal64(p2buf);

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Returns the modulation and coding rate/scheme of the last
/// HIFN received ACK frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscma_init or
/// HIPAR instrSession/rscma_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR reliability/Integer value of the reliability indicator for the entire
/// HIPAR reliability/measurement result; see Reliability Indicator.
/// HIPAR lastACKRate/Returns the modulation and coding rate/scheme of the last
/// HIPAR lastACKRate/received ACK frame.
ViStatus _VI_FUNC rscmwwls_QueryPERLastACKRate(ViSession instrSession,
                                               ViInt32   instance,
                                               ViInt32*  reliability,
                                               ViInt32*  lastACKRate)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  rel;
    ViInt32  val;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:SIGN%ld:PACK?", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwls_CheckStatus(instrSession));
    p2buf = strtok(",", ext_buf);
    if (p2buf == NULL)
    {
        rel = -1;
        checkErr(VI_ERROR_INV_RESPONSE)
    }
    else
    {
        rel = RsCore_Convert_String_To_ViInt32(p2buf);
    }

    p2buf = strtok(",\r\n", NULL);
    if (rel == 0)
    {
        checkErr(RsCore_FindRangeTableDiscreteNumericValue(instrSession, &rscmwwls_rngPERModulationCodingRate, p2buf, &val));
    }
    else
    {
        val = -1;
    }

    if (reliability) *reliability = rel;
    if (lastACKRate) *lastACKRate = val;

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Sets the number of frames for HE TB list mode measurements. This setting
/// HIFN determines the statistic count of the measurement.
/// HIFN received ACK frame.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscma_init or
/// HIPAR instrSession/rscma_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR HETBNumberOfFrames/Sets the number of frames for HE TB list mode measurements.
/// HIPAR HETBNumberOfFrames/This setting determines the statistic count of the measurement.
ViStatus _VI_FUNC rscmwwls_ConfigureHETBNumberOfFrames(ViSession instrSession,
                                                       ViInt32   instance,
                                                       ViInt32   HETBNumberOfFrames)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_SetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_HETB_NUMBER_OF_FRAMES, HETBNumberOfFrames),
            3, "HETB Number Of Frames");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: HE TB Measurement Initiate
 * Purpose:  Starts or restarts the measurement. the R&S CMW enters
             the RUN state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_HETBMeasurementInitiate(ViSession instrSession,
                                                   ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_HETB_MEASUREMENT_INITIATE, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: HE TB Measurement Abort
 * Purpose:  This function causes a running measurement to stop immediately;
             the R&S CMW enters the OFF state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_HETBMeasurementAbort(ViSession instrSession,
                                                ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_HETB_MEASUREMENT_ABORT, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: HE TB Measurement Stop
 * Purpose:  This attribute causes a running measurement to stop after
             the current evaluation period is terminated and valid results
             are available; the R&S CMW enters the RDY state.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_HETBMeasurementStop(ViSession instrSession,
                                               ViInt32   instance)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    checkErr(rscmwwls_SetAttributeViString(instrSession, repCap, RSCMWWLS_ATTR_HETB_MEASUREMENT_STOP, NULL));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the main measurement state.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscma_init or
/// HIPAR instrSession/rscma_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
ViStatus _VI_FUNC rscmwwls_QueryHETBMeasurementState(ViSession instrSession,
                                                     ViInt32   instance,
                                                     ViInt32*  measurementState)
{
    ViStatus error = VI_SUCCESS;
    ViChar   repCap[RS_REPCAP_BUF_SIZE] = "";

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_instanceRepCap(instrSession, instance, repCap));

    viCheckParm(rscmwwls_GetAttributeViInt32(instrSession, repCap, RSCMWWLS_ATTR_HETB_MEASUREMENT_STATE, measurementState),
            3, "Measurement State");

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Queries the results of the signaling HE TB list mode measurements on
/// HIFN  UL power headroom (UPH).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscma_init or
/// HIPAR instrSession/rscma_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR instance/No. of generator firmware application.
/// HIPAR arraySize/Pass the number of results.
/// HIPAR burstPower/Array of the measured burst power in uplink
/// HIPAR UPH/Array of the UL power headroom.
/// HIPAR minTXPowerFlag/Array of the booleans where indication whether the HE TB bursts
/// HIPAR minTXPowerFlag/are sent at the minimum transmit power of the station.
/// HIPAR LST/Array of the Rx timestamp from physical layer.
/// HIPAR numberOfResults/Indicates the number of results the function places in each of
/// HIPAR numberOfResults/I and Q parameters.
ViStatus _VI_FUNC rscmwwls_QueryHETBMeasurementULPowerHeadroom(
                            ViSession instrSession,
                            ViInt32   instance,
                            ViInt32   arraySize,
                            ViReal64  burstPower[],
                            ViInt32   UPH[],
                            ViBoolean minTXPowerFlag[],
                            ViReal64  LST[],
                            ViInt32*  numberOfResults)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE] = "";
    ViChar*  ext_buf = NULL;
    ViChar*  p2buf;
    ViInt32  i = 0;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, instance, 1, 32),
            2, "Instance");

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "FETC:WLAN:SIGN%ld:HETB:UPH?", instance);
    checkErr(RsCore_QueryViStringUnknownLength(instrSession, cmd, &ext_buf));
    checkErr(rscmwwls_CheckStatus(instrSession));

    p2buf = strtok(ext_buf, ",");

    while (ext_buf != NULL && i < arraySize)
    {
        burstPower[i] = RsCore_Convert_String_To_ViReal64(p2buf);
        p2buf = strtok(NULL, ",");
        UPH[i] = RsCore_Convert_String_To_ViInt32(p2buf);
        p2buf = strtok(NULL, ",");
        minTXPowerFlag[i] = RsCore_Convert_String_To_Boolean(p2buf);
        p2buf = strtok(NULL, ",");
        LST[i++] = RsCore_Convert_String_To_ViReal64(p2buf);
        p2buf = strtok(NULL, ",");
    }

    *numberOfResults = i;

Error:
    if (ext_buf) free(ext_buf);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/* ViInt32 */
ViStatus _VI_FUNC rscmwwls_SetAttributeViInt32(ViSession instrSession,
                                               ViString  repeatedCapabilityName,
                                               ViAttr    attributeId,
                                               ViInt32   attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViInt32(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/* ViReal64 */
ViStatus _VI_FUNC rscmwwls_SetAttributeViReal64(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViReal64  attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViReal64(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/* ViString */
ViStatus _VI_FUNC rscmwwls_SetAttributeViString(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViString  attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViStringOrRawString(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/* ViBoolean */
ViStatus _VI_FUNC rscmwwls_SetAttributeViBoolean(ViSession instrSession,
                                                 ViString  repeatedCapabilityName,
                                                 ViAttr    attributeId,
                                                 ViBoolean attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_SetAttributeViBoolean(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: rscmwwls_GetAttribute<type> Functions
 * Purpose:  These functions enable the instrument driver user to get
 *           attribute values directly.  There are typesafe versions for
 *           ViInt32, ViReal64, ViString, ViBoolean, and ViSession attributes.
 *****************************************************************************/

/* ViInt32 */
ViStatus _VI_FUNC rscmwwls_GetAttributeViInt32(ViSession instrSession,
                                               ViString  repeatedCapabilityName,
                                               ViAttr    attributeId,
                                               ViInt32*  attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);
    error = RsCore_GetAttributeViInt32(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/* ViReal64 */
ViStatus _VI_FUNC rscmwwls_GetAttributeViReal64(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViReal64* attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViReal64(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/* ViString */
ViStatus _VI_FUNC rscmwwls_GetAttributeViString(ViSession instrSession,
                                                ViString  repeatedCapabilityName,
                                                ViAttr    attributeId,
                                                ViInt32   bufferSize,
                                                ViChar    attributeValue[])
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViStringOrRawString(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, bufferSize,
        attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/* ViBoolean */
ViStatus _VI_FUNC rscmwwls_GetAttributeViBoolean(ViSession  instrSession,
                                                 ViString   repeatedCapabilityName,
                                                 ViAttr     attributeId,
                                                 ViBoolean* attributeValue)
{
    ViStatus error = VI_SUCCESS;

    (void)RsCore_LockSession(instrSession);

    error = RsCore_GetAttributeViBoolean(instrSession, repeatedCapabilityName, attributeId, RS_VAL_DIRECT_USER_CALL, attributeValue);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN Function used by Hi-level functions to obtain a repCap name from:
/// HIFN - attributeID
/// HIFN - repCapNameID
/// HIFN - 0-based index in the repCapNames
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwwls_init or
/// HIPAR instrSession/rscmwwls_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR attributeId/Pass the ID of an attribute.
/// HIPAR repCapNameId/RepCap Name ID.
/// HIPAR index/Zero based index in the repCapNames.
/// HIPAR bufferSize/Pass the number of bytes in the string you allocate for the repCapName.
/// HIPAR repCapName/String returning RepCap name
ViStatus _VI_FUNC rscmwwls_GetAttributeRepCapName(ViSession instrSession,
                                                  ViAttr    attributeId,
                                                  ViString  repCapNameId,
                                                  ViInt32   index,
                                                  ViInt32   bufferSize,
                                                  ViChar    repCapName[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetAttributeRepCapName(instrSession, attributeId, repCapNameId, index, bufferSize, repCapName));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Rs_GetAttributeRepCapNameId
 * Purpose:  This function returns the repeated capability id(s) that
 *           belongs to the attribute you specify. More then one id is listed
 *           in comma separated string.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_GetAttributeRepeatedCapabilityIds(ViSession instrSession,
                                                             ViAttr    attributeID,
                                                             ViInt32   bufferSize,
                                                             ViChar    repeatedCapabilityIds[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, RS_MAX_SHORT_MESSAGE_BUF_SIZE),
            3, "Buffer Size");

    checkErr(RsCore_GetAttributeRepCapNameIds(instrSession, attributeID, bufferSize, repeatedCapabilityIds));

Error:
    return error;
}

/*****************************************************************************
 * Function: Get Attribute Repeated Capability Id Name(s)
 * Purpose:  This function returns the repeated capability name(s) that
 *           belongs to the attribute and single repeated capability id you
 *           may specify. More then one name is listed in comma separated
 *           string.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViAttr    attributeID,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdNames[])
{
    ViStatus error = VI_SUCCESS;

    viCheckParm(RsCore_InvalidViInt32Range(instrSession, bufferSize, 1, RS_MAX_SHORT_MESSAGE_BUF_SIZE),
            4, "Buffer Size");

    checkErr(RsCore_GetAttributeRepCapNamesAll(instrSession,
        attributeID,
        repeatedCapabilityId,
        bufferSize,
        repeatedCapabilityIdNames));

Error:
    return error;
}

/*****************************************************************************
 * Function: Reset
 * Purpose:  This function resets the instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_reset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;
    ViInt32  OPC = -1;

    checkErr(RsCore_LockSession(instrSession));

    if (RsCore_Simulating(instrSession) == VI_FALSE)
    {
        checkErr(rscmwwls_ClearStatus(instrSession));
        checkErr(RsCore_Write(instrSession, "*RST")); // IGNORE: Check double write
        checkErr(rscmwwls_QueryOPC(instrSession, &OPC));
    }

    checkErr(rscmwwls_DefaultInstrSetup(instrSession));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);

    return error;
}

/*****************************************************************************
 * Function: Self Test
 * Purpose:  This function executes the instrument self-test and returns the
 *           result.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_self_test(ViSession instrSession,
                                     ViInt16*  testResult,
                                     ViChar    testMessage[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, testResult), 2, "Null address for Test Result");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, testMessage), 3, "Null address for Test Message");

    checkErr(RsCore_SelfTest(instrSession, testResult, 48, testMessage));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Self Test Results
 * Purpose:  This function executes the instrument self-test and returns the
 *           result.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_SelfTestResults(ViSession instrSession,
                                           ViInt32   bufferSize,
                                           ViChar    results[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_QueryViStringUnknownLengthToUserBuffer(instrSession, "DIAG:SERV:STES:RES?", bufferSize, results, NULL));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Revision Query
 * Purpose:  This function returns the driver and instrument revisions.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_revision_query(ViSession instrSession,
                                          ViChar    instrumentDriverRevision[],
                                          ViChar    firmwareRevision[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, instrumentDriverRevision), 2, "Null address for Instrument Driver Revision");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, firmwareRevision), 3, "Null address for Instrument Revision");

    checkErr(RsCore_GetAttributeViString(instrSession, NULL, RS_ATTR_SPECIFIC_DRIVER_REVISION, 0, 256, instrumentDriverRevision));
    checkErr(RsCore_GetAttributeViString(instrSession, NULL, RS_ATTR_INSTRUMENT_FIRMWARE_REVISION, 0, 256, firmwareRevision));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function:    System Version
 * Purpose:     This function queries the number of the SCPI version, which
 *              is relevant for the instrument.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_SystemVersion(ViSession instrSession,
                                         ViInt32   length,
                                         ViChar    systemVersion[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(rscmwwls_GetAttributeViString(instrSession, "", RSCMWWLS_ATTR_SYSTEM_VERSION,
            length, systemVersion),
            2, "System Version");
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Error Query
 * Purpose:  This function queries the instrument error queue and returns
 *           the result.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_error_query(ViSession instrSession,
                                       ViInt32*  errorCode,
                                       ViChar    errorMessage[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorCode), 2, "Null address for Error Code");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorMessage), 3, "Null address for Error Message");

    checkErr(RsCore_ErrorQueryAll(instrSession, errorCode, 1024, errorMessage));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Error List
 * Purpose:  This function reads all system messages and returns a list of
 *           comma separated strings.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ErrorList(ViSession instrSession,
                                     ViInt32   bufferSize,
                                     ViChar    errors[])
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidViInt32RangeMin(instrSession, bufferSize, 0), 2, "Buffer Size");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errors), 3, "Null address for Errors");

    checkErr(rscmwwls_GetAttributeViString( instrSession, "", RSCMWWLS_ATTR_SYSTEM_ALL_ERRORS,
        bufferSize, errors));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Error Message
 * Purpose:  This function translates the error codes returned by this
 *           instrument driver into user-readable strings.
 *
 *           Note:  The caller can pass NULL for the vi parameter.  This
 *           is useful if one of the init functions fail.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_error_message(ViSession instrSession,
                                         ViStatus  errorCode,
                                         ViChar    errorMessage[])
{
    return rscmwwls_utility_error_message(instrSession, errorCode, errorMessage);
}

/*****************************************************************************
 * Function: Reliability Indicator
 * Purpose:  This function converts a reliability code returned by an
 *           instrument driver function into a user-readable string.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_ReliabilityIndicator(ViSession instrSession,
                                                ViInt32   reliabilityCode,
                                                ViChar    reliabilityMessage[])
{
    ViStatus  error = VI_SUCCESS;
    ViInt16   cnt = 0;
    ViBoolean found = VI_FALSE;

    static RsCoreStringValueTable reliabilityTable =
    {
        {0, "OK"},
        {1, "Measurement Timeout"},
        {2, "Capture Buffer Overflow"},
        {3, "Overdriven"},
        {4, "Underdriven"},
        {6, "Trigger Timeout"},
        {7, "Acquisition Error"},
        {8, "Sync Error"},
        {9, "Uncal"},
        {15, "Reference Frequency Error"},
        {16, "RF Not Available"},
        {17, "RF Level not Settled"},
        {18, "RF Frequency not Settled"},
        {19, "Call not Established"},
        {20, "Call Type not Usable"},
        {21, "Call Lost"},
        {23, "Missing Option"},
        {24, "Invalid RF Setting"},
        {26, "Resource Conflict"},
        {27, "No Sensor Connected"},
        {28, "Unexpected Parameter Change"},
        {30, "File not Found"},
        {31, "No DTM reply"},
        {32, "ACL Disconnected"},
        {40, "ARB File CRC Error"},
        {42, "ARB Header Tag Invalid"},
        {43, "ARB Segment Overflow"},
        {44, "ARB File not Found"},
        {45, "ARB Memory Overflow"},
        {46, "ARB Sample Rate out of Range)"},
        {47, "ARB Cycles out of Range"},
        {50, "Startup Error"},
        {51, "No Reply"},
        {52, "Connection Error"},
        {53, "Configuration Error"},
        {54, "Filesystem Error"},
        {60, "Invalid RF-Connector Setting"},
        {93, "OCXO Oven Temperature too low"},
        {101, "Firmware Error"},
        {102, "Unidentified Error"},
        {103, "Parameter Error"},
        {104, "Not Functional"},
        {0, NULL}
    };

    (void)RsCore_LockSession(instrSession);

    for (cnt = 0; reliabilityTable[cnt].string; cnt++)
    {
        if (reliabilityTable[cnt].value == reliabilityCode)
        {
            sprintf(reliabilityMessage, "%s", reliabilityTable[cnt].string);
            if (reliabilityCode)
                error = RSCMWWLS_ERROR_RELIABILITY_INDICATOR;
            found = VI_TRUE;
        }
    }

    if (!found)
    {
        sprintf(reliabilityMessage, "Unrecognized reliability indicator! Report problem to R&S support!");
        error = RS_WARN_UNKNOWN_INSTRUMENT_STATUS;
    }

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Preset
 * Purpose:  This function initiates an instrument reset.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_Preset(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_SetAttributeViString(instrSession, "", RSCMWWLS_ATTR_SYSTEM_PRESET, NULL));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function switches ON/OFF various error checkings performed inside of the driver.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR optionChecking/This control switches option checking On or Off.
/// HIPAR rangeChecking/This control enables or disables range checking.
/// HIPAR statusChecking/This control enables or disables instrument state checking
ViStatus _VI_FUNC rscmwwls_ConfigureErrorChecking(ViSession instrSession,
                                                  ViBoolean optionChecking,
                                                  ViBoolean rangeChecking,
                                                  ViBoolean statusChecking)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->optionChecking = optionChecking;
    checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_QUERY_INSTRUMENT_STATUS, 0, statusChecking));
    checkErr(RsCore_SetAttributeViBoolean(instrSession, "", RS_ATTR_RANGE_CHECK, 0, rangeChecking));

Error:
    return error;
}

/// HIFN  This function returns the ID Query response string.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscma_init or
/// HIPAR instrSession/rscma_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR bufferSize/Defines the size of ID Response Query.
/// HIPAR IDQueryResponse/Returns the ID Query response string.
/// HIPAR returnedValues/Returns length of string readed from instrument.
ViStatus _VI_FUNC rscmwwls_IDQueryResponse(ViSession instrSession,
                                           ViInt32   bufferSize,
                                           ViChar    IDQueryResponse[],
                                           ViInt32*  returnedValues)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_QueryViStringUnknownLengthToUserBuffer(instrSession, "*IDN?", bufferSize, IDQueryResponse, returnedValues));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function queries the OPC.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscma_init or
/// HIPAR instrSession/rscma_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR OPC/Queries the OPC.
ViStatus _VI_FUNC rscmwwls_QueryOPC(ViSession instrSession,
                                    ViInt32*  OPC)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_QueryViInt32(instrSession, "*OPC?", OPC));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  Stops further command processing until all commands sent before
/// HIFN  *WAI have been executed.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscma_init or
/// HIPAR instrSession/rscma_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rscmwwls_ProcessAllPreviousCommands(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(rscmwwls_WriteInstrData(instrSession, "*WAI"));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN  This function clears status.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscma_init or
/// HIPAR instrSession/rscma_InitWithOptions function.  The handle identifies a particular
/// HIPAR instrSession/instrument session.
ViStatus _VI_FUNC rscmwwls_ClearStatus(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_ClearStatus(instrSession));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/******************************************************************************************************
* Function: rscmwwls_SetOPCTimeout
* Purpose:  Sets OPC timeout
*****************************************************************************************************/
ViStatus _VI_FUNC rscmwwls_SetOPCTimeout(ViSession instrSession,
                                         ViUInt32  timeout)
{
    return RsCore_SetAttributeViInt32(instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, (ViInt32)timeout);
}

/******************************************************************************************************
* Function: rscmwwls_GetOPCTimeout
* Purpose:  Return OPC timeout
*****************************************************************************************************/
ViStatus _VI_FUNC rscmwwls_GetOPCTimeout(ViSession instrSession,
                                         ViUInt32* timeout)
{
    return RsCore_GetAttributeViInt32(instrSession, NULL, RS_ATTR_OPC_TIMEOUT, 0, (ViInt32*)timeout);
}

/// HIFN This function specifies the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsspecan_init or
/// HIPAR instrSession/rsspecan_InitWithOptions function.
/// HIPAR VISATimeout/This control sets the timeout value.
ViStatus _VI_FUNC rscmwwls_SetVISATimeout(ViSession instrSession,
                                          ViUInt32  VISATimeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_SetVisaTimeout(instrSession, VISATimeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function returns the minimum timeout value to use (in
/// HIFN milliseconds) when accessing the device associated with the
/// HIFN given session.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rsspecan_init or
/// HIPAR instrSession/rsspecan_InitWithOptions function.
/// HIPAR VISATimeout/This control gets the timeout value.
ViStatus _VI_FUNC rscmwwls_GetVISATimeout(ViSession instrSession,
                                          ViUInt32* VISATimeout)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_GetVisaTimeout(instrSession, VISATimeout));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
/// HIFN Use the function rscmwdau_GetError afterwards to get the detailed information about the instrument error(s).
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwdau_init or
/// HIPAR instrSession/rscmwdau_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR autoSystErrQuery/If TRUE (default after init is FALSE), the driver calls SYST:ERR? automatically in CheckStatus() when Instrument Status Error is detected.
ViStatus _VI_FUNC rscmwwls_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                       ViBoolean autoSystErrQuery)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->autoSystErrQuery = autoSystErrQuery;

Error:
    return error;
}

/// HIFN Session-related mutex switch.
/// HIFN If TRUE (default after init is FALSE), the driver sets a mutual-exclusion mechanism for every driver's hi-level function and attribute access.
/// HIFN Set this value to TRUE if you plan to use one session in more than one thread.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/The ViSession handle that you obtain from the rscmwlm_init or
/// HIPAR instrSession/rscmwlm_InitWithOptions function.The handle identifies a particular
/// HIPAR instrSession/instrument session.
/// HIPAR multiThreadLocking/Session-related mutex switch
ViStatus _VI_FUNC rscmwwls_ConfigureMultiThreadLocking(ViSession instrSession,
                                                       ViBoolean multiThreadLocking)
{
    ViStatus         error = VI_SUCCESS;
    RsCoreSessionPtr rsSession = NULL;

    checkErr(RsCore_GetRsSession(instrSession, &rsSession));
    rsSession->multiThreadLocking = multiThreadLocking;

Error:
    return error;
}

/*****************************************************************************
 * Function: Get Error and Clear Error Functions
 * Purpose:  These functions enable the instrument driver user to
 *           get or clear the error information the driver associates with the
 *           RS session.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_GetError(ViSession instrSession,
                                    ViStatus* errorCode,
                                    ViInt32   bufferSize,
                                    ViChar    description[])
{
    ViStatus error = VI_SUCCESS;

    // Lock Session - do not jump to the end, even with invalid instrSession the function continues further
    (void)(RsCore_LockSession(instrSession));

    // Test for nulls and acquire error data
    viCheckParm(RsCore_InvalidNullPointer(instrSession, errorCode), 2, "Null address for Error");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, description), 4, "Null address for Description");

    checkErr(RsCore_GetErrorCompleteDescription(instrSession, &rscmwwls_utility_error_message, errorCode, bufferSize, description));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

ViStatus _VI_FUNC rscmwwls_ClearError(ViSession instrSession)
{
    return RsCore_ClearErrorInfo(instrSession);
}

/// HIFN This function is used to read data from the instrument and write
/// HIFN it to a user specified file on the host computer.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from instrument
/// HIPAR source/to control computer.
/// HIPAR destination/This control defines destination file to which the data transfer
/// HIPAR destination/from instrument to control computer applies.
ViStatus _VI_FUNC rscmwwls_ReadToFileFromInstrument(ViSession instrSession,
                                                    ViString  source,
                                                    ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DATA? '%s'", source);
    checkErr(RsCore_QueryBinaryDataBlockToFile(instrSession, cmd, destination, RS_VAL_TRUNCATE));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/// HIFN This function is used to read data from the host computer and
/// HIFN write it to a user specified file in the instrument.
/// HIRET Returns the status code of this operation.
/// HIPAR instrSession/This control accepts the Instrument Handle returned by the Initialize
/// HIPAR instrSession/function to select the desired instrument driver session.
/// HIPAR source/This control selects file for the data transfer from control
/// HIPAR source/computer to instrument.
/// HIPAR destination/This control defines destination file to which the data transfer
/// HIPAR destination/from control computer to instrument applies.
ViStatus _VI_FUNC rscmwwls_WriteFromFileToInstrument(ViSession instrSession,
                                                     ViString  source,
                                                     ViString  destination)
{
    ViStatus error = VI_SUCCESS;
    ViChar   cmd[RS_MAX_MESSAGE_BUF_SIZE];

    checkErr(RsCore_LockSession(instrSession));

    snprintf(cmd, RS_MAX_MESSAGE_BUF_SIZE, "MMEM:DATA '%s',", destination);
    checkErr(RsCore_WriteBinaryDataFromFile(instrSession, cmd, source));
    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: WriteInstrData and ReadInstrData Functions
 * Purpose:  These functions enable the instrument driver user to
 *           write and read commands directly to and from the instrument.
 *****************************************************************************/

ViStatus _VI_FUNC rscmwwls_WriteInstrData(ViSession instrSession,
                                          ViString  writeBuffer)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    error = RsCore_Write(instrSession, writeBuffer);

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

ViStatus _VI_FUNC rscmwwls_ReadInstrData(ViSession instrSession,
                                         ViInt32   numberOfBytesToRead,
                                         ViChar    readBuffer[],
                                         ViUInt32* bytesRead)
{
    ViStatus error = VI_SUCCESS;
    ViChar*  responseString = NULL;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_ReadViStringUnknownLength(instrSession, &responseString));
    checkErr(RsCore_CopyToUserBufferAsciiData(readBuffer, numberOfBytesToRead, responseString));
    *bytesRead = (ViUInt32)strlen(responseString);

Error:
    if (responseString)
        free(responseString);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query ViBoolean
 * Purpose:  This function queries the ViBoolean value.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_QueryViBoolean(ViSession  instrSession,
                                          ViString   command,
                                          ViBoolean* value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViBoolean(instrSession, command, value));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query ViInt32
 * Purpose:  This function queries the ViInt32 value.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_QueryViInt32(ViSession instrSession,
                                        ViString  command,
                                        ViInt32*  value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViInt32(instrSession, command, value));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: Query ViReal64
 * Purpose:  This function queries the ViReal64 value.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_QueryViReal64(ViSession instrSession,
                                         ViString  command,
                                         ViReal64* value)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViReal64(instrSession, command, value));

    checkErr(rscmwwls_CheckStatus(instrSession));

Error:
    (void)RsCore_UnlockSession(instrSession);
    return error;
}


/*****************************************************************************
 * Function: Query ViString
 * Purpose:  This function queries the ViString value.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_QueryViString(ViSession instrSession,
                                         ViString  command,
                                         ViInt32   bufferSize,
                                         ViChar    value[])
{
    ViStatus error = VI_SUCCESS;
    ViChar*  pbuffer = NULL;

    checkErr(RsCore_LockSession(instrSession));

    viCheckParm(RsCore_InvalidStringLength(instrSession, command, 1, -1), 2, "Command (null string length)");
    viCheckParm(RsCore_InvalidNullPointer(instrSession, value), 3, "Value");

    checkErr(RsCore_QueryViStringUnknownLength(instrSession, command, &pbuffer));

    checkErr(rscmwwls_CheckStatus(instrSession));

    checkErr(RsCore_CopyToUserBufferAsciiData(value, bufferSize, pbuffer));

Error:
    if (pbuffer)
        free(pbuffer);

    (void)RsCore_UnlockSession(instrSession);
    return error;
}

/*****************************************************************************
 * Function: rscmwwls_close
 * Purpose:  This function closes the instrument.
 *
 *           Note:  This function must unlock the session before calling
 *           Rs_Dispose.
 *****************************************************************************/
ViStatus _VI_FUNC rscmwwls_close(ViSession instrSession)
{
    ViStatus error = VI_SUCCESS;

    checkErr(RsCore_LockSession(instrSession));

    checkErr(RsCore_ViClose(instrSession));

Error:
    (void)RsCore_Dispose(instrSession);
    (void)RsCore_UnlockSession(instrSession);
    return error;
}
